#line 1 "ad_aarch64.cpp"
//
// Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2014, 2021, Red Hat, Inc. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_aarch64.hpp"
#include "adfiles/ad_aarch64.hpp"
#include "memory/allocation.inline.hpp"
#include "code/codeCache.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/compressedOops.hpp"
#include "oops/markWord.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/c2_MacroAssembler.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "utilities/powerOfTwo.hpp"

//SourceForm

#line 1324 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"


  // Derived RegMask with conditionally allocatable registers

  void PhaseOutput::pd_perform_mach_node_analysis() {
  }

  int MachNode::pd_alignment_required() const {
    return 1;
  }

  int MachNode::compute_padding(int current_offset) const {
    return 0;
  }

  RegMask _ANY_REG32_mask;
  RegMask _ANY_REG_mask;
  RegMask _PTR_REG_mask;
  RegMask _NO_SPECIAL_REG32_mask;
  RegMask _NO_SPECIAL_REG_mask;
  RegMask _NO_SPECIAL_PTR_REG_mask;

  void reg_mask_init() {
    // We derive below RegMask(s) from the ones which are auto-generated from
    // adlc register classes to make AArch64 rheapbase (r27) and rfp (r29)
    // registers conditionally reserved.

    _ANY_REG32_mask = _ALL_REG32_mask;
    _ANY_REG32_mask.Remove(OptoReg::as_OptoReg(r31_sp->as_VMReg()));

    _ANY_REG_mask = _ALL_REG_mask;

    _PTR_REG_mask = _ALL_REG_mask;

    _NO_SPECIAL_REG32_mask = _ALL_REG32_mask;
    _NO_SPECIAL_REG32_mask.SUBTRACT(_NON_ALLOCATABLE_REG32_mask);

    _NO_SPECIAL_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    _NO_SPECIAL_PTR_REG_mask = _ALL_REG_mask;
    _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_NON_ALLOCATABLE_REG_mask);

    // r27 is not allocatable when compressed oops is on and heapbase is not
    // zero, compressed klass pointers doesn't use r27 after JDK-8234794
    if (UseCompressedOops && (CompressedOops::ptrs_base() != NULL)) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r27->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_HEAPBASE_REG_mask);
    }

    // r29 is not allocatable when PreserveFramePointer is on
    if (PreserveFramePointer) {
      _NO_SPECIAL_REG32_mask.Remove(OptoReg::as_OptoReg(r29->as_VMReg()));
      _NO_SPECIAL_REG_mask.SUBTRACT(_FP_REG_mask);
      _NO_SPECIAL_PTR_REG_mask.SUBTRACT(_FP_REG_mask);
    }
  }

  // Optimizaton of volatile gets and puts
  // -------------------------------------
  //
  // AArch64 has ldar<x> and stlr<x> instructions which we can safely
  // use to implement volatile reads and writes. For a volatile read
  // we simply need
  //
  //   ldar<x>
  //
  // and for a volatile write we need
  //
  //   stlr<x>
  //
  // Alternatively, we can implement them by pairing a normal
  // load/store with a memory barrier. For a volatile read we need
  //
  //   ldr<x>
  //   dmb ishld
  //
  // for a volatile write
  //
  //   dmb ish
  //   str<x>
  //   dmb ish
  //
  // We can also use ldaxr and stlxr to implement compare and swap CAS
  // sequences. These are normally translated to an instruction
  // sequence like the following
  //
  //   dmb      ish
  // retry:
  //   ldxr<x>   rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //   dmb ishld
  //
  // Note that the exclusive store is already using an stlxr
  // instruction. That is required to ensure visibility to other
  // threads of the exclusive write (assuming it succeeds) before that
  // of any subsequent writes.
  //
  // The following instruction sequence is an improvement on the above
  //
  // retry:
  //   ldaxr<x>  rval raddr
  //   cmp       rval rold
  //   b.ne done
  //   stlxr<x>  rval, rnew, rold
  //   cbnz      rval retry
  // done:
  //   cset      r0, eq
  //
  // We don't need the leading dmb ish since the stlxr guarantees
  // visibility of prior writes in the case that the swap is
  // successful. Crucially we don't have to worry about the case where
  // the swap is not successful since no valid program should be
  // relying on visibility of prior changes by the attempting thread
  // in the case where the CAS fails.
  //
  // Similarly, we don't need the trailing dmb ishld if we substitute
  // an ldaxr instruction since that will provide all the guarantees we
  // require regarding observation of changes made by other threads
  // before any change to the CAS address observed by the load.
  //
  // In order to generate the desired instruction sequence we need to
  // be able to identify specific 'signature' ideal graph node
  // sequences which i) occur as a translation of a volatile reads or
  // writes or CAS operations and ii) do not occur through any other
  // translation or graph transformation. We can then provide
  // alternative aldc matching rules which translate these node
  // sequences to the desired machine code sequences. Selection of the
  // alternative rules can be implemented by predicates which identify
  // the relevant node sequences.
  //
  // The ideal graph generator translates a volatile read to the node
  // sequence
  //
  //   LoadX[mo_acquire]
  //   MemBarAcquire
  //
  // As a special case when using the compressed oops optimization we
  // may also see this variant
  //
  //   LoadN[mo_acquire]
  //   DecodeN
  //   MemBarAcquire
  //
  // A volatile write is translated to the node sequence
  //
  //   MemBarRelease
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarVolatile
  //
  // n.b. the above node patterns are generated with a strict
  // 'signature' configuration of input and output dependencies (see
  // the predicates below for exact details). The card mark may be as
  // simple as a few extra nodes or, in a few GC configurations, may
  // include more complex control flow between the leading and
  // trailing memory barriers. However, whatever the card mark
  // configuration these signatures are unique to translated volatile
  // reads/stores -- they will not appear as a result of any other
  // bytecode translation or inlining nor as a consequence of
  // optimizing transforms.
  //
  // We also want to catch inlined unsafe volatile gets and puts and
  // be able to implement them using either ldar<x>/stlr<x> or some
  // combination of ldr<x>/stlr<x> and dmb instructions.
  //
  // Inlined unsafe volatiles puts manifest as a minor variant of the
  // normal volatile put node sequence containing an extra cpuorder
  // membar
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   StoreX[mo_release] {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarVolatile
  //
  // n.b. as an aside, a cpuorder membar is not itself subject to
  // matching and translation by adlc rules.  However, the rule
  // predicates need to detect its presence in order to correctly
  // select the desired adlc rules.
  //
  // Inlined unsafe volatile gets manifest as a slightly different
  // node sequence to a normal volatile get because of the
  // introduction of some CPUOrder memory barriers to bracket the
  // Load. However, but the same basic skeleton of a LoadX feeding a
  // MemBarAcquire, possibly through an optional DecodeN, is still
  // present
  //
  //   MemBarCPUOrder
  //        ||       \\
  //   MemBarCPUOrder LoadX[mo_acquire]
  //        ||            |
  //        ||       {DecodeN} optional
  //        ||       /
  //     MemBarAcquire
  //
  // In this case the acquire membar does not directly depend on the
  // load. However, we can be sure that the load is generated from an
  // inlined unsafe volatile get if we see it dependent on this unique
  // sequence of membar nodes. Similarly, given an acquire membar we
  // can know that it was added because of an inlined unsafe volatile
  // get if it is fed and feeds a cpuorder membar and if its feed
  // membar also feeds an acquiring load.
  //
  // Finally an inlined (Unsafe) CAS operation is translated to the
  // following ideal graph
  //
  //   MemBarRelease
  //   MemBarCPUOrder
  //   CompareAndSwapX {CardMark}-optional
  //   MemBarCPUOrder
  //   MemBarAcquire
  //
  // So, where we can identify these volatile read and write
  // signatures we can choose to plant either of the above two code
  // sequences. For a volatile read we can simply plant a normal
  // ldr<x> and translate the MemBarAcquire to a dmb. However, we can
  // also choose to inhibit translation of the MemBarAcquire and
  // inhibit planting of the ldr<x>, instead planting an ldar<x>.
  //
  // When we recognise a volatile store signature we can choose to
  // plant at a dmb ish as a translation for the MemBarRelease, a
  // normal str<x> and then a dmb ish for the MemBarVolatile.
  // Alternatively, we can inhibit translation of the MemBarRelease
  // and MemBarVolatile and instead plant a simple stlr<x>
  // instruction.
  //
  // when we recognise a CAS signature we can choose to plant a dmb
  // ish as a translation for the MemBarRelease, the conventional
  // macro-instruction sequence for the CompareAndSwap node (which
  // uses ldxr<x>) and then a dmb ishld for the MemBarAcquire.
  // Alternatively, we can elide generation of the dmb instructions
  // and plant the alternative CompareAndSwap macro-instruction
  // sequence (which uses ldaxr<x>).
  //
  // Of course, the above only applies when we see these signature
  // configurations. We still want to plant dmb instructions in any
  // other cases where we may see a MemBarAcquire, MemBarRelease or
  // MemBarVolatile. For example, at the end of a constructor which
  // writes final/volatile fields we will see a MemBarRelease
  // instruction and this needs a 'dmb ish' lest we risk the
  // constructed object being visible without making the
  // final/volatile field writes visible.
  //
  // n.b. the translation rules below which rely on detection of the
  // volatile signatures and insert ldar<x> or stlr<x> are failsafe.
  // If we see anything other than the signature configurations we
  // always just translate the loads and stores to ldr<x> and str<x>
  // and translate acquire, release and volatile membars to the
  // relevant dmb instructions.
  //

  // is_CAS(int opcode, bool maybe_volatile)
  //
  // return true if opcode is one of the possible CompareAndSwapX
  // values otherwise false.

  bool is_CAS(int opcode, bool maybe_volatile)
  {
    switch(opcode) {
      // We handle these
    case Op_CompareAndSwapI:
    case Op_CompareAndSwapL:
    case Op_CompareAndSwapP:
    case Op_CompareAndSwapN:
    case Op_ShenandoahCompareAndSwapP:
    case Op_ShenandoahCompareAndSwapN:
    case Op_CompareAndSwapB:
    case Op_CompareAndSwapS:
    case Op_GetAndSetI:
    case Op_GetAndSetL:
    case Op_GetAndSetP:
    case Op_GetAndSetN:
    case Op_GetAndAddI:
    case Op_GetAndAddL:
      return true;
    case Op_CompareAndExchangeI:
    case Op_CompareAndExchangeN:
    case Op_CompareAndExchangeB:
    case Op_CompareAndExchangeS:
    case Op_CompareAndExchangeL:
    case Op_CompareAndExchangeP:
    case Op_WeakCompareAndSwapB:
    case Op_WeakCompareAndSwapS:
    case Op_WeakCompareAndSwapI:
    case Op_WeakCompareAndSwapL:
    case Op_WeakCompareAndSwapP:
    case Op_WeakCompareAndSwapN:
    case Op_ShenandoahWeakCompareAndSwapP:
    case Op_ShenandoahWeakCompareAndSwapN:
    case Op_ShenandoahCompareAndExchangeP:
    case Op_ShenandoahCompareAndExchangeN:
      return maybe_volatile;
    default:
      return false;
    }
  }

  // helper to determine the maximum number of Phi nodes we may need to
  // traverse when searching from a card mark membar for the merge mem
  // feeding a trailing membar or vice versa

// predicates controlling emit of ldr<x>/ldar<x>

bool unnecessary_acquire(const Node *barrier)
{
  assert(barrier->is_MemBar(), "expecting a membar");

  MemBarNode* mb = barrier->as_MemBar();

  if (mb->trailing_load()) {
    return true;
  }

  if (mb->trailing_load_store()) {
    Node* load_store = mb->in(MemBarNode::Precedent);
    assert(load_store->is_LoadStore(), "unexpected graph shape");
    return is_CAS(load_store->Opcode(), true);
  }

  return false;
}

bool needs_acquiring_load(const Node *n)
{
  assert(n->is_Load(), "expecting a load");
  LoadNode *ld = n->as_Load();
  return ld->is_acquire();
}

bool unnecessary_release(const Node *n)
{
  assert((n->is_MemBar() &&
          n->Opcode() == Op_MemBarRelease),
         "expecting a release membar");

  MemBarNode *barrier = n->as_MemBar();
  if (!barrier->leading()) {
    return false;
  } else {
    Node* trailing = barrier->trailing_membar();
    MemBarNode* trailing_mb = trailing->as_MemBar();
    assert(trailing_mb->trailing(), "Not a trailing membar?");
    assert(trailing_mb->leading_membar() == n, "inconsistent leading/trailing membars");

    Node* mem = trailing_mb->in(MemBarNode::Precedent);
    if (mem->is_Store()) {
      assert(mem->as_Store()->is_release(), "");
      assert(trailing_mb->Opcode() == Op_MemBarVolatile, "");
      return true;
    } else {
      assert(mem->is_LoadStore(), "");
      assert(trailing_mb->Opcode() == Op_MemBarAcquire, "");
      return is_CAS(mem->Opcode(), true);
    }
  }
  return false;
}

bool unnecessary_volatile(const Node *n)
{
  // assert n->is_MemBar();
  MemBarNode *mbvol = n->as_MemBar();

  bool release = mbvol->trailing_store();
  assert(!release || (mbvol->in(MemBarNode::Precedent)->is_Store() && mbvol->in(MemBarNode::Precedent)->as_Store()->is_release()), "");
#ifdef ASSERT
  if (release) {
    Node* leading = mbvol->leading_membar();
    assert(leading->Opcode() == Op_MemBarRelease, "");
    assert(leading->as_MemBar()->leading_store(), "");
    assert(leading->as_MemBar()->trailing_membar() == mbvol, "");
  }
#endif

  return release;
}

// predicates controlling emit of str<x>/stlr<x>

bool needs_releasing_store(const Node *n)
{
  // assert n->is_Store();
  StoreNode *st = n->as_Store();
  return st->trailing_membar() != NULL;
}

// predicate controlling translation of CAS
//
// returns true if CAS needs to use an acquiring load otherwise false

bool needs_acquiring_load_exclusive(const Node *n)
{
  assert(is_CAS(n->Opcode(), true), "expecting a compare and swap");
  LoadStoreNode* ldst = n->as_LoadStore();
  if (is_CAS(n->Opcode(), false)) {
    assert(ldst->trailing_membar() != NULL, "expected trailing membar");
  } else {
    return ldst->trailing_membar() != NULL;
  }

  // so we can just return true here
  return true;
}

// Assert that the given node is not a variable shift.
bool assert_not_var_shift(const Node* n) {
  assert(!n->as_ShiftV()->is_var_shift(), "illegal variable shift");
  return true;
}

#define __ _masm.

// advance declarations for helper functions to convert register
// indices to register objects

// the ad file has to provide implementations of certain methods
// expected by the generic code
//
// REQUIRED FUNCTIONALITY

//=============================================================================

// !!!!! Special hack to get all types of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset()
{
  // call should be a simple bl
  int off = 4;
  return off;
}

int MachCallDynamicJavaNode::ret_addr_offset()
{
  return 16; // movz, movk, movk, bl
}

int MachCallRuntimeNode::ret_addr_offset() {
  // for generated stubs the call will be
  //   bl(addr)
  // or with far branches
  //   bl(trampoline_stub)
  // for real runtime callouts it will be six instructions
  // see aarch64_enc_java_to_runtime
  //   adr(rscratch2, retaddr)
  //   lea(rscratch1, RuntimeAddress(addr)
  //   stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)))
  //   blr(rscratch1)
  CodeBlob *cb = CodeCache::find_blob(_entry_point);
  if (cb) {
    return 1 * NativeInstruction::instruction_size;
  } else {
    return 6 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  __ brk(0);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    C2_MacroAssembler _masm(&cbuf);
    for (int i = 0; i < _count; i++) {
      __ nop();
    }
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count * NativeInstruction::instruction_size;
  }

//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  if (C->output()->need_stack_bang(framesize))
    st->print("# stack bang size=%d\n\t", framesize);

  if (VM_Version::use_rop_protection()) {
    st->print("ldr zr, [lr]\n\t");
    st->print("pacia  lr, rfp\n\t");
  }
  if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("sub  sp, sp, #%d\n\t", framesize);
    st->print("stp  rfp, lr, [sp, #%d]", framesize - 2 * wordSize);
    if (PreserveFramePointer) st->print("\n\tadd  rfp, sp, #%d", framesize - 2 * wordSize);
  } else {
    st->print("stp  lr, rfp, [sp, #%d]!\n\t", -(2 * wordSize));
    if (PreserveFramePointer) st->print("mov  rfp, sp\n\t");
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("sub  sp, sp, rscratch1");
  }
  if (C->stub_function() == NULL && BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
    st->print("\n\t");
    st->print("ldr  rscratch1, [guard]\n\t");
    st->print("dmb ishld\n\t");
    st->print("ldr  rscratch2, [rthread, #thread_disarmed_offset]\n\t");
    st->print("cmp  rscratch1, rscratch2\n\t");
    st->print("b.eq skip");
    st->print("\n\t");
    st->print("blr #nmethod_entry_barrier_stub\n\t");
    st->print("b skip\n\t");
    st->print("guard: int\n\t");
    st->print("\n\t");
    st->print("skip:\n\t");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);

  // n.b. frame size includes space for return pc and rfp
  const int framesize = C->output()->frame_size_in_bytes();

  // insert a nop at the start of the prolog so we can patch in a
  // branch if we need to invalidate the method later
  __ nop();

  if (C->clinit_barrier_on_entry()) {
    assert(!C->method()->holder()->is_not_initialized(), "initialization should have been started");

    Label L_skip_barrier;

    __ mov_metadata(rscratch2, C->method()->holder()->constant_encoding());
    __ clinit_barrier(rscratch2, rscratch1, &L_skip_barrier);
    __ far_jump(RuntimeAddress(SharedRuntime::get_handle_wrong_method_stub()));
    __ bind(L_skip_barrier);
  }

  if (C->max_vector_size() > 0) {
    __ reinitialize_ptrue();
  }

  int bangsize = C->output()->bang_size_in_bytes();
  if (C->output()->need_stack_bang(bangsize))
    __ generate_stack_overflow_check(bangsize);

  __ build_frame(framesize);

  if (C->stub_function() == NULL) {
    BarrierSetAssembler* bs = BarrierSet::barrier_set()->barrier_set_assembler();
    bs->nmethod_entry_barrier(&_masm);
  }

  if (VerifyStackAtCalls) {
    Unimplemented();
  }

  C->output()->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    ConstantTable& constant_table = C->output()->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_); // too many variables; just compute it
                              // the hard way
}

int MachPrologNode::reloc() const
{
  return 0;
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  st->print("# pop frame %d\n\t",framesize);

  if (framesize == 0) {
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  } else if (framesize < ((1 << 9) + 2 * wordSize)) {
    st->print("ldp  lr, rfp, [sp,#%d]\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, #%d\n\t", framesize);
  } else {
    st->print("mov  rscratch1, #%d\n\t", framesize - 2 * wordSize);
    st->print("add  sp, sp, rscratch1\n\t");
    st->print("ldp  lr, rfp, [sp],#%d\n\t", (2 * wordSize));
  }
  if (VM_Version::use_rop_protection()) {
    st->print("autia lr, rfp\n\t");
    st->print("ldr zr, [lr]\n\t");
  }

  if (do_polling() && C->is_method_compilation()) {
    st->print("# test polling word\n\t");
    st->print("ldr  rscratch1, [rthread],#%d\n\t", in_bytes(JavaThread::polling_word_offset()));
    st->print("cmp  sp, rscratch1\n\t");
    st->print("bhi #slow_path");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);
  int framesize = C->output()->frame_slots() << LogBytesPerInt;

  __ remove_frame(framesize);

  if (StackReservedPages > 0 && C->has_reserved_stack_access()) {
    __ reserved_stack_check();
  }

  if (do_polling() && C->is_method_compilation()) {
    Label dummy_label;
    Label* code_stub = &dummy_label;
    if (!C->output()->in_scratch_emit_size()) {
      code_stub = &C->output()->safepoint_poll_table()->add_safepoint(__ offset());
    }
    __ relocate(relocInfo::poll_return_type);
    __ safepoint_poll(*code_stub, true /* at_return */, false /* acquire */, true /* in_nmethod */);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for polling page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_predicate, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {

  if (reg == OptoReg::Bad) {
    return rc_bad;
  }

  // we have 32 int registers * 2 halves
  int slots_of_int_registers = RegisterImpl::max_slots_per_register * RegisterImpl::number_of_registers;

  if (reg < slots_of_int_registers) {
    return rc_int;
  }

  // we have 32 float register * 8 halves
  int slots_of_float_registers = FloatRegisterImpl::max_slots_per_register * FloatRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers) {
    return rc_float;
  }

  int slots_of_predicate_registers = PRegisterImpl::max_slots_per_register * PRegisterImpl::number_of_registers;
  if (reg < slots_of_int_registers + slots_of_float_registers + slots_of_predicate_registers) {
    return rc_predicate;
  }

  // Between predicate regs & stack is the flags.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");

  if (src_hi != OptoReg::Bad && !bottom_type()->isa_vectmask()) {
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  }

  if (src_lo == dst_lo && src_hi == dst_hi) {
    return 0;            // Self copy, no move.
  }

  bool is64 = (src_lo & 1) == 0 && src_lo + 1 == src_hi &&
              (dst_lo & 1) == 0 && dst_lo + 1 == dst_hi;
  int src_offset = ra_->reg2offset(src_lo);
  int dst_offset = ra_->reg2offset(dst_lo);

  if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
    uint ireg = ideal_reg();
    if (ireg == Op_VecA && cbuf) {
      C2_MacroAssembler _masm(cbuf);
      int sve_vector_reg_size_in_bytes = Matcher::scalable_vector_reg_size(T_BYTE);
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        __ spill_copy_sve_vector_stack_to_stack(src_offset, dst_offset,
                                                sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill_sve_vector(as_FloatRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                            sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill_sve_vector(as_FloatRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                              sve_vector_reg_size_in_bytes);
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ sve_orr(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]),
                   as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else {
        ShouldNotReachHere();
      }
    } else if (cbuf) {
      assert(ireg == Op_VecD || ireg == Op_VecX, "must be 64 bit or 128 bit vector");
      C2_MacroAssembler _masm(cbuf);
      assert((src_lo_rc != rc_int && dst_lo_rc != rc_int), "sanity");
      if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
        // stack->stack
        assert((src_offset & 7) == 0 && (dst_offset & 7) == 0, "unaligned stack offset");
        if (ireg == Op_VecD) {
          __ unspill(rscratch1, true, src_offset);
          __ spill(rscratch1, true, dst_offset);
        } else {
          __ spill_copy128(src_offset, dst_offset);
        }
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
        __ mov(as_FloatRegister(Matcher::_regEncode[dst_lo]),
               ireg == Op_VecD ? __ T8B : __ T16B,
               as_FloatRegister(Matcher::_regEncode[src_lo]));
      } else if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 ireg == Op_VecD ? __ D : __ Q,
                 ra_->reg2offset(dst_lo));
      } else if (src_lo_rc == rc_stack && dst_lo_rc == rc_float) {
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   ireg == Op_VecD ? __ D : __ Q,
                   ra_->reg2offset(src_lo));
      } else {
        ShouldNotReachHere();
      }
    }
  } else if (cbuf) {
    C2_MacroAssembler _masm(cbuf);
    switch (src_lo_rc) {
    case rc_int:
      if (dst_lo_rc == rc_int) {  // gpr --> gpr copy
        if (is64) {
            __ mov(as_Register(Matcher::_regEncode[dst_lo]),
                   as_Register(Matcher::_regEncode[src_lo]));
        } else {
            C2_MacroAssembler _masm(cbuf);
            __ movw(as_Register(Matcher::_regEncode[dst_lo]),
                    as_Register(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // gpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_Register(Matcher::_regEncode[src_lo]));
        }
      } else {                    // gpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_Register(Matcher::_regEncode[src_lo]), is64, dst_offset);
      }
      break;
    case rc_float:
      if (dst_lo_rc == rc_int) {  // fpr --> gpr copy
        if (is64) {
            __ fmovd(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_Register(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else if (dst_lo_rc == rc_float) { // fpr --> fpr copy
        if (is64) {
            __ fmovd(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        } else {
            __ fmovs(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                     as_FloatRegister(Matcher::_regEncode[src_lo]));
        }
      } else {                    // fpr --> stack spill
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        __ spill(as_FloatRegister(Matcher::_regEncode[src_lo]),
                 is64 ? __ D : __ S, dst_offset);
      }
      break;
    case rc_stack:
      if (dst_lo_rc == rc_int) {  // stack --> gpr load
        __ unspill(as_Register(Matcher::_regEncode[dst_lo]), is64, src_offset);
      } else if (dst_lo_rc == rc_float) { // stack --> fpr load
        __ unspill(as_FloatRegister(Matcher::_regEncode[dst_lo]),
                   is64 ? __ D : __ S, src_offset);
      } else if (dst_lo_rc == rc_predicate) {
        __ unspill_sve_predicate(as_PRegister(Matcher::_regEncode[dst_lo]), ra_->reg2offset(src_lo),
                                 Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {                    // stack --> stack copy
        assert(dst_lo_rc == rc_stack, "spill to bad register class");
        if (ideal_reg() == Op_RegVectMask) {
          __ spill_copy_sve_predicate_stack_to_stack(src_offset, dst_offset,
                                                     Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
        } else {
          __ unspill(rscratch1, is64, src_offset);
          __ spill(rscratch1, is64, dst_offset);
        }
      }
      break;
    case rc_predicate:
      if (dst_lo_rc == rc_predicate) {
        __ sve_mov(as_PRegister(Matcher::_regEncode[dst_lo]), as_PRegister(Matcher::_regEncode[src_lo]));
      } else if (dst_lo_rc == rc_stack) {
        __ spill_sve_predicate(as_PRegister(Matcher::_regEncode[src_lo]), ra_->reg2offset(dst_lo),
                               Matcher::scalable_vector_reg_size(T_BYTE) >> 3);
      } else {
        assert(false, "bad src and dst rc_class combination.");
        ShouldNotReachHere();
      }
      break;
    default:
      assert(false, "bad rc_class for spill");
      ShouldNotReachHere();
    }
  }

  if (st) {
    st->print("spill ");
    if (src_lo_rc == rc_stack) {
      st->print("[sp, #%d] -> ", ra_->reg2offset(src_lo));
    } else {
      st->print("%s -> ", Matcher::regName[src_lo]);
    }
    if (dst_lo_rc == rc_stack) {
      st->print("[sp, #%d]", ra_->reg2offset(dst_lo));
    } else {
      st->print("%s", Matcher::regName[dst_lo]);
    }
    if (bottom_type()->isa_vect() && !bottom_type()->isa_vectmask()) {
      int vsize = 0;
      switch (ideal_reg()) {
      case Op_VecD:
        vsize = 64;
        break;
      case Op_VecX:
        vsize = 128;
        break;
      case Op_VecA:
        vsize = Matcher::scalable_vector_reg_size(T_BYTE) * 8;
        break;
      default:
        assert(false, "bad register type for spill");
        ShouldNotReachHere();
      }
      st->print("\t# vector spill size = %d", vsize);
    } else if (ideal_reg() == Op_RegVectMask) {
      assert(Matcher::supports_scalable_vector(), "bad register type for spill");
      int vsize = Matcher::scalable_predicate_reg_slots() * 32;
      st->print("\t# predicate spill size = %d", vsize);
    } else {
      st->print("\t# spill size = %d", is64 ? 64 : 32);
    }
  }

  return 0;

}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("add %s, rsp, #%d]\t# box lock",
            Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  // This add will handle any 24-bit signed offset. 24 bits allows an
  // 8 megabyte stack frame.
  __ add(as_Register(reg), sp, offset);
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());

  if (Assembler::operand_valid_for_add_sub_immediate(offset)) {
    return NativeInstruction::instruction_size;
  } else {
    return 2 * NativeInstruction::instruction_size;
  }
}

//=============================================================================

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc* ra_, outputStream* st) const
{
  st->print_cr("# MachUEPNode");
  if (UseCompressedClassPointers) {
    st->print_cr("\tldrw rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
    if (CompressedKlassPointers::shift() != 0) {
      st->print_cr("\tdecode_klass_not_null rscratch1, rscratch1");
    }
  } else {
   st->print_cr("\tldr rscratch1, j_rarg0 + oopDesc::klass_offset_in_bytes()]\t# compressed klass");
  }
  st->print_cr("\tcmp r0, rscratch1\t # Inline cache check");
  st->print_cr("\tbne, SharedRuntime::_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const
{
  // This is the unverified entry point.
  C2_MacroAssembler _masm(&cbuf);

  __ cmp_klass(j_rarg0, rscratch2, rscratch1);
  Label skip;
  // TODO
  // can we avoid this skip and still use a reloc?
  __ br(Assembler::EQ, skip);
  __ far_jump(RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  __ bind(skip);
}

uint MachUEPNode::size(PhaseRegAlloc* ra_) const
{
  return MachNode::size(ra_);
}

// REQUIRED EMIT CODE

//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf)
{
  // mov rscratch1 #exception_blob_entry_point
  // br rscratch1
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();
  __ far_jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// Emit deopt handler code.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf)
{
  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  C2_MacroAssembler _masm(&cbuf);
  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }
  int offset = __ offset();

  __ adr(lr, __ pc());
  __ far_jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));

  assert(__ offset() - offset == (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

// REQUIRED MATCHER CODE

//=============================================================================

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  bool ret_value = true;
  switch (opcode) {
    case Op_OnSpinWait:
      return VM_Version::supports_on_spin_wait();
    case Op_CacheWB:
    case Op_CacheWBPreSync:
    case Op_CacheWBPostSync:
      if (!VM_Version::supports_data_cache_line_flush()) {
        ret_value = false;
      }
      break;
    case Op_LoadVectorMasked:
    case Op_StoreVectorMasked:
    case Op_LoadVectorGatherMasked:
    case Op_StoreVectorScatterMasked:
    case Op_MaskAll:
    case Op_AndVMask:
    case Op_OrVMask:
    case Op_XorVMask:
      if (UseSVE == 0) {
        ret_value = false;
      }
      break;
  }

  return ret_value; // Per default match rules are supported.
}

// Identify extra cases that we might want to provide match rules for vector nodes and
// other intrinsics guarded with vector length (vlen) and element type (bt).
const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {
  if (!match_rule_supported(opcode)) {
    return false;
  }
  int bit_size = vlen * type2aelembytes(bt) * 8;
  if (UseSVE == 0 && bit_size > 128) {
    return false;
  }
  if (UseSVE > 0) {
    return op_sve_supported(opcode, vlen, bt);
  } else { // NEON
    // Special cases
    switch (opcode) {
    case Op_VectorMaskCmp:
      if (vlen < 2 || bit_size < 64) {
        return false;
      }
      break;
    case Op_MulAddVS2VI:
      if (bit_size < 128) {
        return false;
      }
      break;
    case Op_MulVL:
    case Op_PopulateIndex:
      return false;
    case Op_VectorLoadShuffle:
    case Op_VectorRearrange:
      if (vlen < 4) {
        return false;
      }
      break;
    case Op_LoadVectorGather:
    case Op_StoreVectorScatter:
    case Op_CompressV:
    case Op_CompressM:
    case Op_ExpandV:
      return false;
    default:
      break;
    }
  }
  return vector_size_supported(bt, vlen);
}

const bool Matcher::match_rule_supported_vector_masked(int opcode, int vlen, BasicType bt) {
  // Only SVE supports masked operations.
  if (UseSVE == 0) {
    return false;
  }
  return match_rule_supported(opcode) &&
         masked_op_sve_supported(opcode, vlen, bt);
}

const RegMask* Matcher::predicate_reg_mask(void) {
  return &_PR_REG_mask;
}

const TypeVectMask* Matcher::predicate_reg_type(const Type* elemTy, int length) {
  return new TypeVectMask(elemTy, length);
}

// Vector calling convention not yet implemented.
const bool Matcher::supports_vector_calling_convention(void) {
  return false;
}

OptoRegPair Matcher::vector_return_value(uint ideal_reg) {
  Unimplemented();
  return OptoRegPair(0, 0);
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.

  return (-32768 <= offset && offset < 32768);
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  // The MaxVectorSize should have been set by detecting SVE max vector register size.
  int size = MIN2((UseSVE > 0) ? 256 : 16, (int)MaxVectorSize);
  // Minimum 2 values in vector
  if (size < 2*type2aelembytes(bt)) size = 0;
  // But never < 4
  if (size < 4) size = 0;
  return size;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}

const int Matcher::min_vector_size(const BasicType bt) {
  int max_size = max_vector_size(bt);
  // Limit the min vector size to 8 bytes.
  int size = 8 / type2aelembytes(bt);
  if (bt == T_BYTE) {
    // To support vector api shuffle/rearrange.
    size = 4;
  } else if (bt == T_BOOLEAN) {
    // To support vector api load/store mask.
    size = 2;
  }
  if (size < 2) size = 2;
  return MIN2(size, max_size);
}

// Actual max scalable vector register length.
const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Vector ideal reg.
const uint Matcher::vector_ideal_reg(int len) {
  if (UseSVE > 0 && 2 <= len && len <= 256) {
    return Op_VecA;
  }
  switch(len) {
    // For 16-bit/32-bit mask vector, reuse VecD.
    case  2:
    case  4:
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

MachOper* Matcher::pd_specialize_generic_vector_operand(MachOper* original_opnd, uint ideal_reg, bool is_temp) {
  ShouldNotReachHere(); // generic vector operands not supported
  return NULL;
}

bool Matcher::is_reg2reg_move(MachNode* m) {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

bool Matcher::is_generic_vector(MachOper* opnd)  {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

// Return whether or not this register is ever used as an argument.
// This function is used on startup to build the trampoline stubs in
// generateOptoStub.  Registers not mentioned will be killed by the VM
// call in the trampoline, and arguments in those registers not be
// available to the callee.
bool Matcher::can_be_java_arg(int reg)
{
  return
    reg ==  R0_num || reg == R0_H_num ||
    reg ==  R1_num || reg == R1_H_num ||
    reg ==  R2_num || reg == R2_H_num ||
    reg ==  R3_num || reg == R3_H_num ||
    reg ==  R4_num || reg == R4_H_num ||
    reg ==  R5_num || reg == R5_H_num ||
    reg ==  R6_num || reg == R6_H_num ||
    reg ==  R7_num || reg == R7_H_num ||
    reg ==  V0_num || reg == V0_H_num ||
    reg ==  V1_num || reg == V1_H_num ||
    reg ==  V2_num || reg == V2_H_num ||
    reg ==  V3_num || reg == V3_H_num ||
    reg ==  V4_num || reg == V4_H_num ||
    reg ==  V5_num || reg == V5_H_num ||
    reg ==  V6_num || reg == V6_H_num ||
    reg ==  V7_num || reg == V7_H_num;
}

bool Matcher::is_spillable_arg(int reg)
{
  return can_be_java_arg(reg);
}

uint Matcher::int_pressure_limit()
{
  // JDK-8183543: When taking the number of available registers as int
  // register pressure threshold, the jtreg test:
  // test/hotspot/jtreg/compiler/regalloc/TestC2IntPressure.java
  // failed due to C2 compilation failure with
  // "COMPILE SKIPPED: failed spill-split-recycle sanity check".
  //
  // A derived pointer is live at CallNode and then is flagged by RA
  // as a spilled LRG. Spilling heuristics(Spill-USE) explicitly skip
  // derived pointers and lastly fail to spill after reaching maximum
  // number of iterations. Lowering the default pressure threshold to
  // (_NO_SPECIAL_REG32_mask.Size() minus 1) forces CallNode to become
  // a high register pressure area of the code so that split_DEF can
  // generate DefinitionSpillCopy for the derived pointer.
  uint default_int_pressure_threshold = _NO_SPECIAL_REG32_mask.Size() - 1;
  if (!PreserveFramePointer) {
    // When PreserveFramePointer is off, frame pointer is allocatable,
    // but different from other SOC registers, it is excluded from
    // fatproj's mask because its save type is No-Save. Decrease 1 to
    // ensure high pressure at fatproj when PreserveFramePointer is off.
    // See check_pressure_at_fatproj().
    default_int_pressure_threshold--;
  }
  return (INTPRESSURE == -1) ? default_int_pressure_threshold : INTPRESSURE;
}

uint Matcher::float_pressure_limit()
{
  // _FLOAT_REG_mask is generated by adlc from the float_reg register class.
  return (FLOATPRESSURE == -1) ? _FLOAT_REG_mask.Size() : FLOATPRESSURE;
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REG_mask();
}

bool size_fits_all_mem_uses(AddPNode* addp, int shift) {
  for (DUIterator_Fast imax, i = addp->fast_outs(imax); i < imax; i++) {
    Node* u = addp->fast_out(i);
    if (u->is_LoadStore()) {
      // On AArch64, LoadStoreNodes (i.e. compare and swap
      // instructions) only take register indirect as an operand, so
      // any attempt to use an AddPNode as an input to a LoadStoreNode
      // must fail.
      return false;
    }
    if (u->is_Mem()) {
      int opsize = u->as_Mem()->memory_size();
      assert(opsize > 0, "unexpected memory operand size");
      if (u->as_Mem()->memory_size() != (1<<shift)) {
        return false;
      }
    }
  }
  return true;
}

bool can_combine_with_imm(Node* binary_node, Node* replicate_node) {
  if (UseSVE == 0 || !VectorNode::is_invariant_vector(replicate_node)){
    return false;
  }
  Node* imm_node = replicate_node->in(1);
  if (!imm_node->is_Con()) {
    return false;
  }

  const Type* t = imm_node->bottom_type();
  if (!(t->isa_int() || t->isa_long())) {
    return false;
  }

  switch (binary_node->Opcode()) {
  case Op_AndV:
  case Op_OrV:
  case Op_XorV: {
    Assembler::SIMD_RegVariant T = Assembler::elemType_to_regVariant(Matcher::vector_element_basic_type(binary_node));
    uint64_t value = t->isa_long() ? (uint64_t)imm_node->get_long() : (uint64_t)imm_node->get_int();
    return Assembler::operand_valid_for_sve_logical_immediate(Assembler::regVariant_to_elemBits(T), value);
  }
  case Op_AddVB:
    return (imm_node->get_int() <= 255 && imm_node->get_int() >= -255);
  case Op_AddVS:
  case Op_AddVI:
    return Assembler::operand_valid_for_sve_add_sub_immediate((int64_t)imm_node->get_int());
  case Op_AddVL:
    return Assembler::operand_valid_for_sve_add_sub_immediate(imm_node->get_long());
  default:
    return false;
  }
}

bool is_vector_arith_imm_pattern(Node* n, Node* m) {
  if (n != NULL && m != NULL) {
    return can_combine_with_imm(n, m);
  }
  return false;
}

// Should the matcher clone input 'm' of node 'n'?
bool Matcher::pd_clone_node(Node* n, Node* m, Matcher::MStack& mstack) {
  // ShiftV src (ShiftCntV con)
  // Binary src (Replicate con)
  if (is_vshift_con_pattern(n, m) || is_vector_arith_imm_pattern(n, m)) {
    mstack.push(m, Visit);
    return true;
  }

  return false;
}

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::pd_clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  if (clone_base_plus_offset_address(m, mstack, address_visited)) {
    return true;
  }

  Node *off = m->in(AddPNode::Offset);
  if (off->Opcode() == Op_LShiftL && off->in(2)->is_Con() &&
      size_fits_all_mem_uses(m, off->in(2)->get_int()) &&
      // Are there other uses besides address expressions?
      !is_visited(off)) {
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(2), Visit);
    Node *conv = off->in(1);
    if (conv->Opcode() == Op_ConvI2L &&
        // Are there other uses besides address expressions?
        !is_visited(conv)) {
      address_visited.set(conv->_idx); // Flag as address_visited
      mstack.push(conv->in(1), Pre_Visit);
    } else {
      mstack.push(conv, Pre_Visit);
    }
    address_visited.test_set(m->_idx); // Flag as address_visited
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  } else if (off->Opcode() == Op_ConvI2L &&
             // Are there other uses besides address expressions?
             !is_visited(off)) {
    address_visited.test_set(m->_idx); // Flag as address_visited
    address_visited.set(off->_idx); // Flag as address_visited
    mstack.push(off->in(1), Pre_Visit);
    mstack.push(m->in(AddPNode::Address), Pre_Visit);
    mstack.push(m->in(AddPNode::Base), Pre_Visit);
    return true;
  }
  return false;
}

#define MOV_VOLATILE(REG, BASE, INDEX, SCALE, DISP, SCRATCH, INSN)      \
  C2_MacroAssembler _masm(&cbuf);                                       \
  {                                                                     \
    guarantee(INDEX == -1, "mode not permitted for volatile");          \
    guarantee(DISP == 0, "mode not permitted for volatile");            \
    guarantee(SCALE == 0, "mode not permitted for volatile");           \
    __ INSN(REG, as_Register(BASE));                                    \
  }


static Address mem2address(int opcode, Register base, int index, int size, int disp)
  {
    Address::extend scale;

    // Hooboy, this is fugly.  We need a way to communicate to the
    // encoder that the index needs to be sign extended, so we have to
    // enumerate all the cases.
    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
    case INDINDEXI2L:
    case INDINDEXI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      return Address(base, disp);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      return Address(base, as_Register(index), scale);
    }
  }


typedef void (MacroAssembler::* mem_insn)(Register Rt, const Address &adr);
typedef void (MacroAssembler::* mem_insn2)(Register Rt, Register adr);
typedef void (MacroAssembler::* mem_float_insn)(FloatRegister Rt, const Address &adr);
typedef void (MacroAssembler::* mem_vector_insn)(FloatRegister Rt,
                                  MacroAssembler::SIMD_RegVariant T, const Address &adr);

  // Used for all non-volatile memory accesses.  The use of
  // $mem->opcode() to discover whether this pattern uses sign-extended
  // offsets is something of a kludge.
  static void loadStore(C2_MacroAssembler masm, mem_insn insn,
                        Register reg, int opcode,
                        Register base, int index, int scale, int disp,
                        int size_in_memory)
  {
    Address addr = mem2address(opcode, base, index, scale, disp);
    if (addr.getMode() == Address::base_plus_offset) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(addr.offset(), exact_log2(size_in_memory)),
             "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      assert_different_registers(rscratch1, reg);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
    }
    (masm.*insn)(reg, addr);
  }

  static void loadStore(C2_MacroAssembler masm, mem_float_insn insn,
                        FloatRegister reg, int opcode,
                        Register base, int index, int size, int disp,
                        int size_in_memory)
  {
    Address::extend scale;

    switch (opcode) {
    case INDINDEXSCALEDI2L:
    case INDINDEXSCALEDI2LN:
      scale = Address::sxtw(size);
      break;
    default:
      scale = Address::lsl(size);
    }

    if (index == -1) {
      /* If we get an out-of-range offset it is a bug in the compiler,
         so we assert here. */
      assert(Address::offset_ok_for_immed(disp, exact_log2(size_in_memory)), "c2 compiler bug");
      /* Fix up any out-of-range offsets. */
      assert_different_registers(rscratch1, base);
      Address addr = Address(base, disp);
      addr = masm.legitimize_address(addr, size_in_memory, rscratch1);
      (masm.*insn)(reg, addr);
    } else {
      assert(disp == 0, "unsupported address mode: disp = %d", disp);
      (masm.*insn)(reg, Address(base, as_Register(index), scale));
    }
  }

  static void loadStore(C2_MacroAssembler masm, mem_vector_insn insn,
                        FloatRegister reg, MacroAssembler::SIMD_RegVariant T,
                        int opcode, Register base, int index, int size, int disp)
  {
    if (index == -1) {
      (masm.*insn)(reg, T, Address(base, disp));
    } else {
      assert(disp == 0, "unsupported address mode");
      (masm.*insn)(reg, T, Address(base, as_Register(index), Address::lsl(size)));
    }
  }


#line 1641 "ad_aarch64.cpp"


//SourceForm

#line 94 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"


  typedef void (C2_MacroAssembler::* sve_mem_insn_predicate)(FloatRegister Rt, Assembler::SIMD_RegVariant T,
                                                             PRegister Pg, const Address &adr);

  // Predicated load/store, with optional ptrue to all elements of given predicate register.
  static void loadStoreA_predicated(C2_MacroAssembler masm, bool is_store, FloatRegister reg,
                                    PRegister pg, BasicType mem_elem_bt, BasicType vector_elem_bt,
                                    int opcode, Register base, int index, int size, int disp) {
    sve_mem_insn_predicate insn;
    int mesize = type2aelembytes(mem_elem_bt);
    if (index == -1) {
      assert(size == 0, "unsupported address mode: scale size = %d", size);
      switch(mesize) {
      case 1:
        insn = is_store ? &C2_MacroAssembler::sve_st1b : &C2_MacroAssembler::sve_ld1b;
        break;
      case 2:
        insn = is_store ? &C2_MacroAssembler::sve_st1h : &C2_MacroAssembler::sve_ld1h;
        break;
      case 4:
        insn = is_store ? &C2_MacroAssembler::sve_st1w : &C2_MacroAssembler::sve_ld1w;
        break;
      case 8:
        insn = is_store ? &C2_MacroAssembler::sve_st1d : &C2_MacroAssembler::sve_ld1d;
        break;
      default:
        assert(false, "unsupported");
        ShouldNotReachHere();
      }
      int imm4 = disp / mesize / Matcher::scalable_vector_reg_size(vector_elem_bt);
      (masm.*insn)(reg, Assembler::elemType_to_regVariant(vector_elem_bt), pg, Address(base, imm4));
    } else {
      assert(false, "unimplemented");
      ShouldNotReachHere();
    }
  }

  bool op_sve_supported(int opcode, int vlen, BasicType bt) {
    int length_in_bytes = vlen * type2aelembytes(bt);
    switch (opcode) {
      case Op_MulAddVS2VI:
      // No multiply reduction instructions
      case Op_MulReductionVD:
      case Op_MulReductionVF:
      case Op_MulReductionVI:
      case Op_MulReductionVL:
      // Others
      case Op_ExtractC:
      case Op_ExtractUB:
        return false;
      // Vector API specific
      case Op_VectorLoadShuffle:
      case Op_VectorRearrange:
        return vlen >= 4 && length_in_bytes <= MaxVectorSize;
      case Op_LoadVector:
      case Op_StoreVector:
        return Matcher::vector_size_supported(bt, vlen);
      case Op_ExpandV:
        if (UseSVE < 2 || is_subword_type(bt)) return false;
      case Op_VectorMaskToLong:
        if (vlen > 64) return false;
      default:
        break;
    }
    // By default, we only support vector operations with no less than 8 bytes and 2 elements.
    return 8 <= length_in_bytes && length_in_bytes <= MaxVectorSize && vlen >= 2;
  }

  bool masked_op_sve_supported(int opcode, int vlen, BasicType bt) {
    if (opcode == Op_VectorRearrange) {
      return false;
    }
    return op_sve_supported(opcode, vlen, bt);
  }

#line 1723 "ad_aarch64.cpp"


//SourceForm

#line 32 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"


static void z_load_barrier(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp, uint8_t barrier_data) {
  if (barrier_data == ZLoadBarrierElided) {
    return;
  }
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, barrier_data);
  __ ldr(tmp, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
  __ andr(tmp, tmp, ref);
  __ cbnz(tmp, *stub->entry());
  __ bind(*stub->continuation());
}

static void z_load_barrier_slow_path(MacroAssembler& _masm, const MachNode* node, Address ref_addr, Register ref, Register tmp) {
  ZLoadBarrierStubC2* const stub = ZLoadBarrierStubC2::create(node, ref_addr, ref, tmp, ZLoadBarrierStrong);
  __ b(*stub->entry());
  __ bind(*stub->continuation());
}


#line 1749 "ad_aarch64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( INSN_COST == 100, "Expect (100) to equal 100");
  assert( BRANCH_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( CALL_COST == 200, "Expect (2 * INSN_COST) to equal 200");
  assert( VOLATILE_REF_COST == 1000, "Expect (10 * INSN_COST) to equal 1000");
  assert( SVE_COST == 200, "Expect (200) to equal 200");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R27
  'C', // R27_H
  'N', // R28
  'N', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'N', // R8
  'N', // R8_H
  'N', // R9
  'N', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'C', // V8
  'C', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'C', // V9
  'C', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'C', // V10
  'C', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'C', // V11
  'C', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'C', // V12
  'C', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'C', // V13
  'C', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'C', // V14
  'C', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'C', // V15
  'C', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C', // R10
  'C', // R10_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R13
  'C', // R13_H
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R16
  'C', // R16_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R0
  'C', // R0_H
  'C', // R1
  'C', // R1_H
  'C', // R2
  'C', // R2_H
  'C', // R3
  'C', // R3_H
  'C', // R4
  'C', // R4_H
  'C', // R5
  'C', // R5_H
  'C', // R6
  'C', // R6_H
  'C', // R7
  'C', // R7_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'N', // R29
  'N', // R29_H
  'N', // R30
  'N', // R30_H
  'N', // R31
  'N', // R31_H
  'C', // R8
  'C', // R8_H
  'C', // R9
  'C', // R9_H
  'C', // V16
  'C', // V16_H
  'C', // V16_J
  'C', // V16_K
  'C', // V16_L
  'C', // V16_M
  'C', // V16_N
  'C', // V16_O
  'C', // V17
  'C', // V17_H
  'C', // V17_J
  'C', // V17_K
  'C', // V17_L
  'C', // V17_M
  'C', // V17_N
  'C', // V17_O
  'C', // V18
  'C', // V18_H
  'C', // V18_J
  'C', // V18_K
  'C', // V18_L
  'C', // V18_M
  'C', // V18_N
  'C', // V18_O
  'C', // V19
  'C', // V19_H
  'C', // V19_J
  'C', // V19_K
  'C', // V19_L
  'C', // V19_M
  'C', // V19_N
  'C', // V19_O
  'C', // V20
  'C', // V20_H
  'C', // V20_J
  'C', // V20_K
  'C', // V20_L
  'C', // V20_M
  'C', // V20_N
  'C', // V20_O
  'C', // V21
  'C', // V21_H
  'C', // V21_J
  'C', // V21_K
  'C', // V21_L
  'C', // V21_M
  'C', // V21_N
  'C', // V21_O
  'C', // V22
  'C', // V22_H
  'C', // V22_J
  'C', // V22_K
  'C', // V22_L
  'C', // V22_M
  'C', // V22_N
  'C', // V22_O
  'C', // V23
  'C', // V23_H
  'C', // V23_J
  'C', // V23_K
  'C', // V23_L
  'C', // V23_M
  'C', // V23_N
  'C', // V23_O
  'C', // V24
  'C', // V24_H
  'C', // V24_J
  'C', // V24_K
  'C', // V24_L
  'C', // V24_M
  'C', // V24_N
  'C', // V24_O
  'C', // V25
  'C', // V25_H
  'C', // V25_J
  'C', // V25_K
  'C', // V25_L
  'C', // V25_M
  'C', // V25_N
  'C', // V25_O
  'C', // V26
  'C', // V26_H
  'C', // V26_J
  'C', // V26_K
  'C', // V26_L
  'C', // V26_M
  'C', // V26_N
  'C', // V26_O
  'C', // V27
  'C', // V27_H
  'C', // V27_J
  'C', // V27_K
  'C', // V27_L
  'C', // V27_M
  'C', // V27_N
  'C', // V27_O
  'C', // V28
  'C', // V28_H
  'C', // V28_J
  'C', // V28_K
  'C', // V28_L
  'C', // V28_M
  'C', // V28_N
  'C', // V28_O
  'C', // V29
  'C', // V29_H
  'C', // V29_J
  'C', // V29_K
  'C', // V29_L
  'C', // V29_M
  'C', // V29_N
  'C', // V29_O
  'C', // V30
  'C', // V30_H
  'C', // V30_J
  'C', // V30_K
  'C', // V30_L
  'C', // V30_M
  'C', // V30_N
  'C', // V30_O
  'C', // V31
  'C', // V31_H
  'C', // V31_J
  'C', // V31_K
  'C', // V31_L
  'C', // V31_M
  'C', // V31_N
  'C', // V31_O
  'C', // V0
  'C', // V0_H
  'C', // V0_J
  'C', // V0_K
  'C', // V0_L
  'C', // V0_M
  'C', // V0_N
  'C', // V0_O
  'C', // V1
  'C', // V1_H
  'C', // V1_J
  'C', // V1_K
  'C', // V1_L
  'C', // V1_M
  'C', // V1_N
  'C', // V1_O
  'C', // V2
  'C', // V2_H
  'C', // V2_J
  'C', // V2_K
  'C', // V2_L
  'C', // V2_M
  'C', // V2_N
  'C', // V2_O
  'C', // V3
  'C', // V3_H
  'C', // V3_J
  'C', // V3_K
  'C', // V3_L
  'C', // V3_M
  'C', // V3_N
  'C', // V3_O
  'C', // V4
  'C', // V4_H
  'C', // V4_J
  'C', // V4_K
  'C', // V4_L
  'C', // V4_M
  'C', // V4_N
  'C', // V4_O
  'C', // V5
  'C', // V5_H
  'C', // V5_J
  'C', // V5_K
  'C', // V5_L
  'C', // V5_M
  'C', // V5_N
  'C', // V5_O
  'C', // V6
  'C', // V6_H
  'C', // V6_J
  'C', // V6_K
  'C', // V6_L
  'C', // V6_M
  'C', // V6_N
  'C', // V6_O
  'C', // V7
  'C', // V7_H
  'C', // V7_J
  'C', // V7_K
  'C', // V7_L
  'C', // V7_M
  'C', // V7_N
  'C', // V7_O
  'E', // V8
  'E', // V8_H
  'C', // V8_J
  'C', // V8_K
  'C', // V8_L
  'C', // V8_M
  'C', // V8_N
  'C', // V8_O
  'E', // V9
  'E', // V9_H
  'C', // V9_J
  'C', // V9_K
  'C', // V9_L
  'C', // V9_M
  'C', // V9_N
  'C', // V9_O
  'E', // V10
  'E', // V10_H
  'C', // V10_J
  'C', // V10_K
  'C', // V10_L
  'C', // V10_M
  'C', // V10_N
  'C', // V10_O
  'E', // V11
  'E', // V11_H
  'C', // V11_J
  'C', // V11_K
  'C', // V11_L
  'C', // V11_M
  'C', // V11_N
  'C', // V11_O
  'E', // V12
  'E', // V12_H
  'C', // V12_J
  'C', // V12_K
  'C', // V12_L
  'C', // V12_M
  'C', // V12_N
  'C', // V12_O
  'E', // V13
  'E', // V13_H
  'C', // V13_J
  'C', // V13_K
  'C', // V13_L
  'C', // V13_M
  'C', // V13_N
  'C', // V13_O
  'E', // V14
  'E', // V14_H
  'C', // V14_J
  'C', // V14_K
  'C', // V14_L
  'C', // V14_M
  'C', // V14_N
  'C', // V14_O
  'E', // V15
  'E', // V15_H
  'C', // V15_J
  'C', // V15_K
  'C', // V15_L
  'C', // V15_M
  'C', // V15_N
  'C', // V15_O
  'C', // P0
  'C', // P1
  'C', // P2
  'C', // P3
  'C', // P4
  'C', // P5
  'C', // P6
  'C', // P7
  'C', // P8
  'C', // P9
  'C', // P10
  'C', // P11
  'C', // P12
  'C', // P13
  'C', // P14
  'C', // P15
  'C' // no trailing comma // RFLAGS
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  Op_RegVectMask,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI0_rule,
  /*   10 */  immI_1_rule,
  /*   11 */  immI_M1_rule,
  /*   12 */  immIExt_rule,
  /*   13 */  immI_gt_1_rule,
  /*   14 */  immI_le_4_rule,
  /*   15 */  immI_31_rule,
  /*   16 */  immI_2_rule,
  /*   17 */  immI_4_rule,
  /*   18 */  immI_8_rule,
  /*   19 */  immI_16_rule,
  /*   20 */  immI_24_rule,
  /*   21 */  immI_32_rule,
  /*   22 */  immI_48_rule,
  /*   23 */  immI_56_rule,
  /*   24 */  immI_63_rule,
  /*   25 */  immI_64_rule,
  /*   26 */  immI_255_rule,
  /*   27 */  immI_65535_rule,
  /*   28 */  immI_positive_rule,
  /*   29 */  immL_255_rule,
  /*   30 */  immL_65535_rule,
  /*   31 */  immL_4294967295_rule,
  /*   32 */  immL_bitmask_rule,
  /*   33 */  immI_bitmask_rule,
  /*   34 */  immL_positive_bitmaskI_rule,
  /*   35 */  immIScale_rule,
  /*   36 */  immI26_rule,
  /*   37 */  immI19_rule,
  /*   38 */  immIU12_rule,
  /*   39 */  immLU12_rule,
  /*   40 */  immIOffset_rule,
  /*   41 */  immIOffset1_rule,
  /*   42 */  immIOffset2_rule,
  /*   43 */  immIOffset4_rule,
  /*   44 */  immIOffset8_rule,
  /*   45 */  immIOffset16_rule,
  /*   46 */  immLoffset_rule,
  /*   47 */  immLoffset1_rule,
  /*   48 */  immLoffset2_rule,
  /*   49 */  immLoffset4_rule,
  /*   50 */  immLoffset8_rule,
  /*   51 */  immLoffset16_rule,
  /*   52 */  immI8_rule,
  /*   53 */  immI8_shift8_rule,
  /*   54 */  immL8_shift8_rule,
  /*   55 */  immBAddSubV_rule,
  /*   56 */  immIAddSub_rule,
  /*   57 */  immIAddSubV_rule,
  /*   58 */  immBLog_rule,
  /*   59 */  immSLog_rule,
  /*   60 */  immILog_rule,
  /*   61 */  immL_rule,
  /*   62 */  immL0_rule,
  /*   63 */  immL_1_rule,
  /*   64 */  immL_M1_rule,
  /*   65 */  immL_pc_off_rule,
  /*   66 */  immLAddSub_rule,
  /*   67 */  immLAddSubV_rule,
  /*   68 */  immLLog_rule,
  /*   69 */  immL_32bits_rule,
  /*   70 */  immP_rule,
  /*   71 */  immP0_rule,
  /*   72 */  immP_1_rule,
  /*   73 */  immByteMapBase_rule,
  /*   74 */  immP_M1_rule,
  /*   75 */  immP_M2_rule,
  /*   76 */  immD_rule,
  /*   77 */  immD0_rule,
  /*   78 */  immDPacked_rule,
  /*   79 */  immF_rule,
  /*   80 */  immF0_rule,
  /*   81 */  immFPacked_rule,
  /*   82 */  immN_rule,
  /*   83 */  immN0_rule,
  /*   84 */  immNKlass_rule,
  /*   85 */  iRegI_rule,
  /*   86 */  iRegINoSp_rule,
  /*   87 */  iRegL_rule,
  /*   88 */  iRegLNoSp_rule,
  /*   89 */  iRegP_rule,
  /*   90 */  iRegPNoSp_rule,
  /*   91 */  iRegP_R0_rule,
  /*   92 */  iRegP_R1_rule,
  /*   93 */  iRegP_R2_rule,
  /*   94 */  iRegP_R3_rule,
  /*   95 */  iRegP_R4_rule,
  /*   96 */  iRegP_R5_rule,
  /*   97 */  iRegP_R10_rule,
  /*   98 */  iRegL_R0_rule,
  /*   99 */  iRegL_R2_rule,
  /*  100 */  iRegL_R3_rule,
  /*  101 */  iRegL_R11_rule,
  /*  102 */  iRegP_FP_rule,
  /*  103 */  iRegI_R0_rule,
  /*  104 */  iRegI_R2_rule,
  /*  105 */  iRegI_R3_rule,
  /*  106 */  iRegI_R4_rule,
  /*  107 */  iRegN_rule,
  /*  108 */  iRegN_R0_rule,
  /*  109 */  iRegN_R2_rule,
  /*  110 */  iRegN_R3_rule,
  /*  111 */  iRegNNoSp_rule,
  /*  112 */  iRegIHeapbase_rule,
  /*  113 */  vRegF_rule,
  /*  114 */  vRegD_rule,
  /*  115 */  vReg_rule,
  /*  116 */  vecD_rule,
  /*  117 */  vecX_rule,
  /*  118 */  vRegD_V0_rule,
  /*  119 */  vRegD_V1_rule,
  /*  120 */  vRegD_V2_rule,
  /*  121 */  vRegD_V3_rule,
  /*  122 */  vRegD_V4_rule,
  /*  123 */  vRegD_V5_rule,
  /*  124 */  vRegD_V6_rule,
  /*  125 */  vRegD_V7_rule,
  /*  126 */  vRegD_V8_rule,
  /*  127 */  vRegD_V9_rule,
  /*  128 */  vRegD_V10_rule,
  /*  129 */  vRegD_V11_rule,
  /*  130 */  vRegD_V12_rule,
  /*  131 */  vRegD_V13_rule,
  /*  132 */  vRegD_V14_rule,
  /*  133 */  vRegD_V15_rule,
  /*  134 */  vRegD_V16_rule,
  /*  135 */  vRegD_V17_rule,
  /*  136 */  vRegD_V18_rule,
  /*  137 */  vRegD_V19_rule,
  /*  138 */  vRegD_V20_rule,
  /*  139 */  vRegD_V21_rule,
  /*  140 */  vRegD_V22_rule,
  /*  141 */  vRegD_V23_rule,
  /*  142 */  vRegD_V24_rule,
  /*  143 */  vRegD_V25_rule,
  /*  144 */  vRegD_V26_rule,
  /*  145 */  vRegD_V27_rule,
  /*  146 */  vRegD_V28_rule,
  /*  147 */  vRegD_V29_rule,
  /*  148 */  vRegD_V30_rule,
  /*  149 */  vRegD_V31_rule,
  /*  150 */  pReg_rule,
  /*  151 */  pRegGov_rule,
  /*  152 */  pRegGov_P0_rule,
  /*  153 */  pRegGov_P1_rule,
  /*  154 */  rFlagsReg_rule,
  /*  155 */  rFlagsRegU_rule,
  /*  156 */  inline_cache_RegP_rule,
  /*  157 */  thread_RegP_rule,
  /*  158 */  lr_RegP_rule,
  /*  159 */  indirect_rule,
  /*  160 */  indIndexScaledI2L_rule,
  /*  161 */  indIndexScaled_rule,
  /*  162 */  indIndexI2L_rule,
  /*  163 */  indIndex_rule,
  /*  164 */  indOffI_rule,
  /*  165 */  indOffI1_rule,
  /*  166 */  indOffI2_rule,
  /*  167 */  indOffI4_rule,
  /*  168 */  indOffI8_rule,
  /*  169 */  indOffI16_rule,
  /*  170 */  indOffL_rule,
  /*  171 */  indOffL1_rule,
  /*  172 */  indOffL2_rule,
  /*  173 */  indOffL4_rule,
  /*  174 */  indOffL8_rule,
  /*  175 */  indOffL16_rule,
  /*  176 */  indirectN_rule,
  /*  177 */  indIndexScaledI2LN_rule,
  /*  178 */  indIndexScaledN_rule,
  /*  179 */  indIndexI2LN_rule,
  /*  180 */  indIndexN_rule,
  /*  181 */  indOffIN_rule,
  /*  182 */  indOffLN_rule,
  /*  183 */  thread_anchor_pc_rule,
  /*  184 */  stackSlotP_rule,
  /*  185 */  stackSlotI_rule,
  /*  186 */  stackSlotF_rule,
  /*  187 */  stackSlotD_rule,
  /*  188 */  stackSlotL_rule,
  /*  189 */  cmpOp_rule,
  /*  190 */  cmpOpU_rule,
  /*  191 */  cmpOpEqNe_rule,
  /*  192 */  cmpOpLtGe_rule,
  /*  193 */  cmpOpUEqNeLtGe_rule,
  /*  194 */  iRegL2I_rule,
  /*  195 */  vmemA_immIOffset4_rule,
  /*  196 */  vmemA_immLOffset4_rule,
  /*  197 */  vmemA_indOffI4_rule,
  /*  198 */  vmemA_indOffL4_rule,
  // last operand
  /*  199 */  vmem2_rule,
  /*  200 */  vmem4_rule,
  /*  201 */  vmem8_rule,
  /*  202 */  vmem16_rule,
  /*  203 */  memory1_rule,
  /*  204 */  memory2_rule,
  /*  205 */  memory4_rule,
  /*  206 */  memory8_rule,
  /*  207 */  memory_rule,
  /*  208 */  iRegIorL2I_rule,
  /*  209 */  vmemA_rule,
  // last operand class
  /*  210 */  _ConvI2L_iRegI__rule,
  /*  211 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  212 */  _LShiftL_iRegL_immIScale_rule,
  /*  213 */  _DecodeN_iRegN__rule,
  /*  214 */  _LoadB_memory1__rule,
  /*  215 */  _LoadUB_memory1__rule,
  /*  216 */  _LoadS_memory2__rule,
  /*  217 */  _LoadUS_memory2__rule,
  /*  218 */  _LoadI_memory4__rule,
  /*  219 */  _ConvI2L__LoadI_memory4___rule,
  /*  220 */  _LoadB_indirect__rule,
  /*  221 */  _LoadUB_indirect__rule,
  /*  222 */  _LoadUS_indirect__rule,
  /*  223 */  _LoadS_indirect__rule,
  /*  224 */  _LoadI_indirect__rule,
  /*  225 */  _ConvI2L__LoadI_indirect___rule,
  /*  226 */  _LoadL_memory8__rule,
  /*  227 */  _CastP2X_iRegP__rule,
  /*  228 */  _CastP2X__DecodeN_iRegN___rule,
  /*  229 */  _Binary_iRegP_iRegP_rule,
  /*  230 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  231 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  232 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  233 */  _Binary_iRegI_iRegI_rule,
  /*  234 */  _Binary_iRegL_iRegL_rule,
  /*  235 */  _Binary_iRegN_iRegN_rule,
  /*  236 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  237 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  238 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  239 */  _Binary_immI0_iRegIorL2I_rule,
  /*  240 */  _Binary_iRegIorL2I_immI0_rule,
  /*  241 */  _Binary_immI_1_immI0_rule,
  /*  242 */  _Binary_iRegL_immL0_rule,
  /*  243 */  _Binary_immL0_iRegL_rule,
  /*  244 */  _Binary_iRegP_immP0_rule,
  /*  245 */  _Binary_immP0_iRegP_rule,
  /*  246 */  _Binary_iRegN_immN0_rule,
  /*  247 */  _Binary_immN0_iRegN_rule,
  /*  248 */  _Binary_vRegF_vRegF_rule,
  /*  249 */  _Binary_vRegD_vRegD_rule,
  /*  250 */  _ConvL2I_iRegL__rule,
  /*  251 */  _ConvI2L_iRegIorL2I__rule,
  /*  252 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  253 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  254 */  _SubI_immI0_iRegIorL2I_rule,
  /*  255 */  _MulL_iRegL_iRegL_rule,
  /*  256 */  _SubL_immL0_iRegL_rule,
  /*  257 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  258 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  259 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  260 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  261 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  262 */  _URShiftL_iRegL_immI_rule,
  /*  263 */  _RShiftL_iRegL_immI_rule,
  /*  264 */  _LShiftL_iRegL_immI_rule,
  /*  265 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  266 */  _XorL_iRegL_immL_M1_rule,
  /*  267 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  268 */  _XorL_iRegL_iRegL_rule,
  /*  269 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  270 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  271 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  272 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  273 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  274 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  275 */  _RotateRight_iRegL_immI_rule,
  /*  276 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  277 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  278 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  279 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  280 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  281 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  282 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /*  283 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  284 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /*  285 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /*  286 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /*  287 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  288 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /*  289 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /*  290 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /*  291 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  292 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /*  293 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /*  294 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /*  295 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /*  296 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  297 */  _AndL_iRegL_immL_bitmask_rule,
  /*  298 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /*  299 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  300 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /*  301 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /*  302 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /*  303 */  _AndI_iRegI_immI_bitmask_rule,
  /*  304 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  305 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  306 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  307 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  308 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  309 */  _LShiftL_iRegL_immI_48_rule,
  /*  310 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  311 */  _LShiftL_iRegL_immI_32_rule,
  /*  312 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  313 */  _LShiftL_iRegL_immI_56_rule,
  /*  314 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  315 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  316 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  317 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  318 */  _AndL_iRegL_immL_255_rule,
  /*  319 */  _AndL_iRegL_immL_65535_rule,
  /*  320 */  _AndL_iRegL_immL_4294967295_rule,
  /*  321 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /*  322 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /*  323 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /*  324 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /*  325 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /*  326 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /*  327 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /*  328 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /*  329 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /*  330 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /*  331 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /*  332 */  _NegF_vRegF__rule,
  /*  333 */  _Binary__NegF_vRegF__vRegF_rule,
  /*  334 */  _Binary_vRegF__NegF_vRegF__rule,
  /*  335 */  _NegD_vRegD__rule,
  /*  336 */  _Binary__NegD_vRegD__vRegD_rule,
  /*  337 */  _Binary_vRegD__NegD_vRegD__rule,
  /*  338 */  _SubF_vRegF_vRegF_rule,
  /*  339 */  _SubD_vRegD_vRegD_rule,
  /*  340 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /*  341 */  _OverflowMulL_iRegL_iRegL_rule,
  /*  342 */  _CmpI_iRegIorL2I_immI0_rule,
  /*  343 */  _CmpL_iRegL_immL0_rule,
  /*  344 */  _CmpP_iRegP_immP0_rule,
  /*  345 */  _CmpN_iRegN_immN0_rule,
  /*  346 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /*  347 */  _CmpU_iRegIorL2I_immI0_rule,
  /*  348 */  _CmpUL_iRegL_immL0_rule,
  /*  349 */  _AndL_iRegL_immL_rule,
  /*  350 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /*  351 */  _AndI_iRegIorL2I_immI_rule,
  /*  352 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /*  353 */  _AndL_iRegL_iRegL_rule,
  /*  354 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  355 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  356 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /*  357 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /*  358 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /*  359 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /*  360 */  _Binary_iRegP_R3_immI_le_4_rule,
  /*  361 */  _Binary_iRegP_R3_immI_1_rule,
  /*  362 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /*  363 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /*  364 */  _Binary_vecD_iRegIorL2I_rule,
  /*  365 */  _Binary_vecX_iRegIorL2I_rule,
  /*  366 */  _Binary_vecX_iRegL_rule,
  /*  367 */  _Binary_vecD_vRegF_rule,
  /*  368 */  _Binary_vecX_vRegF_rule,
  /*  369 */  _Binary_vecX_vRegD_rule,
  /*  370 */  _Binary_vecD_vecD_rule,
  /*  371 */  _Binary_vecX_vecX_rule,
  /*  372 */  _ReplicateB_immI_M1__rule,
  /*  373 */  _ReplicateS_immI_M1__rule,
  /*  374 */  _ReplicateI_immI_M1__rule,
  /*  375 */  _ReplicateL_immL_M1__rule,
  /*  376 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /*  377 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /*  378 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /*  379 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /*  380 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /*  381 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /*  382 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /*  383 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /*  384 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /*  385 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /*  386 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /*  387 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /*  388 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /*  389 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /*  390 */  _SubVF_vecD_vecD_rule,
  /*  391 */  _SubVF_vecX_vecX_rule,
  /*  392 */  _SubVD_vecX_vecX_rule,
  /*  393 */  _MulVS_vecD_vecD_rule,
  /*  394 */  _MulVS_vecX_vecX_rule,
  /*  395 */  _MulVI_vecD_vecD_rule,
  /*  396 */  _MulVI_vecX_vecX_rule,
  /*  397 */  _NegVF_vecD__rule,
  /*  398 */  _Binary__NegVF_vecD__vecD_rule,
  /*  399 */  _Binary_vecD__NegVF_vecD__rule,
  /*  400 */  _NegVF_vecX__rule,
  /*  401 */  _Binary__NegVF_vecX__vecX_rule,
  /*  402 */  _Binary_vecX__NegVF_vecX__rule,
  /*  403 */  _NegVD_vecX__rule,
  /*  404 */  _Binary__NegVD_vecX__vecX_rule,
  /*  405 */  _Binary_vecX__NegVD_vecX__rule,
  /*  406 */  _LShiftCntV_immI__rule,
  /*  407 */  _RShiftCntV_immI_positive__rule,
  /*  408 */  _RShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /*  409 */  _RShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /*  410 */  _RShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /*  411 */  _RShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /*  412 */  _RShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /*  413 */  _RShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /*  414 */  _RShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /*  415 */  _URShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /*  416 */  _URShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /*  417 */  _URShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /*  418 */  _URShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /*  419 */  _URShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /*  420 */  _URShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /*  421 */  _URShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /*  422 */  _Binary_vReg_pRegGov_rule,
  /*  423 */  _MaskAll_immI_M1__rule,
  /*  424 */  _XorVMask_pRegGov__MaskAll_immI_M1__rule,
  /*  425 */  _MaskAll_immL_M1__rule,
  /*  426 */  _XorVMask_pRegGov__MaskAll_immL_M1__rule,
  /*  427 */  _Binary_vReg_vReg_rule,
  /*  428 */  _ReplicateB_immBAddSubV__rule,
  /*  429 */  _ReplicateS_immIAddSubV__rule,
  /*  430 */  _ReplicateI_immIAddSubV__rule,
  /*  431 */  _ReplicateL_immLAddSubV__rule,
  /*  432 */  _ReplicateB_immBLog__rule,
  /*  433 */  _ReplicateS_immSLog__rule,
  /*  434 */  _ReplicateI_immILog__rule,
  /*  435 */  _ReplicateL_immLLog__rule,
  /*  436 */  _Binary_vReg__ReplicateB_immI_M1__rule,
  /*  437 */  _Binary_vReg__ReplicateS_immI_M1__rule,
  /*  438 */  _Binary_vReg__ReplicateI_immI_M1__rule,
  /*  439 */  _Binary_vReg__ReplicateL_immL_M1__rule,
  /*  440 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  441 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  442 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  443 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  444 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  445 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  446 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  447 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  448 */  _Binary_vReg__XorV_vReg__ReplicateB_immI_M1__rule,
  /*  449 */  _Binary_vReg__XorV__ReplicateB_immI_M1__vReg_rule,
  /*  450 */  _Binary_vReg__XorV_vReg__ReplicateS_immI_M1__rule,
  /*  451 */  _Binary_vReg__XorV__ReplicateS_immI_M1__vReg_rule,
  /*  452 */  _Binary_vReg__XorV_vReg__ReplicateI_immI_M1__rule,
  /*  453 */  _Binary_vReg__XorV__ReplicateI_immI_M1__vReg_rule,
  /*  454 */  _Binary_vReg__XorV_vReg__ReplicateL_immL_M1__rule,
  /*  455 */  _Binary_vReg__XorV__ReplicateL_immL_M1__vReg_rule,
  /*  456 */  _NegVF_vReg__rule,
  /*  457 */  _Binary__NegVF_vReg__vReg_rule,
  /*  458 */  _Binary_vReg__NegVF_vReg__rule,
  /*  459 */  _NegVD_vReg__rule,
  /*  460 */  _Binary__NegVD_vReg__vReg_rule,
  /*  461 */  _Binary_vReg__NegVD_vReg__rule,
  /*  462 */  _Binary__NegVF_vReg__pRegGov_rule,
  /*  463 */  _Binary__NegVD_vReg__pRegGov_rule,
  /*  464 */  _MulVB_vReg_vReg_rule,
  /*  465 */  _MulVS_vReg_vReg_rule,
  /*  466 */  _MulVI_vReg_vReg_rule,
  /*  467 */  _MulVL_vReg_vReg_rule,
  /*  468 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /*  469 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /*  470 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /*  471 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /*  472 */  _LoadVector_indirect__rule,
  /*  473 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /*  474 */  _Binary_iRegIorL2I_vReg_rule,
  /*  475 */  _Binary_iRegL_vReg_rule,
  /*  476 */  _Binary_vRegF_vReg_rule,
  /*  477 */  _Binary_vRegD_vReg_rule,
  /*  478 */  _RShiftCntV_immI__rule,
  /*  479 */  _Binary_vReg__RShiftCntV_immI__rule,
  /*  480 */  _Binary_vReg__LShiftCntV_immI__rule,
  /*  481 */  _Binary_vReg_iRegIorL2I_rule,
  /*  482 */  _Binary_vReg_iRegL_rule,
  /*  483 */  _Binary_vReg_vRegF_rule,
  /*  484 */  _Binary_vReg_vRegD_rule,
  /*  485 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /*  486 */  _Binary_immI_pRegGov_rule,
  // last internally defined operand
  /*  487 */  iRegINoSp_rule,
  /*  488 */  iRegLNoSp_rule,
  /*  489 */  iRegPNoSp_rule,
  /*  490 */  iRegPNoSp_rule,
  /*  491 */  iRegPNoSp_rule,
  /*  492 */  iRegPNoSp_rule,
  /*  493 */  iRegNNoSp_rule,
  /*  494 */  iRegNNoSp_rule,
  /*  495 */  iRegNNoSp_rule,
  /*  496 */  vRegF_rule,
  /*  497 */  vRegF_rule,
  /*  498 */  vRegD_rule,
  /*  499 */  vRegD_rule,
  /*  500 */  iRegINoSp_rule,
  /*  501 */  iRegINoSp_rule,
  /*  502 */  iRegINoSp_rule,
  /*  503 */  iRegINoSp_rule,
  /*  504 */  iRegPNoSp_rule,
  /*  505 */  iRegLNoSp_rule,
  /*  506 */  iRegPNoSp_rule,
  /*  507 */  iRegPNoSp_rule,
  /*  508 */  iRegI_rule,
  /*  509 */  iRegL_rule,
  /*  510 */  vRegF_rule,
  /*  511 */  vRegD_rule,
  /*  512 */  vecD_rule,
  /*  513 */  vecX_rule,
  /*  514 */  vReg_rule,
  /*  515 */  pRegGov_rule,
  /*  516 */  rFlagsReg_rule,
  /*  517 */  rFlagsReg_rule,
  /*  518 */  rFlagsReg_rule,
  /*  519 */  vRegF_rule,
  /*  520 */  vRegD_rule,
  /*  521 */  vRegF_rule,
  /*  522 */  vRegD_rule,
  /*  523 */  iRegINoSp_rule,
  /*  524 */  vRegF_rule,
  /*  525 */  iRegLNoSp_rule,
  /*  526 */  vRegD_rule,
  /*  527 */  iRegINoSp_rule,
  /*  528 */  vRegF_rule,
  /*  529 */  iRegLNoSp_rule,
  /*  530 */  vRegD_rule,
  /*  531 */  rFlagsReg_rule,
  /*  532 */  rFlagsReg_rule,
  /*  533 */  rFlagsReg_rule,
  /*  534 */  rFlagsReg_rule,
  /*  535 */  rFlagsReg_rule,
  /*  536 */  rFlagsReg_rule,
  /*  537 */  rFlagsReg_rule,
  /*  538 */  rFlagsReg_rule,
  /*  539 */  rFlagsReg_rule,
  /*  540 */  rFlagsReg_rule,
  /*  541 */  rFlagsReg_rule,
  /*  542 */  rFlagsReg_rule,
  /*  543 */  rFlagsReg_rule,
  /*  544 */  rFlagsReg_rule,
  /*  545 */  rFlagsReg_rule,
  /*  546 */  rFlagsReg_rule,
  /*  547 */  rFlagsRegU_rule,
  /*  548 */  rFlagsRegU_rule,
  /*  549 */  rFlagsRegU_rule,
  /*  550 */  rFlagsRegU_rule,
  /*  551 */  rFlagsReg_rule,
  /*  552 */  rFlagsReg_rule,
  /*  553 */  rFlagsReg_rule,
  /*  554 */  rFlagsReg_rule,
  /*  555 */  rFlagsRegU_rule,
  /*  556 */  rFlagsRegU_rule,
  /*  557 */  rFlagsRegU_rule,
  /*  558 */  rFlagsRegU_rule,
  /*  559 */  rFlagsRegU_rule,
  /*  560 */  rFlagsRegU_rule,
  /*  561 */  rFlagsRegU_rule,
  /*  562 */  rFlagsRegU_rule,
  /*  563 */  rFlagsReg_rule,
  /*  564 */  rFlagsReg_rule,
  /*  565 */  rFlagsReg_rule,
  /*  566 */  rFlagsReg_rule,
  /*  567 */  rFlagsReg_rule,
  /*  568 */  rFlagsReg_rule,
  /*  569 */  rFlagsReg_rule,
  /*  570 */  rFlagsReg_rule,
  /*  571 */  rFlagsReg_rule,
  /*  572 */  rFlagsReg_rule,
  /*  573 */  rFlagsReg_rule,
  /*  574 */  thread_RegP_rule,
  /*  575 */  vecD_rule,
  /*  576 */  vecX_rule,
  /*  577 */  vecX_rule,
  /*  578 */  vecD_rule,
  /*  579 */  vecX_rule,
  /*  580 */  vecD_rule,
  /*  581 */  vecD_rule,
  /*  582 */  vecD_rule,
  /*  583 */  vecX_rule,
  /*  584 */  vecD_rule,
  /*  585 */  vecD_rule,
  /*  586 */  vecD_rule,
  /*  587 */  vecX_rule,
  /*  588 */  vecD_rule,
  /*  589 */  vecX_rule,
  /*  590 */  vecD_rule,
  /*  591 */  vecD_rule,
  /*  592 */  vecX_rule,
  /*  593 */  vecD_rule,
  /*  594 */  vecX_rule,
  /*  595 */  vecX_rule,
  /*  596 */  vecX_rule,
  /*  597 */  vecX_rule,
  /*  598 */  vecX_rule,
  /*  599 */  vecX_rule,
  /*  600 */  vecD_rule,
  /*  601 */  vecX_rule,
  /*  602 */  vecX_rule,
  /*  603 */  vecD_rule,
  /*  604 */  vecD_rule,
  /*  605 */  vecX_rule,
  /*  606 */  vecD_rule,
  /*  607 */  vecD_rule,
  /*  608 */  vecX_rule,
  /*  609 */  vecD_rule,
  /*  610 */  vecX_rule,
  /*  611 */  vecD_rule,
  /*  612 */  vecX_rule,
  /*  613 */  vecX_rule,
  /*  614 */  vecD_rule,
  /*  615 */  vecX_rule,
  /*  616 */  vecD_rule,
  /*  617 */  vecX_rule,
  /*  618 */  vecD_rule,
  /*  619 */  vecX_rule,
  /*  620 */  vecD_rule,
  /*  621 */  vecX_rule,
  /*  622 */  vecX_rule,
  /*  623 */  vecD_rule,
  /*  624 */  vecX_rule,
  /*  625 */  vecD_rule,
  /*  626 */  vecX_rule,
  /*  627 */  vecD_rule,
  /*  628 */  vecX_rule,
  /*  629 */  vecX_rule,
  /*  630 */  vecD_rule,
  /*  631 */  vecX_rule,
  /*  632 */  vecX_rule,
  /*  633 */  vecD_rule,
  /*  634 */  vecX_rule,
  /*  635 */  vecX_rule,
  /*  636 */  vecD_rule,
  /*  637 */  vecX_rule,
  /*  638 */  vecX_rule,
  /*  639 */  vecD_rule,
  /*  640 */  vecX_rule,
  /*  641 */  vecX_rule,
  /*  642 */  vecD_rule,
  /*  643 */  vecX_rule,
  /*  644 */  vecD_rule,
  /*  645 */  vecX_rule,
  /*  646 */  vecD_rule,
  /*  647 */  vecX_rule,
  /*  648 */  vecD_rule,
  /*  649 */  vecX_rule,
  /*  650 */  iRegINoSp_rule,
  /*  651 */  iRegINoSp_rule,
  /*  652 */  iRegINoSp_rule,
  /*  653 */  iRegINoSp_rule,
  /*  654 */  iRegLNoSp_rule,
  /*  655 */  iRegLNoSp_rule,
  /*  656 */  vecD_rule,
  /*  657 */  vecX_rule,
  /*  658 */  vecD_rule,
  /*  659 */  vecX_rule,
  /*  660 */  vecD_rule,
  /*  661 */  vecX_rule,
  /*  662 */  vecD_rule,
  /*  663 */  vecX_rule,
  /*  664 */  vReg_rule,
  /*  665 */  pRegGov_rule,
  /*  666 */  vReg_rule,
  /*  667 */  vReg_rule,
  /*  668 */  vReg_rule,
  /*  669 */  vReg_rule,
  /*  670 */  vReg_rule,
  /*  671 */  vReg_rule,
  /*  672 */  vReg_rule,
  /*  673 */  vReg_rule,
  /*  674 */  vReg_rule,
  /*  675 */  vReg_rule,
  /*  676 */  vReg_rule,
  /*  677 */  vReg_rule,
  /*  678 */  vReg_rule,
  /*  679 */  vReg_rule,
  /*  680 */  vReg_rule,
  /*  681 */  vReg_rule,
  /*  682 */  vReg_rule,
  /*  683 */  vReg_rule,
  /*  684 */  vReg_rule,
  /*  685 */  vReg_rule,
  /*  686 */  vReg_rule,
  /*  687 */  vReg_rule,
  /*  688 */  pRegGov_rule,
  /*  689 */  pRegGov_rule,
  /*  690 */  pRegGov_rule,
  /*  691 */  vReg_rule,
  /*  692 */  vReg_rule,
  /*  693 */  vReg_rule,
  /*  694 */  vReg_rule,
  /*  695 */  vReg_rule,
  /*  696 */  vReg_rule,
  /*  697 */  vReg_rule,
  /*  698 */  vReg_rule,
  /*  699 */  vReg_rule,
  /*  700 */  vReg_rule,
  /*  701 */  vReg_rule,
  /*  702 */  vReg_rule,
  /*  703 */  iRegINoSp_rule,
  /*  704 */  vReg_rule,
  /*  705 */  vReg_rule,
  /*  706 */  vReg_rule,
  /*  707 */  vReg_rule,
  /*  708 */  iRegINoSp_rule,
  /*  709 */  iRegLNoSp_rule,
  /*  710 */  iRegINoSp_rule,
  /*  711 */  iRegLNoSp_rule,
  /*  712 */  iRegINoSp_rule,
  /*  713 */  iRegLNoSp_rule,
  /*  714 */  iRegINoSp_rule,
  /*  715 */  iRegLNoSp_rule,
  /*  716 */  iRegINoSp_rule,
  /*  717 */  iRegLNoSp_rule,
  /*  718 */  iRegLNoSp_rule,
  /*  719 */  iRegLNoSp_rule,
  /*  720 */  iRegINoSp_rule,
  /*  721 */  iRegPNoSp_rule,
  /*  722 */  iRegNNoSp_rule,
  /*  723 */  iRegPNoSp_rule,
  /*  724 */  iRegNNoSp_rule,
  /*  725 */  vRegF_rule,
  /*  726 */  vRegD_rule,
  /*  727 */  Universe_rule,
  /*  728 */  Universe_rule,
  /*  729 */  Universe_rule,
  /*  730 */  Universe_rule,
  /*  731 */  Universe_rule,
  /*  732 */  Universe_rule,
  /*  733 */  Universe_rule,
  /*  734 */  Universe_rule,
  /*  735 */  Universe_rule,
  /*  736 */  Universe_rule,
  /*  737 */  Universe_rule,
  /*  738 */  Universe_rule,
  /*  739 */  Universe_rule,
  /*  740 */  Universe_rule,
  /*  741 */  Universe_rule,
  /*  742 */  Universe_rule,
  /*  743 */  Universe_rule,
  /*  744 */  Universe_rule,
  /*  745 */  iRegINoSp_rule,
  /*  746 */  iRegLNoSp_rule,
  /*  747 */  iRegINoSp_rule,
  /*  748 */  iRegLNoSp_rule,
  /*  749 */  iRegINoSp_rule,
  /*  750 */  iRegINoSp_rule,
  /*  751 */  iRegLNoSp_rule,
  /*  752 */  iRegLNoSp_rule,
  /*  753 */  iRegINoSp_rule,
  /*  754 */  iRegLNoSp_rule,
  /*  755 */  iRegLNoSp_rule,
  /*  756 */  iRegPNoSp_rule,
  /*  757 */  iRegNNoSp_rule,
  /*  758 */  vRegF_rule,
  /*  759 */  vRegD_rule,
  /*  760 */  Universe_rule,
  /*  761 */  Universe_rule,
  /*  762 */  Universe_rule,
  /*  763 */  Universe_rule,
  /*  764 */  Universe_rule,
  /*  765 */  Universe_rule,
  /*  766 */  Universe_rule,
  /*  767 */  Universe_rule,
  /*  768 */  Universe_rule,
  /*  769 */  Universe_rule,
  /*  770 */  Universe_rule,
  /*  771 */  Universe_rule,
  /*  772 */  Universe_rule,
  /*  773 */  Universe_rule,
  /*  774 */  Universe_rule,
  /*  775 */  Universe_rule,
  /*  776 */  Universe_rule,
  /*  777 */  iRegINoSp_rule,
  /*  778 */  iRegLNoSp_rule,
  /*  779 */  iRegINoSp_rule,
  /*  780 */  iRegINoSp_rule,
  /*  781 */  iRegINoSp_rule,
  /*  782 */  iRegINoSp_rule,
  /*  783 */  iRegINoSp_rule,
  /*  784 */  iRegINoSp_rule,
  /*  785 */  Universe_rule,
  /*  786 */  Universe_rule,
  /*  787 */  Universe_rule,
  /*  788 */  Universe_rule,
  /*  789 */  Universe_rule,
  /*  790 */  Universe_rule,
  /*  791 */  Universe_rule,
  /*  792 */  Universe_rule,
  /*  793 */  Universe_rule,
  /*  794 */  Universe_rule,
  /*  795 */  Universe_rule,
  /*  796 */  Universe_rule,
  /*  797 */  iRegINoSp_rule,
  /*  798 */  iRegINoSp_rule,
  /*  799 */  iRegNNoSp_rule,
  /*  800 */  iRegNNoSp_rule,
  /*  801 */  iRegPNoSp_rule,
  /*  802 */  iRegPNoSp_rule,
  /*  803 */  iRegNNoSp_rule,
  /*  804 */  iRegPNoSp_rule,
  /*  805 */  iRegPNoSp_rule,
  /*  806 */  iRegINoSp_rule,
  /*  807 */  iRegINoSp_rule,
  /*  808 */  iRegINoSp_rule,
  /*  809 */  iRegINoSp_rule,
  /*  810 */  iRegINoSp_rule,
  /*  811 */  iRegINoSp_rule,
  /*  812 */  iRegINoSp_rule,
  /*  813 */  iRegINoSp_rule,
  /*  814 */  iRegINoSp_rule,
  /*  815 */  iRegINoSp_rule,
  /*  816 */  iRegINoSp_rule,
  /*  817 */  iRegINoSp_rule,
  /*  818 */  iRegINoSp_rule,
  /*  819 */  iRegINoSp_rule,
  /*  820 */  iRegINoSp_rule,
  /*  821 */  iRegLNoSp_rule,
  /*  822 */  iRegNNoSp_rule,
  /*  823 */  iRegPNoSp_rule,
  /*  824 */  iRegINoSp_rule,
  /*  825 */  iRegINoSp_rule,
  /*  826 */  iRegINoSp_rule,
  /*  827 */  iRegLNoSp_rule,
  /*  828 */  iRegNNoSp_rule,
  /*  829 */  iRegPNoSp_rule,
  /*  830 */  iRegINoSp_rule,
  /*  831 */  iRegINoSp_rule,
  /*  832 */  iRegINoSp_rule,
  /*  833 */  iRegINoSp_rule,
  /*  834 */  iRegINoSp_rule,
  /*  835 */  iRegINoSp_rule,
  /*  836 */  iRegINoSp_rule,
  /*  837 */  iRegINoSp_rule,
  /*  838 */  iRegINoSp_rule,
  /*  839 */  iRegINoSp_rule,
  /*  840 */  iRegINoSp_rule,
  /*  841 */  iRegINoSp_rule,
  /*  842 */  iRegINoSp_rule,
  /*  843 */  iRegLNoSp_rule,
  /*  844 */  iRegINoSp_rule,
  /*  845 */  iRegPNoSp_rule,
  /*  846 */  iRegINoSp_rule,
  /*  847 */  iRegLNoSp_rule,
  /*  848 */  iRegINoSp_rule,
  /*  849 */  iRegPNoSp_rule,
  /*  850 */  iRegLNoSp_rule,
  /*  851 */  Universe_rule,
  /*  852 */  iRegLNoSp_rule,
  /*  853 */  Universe_rule,
  /*  854 */  iRegINoSp_rule,
  /*  855 */  Universe_rule,
  /*  856 */  iRegINoSp_rule,
  /*  857 */  Universe_rule,
  /*  858 */  iRegLNoSp_rule,
  /*  859 */  Universe_rule,
  /*  860 */  iRegLNoSp_rule,
  /*  861 */  Universe_rule,
  /*  862 */  iRegINoSp_rule,
  /*  863 */  Universe_rule,
  /*  864 */  iRegINoSp_rule,
  /*  865 */  Universe_rule,
  /*  866 */  iRegINoSp_rule,
  /*  867 */  iRegINoSp_rule,
  /*  868 */  iRegINoSp_rule,
  /*  869 */  iRegINoSp_rule,
  /*  870 */  iRegINoSp_rule,
  /*  871 */  iRegINoSp_rule,
  /*  872 */  iRegINoSp_rule,
  /*  873 */  iRegINoSp_rule,
  /*  874 */  iRegINoSp_rule,
  /*  875 */  iRegINoSp_rule,
  /*  876 */  iRegLNoSp_rule,
  /*  877 */  iRegLNoSp_rule,
  /*  878 */  iRegLNoSp_rule,
  /*  879 */  iRegLNoSp_rule,
  /*  880 */  iRegLNoSp_rule,
  /*  881 */  iRegLNoSp_rule,
  /*  882 */  iRegPNoSp_rule,
  /*  883 */  iRegPNoSp_rule,
  /*  884 */  iRegPNoSp_rule,
  /*  885 */  iRegPNoSp_rule,
  /*  886 */  iRegPNoSp_rule,
  /*  887 */  iRegPNoSp_rule,
  /*  888 */  iRegNNoSp_rule,
  /*  889 */  iRegNNoSp_rule,
  /*  890 */  iRegNNoSp_rule,
  /*  891 */  iRegNNoSp_rule,
  /*  892 */  iRegNNoSp_rule,
  /*  893 */  iRegNNoSp_rule,
  /*  894 */  vRegF_rule,
  /*  895 */  vRegF_rule,
  /*  896 */  vRegD_rule,
  /*  897 */  vRegD_rule,
  /*  898 */  iRegINoSp_rule,
  /*  899 */  iRegINoSp_rule,
  /*  900 */  iRegINoSp_rule,
  /*  901 */  iRegPNoSp_rule,
  /*  902 */  iRegPNoSp_rule,
  /*  903 */  iRegPNoSp_rule,
  /*  904 */  iRegPNoSp_rule,
  /*  905 */  iRegLNoSp_rule,
  /*  906 */  iRegPNoSp_rule,
  /*  907 */  iRegLNoSp_rule,
  /*  908 */  iRegLNoSp_rule,
  /*  909 */  iRegINoSp_rule,
  /*  910 */  iRegINoSp_rule,
  /*  911 */  iRegLNoSp_rule,
  /*  912 */  iRegLNoSp_rule,
  /*  913 */  iRegINoSp_rule,
  /*  914 */  iRegLNoSp_rule,
  /*  915 */  iRegINoSp_rule,
  /*  916 */  iRegLNoSp_rule,
  /*  917 */  iRegLNoSp_rule,
  /*  918 */  iRegLNoSp_rule,
  /*  919 */  iRegLNoSp_rule,
  /*  920 */  iRegLNoSp_rule,
  /*  921 */  iRegINoSp_rule,
  /*  922 */  iRegINoSp_rule,
  /*  923 */  iRegINoSp_rule,
  /*  924 */  iRegINoSp_rule,
  /*  925 */  iRegINoSp_rule,
  /*  926 */  iRegLNoSp_rule,
  /*  927 */  iRegLNoSp_rule,
  /*  928 */  iRegLNoSp_rule,
  /*  929 */  iRegLNoSp_rule,
  /*  930 */  iRegLNoSp_rule,
  /*  931 */  iRegLNoSp_rule,
  /*  932 */  iRegLNoSp_rule,
  /*  933 */  iRegLNoSp_rule,
  /*  934 */  iRegLNoSp_rule,
  /*  935 */  iRegLNoSp_rule,
  /*  936 */  iRegLNoSp_rule,
  /*  937 */  iRegLNoSp_rule,
  /*  938 */  iRegLNoSp_rule,
  /*  939 */  iRegINoSp_rule,
  /*  940 */  iRegINoSp_rule,
  /*  941 */  iRegLNoSp_rule,
  /*  942 */  iRegINoSp_rule,
  /*  943 */  iRegLNoSp_rule,
  /*  944 */  iRegINoSp_rule,
  /*  945 */  iRegINoSp_rule,
  /*  946 */  iRegINoSp_rule,
  /*  947 */  iRegINoSp_rule,
  /*  948 */  iRegINoSp_rule,
  /*  949 */  iRegINoSp_rule,
  /*  950 */  iRegLNoSp_rule,
  /*  951 */  iRegLNoSp_rule,
  /*  952 */  iRegLNoSp_rule,
  /*  953 */  iRegLNoSp_rule,
  /*  954 */  iRegLNoSp_rule,
  /*  955 */  iRegLNoSp_rule,
  /*  956 */  iRegLNoSp_rule,
  /*  957 */  iRegLNoSp_rule,
  /*  958 */  iRegINoSp_rule,
  /*  959 */  iRegINoSp_rule,
  /*  960 */  iRegINoSp_rule,
  /*  961 */  iRegINoSp_rule,
  /*  962 */  iRegLNoSp_rule,
  /*  963 */  iRegLNoSp_rule,
  /*  964 */  iRegLNoSp_rule,
  /*  965 */  iRegINoSp_rule,
  /*  966 */  iRegINoSp_rule,
  /*  967 */  iRegLNoSp_rule,
  /*  968 */  iRegLNoSp_rule,
  /*  969 */  iRegINoSp_rule,
  /*  970 */  iRegINoSp_rule,
  /*  971 */  iRegLNoSp_rule,
  /*  972 */  iRegLNoSp_rule,
  /*  973 */  iRegINoSp_rule,
  /*  974 */  iRegINoSp_rule,
  /*  975 */  iRegLNoSp_rule,
  /*  976 */  iRegLNoSp_rule,
  /*  977 */  iRegINoSp_rule,
  /*  978 */  iRegINoSp_rule,
  /*  979 */  iRegLNoSp_rule,
  /*  980 */  iRegLNoSp_rule,
  /*  981 */  iRegINoSp_rule,
  /*  982 */  iRegINoSp_rule,
  /*  983 */  iRegLNoSp_rule,
  /*  984 */  iRegLNoSp_rule,
  /*  985 */  iRegINoSp_rule,
  /*  986 */  iRegINoSp_rule,
  /*  987 */  iRegLNoSp_rule,
  /*  988 */  iRegLNoSp_rule,
  /*  989 */  iRegINoSp_rule,
  /*  990 */  iRegINoSp_rule,
  /*  991 */  iRegLNoSp_rule,
  /*  992 */  iRegLNoSp_rule,
  /*  993 */  iRegINoSp_rule,
  /*  994 */  iRegINoSp_rule,
  /*  995 */  iRegINoSp_rule,
  /*  996 */  iRegINoSp_rule,
  /*  997 */  iRegLNoSp_rule,
  /*  998 */  iRegLNoSp_rule,
  /*  999 */  iRegLNoSp_rule,
  /* 1000 */  iRegLNoSp_rule,
  /* 1001 */  iRegINoSp_rule,
  /* 1002 */  iRegINoSp_rule,
  /* 1003 */  iRegINoSp_rule,
  /* 1004 */  iRegINoSp_rule,
  /* 1005 */  iRegLNoSp_rule,
  /* 1006 */  iRegLNoSp_rule,
  /* 1007 */  iRegLNoSp_rule,
  /* 1008 */  iRegLNoSp_rule,
  /* 1009 */  iRegINoSp_rule,
  /* 1010 */  iRegINoSp_rule,
  /* 1011 */  iRegINoSp_rule,
  /* 1012 */  iRegINoSp_rule,
  /* 1013 */  iRegLNoSp_rule,
  /* 1014 */  iRegLNoSp_rule,
  /* 1015 */  iRegLNoSp_rule,
  /* 1016 */  iRegLNoSp_rule,
  /* 1017 */  iRegINoSp_rule,
  /* 1018 */  iRegINoSp_rule,
  /* 1019 */  iRegINoSp_rule,
  /* 1020 */  iRegINoSp_rule,
  /* 1021 */  iRegLNoSp_rule,
  /* 1022 */  iRegLNoSp_rule,
  /* 1023 */  iRegLNoSp_rule,
  /* 1024 */  iRegLNoSp_rule,
  /* 1025 */  iRegINoSp_rule,
  /* 1026 */  iRegINoSp_rule,
  /* 1027 */  iRegLNoSp_rule,
  /* 1028 */  iRegLNoSp_rule,
  /* 1029 */  iRegINoSp_rule,
  /* 1030 */  iRegINoSp_rule,
  /* 1031 */  iRegLNoSp_rule,
  /* 1032 */  iRegLNoSp_rule,
  /* 1033 */  iRegINoSp_rule,
  /* 1034 */  iRegINoSp_rule,
  /* 1035 */  iRegLNoSp_rule,
  /* 1036 */  iRegLNoSp_rule,
  /* 1037 */  iRegINoSp_rule,
  /* 1038 */  iRegINoSp_rule,
  /* 1039 */  iRegLNoSp_rule,
  /* 1040 */  iRegLNoSp_rule,
  /* 1041 */  iRegINoSp_rule,
  /* 1042 */  iRegINoSp_rule,
  /* 1043 */  iRegLNoSp_rule,
  /* 1044 */  iRegLNoSp_rule,
  /* 1045 */  iRegINoSp_rule,
  /* 1046 */  iRegINoSp_rule,
  /* 1047 */  iRegLNoSp_rule,
  /* 1048 */  iRegLNoSp_rule,
  /* 1049 */  iRegINoSp_rule,
  /* 1050 */  iRegINoSp_rule,
  /* 1051 */  iRegLNoSp_rule,
  /* 1052 */  iRegLNoSp_rule,
  /* 1053 */  iRegINoSp_rule,
  /* 1054 */  iRegINoSp_rule,
  /* 1055 */  iRegLNoSp_rule,
  /* 1056 */  iRegLNoSp_rule,
  /* 1057 */  iRegINoSp_rule,
  /* 1058 */  iRegINoSp_rule,
  /* 1059 */  iRegLNoSp_rule,
  /* 1060 */  iRegLNoSp_rule,
  /* 1061 */  iRegINoSp_rule,
  /* 1062 */  iRegINoSp_rule,
  /* 1063 */  iRegLNoSp_rule,
  /* 1064 */  iRegLNoSp_rule,
  /* 1065 */  iRegINoSp_rule,
  /* 1066 */  iRegINoSp_rule,
  /* 1067 */  iRegLNoSp_rule,
  /* 1068 */  iRegLNoSp_rule,
  /* 1069 */  iRegINoSp_rule,
  /* 1070 */  iRegINoSp_rule,
  /* 1071 */  iRegLNoSp_rule,
  /* 1072 */  iRegLNoSp_rule,
  /* 1073 */  iRegINoSp_rule,
  /* 1074 */  iRegINoSp_rule,
  /* 1075 */  iRegLNoSp_rule,
  /* 1076 */  iRegLNoSp_rule,
  /* 1077 */  iRegINoSp_rule,
  /* 1078 */  iRegINoSp_rule,
  /* 1079 */  iRegLNoSp_rule,
  /* 1080 */  iRegLNoSp_rule,
  /* 1081 */  iRegINoSp_rule,
  /* 1082 */  iRegINoSp_rule,
  /* 1083 */  iRegLNoSp_rule,
  /* 1084 */  iRegLNoSp_rule,
  /* 1085 */  iRegINoSp_rule,
  /* 1086 */  iRegINoSp_rule,
  /* 1087 */  iRegLNoSp_rule,
  /* 1088 */  iRegLNoSp_rule,
  /* 1089 */  iRegINoSp_rule,
  /* 1090 */  iRegINoSp_rule,
  /* 1091 */  iRegLNoSp_rule,
  /* 1092 */  iRegLNoSp_rule,
  /* 1093 */  iRegINoSp_rule,
  /* 1094 */  iRegINoSp_rule,
  /* 1095 */  iRegLNoSp_rule,
  /* 1096 */  iRegLNoSp_rule,
  /* 1097 */  iRegINoSp_rule,
  /* 1098 */  iRegINoSp_rule,
  /* 1099 */  iRegLNoSp_rule,
  /* 1100 */  iRegLNoSp_rule,
  /* 1101 */  iRegINoSp_rule,
  /* 1102 */  iRegLNoSp_rule,
  /* 1103 */  iRegINoSp_rule,
  /* 1104 */  iRegLNoSp_rule,
  /* 1105 */  iRegINoSp_rule,
  /* 1106 */  iRegLNoSp_rule,
  /* 1107 */  iRegLNoSp_rule,
  /* 1108 */  iRegINoSp_rule,
  /* 1109 */  iRegLNoSp_rule,
  /* 1110 */  iRegINoSp_rule,
  /* 1111 */  iRegINoSp_rule,
  /* 1112 */  iRegLNoSp_rule,
  /* 1113 */  iRegLNoSp_rule,
  /* 1114 */  iRegINoSp_rule,
  /* 1115 */  iRegLNoSp_rule,
  /* 1116 */  iRegLNoSp_rule,
  /* 1117 */  iRegINoSp_rule,
  /* 1118 */  iRegLNoSp_rule,
  /* 1119 */  iRegINoSp_rule,
  /* 1120 */  iRegLNoSp_rule,
  /* 1121 */  iRegLNoSp_rule,
  /* 1122 */  iRegLNoSp_rule,
  /* 1123 */  iRegINoSp_rule,
  /* 1124 */  iRegINoSp_rule,
  /* 1125 */  iRegLNoSp_rule,
  /* 1126 */  iRegLNoSp_rule,
  /* 1127 */  iRegINoSp_rule,
  /* 1128 */  iRegINoSp_rule,
  /* 1129 */  iRegINoSp_rule,
  /* 1130 */  iRegLNoSp_rule,
  /* 1131 */  iRegINoSp_rule,
  /* 1132 */  iRegLNoSp_rule,
  /* 1133 */  iRegINoSp_rule,
  /* 1134 */  iRegLNoSp_rule,
  /* 1135 */  iRegLNoSp_rule,
  /* 1136 */  iRegLNoSp_rule,
  /* 1137 */  iRegLNoSp_rule,
  /* 1138 */  iRegINoSp_rule,
  /* 1139 */  iRegINoSp_rule,
  /* 1140 */  iRegINoSp_rule,
  /* 1141 */  iRegINoSp_rule,
  /* 1142 */  iRegINoSp_rule,
  /* 1143 */  iRegINoSp_rule,
  /* 1144 */  iRegLNoSp_rule,
  /* 1145 */  iRegLNoSp_rule,
  /* 1146 */  iRegLNoSp_rule,
  /* 1147 */  iRegLNoSp_rule,
  /* 1148 */  iRegLNoSp_rule,
  /* 1149 */  iRegLNoSp_rule,
  /* 1150 */  iRegLNoSp_rule,
  /* 1151 */  iRegLNoSp_rule,
  /* 1152 */  iRegINoSp_rule,
  /* 1153 */  iRegINoSp_rule,
  /* 1154 */  iRegINoSp_rule,
  /* 1155 */  iRegINoSp_rule,
  /* 1156 */  iRegLNoSp_rule,
  /* 1157 */  iRegLNoSp_rule,
  /* 1158 */  iRegLNoSp_rule,
  /* 1159 */  iRegLNoSp_rule,
  /* 1160 */  iRegLNoSp_rule,
  /* 1161 */  iRegLNoSp_rule,
  /* 1162 */  iRegINoSp_rule,
  /* 1163 */  iRegINoSp_rule,
  /* 1164 */  iRegLNoSp_rule,
  /* 1165 */  iRegLNoSp_rule,
  /* 1166 */  iRegLNoSp_rule,
  /* 1167 */  iRegLNoSp_rule,
  /* 1168 */  iRegLNoSp_rule,
  /* 1169 */  iRegLNoSp_rule,
  /* 1170 */  iRegLNoSp_rule,
  /* 1171 */  iRegLNoSp_rule,
  /* 1172 */  iRegLNoSp_rule,
  /* 1173 */  iRegLNoSp_rule,
  /* 1174 */  iRegLNoSp_rule,
  /* 1175 */  iRegLNoSp_rule,
  /* 1176 */  iRegINoSp_rule,
  /* 1177 */  iRegINoSp_rule,
  /* 1178 */  iRegINoSp_rule,
  /* 1179 */  iRegINoSp_rule,
  /* 1180 */  iRegINoSp_rule,
  /* 1181 */  iRegINoSp_rule,
  /* 1182 */  iRegLNoSp_rule,
  /* 1183 */  iRegLNoSp_rule,
  /* 1184 */  iRegLNoSp_rule,
  /* 1185 */  iRegLNoSp_rule,
  /* 1186 */  iRegLNoSp_rule,
  /* 1187 */  iRegLNoSp_rule,
  /* 1188 */  iRegLNoSp_rule,
  /* 1189 */  iRegLNoSp_rule,
  /* 1190 */  iRegLNoSp_rule,
  /* 1191 */  iRegLNoSp_rule,
  /* 1192 */  iRegLNoSp_rule,
  /* 1193 */  iRegLNoSp_rule,
  /* 1194 */  iRegINoSp_rule,
  /* 1195 */  iRegINoSp_rule,
  /* 1196 */  iRegINoSp_rule,
  /* 1197 */  iRegINoSp_rule,
  /* 1198 */  iRegINoSp_rule,
  /* 1199 */  iRegINoSp_rule,
  /* 1200 */  vRegF_rule,
  /* 1201 */  vRegD_rule,
  /* 1202 */  vRegF_rule,
  /* 1203 */  vRegD_rule,
  /* 1204 */  vRegF_rule,
  /* 1205 */  vRegD_rule,
  /* 1206 */  vRegF_rule,
  /* 1207 */  vRegD_rule,
  /* 1208 */  vRegF_rule,
  /* 1209 */  vRegF_rule,
  /* 1210 */  vRegD_rule,
  /* 1211 */  vRegD_rule,
  /* 1212 */  vRegF_rule,
  /* 1213 */  vRegF_rule,
  /* 1214 */  vRegD_rule,
  /* 1215 */  vRegD_rule,
  /* 1216 */  vRegF_rule,
  /* 1217 */  vRegD_rule,
  /* 1218 */  vRegF_rule,
  /* 1219 */  vRegF_rule,
  /* 1220 */  vRegD_rule,
  /* 1221 */  vRegD_rule,
  /* 1222 */  vRegF_rule,
  /* 1223 */  vRegD_rule,
  /* 1224 */  iRegINoSp_rule,
  /* 1225 */  iRegLNoSp_rule,
  /* 1226 */  vRegF_rule,
  /* 1227 */  vRegD_rule,
  /* 1228 */  vRegD_rule,
  /* 1229 */  vRegF_rule,
  /* 1230 */  vRegD_rule,
  /* 1231 */  vRegD_rule,
  /* 1232 */  vRegF_rule,
  /* 1233 */  vRegD_rule,
  /* 1234 */  vRegF_rule,
  /* 1235 */  Universe_rule,
  /* 1236 */  iRegINoSp_rule,
  /* 1237 */  iRegINoSp_rule,
  /* 1238 */  iRegINoSp_rule,
  /* 1239 */  iRegINoSp_rule,
  /* 1240 */  iRegINoSp_rule,
  /* 1241 */  iRegINoSp_rule,
  /* 1242 */  iRegLNoSp_rule,
  /* 1243 */  iRegLNoSp_rule,
  /* 1244 */  iRegLNoSp_rule,
  /* 1245 */  iRegLNoSp_rule,
  /* 1246 */  iRegLNoSp_rule,
  /* 1247 */  iRegLNoSp_rule,
  /* 1248 */  iRegLNoSp_rule,
  /* 1249 */  iRegLNoSp_rule,
  /* 1250 */  iRegINoSp_rule,
  /* 1251 */  iRegINoSp_rule,
  /* 1252 */  iRegINoSp_rule,
  /* 1253 */  vRegF_rule,
  /* 1254 */  vRegD_rule,
  /* 1255 */  iRegINoSp_rule,
  /* 1256 */  iRegLNoSp_rule,
  /* 1257 */  vRegF_rule,
  /* 1258 */  vRegF_rule,
  /* 1259 */  iRegINoSp_rule,
  /* 1260 */  iRegLNoSp_rule,
  /* 1261 */  vRegD_rule,
  /* 1262 */  vRegD_rule,
  /* 1263 */  iRegLNoSp_rule,
  /* 1264 */  iRegINoSp_rule,
  /* 1265 */  stackSlotI_rule,
  /* 1266 */  stackSlotF_rule,
  /* 1267 */  stackSlotL_rule,
  /* 1268 */  stackSlotD_rule,
  /* 1269 */  Universe_rule,
  /* 1270 */  Universe_rule,
  /* 1271 */  Universe_rule,
  /* 1272 */  Universe_rule,
  /* 1273 */  iRegINoSp_rule,
  /* 1274 */  iRegINoSp_rule,
  /* 1275 */  iRegINoSp_rule,
  /* 1276 */  iRegINoSp_rule,
  /* 1277 */  iRegINoSp_rule,
  /* 1278 */  iRegINoSp_rule,
  /* 1279 */  0,
  /* 1280 */  iRegINoSp_rule,
  /* 1281 */  0,
  /* 1282 */  iRegINoSp_rule,
  /* 1283 */  Universe_rule,
  /* 1284 */  Universe_rule,
  /* 1285 */  Universe_rule,
  /* 1286 */  Universe_rule,
  /* 1287 */  Universe_rule,
  /* 1288 */  Universe_rule,
  /* 1289 */  Universe_rule,
  /* 1290 */  Universe_rule,
  /* 1291 */  Universe_rule,
  /* 1292 */  Universe_rule,
  /* 1293 */  Universe_rule,
  /* 1294 */  Universe_rule,
  /* 1295 */  Universe_rule,
  /* 1296 */  Universe_rule,
  /* 1297 */  Universe_rule,
  /* 1298 */  Universe_rule,
  /* 1299 */  Universe_rule,
  /* 1300 */  Universe_rule,
  /* 1301 */  Universe_rule,
  /* 1302 */  Universe_rule,
  /* 1303 */  Universe_rule,
  /* 1304 */  Universe_rule,
  /* 1305 */  Universe_rule,
  /* 1306 */  Universe_rule,
  /* 1307 */  Universe_rule,
  /* 1308 */  Universe_rule,
  /* 1309 */  Universe_rule,
  /* 1310 */  Universe_rule,
  /* 1311 */  iRegP_R0_rule,
  /* 1312 */  Universe_rule,
  /* 1313 */  Universe_rule,
  /* 1314 */  Universe_rule,
  /* 1315 */  iRegP_R5_rule,
  /* 1316 */  iRegI_R0_rule,
  /* 1317 */  iRegI_R0_rule,
  /* 1318 */  iRegI_R0_rule,
  /* 1319 */  iRegI_R0_rule,
  /* 1320 */  iRegI_R0_rule,
  /* 1321 */  iRegI_R0_rule,
  /* 1322 */  iRegI_R0_rule,
  /* 1323 */  iRegI_R0_rule,
  /* 1324 */  iRegI_R0_rule,
  /* 1325 */  iRegI_R0_rule,
  /* 1326 */  iRegI_R0_rule,
  /* 1327 */  iRegI_R0_rule,
  /* 1328 */  iRegI_R0_rule,
  /* 1329 */  iRegI_R0_rule,
  /* 1330 */  iRegI_R0_rule,
  /* 1331 */  iRegI_R0_rule,
  /* 1332 */  iRegI_R0_rule,
  /* 1333 */  iRegI_R0_rule,
  /* 1334 */  Universe_rule,
  /* 1335 */  iRegI_R0_rule,
  /* 1336 */  iRegI_R0_rule,
  /* 1337 */  vecD_rule,
  /* 1338 */  vecD_rule,
  /* 1339 */  vecD_rule,
  /* 1340 */  vecX_rule,
  /* 1341 */  Universe_rule,
  /* 1342 */  Universe_rule,
  /* 1343 */  Universe_rule,
  /* 1344 */  Universe_rule,
  /* 1345 */  vecD_rule,
  /* 1346 */  vecD_rule,
  /* 1347 */  vecD_rule,
  /* 1348 */  vecX_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  iRegINoSp_rule,
  /* 1351 */  iRegINoSp_rule,
  /* 1352 */  iRegINoSp_rule,
  /* 1353 */  iRegINoSp_rule,
  /* 1354 */  iRegLNoSp_rule,
  /* 1355 */  iRegINoSp_rule,
  /* 1356 */  iRegINoSp_rule,
  /* 1357 */  iRegINoSp_rule,
  /* 1358 */  iRegINoSp_rule,
  /* 1359 */  iRegLNoSp_rule,
  /* 1360 */  iRegINoSp_rule,
  /* 1361 */  iRegINoSp_rule,
  /* 1362 */  iRegINoSp_rule,
  /* 1363 */  iRegINoSp_rule,
  /* 1364 */  iRegINoSp_rule,
  /* 1365 */  iRegINoSp_rule,
  /* 1366 */  iRegINoSp_rule,
  /* 1367 */  iRegINoSp_rule,
  /* 1368 */  iRegINoSp_rule,
  /* 1369 */  iRegINoSp_rule,
  /* 1370 */  iRegINoSp_rule,
  /* 1371 */  iRegINoSp_rule,
  /* 1372 */  iRegLNoSp_rule,
  /* 1373 */  iRegLNoSp_rule,
  /* 1374 */  vRegF_rule,
  /* 1375 */  vRegF_rule,
  /* 1376 */  vRegD_rule,
  /* 1377 */  vRegF_rule,
  /* 1378 */  vRegF_rule,
  /* 1379 */  vRegD_rule,
  /* 1380 */  iRegINoSp_rule,
  /* 1381 */  iRegINoSp_rule,
  /* 1382 */  iRegINoSp_rule,
  /* 1383 */  iRegINoSp_rule,
  /* 1384 */  iRegINoSp_rule,
  /* 1385 */  iRegINoSp_rule,
  /* 1386 */  iRegINoSp_rule,
  /* 1387 */  iRegINoSp_rule,
  /* 1388 */  iRegINoSp_rule,
  /* 1389 */  iRegINoSp_rule,
  /* 1390 */  iRegINoSp_rule,
  /* 1391 */  iRegINoSp_rule,
  /* 1392 */  iRegINoSp_rule,
  /* 1393 */  iRegINoSp_rule,
  /* 1394 */  iRegINoSp_rule,
  /* 1395 */  iRegINoSp_rule,
  /* 1396 */  iRegINoSp_rule,
  /* 1397 */  iRegINoSp_rule,
  /* 1398 */  iRegLNoSp_rule,
  /* 1399 */  iRegLNoSp_rule,
  /* 1400 */  iRegLNoSp_rule,
  /* 1401 */  vecD_rule,
  /* 1402 */  vecX_rule,
  /* 1403 */  vecX_rule,
  /* 1404 */  vecD_rule,
  /* 1405 */  vecX_rule,
  /* 1406 */  vecX_rule,
  /* 1407 */  iRegINoSp_rule,
  /* 1408 */  iRegINoSp_rule,
  /* 1409 */  iRegINoSp_rule,
  /* 1410 */  iRegINoSp_rule,
  /* 1411 */  iRegINoSp_rule,
  /* 1412 */  iRegINoSp_rule,
  /* 1413 */  iRegLNoSp_rule,
  /* 1414 */  vRegF_rule,
  /* 1415 */  vRegF_rule,
  /* 1416 */  vRegD_rule,
  /* 1417 */  vecD_rule,
  /* 1418 */  vecX_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecD_rule,
  /* 1421 */  vecD_rule,
  /* 1422 */  vecD_rule,
  /* 1423 */  vecD_rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  vecD_rule,
  /* 1426 */  vecX_rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  vecX_rule,
  /* 1429 */  vecX_rule,
  /* 1430 */  vecX_rule,
  /* 1431 */  vecX_rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  vecX_rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  vecD_rule,
  /* 1436 */  vecD_rule,
  /* 1437 */  vecD_rule,
  /* 1438 */  vecD_rule,
  /* 1439 */  vecD_rule,
  /* 1440 */  vecD_rule,
  /* 1441 */  vecD_rule,
  /* 1442 */  vecD_rule,
  /* 1443 */  vecD_rule,
  /* 1444 */  vecD_rule,
  /* 1445 */  vecD_rule,
  /* 1446 */  vecX_rule,
  /* 1447 */  vecX_rule,
  /* 1448 */  vecX_rule,
  /* 1449 */  vecX_rule,
  /* 1450 */  vecX_rule,
  /* 1451 */  vecX_rule,
  /* 1452 */  vecX_rule,
  /* 1453 */  vecX_rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  vecX_rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  vecX_rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  vecX_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecX_rule,
  /* 1476 */  vecD_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecD_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecD_rule,
  /* 1484 */  vecD_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecD_rule,
  /* 1488 */  vecX_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  iRegINoSp_rule,
  /* 1491 */  iRegINoSp_rule,
  /* 1492 */  iRegINoSp_rule,
  /* 1493 */  iRegINoSp_rule,
  /* 1494 */  vecD_rule,
  /* 1495 */  vecX_rule,
  /* 1496 */  vecX_rule,
  /* 1497 */  vecD_rule,
  /* 1498 */  vecX_rule,
  /* 1499 */  vecD_rule,
  /* 1500 */  vecX_rule,
  /* 1501 */  vecD_rule,
  /* 1502 */  vecX_rule,
  /* 1503 */  vecD_rule,
  /* 1504 */  vecX_rule,
  /* 1505 */  vecD_rule,
  /* 1506 */  vecX_rule,
  /* 1507 */  vecD_rule,
  /* 1508 */  vecX_rule,
  /* 1509 */  vecX_rule,
  /* 1510 */  vecX_rule,
  /* 1511 */  vecD_rule,
  /* 1512 */  vecX_rule,
  /* 1513 */  vecX_rule,
  /* 1514 */  iRegINoSp_rule,
  /* 1515 */  iRegINoSp_rule,
  /* 1516 */  iRegINoSp_rule,
  /* 1517 */  iRegINoSp_rule,
  /* 1518 */  vRegF_rule,
  /* 1519 */  vRegF_rule,
  /* 1520 */  vRegF_rule,
  /* 1521 */  vRegF_rule,
  /* 1522 */  vRegD_rule,
  /* 1523 */  vRegD_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecX_rule,
  /* 1531 */  vecD_rule,
  /* 1532 */  vecX_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecD_rule,
  /* 1537 */  vecX_rule,
  /* 1538 */  vecD_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecX_rule,
  /* 1541 */  vecD_rule,
  /* 1542 */  vecX_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  vecD_rule,
  /* 1547 */  vecX_rule,
  /* 1548 */  vecD_rule,
  /* 1549 */  vecX_rule,
  /* 1550 */  vecD_rule,
  /* 1551 */  vecX_rule,
  /* 1552 */  vecX_rule,
  /* 1553 */  vecD_rule,
  /* 1554 */  vecD_rule,
  /* 1555 */  vecX_rule,
  /* 1556 */  vecX_rule,
  /* 1557 */  vecD_rule,
  /* 1558 */  vecD_rule,
  /* 1559 */  vecX_rule,
  /* 1560 */  vecX_rule,
  /* 1561 */  vecD_rule,
  /* 1562 */  vecX_rule,
  /* 1563 */  vecX_rule,
  /* 1564 */  vecD_rule,
  /* 1565 */  vecX_rule,
  /* 1566 */  vecD_rule,
  /* 1567 */  vecX_rule,
  /* 1568 */  vecD_rule,
  /* 1569 */  vecD_rule,
  /* 1570 */  vecX_rule,
  /* 1571 */  vecX_rule,
  /* 1572 */  vecX_rule,
  /* 1573 */  vecX_rule,
  /* 1574 */  vecX_rule,
  /* 1575 */  vecD_rule,
  /* 1576 */  vecX_rule,
  /* 1577 */  vecX_rule,
  /* 1578 */  vecD_rule,
  /* 1579 */  vecX_rule,
  /* 1580 */  vecD_rule,
  /* 1581 */  vecX_rule,
  /* 1582 */  vecD_rule,
  /* 1583 */  vecX_rule,
  /* 1584 */  vecD_rule,
  /* 1585 */  vecX_rule,
  /* 1586 */  vecD_rule,
  /* 1587 */  vecD_rule,
  /* 1588 */  vecX_rule,
  /* 1589 */  vecX_rule,
  /* 1590 */  vecD_rule,
  /* 1591 */  vecD_rule,
  /* 1592 */  vecX_rule,
  /* 1593 */  vecX_rule,
  /* 1594 */  vecD_rule,
  /* 1595 */  vecX_rule,
  /* 1596 */  vecD_rule,
  /* 1597 */  vecX_rule,
  /* 1598 */  vecD_rule,
  /* 1599 */  vecX_rule,
  /* 1600 */  vecD_rule,
  /* 1601 */  vecX_rule,
  /* 1602 */  vecD_rule,
  /* 1603 */  vecD_rule,
  /* 1604 */  vecX_rule,
  /* 1605 */  vecX_rule,
  /* 1606 */  vecD_rule,
  /* 1607 */  vecD_rule,
  /* 1608 */  vecX_rule,
  /* 1609 */  vecX_rule,
  /* 1610 */  vecD_rule,
  /* 1611 */  vecX_rule,
  /* 1612 */  vecD_rule,
  /* 1613 */  vecX_rule,
  /* 1614 */  vecD_rule,
  /* 1615 */  vecX_rule,
  /* 1616 */  vecD_rule,
  /* 1617 */  vecX_rule,
  /* 1618 */  vecD_rule,
  /* 1619 */  vecD_rule,
  /* 1620 */  vecX_rule,
  /* 1621 */  vecX_rule,
  /* 1622 */  vecD_rule,
  /* 1623 */  vecD_rule,
  /* 1624 */  vecX_rule,
  /* 1625 */  vecX_rule,
  /* 1626 */  vecD_rule,
  /* 1627 */  vecX_rule,
  /* 1628 */  vecD_rule,
  /* 1629 */  vecX_rule,
  /* 1630 */  vecD_rule,
  /* 1631 */  vecX_rule,
  /* 1632 */  vecX_rule,
  /* 1633 */  vecX_rule,
  /* 1634 */  vecX_rule,
  /* 1635 */  vecX_rule,
  /* 1636 */  vecX_rule,
  /* 1637 */  vecX_rule,
  /* 1638 */  vecX_rule,
  /* 1639 */  vecX_rule,
  /* 1640 */  vecD_rule,
  /* 1641 */  vecD_rule,
  /* 1642 */  vecX_rule,
  /* 1643 */  vecX_rule,
  /* 1644 */  vecD_rule,
  /* 1645 */  vecD_rule,
  /* 1646 */  vecX_rule,
  /* 1647 */  vecX_rule,
  /* 1648 */  vecD_rule,
  /* 1649 */  vecD_rule,
  /* 1650 */  vecX_rule,
  /* 1651 */  vecX_rule,
  /* 1652 */  vecX_rule,
  /* 1653 */  vecX_rule,
  /* 1654 */  vecD_rule,
  /* 1655 */  vecD_rule,
  /* 1656 */  vecX_rule,
  /* 1657 */  vecX_rule,
  /* 1658 */  vecD_rule,
  /* 1659 */  vecD_rule,
  /* 1660 */  vecX_rule,
  /* 1661 */  vecX_rule,
  /* 1662 */  vecD_rule,
  /* 1663 */  vecD_rule,
  /* 1664 */  vecX_rule,
  /* 1665 */  vecX_rule,
  /* 1666 */  vecX_rule,
  /* 1667 */  vecX_rule,
  /* 1668 */  vecD_rule,
  /* 1669 */  vecX_rule,
  /* 1670 */  vecX_rule,
  /* 1671 */  vecD_rule,
  /* 1672 */  vecX_rule,
  /* 1673 */  vecX_rule,
  /* 1674 */  vecX_rule,
  /* 1675 */  iRegINoSp_rule,
  /* 1676 */  iRegINoSp_rule,
  /* 1677 */  iRegINoSp_rule,
  /* 1678 */  vReg_rule,
  /* 1679 */  Universe_rule,
  /* 1680 */  vReg_rule,
  /* 1681 */  Universe_rule,
  /* 1682 */  vReg_rule,
  /* 1683 */  Universe_rule,
  /* 1684 */  vReg_rule,
  /* 1685 */  Universe_rule,
  /* 1686 */  vReg_rule,
  /* 1687 */  Universe_rule,
  /* 1688 */  vReg_rule,
  /* 1689 */  Universe_rule,
  /* 1690 */  vReg_rule,
  /* 1691 */  Universe_rule,
  /* 1692 */  pRegGov_rule,
  /* 1693 */  pRegGov_rule,
  /* 1694 */  pRegGov_rule,
  /* 1695 */  pRegGov_rule,
  /* 1696 */  pRegGov_rule,
  /* 1697 */  vReg_rule,
  /* 1698 */  pRegGov_rule,
  /* 1699 */  vReg_rule,
  /* 1700 */  vReg_rule,
  /* 1701 */  vReg_rule,
  /* 1702 */  vReg_rule,
  /* 1703 */  vReg_rule,
  /* 1704 */  vReg_rule,
  /* 1705 */  vReg_rule,
  /* 1706 */  vReg_rule,
  /* 1707 */  vReg_rule,
  /* 1708 */  vReg_rule,
  /* 1709 */  vReg_rule,
  /* 1710 */  vReg_rule,
  /* 1711 */  vReg_rule,
  /* 1712 */  vReg_rule,
  /* 1713 */  vReg_rule,
  /* 1714 */  vReg_rule,
  /* 1715 */  vReg_rule,
  /* 1716 */  vReg_rule,
  /* 1717 */  vReg_rule,
  /* 1718 */  vReg_rule,
  /* 1719 */  vReg_rule,
  /* 1720 */  vReg_rule,
  /* 1721 */  vReg_rule,
  /* 1722 */  vReg_rule,
  /* 1723 */  vReg_rule,
  /* 1724 */  vReg_rule,
  /* 1725 */  vReg_rule,
  /* 1726 */  vReg_rule,
  /* 1727 */  vReg_rule,
  /* 1728 */  vReg_rule,
  /* 1729 */  vReg_rule,
  /* 1730 */  vReg_rule,
  /* 1731 */  vReg_rule,
  /* 1732 */  vReg_rule,
  /* 1733 */  vReg_rule,
  /* 1734 */  vReg_rule,
  /* 1735 */  vReg_rule,
  /* 1736 */  vReg_rule,
  /* 1737 */  vReg_rule,
  /* 1738 */  vReg_rule,
  /* 1739 */  vReg_rule,
  /* 1740 */  vReg_rule,
  /* 1741 */  vReg_rule,
  /* 1742 */  vReg_rule,
  /* 1743 */  vReg_rule,
  /* 1744 */  vReg_rule,
  /* 1745 */  vReg_rule,
  /* 1746 */  vReg_rule,
  /* 1747 */  vReg_rule,
  /* 1748 */  vReg_rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  vReg_rule,
  /* 1753 */  vReg_rule,
  /* 1754 */  vReg_rule,
  /* 1755 */  vReg_rule,
  /* 1756 */  vReg_rule,
  /* 1757 */  vReg_rule,
  /* 1758 */  vReg_rule,
  /* 1759 */  vReg_rule,
  /* 1760 */  vReg_rule,
  /* 1761 */  vReg_rule,
  /* 1762 */  vReg_rule,
  /* 1763 */  vReg_rule,
  /* 1764 */  vReg_rule,
  /* 1765 */  vReg_rule,
  /* 1766 */  vReg_rule,
  /* 1767 */  vReg_rule,
  /* 1768 */  vReg_rule,
  /* 1769 */  vReg_rule,
  /* 1770 */  vReg_rule,
  /* 1771 */  vReg_rule,
  /* 1772 */  vReg_rule,
  /* 1773 */  vReg_rule,
  /* 1774 */  vReg_rule,
  /* 1775 */  vReg_rule,
  /* 1776 */  vReg_rule,
  /* 1777 */  vReg_rule,
  /* 1778 */  vReg_rule,
  /* 1779 */  vReg_rule,
  /* 1780 */  vReg_rule,
  /* 1781 */  vReg_rule,
  /* 1782 */  vReg_rule,
  /* 1783 */  vReg_rule,
  /* 1784 */  vReg_rule,
  /* 1785 */  vReg_rule,
  /* 1786 */  vReg_rule,
  /* 1787 */  vReg_rule,
  /* 1788 */  vReg_rule,
  /* 1789 */  vReg_rule,
  /* 1790 */  vReg_rule,
  /* 1791 */  vReg_rule,
  /* 1792 */  vReg_rule,
  /* 1793 */  vReg_rule,
  /* 1794 */  vReg_rule,
  /* 1795 */  vReg_rule,
  /* 1796 */  vReg_rule,
  /* 1797 */  vReg_rule,
  /* 1798 */  vReg_rule,
  /* 1799 */  vReg_rule,
  /* 1800 */  vReg_rule,
  /* 1801 */  vReg_rule,
  /* 1802 */  vReg_rule,
  /* 1803 */  vReg_rule,
  /* 1804 */  vReg_rule,
  /* 1805 */  vReg_rule,
  /* 1806 */  vReg_rule,
  /* 1807 */  vReg_rule,
  /* 1808 */  vReg_rule,
  /* 1809 */  vReg_rule,
  /* 1810 */  vReg_rule,
  /* 1811 */  vReg_rule,
  /* 1812 */  vReg_rule,
  /* 1813 */  vReg_rule,
  /* 1814 */  vReg_rule,
  /* 1815 */  vReg_rule,
  /* 1816 */  vReg_rule,
  /* 1817 */  vReg_rule,
  /* 1818 */  vReg_rule,
  /* 1819 */  vReg_rule,
  /* 1820 */  vReg_rule,
  /* 1821 */  vReg_rule,
  /* 1822 */  vReg_rule,
  /* 1823 */  vReg_rule,
  /* 1824 */  vReg_rule,
  /* 1825 */  vReg_rule,
  /* 1826 */  vReg_rule,
  /* 1827 */  vReg_rule,
  /* 1828 */  vReg_rule,
  /* 1829 */  vReg_rule,
  /* 1830 */  vReg_rule,
  /* 1831 */  vReg_rule,
  /* 1832 */  vReg_rule,
  /* 1833 */  vReg_rule,
  /* 1834 */  vReg_rule,
  /* 1835 */  vReg_rule,
  /* 1836 */  vReg_rule,
  /* 1837 */  vReg_rule,
  /* 1838 */  vReg_rule,
  /* 1839 */  vReg_rule,
  /* 1840 */  vReg_rule,
  /* 1841 */  vReg_rule,
  /* 1842 */  vReg_rule,
  /* 1843 */  vReg_rule,
  /* 1844 */  vReg_rule,
  /* 1845 */  vReg_rule,
  /* 1846 */  vReg_rule,
  /* 1847 */  vReg_rule,
  /* 1848 */  vReg_rule,
  /* 1849 */  vReg_rule,
  /* 1850 */  vReg_rule,
  /* 1851 */  vReg_rule,
  /* 1852 */  vReg_rule,
  /* 1853 */  vReg_rule,
  /* 1854 */  vReg_rule,
  /* 1855 */  vReg_rule,
  /* 1856 */  vReg_rule,
  /* 1857 */  vReg_rule,
  /* 1858 */  vReg_rule,
  /* 1859 */  vReg_rule,
  /* 1860 */  vReg_rule,
  /* 1861 */  pRegGov_rule,
  /* 1862 */  pRegGov_rule,
  /* 1863 */  Universe_rule,
  /* 1864 */  Universe_rule,
  /* 1865 */  iRegINoSp_rule,
  /* 1866 */  iRegLNoSp_rule,
  /* 1867 */  vRegF_rule,
  /* 1868 */  vRegD_rule,
  /* 1869 */  iRegINoSp_rule,
  /* 1870 */  iRegLNoSp_rule,
  /* 1871 */  vRegF_rule,
  /* 1872 */  vRegD_rule,
  /* 1873 */  iRegINoSp_rule,
  /* 1874 */  iRegLNoSp_rule,
  /* 1875 */  vRegF_rule,
  /* 1876 */  vRegD_rule,
  /* 1877 */  iRegINoSp_rule,
  /* 1878 */  iRegLNoSp_rule,
  /* 1879 */  iRegINoSp_rule,
  /* 1880 */  iRegLNoSp_rule,
  /* 1881 */  iRegINoSp_rule,
  /* 1882 */  iRegLNoSp_rule,
  /* 1883 */  iRegINoSp_rule,
  /* 1884 */  iRegLNoSp_rule,
  /* 1885 */  iRegINoSp_rule,
  /* 1886 */  iRegLNoSp_rule,
  /* 1887 */  iRegINoSp_rule,
  /* 1888 */  iRegLNoSp_rule,
  /* 1889 */  iRegINoSp_rule,
  /* 1890 */  iRegLNoSp_rule,
  /* 1891 */  iRegINoSp_rule,
  /* 1892 */  iRegLNoSp_rule,
  /* 1893 */  iRegINoSp_rule,
  /* 1894 */  iRegLNoSp_rule,
  /* 1895 */  iRegINoSp_rule,
  /* 1896 */  iRegLNoSp_rule,
  /* 1897 */  iRegINoSp_rule,
  /* 1898 */  iRegLNoSp_rule,
  /* 1899 */  vRegF_rule,
  /* 1900 */  vRegF_rule,
  /* 1901 */  vRegD_rule,
  /* 1902 */  vRegD_rule,
  /* 1903 */  iRegINoSp_rule,
  /* 1904 */  iRegLNoSp_rule,
  /* 1905 */  vRegF_rule,
  /* 1906 */  vRegD_rule,
  /* 1907 */  iRegINoSp_rule,
  /* 1908 */  iRegLNoSp_rule,
  /* 1909 */  iRegINoSp_rule,
  /* 1910 */  iRegLNoSp_rule,
  /* 1911 */  vRegF_rule,
  /* 1912 */  vRegF_rule,
  /* 1913 */  vRegD_rule,
  /* 1914 */  vRegD_rule,
  /* 1915 */  iRegINoSp_rule,
  /* 1916 */  iRegLNoSp_rule,
  /* 1917 */  vRegF_rule,
  /* 1918 */  vRegD_rule,
  /* 1919 */  vReg_rule,
  /* 1920 */  vReg_rule,
  /* 1921 */  vReg_rule,
  /* 1922 */  vReg_rule,
  /* 1923 */  vReg_rule,
  /* 1924 */  vReg_rule,
  /* 1925 */  vReg_rule,
  /* 1926 */  vReg_rule,
  /* 1927 */  vReg_rule,
  /* 1928 */  vReg_rule,
  /* 1929 */  vReg_rule,
  /* 1930 */  vReg_rule,
  /* 1931 */  vReg_rule,
  /* 1932 */  vReg_rule,
  /* 1933 */  vReg_rule,
  /* 1934 */  vReg_rule,
  /* 1935 */  vReg_rule,
  /* 1936 */  vReg_rule,
  /* 1937 */  vReg_rule,
  /* 1938 */  vReg_rule,
  /* 1939 */  vReg_rule,
  /* 1940 */  vReg_rule,
  /* 1941 */  vReg_rule,
  /* 1942 */  vReg_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  vReg_rule,
  /* 1945 */  vReg_rule,
  /* 1946 */  vReg_rule,
  /* 1947 */  vReg_rule,
  /* 1948 */  vReg_rule,
  /* 1949 */  vReg_rule,
  /* 1950 */  vReg_rule,
  /* 1951 */  vReg_rule,
  /* 1952 */  vReg_rule,
  /* 1953 */  vReg_rule,
  /* 1954 */  vReg_rule,
  /* 1955 */  vReg_rule,
  /* 1956 */  vReg_rule,
  /* 1957 */  vReg_rule,
  /* 1958 */  vReg_rule,
  /* 1959 */  vReg_rule,
  /* 1960 */  vReg_rule,
  /* 1961 */  vReg_rule,
  /* 1962 */  vReg_rule,
  /* 1963 */  vReg_rule,
  /* 1964 */  vReg_rule,
  /* 1965 */  vReg_rule,
  /* 1966 */  vReg_rule,
  /* 1967 */  vReg_rule,
  /* 1968 */  vReg_rule,
  /* 1969 */  vReg_rule,
  /* 1970 */  vReg_rule,
  /* 1971 */  vReg_rule,
  /* 1972 */  vReg_rule,
  /* 1973 */  vReg_rule,
  /* 1974 */  vReg_rule,
  /* 1975 */  vReg_rule,
  /* 1976 */  vReg_rule,
  /* 1977 */  vReg_rule,
  /* 1978 */  vReg_rule,
  /* 1979 */  vReg_rule,
  /* 1980 */  vReg_rule,
  /* 1981 */  vReg_rule,
  /* 1982 */  vReg_rule,
  /* 1983 */  vReg_rule,
  /* 1984 */  vReg_rule,
  /* 1985 */  vReg_rule,
  /* 1986 */  vReg_rule,
  /* 1987 */  vReg_rule,
  /* 1988 */  vReg_rule,
  /* 1989 */  vReg_rule,
  /* 1990 */  vReg_rule,
  /* 1991 */  vReg_rule,
  /* 1992 */  vReg_rule,
  /* 1993 */  vReg_rule,
  /* 1994 */  vReg_rule,
  /* 1995 */  vReg_rule,
  /* 1996 */  vReg_rule,
  /* 1997 */  vReg_rule,
  /* 1998 */  vReg_rule,
  /* 1999 */  vReg_rule,
  /* 2000 */  vReg_rule,
  /* 2001 */  vReg_rule,
  /* 2002 */  iRegINoSp_rule,
  /* 2003 */  iRegINoSp_rule,
  /* 2004 */  iRegINoSp_rule,
  /* 2005 */  iRegLNoSp_rule,
  /* 2006 */  iRegINoSp_rule,
  /* 2007 */  iRegINoSp_rule,
  /* 2008 */  iRegINoSp_rule,
  /* 2009 */  iRegLNoSp_rule,
  /* 2010 */  vRegF_rule,
  /* 2011 */  vRegD_rule,
  /* 2012 */  iRegINoSp_rule,
  /* 2013 */  iRegINoSp_rule,
  /* 2014 */  vReg_rule,
  /* 2015 */  vReg_rule,
  /* 2016 */  vReg_rule,
  /* 2017 */  vReg_rule,
  /* 2018 */  vReg_rule,
  /* 2019 */  vReg_rule,
  /* 2020 */  vReg_rule,
  /* 2021 */  vReg_rule,
  /* 2022 */  vReg_rule,
  /* 2023 */  vReg_rule,
  /* 2024 */  vReg_rule,
  /* 2025 */  vReg_rule,
  /* 2026 */  vReg_rule,
  /* 2027 */  vReg_rule,
  /* 2028 */  vReg_rule,
  /* 2029 */  vReg_rule,
  /* 2030 */  vReg_rule,
  /* 2031 */  Universe_rule,
  /* 2032 */  Universe_rule,
  /* 2033 */  Universe_rule,
  /* 2034 */  Universe_rule,
  /* 2035 */  Universe_rule,
  /* 2036 */  Universe_rule,
  /* 2037 */  vReg_rule,
  /* 2038 */  iRegI_R0_rule,
  /* 2039 */  iRegI_R0_rule,
  /* 2040 */  iRegI_R0_rule,
  /* 2041 */  iRegI_R0_rule,
  /* 2042 */  iRegI_R0_rule,
  /* 2043 */  iRegI_R0_rule,
  /* 2044 */  iRegINoSp_rule,
  /* 2045 */  iRegINoSp_rule,
  /* 2046 */  iRegLNoSp_rule,
  /* 2047 */  pRegGov_rule,
  /* 2048 */  pRegGov_rule,
  /* 2049 */  pRegGov_rule,
  /* 2050 */  pRegGov_rule,
  /* 2051 */  pRegGov_rule,
  /* 2052 */  pRegGov_rule,
  /* 2053 */  pRegGov_rule,
  /* 2054 */  pRegGov_rule,
  /* 2055 */  pReg_rule,
  /* 2056 */  vReg_rule,
  /* 2057 */  vReg_rule,
  /* 2058 */  vReg_rule,
  /* 2059 */  vReg_rule,
  /* 2060 */  pRegGov_rule,
  /* 2061 */  vReg_rule,
  /* 2062 */  vReg_rule,
  /* 2063 */  vReg_rule,
  /* 2064 */  vReg_rule,
  /* 2065 */  iRegINoSp_rule,
  /* 2066 */  iRegINoSp_rule,
  /* 2067 */  iRegINoSp_rule,
  /* 2068 */  iRegINoSp_rule,
  /* 2069 */  iRegNNoSp_rule,
  /* 2070 */  iRegPNoSp_rule,
  /* 2071 */  iRegNNoSp_rule,
  /* 2072 */  iRegPNoSp_rule,
  /* 2073 */  iRegINoSp_rule,
  /* 2074 */  iRegINoSp_rule,
  /* 2075 */  iRegINoSp_rule,
  /* 2076 */  iRegINoSp_rule,
  /* 2077 */  iRegPNoSp_rule,
  /* 2078 */  iRegPNoSp_rule,
  /* 2079 */  iRegINoSp_rule,
  /* 2080 */  iRegINoSp_rule,
  /* 2081 */  iRegINoSp_rule,
  /* 2082 */  iRegINoSp_rule,
  /* 2083 */  iRegPNoSp_rule,
  /* 2084 */  iRegPNoSp_rule,
  /* 2085 */  iRegPNoSp_rule,
  /* 2086 */  iRegPNoSp_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  0,
  /*  158 */  0,
  /*  159 */  0,
  /*  160 */  iRegP_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  iRegP_rule,
  /*  163 */  iRegP_rule,
  /*  164 */  iRegP_rule,
  /*  165 */  iRegP_rule,
  /*  166 */  iRegP_rule,
  /*  167 */  iRegP_rule,
  /*  168 */  iRegP_rule,
  /*  169 */  iRegP_rule,
  /*  170 */  iRegP_rule,
  /*  171 */  iRegP_rule,
  /*  172 */  iRegP_rule,
  /*  173 */  iRegP_rule,
  /*  174 */  iRegP_rule,
  /*  175 */  iRegP_rule,
  /*  176 */  iRegN_rule,
  /*  177 */  _DecodeN_iRegN__rule,
  /*  178 */  _DecodeN_iRegN__rule,
  /*  179 */  _DecodeN_iRegN__rule,
  /*  180 */  _DecodeN_iRegN__rule,
  /*  181 */  _DecodeN_iRegN__rule,
  /*  182 */  _DecodeN_iRegN__rule,
  /*  183 */  thread_RegP_rule,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  iRegL_rule,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  iRegP_rule,
  /*  198 */  iRegP_rule,
  // last operand
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  /*  207 */  0,
  /*  208 */  0,
  /*  209 */  0,
  // last operand class
  /*  210 */  iRegI_rule,
  /*  211 */  _ConvI2L_iRegI__rule,
  /*  212 */  iRegL_rule,
  /*  213 */  iRegN_rule,
  /*  214 */  memory1_rule,
  /*  215 */  memory1_rule,
  /*  216 */  memory2_rule,
  /*  217 */  memory2_rule,
  /*  218 */  memory4_rule,
  /*  219 */  _LoadI_memory4__rule,
  /*  220 */  indirect_rule,
  /*  221 */  indirect_rule,
  /*  222 */  indirect_rule,
  /*  223 */  indirect_rule,
  /*  224 */  indirect_rule,
  /*  225 */  _LoadI_indirect__rule,
  /*  226 */  memory8_rule,
  /*  227 */  iRegP_rule,
  /*  228 */  _DecodeN_iRegN__rule,
  /*  229 */  iRegP_rule,
  /*  230 */  iRegLNoSp_rule,
  /*  231 */  iRegINoSp_rule,
  /*  232 */  iRegNNoSp_rule,
  /*  233 */  iRegI_rule,
  /*  234 */  iRegL_rule,
  /*  235 */  iRegN_rule,
  /*  236 */  cmpOp_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  cmpOpU_rule,
  /*  239 */  immI0_rule,
  /*  240 */  iRegIorL2I_rule,
  /*  241 */  immI_1_rule,
  /*  242 */  iRegL_rule,
  /*  243 */  immL0_rule,
  /*  244 */  iRegP_rule,
  /*  245 */  immP0_rule,
  /*  246 */  iRegN_rule,
  /*  247 */  immN0_rule,
  /*  248 */  vRegF_rule,
  /*  249 */  vRegD_rule,
  /*  250 */  iRegL_rule,
  /*  251 */  iRegIorL2I_rule,
  /*  252 */  _ConvI2L_iRegIorL2I__rule,
  /*  253 */  iRegIorL2I_rule,
  /*  254 */  immI0_rule,
  /*  255 */  iRegL_rule,
  /*  256 */  immL0_rule,
  /*  257 */  _ConvI2L_iRegIorL2I__rule,
  /*  258 */  immL0_rule,
  /*  259 */  iRegIorL2I_rule,
  /*  260 */  iRegIorL2I_rule,
  /*  261 */  iRegIorL2I_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  iRegL_rule,
  /*  264 */  iRegL_rule,
  /*  265 */  iRegIorL2I_rule,
  /*  266 */  iRegL_rule,
  /*  267 */  iRegIorL2I_rule,
  /*  268 */  iRegL_rule,
  /*  269 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  270 */  _URShiftL_iRegL_immI_rule,
  /*  271 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  272 */  _RShiftL_iRegL_immI_rule,
  /*  273 */  iRegIorL2I_rule,
  /*  274 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  275 */  iRegL_rule,
  /*  276 */  _RotateRight_iRegL_immI_rule,
  /*  277 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  278 */  _LShiftL_iRegL_immI_rule,
  /*  279 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  280 */  iRegIorL2I_rule,
  /*  281 */  _URShiftL_iRegL_immI_rule,
  /*  282 */  iRegL_rule,
  /*  283 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  284 */  iRegIorL2I_rule,
  /*  285 */  _RShiftL_iRegL_immI_rule,
  /*  286 */  iRegL_rule,
  /*  287 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  288 */  iRegIorL2I_rule,
  /*  289 */  _RotateRight_iRegL_immI_rule,
  /*  290 */  iRegL_rule,
  /*  291 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  292 */  iRegIorL2I_rule,
  /*  293 */  _LShiftL_iRegL_immI_rule,
  /*  294 */  iRegL_rule,
  /*  295 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  296 */  iRegIorL2I_rule,
  /*  297 */  iRegL_rule,
  /*  298 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  299 */  iRegL_rule,
  /*  300 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  301 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /*  302 */  _AndL_iRegL_immL_positive_bitmaskI_rule,
  /*  303 */  iRegI_rule,
  /*  304 */  iRegIorL2I_rule,
  /*  305 */  _LShiftI_iRegIorL2I_immI_16_rule,
  /*  306 */  iRegIorL2I_rule,
  /*  307 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  308 */  _LShiftI_iRegIorL2I_immI_24_rule,
  /*  309 */  iRegL_rule,
  /*  310 */  _LShiftL_iRegL_immI_48_rule,
  /*  311 */  iRegL_rule,
  /*  312 */  _LShiftL_iRegL_immI_32_rule,
  /*  313 */  iRegL_rule,
  /*  314 */  _LShiftL_iRegL_immI_56_rule,
  /*  315 */  _LShiftL_iRegL_immI_56_rule,
  /*  316 */  iRegIorL2I_rule,
  /*  317 */  iRegIorL2I_rule,
  /*  318 */  iRegL_rule,
  /*  319 */  iRegL_rule,
  /*  320 */  iRegL_rule,
  /*  321 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /*  322 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /*  323 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /*  324 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /*  325 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /*  326 */  _ConvI2L_iRegIorL2I__rule,
  /*  327 */  _AndL_iRegL_immL_255_rule,
  /*  328 */  _AndL_iRegL_immL_65535_rule,
  /*  329 */  _AndL_iRegL_immL_4294967295_rule,
  /*  330 */  _AndI_iRegIorL2I_immI_255_rule,
  /*  331 */  _AndI_iRegIorL2I_immI_65535_rule,
  /*  332 */  vRegF_rule,
  /*  333 */  _NegF_vRegF__rule,
  /*  334 */  vRegF_rule,
  /*  335 */  vRegD_rule,
  /*  336 */  _NegD_vRegD__rule,
  /*  337 */  vRegD_rule,
  /*  338 */  vRegF_rule,
  /*  339 */  vRegD_rule,
  /*  340 */  iRegIorL2I_rule,
  /*  341 */  iRegL_rule,
  /*  342 */  iRegIorL2I_rule,
  /*  343 */  iRegL_rule,
  /*  344 */  iRegP_rule,
  /*  345 */  iRegN_rule,
  /*  346 */  _DecodeN_iRegN__rule,
  /*  347 */  iRegIorL2I_rule,
  /*  348 */  iRegL_rule,
  /*  349 */  iRegL_rule,
  /*  350 */  _AndL_iRegL_immL_rule,
  /*  351 */  iRegIorL2I_rule,
  /*  352 */  _AndI_iRegIorL2I_immI_rule,
  /*  353 */  iRegL_rule,
  /*  354 */  iRegIorL2I_rule,
  /*  355 */  iRegP_R4_rule,
  /*  356 */  iRegP_R1_rule,
  /*  357 */  iRegP_R3_rule,
  /*  358 */  iRegP_R1_rule,
  /*  359 */  iRegP_R3_rule,
  /*  360 */  iRegP_R3_rule,
  /*  361 */  iRegP_R3_rule,
  /*  362 */  iRegP_R1_rule,
  /*  363 */  iRegP_R1_rule,
  /*  364 */  vecD_rule,
  /*  365 */  vecX_rule,
  /*  366 */  vecX_rule,
  /*  367 */  vecD_rule,
  /*  368 */  vecX_rule,
  /*  369 */  vecX_rule,
  /*  370 */  vecD_rule,
  /*  371 */  vecX_rule,
  /*  372 */  immI_M1_rule,
  /*  373 */  immI_M1_rule,
  /*  374 */  immI_M1_rule,
  /*  375 */  immL_M1_rule,
  /*  376 */  vecD_rule,
  /*  377 */  _ReplicateB_immI_M1__rule,
  /*  378 */  vecD_rule,
  /*  379 */  _ReplicateS_immI_M1__rule,
  /*  380 */  vecD_rule,
  /*  381 */  _ReplicateI_immI_M1__rule,
  /*  382 */  vecX_rule,
  /*  383 */  _ReplicateB_immI_M1__rule,
  /*  384 */  vecX_rule,
  /*  385 */  _ReplicateS_immI_M1__rule,
  /*  386 */  vecX_rule,
  /*  387 */  _ReplicateI_immI_M1__rule,
  /*  388 */  vecX_rule,
  /*  389 */  _ReplicateL_immL_M1__rule,
  /*  390 */  vecD_rule,
  /*  391 */  vecX_rule,
  /*  392 */  vecX_rule,
  /*  393 */  vecD_rule,
  /*  394 */  vecX_rule,
  /*  395 */  vecD_rule,
  /*  396 */  vecX_rule,
  /*  397 */  vecD_rule,
  /*  398 */  _NegVF_vecD__rule,
  /*  399 */  vecD_rule,
  /*  400 */  vecX_rule,
  /*  401 */  _NegVF_vecX__rule,
  /*  402 */  vecX_rule,
  /*  403 */  vecX_rule,
  /*  404 */  _NegVD_vecX__rule,
  /*  405 */  vecX_rule,
  /*  406 */  immI_rule,
  /*  407 */  immI_positive_rule,
  /*  408 */  vecD_rule,
  /*  409 */  vecX_rule,
  /*  410 */  vecD_rule,
  /*  411 */  vecX_rule,
  /*  412 */  vecD_rule,
  /*  413 */  vecX_rule,
  /*  414 */  vecX_rule,
  /*  415 */  vecD_rule,
  /*  416 */  vecX_rule,
  /*  417 */  vecD_rule,
  /*  418 */  vecX_rule,
  /*  419 */  vecD_rule,
  /*  420 */  vecX_rule,
  /*  421 */  vecX_rule,
  /*  422 */  vReg_rule,
  /*  423 */  immI_M1_rule,
  /*  424 */  pRegGov_rule,
  /*  425 */  immL_M1_rule,
  /*  426 */  pRegGov_rule,
  /*  427 */  vReg_rule,
  /*  428 */  immBAddSubV_rule,
  /*  429 */  immIAddSubV_rule,
  /*  430 */  immIAddSubV_rule,
  /*  431 */  immLAddSubV_rule,
  /*  432 */  immBLog_rule,
  /*  433 */  immSLog_rule,
  /*  434 */  immILog_rule,
  /*  435 */  immLLog_rule,
  /*  436 */  vReg_rule,
  /*  437 */  vReg_rule,
  /*  438 */  vReg_rule,
  /*  439 */  vReg_rule,
  /*  440 */  vReg_rule,
  /*  441 */  _ReplicateB_immI_M1__rule,
  /*  442 */  vReg_rule,
  /*  443 */  _ReplicateS_immI_M1__rule,
  /*  444 */  vReg_rule,
  /*  445 */  _ReplicateI_immI_M1__rule,
  /*  446 */  vReg_rule,
  /*  447 */  _ReplicateL_immL_M1__rule,
  /*  448 */  vReg_rule,
  /*  449 */  vReg_rule,
  /*  450 */  vReg_rule,
  /*  451 */  vReg_rule,
  /*  452 */  vReg_rule,
  /*  453 */  vReg_rule,
  /*  454 */  vReg_rule,
  /*  455 */  vReg_rule,
  /*  456 */  vReg_rule,
  /*  457 */  _NegVF_vReg__rule,
  /*  458 */  vReg_rule,
  /*  459 */  vReg_rule,
  /*  460 */  _NegVD_vReg__rule,
  /*  461 */  vReg_rule,
  /*  462 */  _NegVF_vReg__rule,
  /*  463 */  _NegVD_vReg__rule,
  /*  464 */  vReg_rule,
  /*  465 */  vReg_rule,
  /*  466 */  vReg_rule,
  /*  467 */  vReg_rule,
  /*  468 */  vReg_rule,
  /*  469 */  vReg_rule,
  /*  470 */  vReg_rule,
  /*  471 */  vReg_rule,
  /*  472 */  indirect_rule,
  /*  473 */  pRegGov_rule,
  /*  474 */  iRegIorL2I_rule,
  /*  475 */  iRegL_rule,
  /*  476 */  vRegF_rule,
  /*  477 */  vRegD_rule,
  /*  478 */  immI_rule,
  /*  479 */  vReg_rule,
  /*  480 */  vReg_rule,
  /*  481 */  vReg_rule,
  /*  482 */  vReg_rule,
  /*  483 */  vReg_rule,
  /*  484 */  vReg_rule,
  /*  485 */  vReg_rule,
  /*  486 */  immI_rule,
  // last internally defined operand
  /*  487 */  immI_rule,
  /*  488 */  immL_rule,
  /*  489 */  immP_rule,
  /*  490 */  immP0_rule,
  /*  491 */  immP_1_rule,
  /*  492 */  immByteMapBase_rule,
  /*  493 */  immN_rule,
  /*  494 */  immN0_rule,
  /*  495 */  immNKlass_rule,
  /*  496 */  immFPacked_rule,
  /*  497 */  immF_rule,
  /*  498 */  immDPacked_rule,
  /*  499 */  immD_rule,
  /*  500 */  iRegIorL2I_rule,
  /*  501 */  iRegL_rule,
  /*  502 */  iRegIorL2I_rule,
  /*  503 */  iRegL_rule,
  /*  504 */  iRegL_rule,
  /*  505 */  iRegP_rule,
  /*  506 */  iRegPNoSp_rule,
  /*  507 */  iRegPNoSp_rule,
  /*  508 */  iRegI_rule,
  /*  509 */  iRegL_rule,
  /*  510 */  vRegF_rule,
  /*  511 */  vRegD_rule,
  /*  512 */  vecD_rule,
  /*  513 */  vecX_rule,
  /*  514 */  vReg_rule,
  /*  515 */  pRegGov_rule,
  /*  516 */  memory8_rule,
  /*  517 */  indirect_rule,
  /*  518 */  indirect_rule,
  /*  519 */  vRegF_rule,
  /*  520 */  vRegD_rule,
  /*  521 */  vRegF_rule,
  /*  522 */  vRegD_rule,
  /*  523 */  stackSlotF_rule,
  /*  524 */  stackSlotI_rule,
  /*  525 */  stackSlotD_rule,
  /*  526 */  stackSlotL_rule,
  /*  527 */  vRegF_rule,
  /*  528 */  iRegI_rule,
  /*  529 */  vRegD_rule,
  /*  530 */  iRegL_rule,
  /*  531 */  iRegIorL2I_rule,
  /*  532 */  iRegIorL2I_rule,
  /*  533 */  iRegL_rule,
  /*  534 */  iRegL_rule,
  /*  535 */  iRegIorL2I_rule,
  /*  536 */  iRegIorL2I_rule,
  /*  537 */  iRegL_rule,
  /*  538 */  iRegL_rule,
  /*  539 */  immI0_rule,
  /*  540 */  immI0_rule,
  /*  541 */  iRegIorL2I_rule,
  /*  542 */  iRegL_rule,
  /*  543 */  iRegI_rule,
  /*  544 */  iRegI_rule,
  /*  545 */  iRegI_rule,
  /*  546 */  iRegI_rule,
  /*  547 */  iRegI_rule,
  /*  548 */  iRegI_rule,
  /*  549 */  iRegI_rule,
  /*  550 */  iRegI_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  iRegL_rule,
  /*  553 */  iRegL_rule,
  /*  554 */  iRegL_rule,
  /*  555 */  iRegL_rule,
  /*  556 */  iRegL_rule,
  /*  557 */  iRegL_rule,
  /*  558 */  iRegL_rule,
  /*  559 */  iRegP_rule,
  /*  560 */  iRegN_rule,
  /*  561 */  iRegP_rule,
  /*  562 */  iRegN_rule,
  /*  563 */  vRegF_rule,
  /*  564 */  vRegF_rule,
  /*  565 */  vRegD_rule,
  /*  566 */  vRegD_rule,
  /*  567 */  _AndL_iRegL_immL_rule,
  /*  568 */  _AndI_iRegIorL2I_immI_rule,
  /*  569 */  _AndL_iRegL_iRegL_rule,
  /*  570 */  _AndI_iRegIorL2I_iRegIorL2I_rule,
  /*  571 */  iRegP_rule,
  /*  572 */  iRegP_rule,
  /*  573 */  _PartialSubtypeCheck_iRegP_R4_iRegP_R0_rule,
  /*  574 */  0,
  /*  575 */  vecD_rule,
  /*  576 */  vecX_rule,
  /*  577 */  vecD_rule,
  /*  578 */  vecX_rule,
  /*  579 */  vecD_rule,
  /*  580 */  vecX_rule,
  /*  581 */  vecD_rule,
  /*  582 */  vecD_rule,
  /*  583 */  vecD_rule,
  /*  584 */  vecD_rule,
  /*  585 */  vecX_rule,
  /*  586 */  vecD_rule,
  /*  587 */  vecD_rule,
  /*  588 */  vecX_rule,
  /*  589 */  vecD_rule,
  /*  590 */  vecX_rule,
  /*  591 */  vecX_rule,
  /*  592 */  vecD_rule,
  /*  593 */  vecD_rule,
  /*  594 */  vecX_rule,
  /*  595 */  vecX_rule,
  /*  596 */  vecD_rule,
  /*  597 */  vecD_rule,
  /*  598 */  vecD_rule,
  /*  599 */  vecD_rule,
  /*  600 */  vecD_rule,
  /*  601 */  vecX_rule,
  /*  602 */  vecX_rule,
  /*  603 */  vecX_rule,
  /*  604 */  vecX_rule,
  /*  605 */  vecD_rule,
  /*  606 */  vecX_rule,
  /*  607 */  vecD_rule,
  /*  608 */  vecX_rule,
  /*  609 */  vecD_rule,
  /*  610 */  vecD_rule,
  /*  611 */  vecD_rule,
  /*  612 */  vecD_rule,
  /*  613 */  vecD_rule,
  /*  614 */  vecD_rule,
  /*  615 */  vecX_rule,
  /*  616 */  immI0_rule,
  /*  617 */  immI0_rule,
  /*  618 */  vecD_rule,
  /*  619 */  vecX_rule,
  /*  620 */  vecD_rule,
  /*  621 */  vecD_rule,
  /*  622 */  vecD_rule,
  /*  623 */  vecD_rule,
  /*  624 */  vecX_rule,
  /*  625 */  vecD_rule,
  /*  626 */  vecX_rule,
  /*  627 */  vecD_rule,
  /*  628 */  vecX_rule,
  /*  629 */  vecX_rule,
  /*  630 */  vecD_rule,
  /*  631 */  vecX_rule,
  /*  632 */  vecX_rule,
  /*  633 */  vecD_rule,
  /*  634 */  vecX_rule,
  /*  635 */  vecX_rule,
  /*  636 */  vecD_rule,
  /*  637 */  vecX_rule,
  /*  638 */  vecX_rule,
  /*  639 */  vecD_rule,
  /*  640 */  vecX_rule,
  /*  641 */  vecX_rule,
  /*  642 */  iRegIorL2I_rule,
  /*  643 */  iRegIorL2I_rule,
  /*  644 */  iRegIorL2I_rule,
  /*  645 */  iRegIorL2I_rule,
  /*  646 */  vecD_rule,
  /*  647 */  vecX_rule,
  /*  648 */  vecX_rule,
  /*  649 */  vecX_rule,
  /*  650 */  vecD_rule,
  /*  651 */  vecX_rule,
  /*  652 */  vecD_rule,
  /*  653 */  vecX_rule,
  /*  654 */  vecD_rule,
  /*  655 */  vecX_rule,
  /*  656 */  vecD_rule,
  /*  657 */  vecX_rule,
  /*  658 */  vecD_rule,
  /*  659 */  vecX_rule,
  /*  660 */  vecD_rule,
  /*  661 */  vecX_rule,
  /*  662 */  vecD_rule,
  /*  663 */  vecX_rule,
  /*  664 */  vReg_rule,
  /*  665 */  pRegGov_rule,
  /*  666 */  vReg_rule,
  /*  667 */  vReg_rule,
  /*  668 */  vReg_rule,
  /*  669 */  vReg_rule,
  /*  670 */  vReg_rule,
  /*  671 */  vReg_rule,
  /*  672 */  vReg_rule,
  /*  673 */  vReg_rule,
  /*  674 */  vReg_rule,
  /*  675 */  vReg_rule,
  /*  676 */  vReg_rule,
  /*  677 */  vReg_rule,
  /*  678 */  iRegIorL2I_rule,
  /*  679 */  iRegIorL2I_rule,
  /*  680 */  iRegIorL2I_rule,
  /*  681 */  iRegIorL2I_rule,
  /*  682 */  iRegIorL2I_rule,
  /*  683 */  iRegIorL2I_rule,
  /*  684 */  iRegIorL2I_rule,
  /*  685 */  iRegIorL2I_rule,
  /*  686 */  vReg_rule,
  /*  687 */  vReg_rule,
  /*  688 */  pRegGov_rule,
  /*  689 */  pReg_rule,
  /*  690 */  pReg_rule,
  /*  691 */  vReg_rule,
  /*  692 */  vReg_rule,
  /*  693 */  vReg_rule,
  /*  694 */  vReg_rule,
  /*  695 */  vReg_rule,
  /*  696 */  vReg_rule,
  /*  697 */  vReg_rule,
  /*  698 */  vReg_rule,
  /*  699 */  vReg_rule,
  /*  700 */  vReg_rule,
  /*  701 */  vReg_rule,
  /*  702 */  immI0_rule,
  /*  703 */  pReg_rule,
  /*  704 */  vReg_rule,
  /*  705 */  vReg_rule,
  /*  706 */  vReg_rule,
  /*  707 */  vReg_rule,
  /*  708 */  memory1_rule,
  /*  709 */  _LoadB_memory1__rule,
  /*  710 */  memory1_rule,
  /*  711 */  _LoadUB_memory1__rule,
  /*  712 */  memory2_rule,
  /*  713 */  _LoadS_memory2__rule,
  /*  714 */  memory2_rule,
  /*  715 */  _LoadUS_memory2__rule,
  /*  716 */  memory4_rule,
  /*  717 */  _LoadI_memory4__rule,
  /*  718 */  _ConvI2L__LoadI_memory4___rule,
  /*  719 */  memory8_rule,
  /*  720 */  memory4_rule,
  /*  721 */  memory8_rule,
  /*  722 */  memory4_rule,
  /*  723 */  memory8_rule,
  /*  724 */  memory4_rule,
  /*  725 */  memory4_rule,
  /*  726 */  memory8_rule,
  /*  727 */  memory1_rule,
  /*  728 */  memory1_rule,
  /*  729 */  memory1_rule,
  /*  730 */  memory1_rule,
  /*  731 */  memory2_rule,
  /*  732 */  memory2_rule,
  /*  733 */  memory4_rule,
  /*  734 */  memory4_rule,
  /*  735 */  memory8_rule,
  /*  736 */  memory8_rule,
  /*  737 */  memory8_rule,
  /*  738 */  memory8_rule,
  /*  739 */  memory4_rule,
  /*  740 */  memory4_rule,
  /*  741 */  memory4_rule,
  /*  742 */  memory8_rule,
  /*  743 */  memory4_rule,
  /*  744 */  memory8_rule,
  /*  745 */  indirect_rule,
  /*  746 */  _LoadB_indirect__rule,
  /*  747 */  indirect_rule,
  /*  748 */  _LoadUB_indirect__rule,
  /*  749 */  indirect_rule,
  /*  750 */  indirect_rule,
  /*  751 */  _LoadUS_indirect__rule,
  /*  752 */  _LoadS_indirect__rule,
  /*  753 */  indirect_rule,
  /*  754 */  _ConvI2L__LoadI_indirect___rule,
  /*  755 */  indirect_rule,
  /*  756 */  indirect_rule,
  /*  757 */  indirect_rule,
  /*  758 */  indirect_rule,
  /*  759 */  indirect_rule,
  /*  760 */  indirect_rule,
  /*  761 */  indirect_rule,
  /*  762 */  indirect_rule,
  /*  763 */  indirect_rule,
  /*  764 */  indirect_rule,
  /*  765 */  indirect_rule,
  /*  766 */  indirect_rule,
  /*  767 */  indirect_rule,
  /*  768 */  indirect_rule,
  /*  769 */  indirect_rule,
  /*  770 */  indirect_rule,
  /*  771 */  indirect_rule,
  /*  772 */  indirect_rule,
  /*  773 */  indirect_rule,
  /*  774 */  indirect_rule,
  /*  775 */  0,
  /*  776 */  0,
  /*  777 */  iRegIorL2I_rule,
  /*  778 */  iRegL_rule,
  /*  779 */  iRegIorL2I_rule,
  /*  780 */  iRegIorL2I_rule,
  /*  781 */  iRegIorL2I_rule,
  /*  782 */  _LoadI_memory4__rule,
  /*  783 */  iRegL_rule,
  /*  784 */  _LoadL_memory8__rule,
  /*  785 */  0,
  /*  786 */  0,
  /*  787 */  0,
  /*  788 */  0,
  /*  789 */  0,
  /*  790 */  0,
  /*  791 */  0,
  /*  792 */  0,
  /*  793 */  0,
  /*  794 */  0,
  /*  795 */  0,
  /*  796 */  0,
  /*  797 */  _CastP2X_iRegP__rule,
  /*  798 */  _CastP2X__DecodeN_iRegN___rule,
  /*  799 */  iRegP_rule,
  /*  800 */  iRegP_rule,
  /*  801 */  iRegN_rule,
  /*  802 */  iRegN_rule,
  /*  803 */  iRegP_rule,
  /*  804 */  iRegN_rule,
  /*  805 */  indirect_rule,
  /*  806 */  indirect_rule,
  /*  807 */  indirect_rule,
  /*  808 */  indirect_rule,
  /*  809 */  indirect_rule,
  /*  810 */  indirect_rule,
  /*  811 */  indirect_rule,
  /*  812 */  indirect_rule,
  /*  813 */  indirect_rule,
  /*  814 */  indirect_rule,
  /*  815 */  indirect_rule,
  /*  816 */  indirect_rule,
  /*  817 */  indirect_rule,
  /*  818 */  indirect_rule,
  /*  819 */  indirect_rule,
  /*  820 */  indirect_rule,
  /*  821 */  indirect_rule,
  /*  822 */  indirect_rule,
  /*  823 */  indirect_rule,
  /*  824 */  indirect_rule,
  /*  825 */  indirect_rule,
  /*  826 */  indirect_rule,
  /*  827 */  indirect_rule,
  /*  828 */  indirect_rule,
  /*  829 */  indirect_rule,
  /*  830 */  indirect_rule,
  /*  831 */  indirect_rule,
  /*  832 */  indirect_rule,
  /*  833 */  indirect_rule,
  /*  834 */  indirect_rule,
  /*  835 */  indirect_rule,
  /*  836 */  indirect_rule,
  /*  837 */  indirect_rule,
  /*  838 */  indirect_rule,
  /*  839 */  indirect_rule,
  /*  840 */  indirect_rule,
  /*  841 */  indirect_rule,
  /*  842 */  indirect_rule,
  /*  843 */  indirect_rule,
  /*  844 */  indirect_rule,
  /*  845 */  indirect_rule,
  /*  846 */  indirect_rule,
  /*  847 */  indirect_rule,
  /*  848 */  indirect_rule,
  /*  849 */  indirect_rule,
  /*  850 */  indirect_rule,
  /*  851 */  indirect_rule,
  /*  852 */  indirect_rule,
  /*  853 */  indirect_rule,
  /*  854 */  indirect_rule,
  /*  855 */  indirect_rule,
  /*  856 */  indirect_rule,
  /*  857 */  indirect_rule,
  /*  858 */  indirect_rule,
  /*  859 */  indirect_rule,
  /*  860 */  indirect_rule,
  /*  861 */  indirect_rule,
  /*  862 */  indirect_rule,
  /*  863 */  indirect_rule,
  /*  864 */  indirect_rule,
  /*  865 */  indirect_rule,
  /*  866 */  iRegL_rule,
  /*  867 */  iRegL_rule,
  /*  868 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  869 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  870 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  871 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  872 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  873 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  874 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  875 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  876 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  877 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  878 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  879 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  880 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  881 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  882 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  883 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  884 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  885 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  886 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  887 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  888 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  889 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  890 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  891 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  892 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  893 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  894 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  895 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  896 */  _Binary_cmpOp_rFlagsReg_rule,
  /*  897 */  _Binary_cmpOpU_rFlagsRegU_rule,
  /*  898 */  iRegIorL2I_rule,
  /*  899 */  iRegIorL2I_rule,
  /*  900 */  _ConvL2I_iRegL__rule,
  /*  901 */  iRegP_rule,
  /*  902 */  iRegP_rule,
  /*  903 */  iRegP_rule,
  /*  904 */  iRegP_rule,
  /*  905 */  _ConvI2L_iRegIorL2I__rule,
  /*  906 */  iRegP_rule,
  /*  907 */  iRegL_rule,
  /*  908 */  iRegL_rule,
  /*  909 */  iRegIorL2I_rule,
  /*  910 */  iRegIorL2I_rule,
  /*  911 */  iRegL_rule,
  /*  912 */  iRegL_rule,
  /*  913 */  immI0_rule,
  /*  914 */  immL0_rule,
  /*  915 */  iRegIorL2I_rule,
  /*  916 */  _ConvI2L_iRegIorL2I__rule,
  /*  917 */  _ConvI2L_iRegIorL2I__rule,
  /*  918 */  iRegL_rule,
  /*  919 */  iRegL_rule,
  /*  920 */  iRegL_rule,
  /*  921 */  iRegIorL2I_rule,
  /*  922 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  923 */  iRegIorL2I_rule,
  /*  924 */  _SubI_immI0_iRegIorL2I_rule,
  /*  925 */  iRegIorL2I_rule,
  /*  926 */  iRegL_rule,
  /*  927 */  _MulL_iRegL_iRegL_rule,
  /*  928 */  iRegL_rule,
  /*  929 */  _SubL_immL0_iRegL_rule,
  /*  930 */  iRegL_rule,
  /*  931 */  iRegLNoSp_rule,
  /*  932 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  933 */  iRegLNoSp_rule,
  /*  934 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  935 */  iRegLNoSp_rule,
  /*  936 */  iRegLNoSp_rule,
  /*  937 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  938 */  _ConvI2L_iRegIorL2I__rule,
  /*  939 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  940 */  iRegIorL2I_rule,
  /*  941 */  iRegL_rule,
  /*  942 */  iRegIorL2I_rule,
  /*  943 */  iRegL_rule,
  /*  944 */  iRegIorL2I_rule,
  /*  945 */  iRegIorL2I_rule,
  /*  946 */  iRegIorL2I_rule,
  /*  947 */  iRegIorL2I_rule,
  /*  948 */  iRegIorL2I_rule,
  /*  949 */  iRegIorL2I_rule,
  /*  950 */  iRegL_rule,
  /*  951 */  iRegL_rule,
  /*  952 */  iRegL_rule,
  /*  953 */  iRegL_rule,
  /*  954 */  _CastP2X_iRegP__rule,
  /*  955 */  iRegL_rule,
  /*  956 */  iRegL_rule,
  /*  957 */  iRegL_rule,
  /*  958 */  iRegIorL2I_rule,
  /*  959 */  immI0_rule,
  /*  960 */  immI0_rule,
  /*  961 */  immI0_rule,
  /*  962 */  immL0_rule,
  /*  963 */  immL0_rule,
  /*  964 */  immL0_rule,
  /*  965 */  iRegIorL2I_rule,
  /*  966 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  967 */  iRegL_rule,
  /*  968 */  _XorL_iRegL_immL_M1_rule,
  /*  969 */  iRegIorL2I_rule,
  /*  970 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  971 */  iRegL_rule,
  /*  972 */  _XorL_iRegL_immL_M1_rule,
  /*  973 */  immI_M1_rule,
  /*  974 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  975 */  immL_M1_rule,
  /*  976 */  _XorL_iRegL_iRegL_rule,
  /*  977 */  iRegIorL2I_rule,
  /*  978 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  979 */  iRegL_rule,
  /*  980 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  981 */  iRegIorL2I_rule,
  /*  982 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  983 */  iRegL_rule,
  /*  984 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  985 */  iRegIorL2I_rule,
  /*  986 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  987 */  iRegL_rule,
  /*  988 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  989 */  iRegIorL2I_rule,
  /*  990 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  991 */  iRegL_rule,
  /*  992 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  993 */  immI_M1_rule,
  /*  994 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  995 */  immI_M1_rule,
  /*  996 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  997 */  immL_M1_rule,
  /*  998 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  999 */  immL_M1_rule,
  /* 1000 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /* 1001 */  immI_M1_rule,
  /* 1002 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1003 */  immI_M1_rule,
  /* 1004 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /* 1005 */  immL_M1_rule,
  /* 1006 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /* 1007 */  immL_M1_rule,
  /* 1008 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /* 1009 */  immI_M1_rule,
  /* 1010 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1011 */  immI_M1_rule,
  /* 1012 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /* 1013 */  immL_M1_rule,
  /* 1014 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /* 1015 */  immL_M1_rule,
  /* 1016 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /* 1017 */  immI_M1_rule,
  /* 1018 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1019 */  immI_M1_rule,
  /* 1020 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /* 1021 */  immL_M1_rule,
  /* 1022 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /* 1023 */  immL_M1_rule,
  /* 1024 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /* 1025 */  iRegIorL2I_rule,
  /* 1026 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1027 */  iRegL_rule,
  /* 1028 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /* 1029 */  iRegIorL2I_rule,
  /* 1030 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1031 */  iRegL_rule,
  /* 1032 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /* 1033 */  iRegIorL2I_rule,
  /* 1034 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /* 1035 */  iRegL_rule,
  /* 1036 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /* 1037 */  iRegIorL2I_rule,
  /* 1038 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1039 */  iRegL_rule,
  /* 1040 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /* 1041 */  iRegIorL2I_rule,
  /* 1042 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1043 */  iRegL_rule,
  /* 1044 */  _URShiftL_iRegL_immI_rule,
  /* 1045 */  iRegIorL2I_rule,
  /* 1046 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1047 */  iRegL_rule,
  /* 1048 */  _RShiftL_iRegL_immI_rule,
  /* 1049 */  iRegIorL2I_rule,
  /* 1050 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1051 */  iRegL_rule,
  /* 1052 */  _LShiftL_iRegL_immI_rule,
  /* 1053 */  iRegIorL2I_rule,
  /* 1054 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1055 */  iRegL_rule,
  /* 1056 */  _RotateRight_iRegL_immI_rule,
  /* 1057 */  iRegIorL2I_rule,
  /* 1058 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1059 */  iRegL_rule,
  /* 1060 */  _URShiftL_iRegL_immI_rule,
  /* 1061 */  iRegIorL2I_rule,
  /* 1062 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1063 */  iRegL_rule,
  /* 1064 */  _RShiftL_iRegL_immI_rule,
  /* 1065 */  iRegIorL2I_rule,
  /* 1066 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1067 */  iRegL_rule,
  /* 1068 */  _LShiftL_iRegL_immI_rule,
  /* 1069 */  iRegIorL2I_rule,
  /* 1070 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1071 */  iRegL_rule,
  /* 1072 */  _RotateRight_iRegL_immI_rule,
  /* 1073 */  iRegIorL2I_rule,
  /* 1074 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1075 */  iRegL_rule,
  /* 1076 */  _URShiftL_iRegL_immI_rule,
  /* 1077 */  iRegIorL2I_rule,
  /* 1078 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1079 */  iRegL_rule,
  /* 1080 */  _RShiftL_iRegL_immI_rule,
  /* 1081 */  iRegIorL2I_rule,
  /* 1082 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1083 */  iRegL_rule,
  /* 1084 */  _LShiftL_iRegL_immI_rule,
  /* 1085 */  iRegIorL2I_rule,
  /* 1086 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1087 */  iRegL_rule,
  /* 1088 */  _RotateRight_iRegL_immI_rule,
  /* 1089 */  iRegIorL2I_rule,
  /* 1090 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1091 */  iRegL_rule,
  /* 1092 */  _URShiftL_iRegL_immI_rule,
  /* 1093 */  iRegIorL2I_rule,
  /* 1094 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1095 */  iRegL_rule,
  /* 1096 */  _RShiftL_iRegL_immI_rule,
  /* 1097 */  iRegIorL2I_rule,
  /* 1098 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1099 */  iRegL_rule,
  /* 1100 */  _LShiftL_iRegL_immI_rule,
  /* 1101 */  iRegIorL2I_rule,
  /* 1102 */  iRegL_rule,
  /* 1103 */  iRegIorL2I_rule,
  /* 1104 */  iRegL_rule,
  /* 1105 */  iRegIorL2I_rule,
  /* 1106 */  iRegL_rule,
  /* 1107 */  _LShiftL_iRegL_immI_rule,
  /* 1108 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1109 */  _LShiftL_iRegL_immI_rule,
  /* 1110 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1111 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1112 */  _URShiftL_iRegL_immI_rule,
  /* 1113 */  _AndI__URShiftI_iRegIorL2I_immI_immI_bitmask_rule,
  /* 1114 */  _AndI_iRegIorL2I_immI_bitmask_rule,
  /* 1115 */  _AndL_iRegL_immL_bitmask_rule,
  /* 1116 */  _LShiftI__AndI_iRegIorL2I_immI_bitmask_immI_rule,
  /* 1117 */  _LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI_rule,
  /* 1118 */  _ConvI2L__AndI_iRegIorL2I_immI_bitmask__rule,
  /* 1119 */  _ConvL2I__AndL_iRegL_immL_positive_bitmaskI__rule,
  /* 1120 */  _AndI_iRegI_immI_bitmask_rule,
  /* 1121 */  _LShiftL_iRegL_immI_rule,
  /* 1122 */  _URShiftL_iRegL_immI_rule,
  /* 1123 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1124 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1125 */  _LShiftL_iRegL_immI_rule,
  /* 1126 */  _URShiftL_iRegL_immI_rule,
  /* 1127 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1128 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1129 */  iRegI_rule,
  /* 1130 */  iRegL_rule,
  /* 1131 */  iRegI_rule,
  /* 1132 */  iRegL_rule,
  /* 1133 */  iRegI_rule,
  /* 1134 */  iRegL_rule,
  /* 1135 */  iRegL_rule,
  /* 1136 */  _ConvI2L_iRegIorL2I__rule,
  /* 1137 */  iRegL_rule,
  /* 1138 */  iRegIorL2I_rule,
  /* 1139 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1140 */  iRegIorL2I_rule,
  /* 1141 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1142 */  iRegIorL2I_rule,
  /* 1143 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1144 */  iRegL_rule,
  /* 1145 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1146 */  iRegL_rule,
  /* 1147 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1148 */  iRegL_rule,
  /* 1149 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1150 */  iRegL_rule,
  /* 1151 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1152 */  iRegIorL2I_rule,
  /* 1153 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1154 */  iRegIorL2I_rule,
  /* 1155 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1156 */  iRegL_rule,
  /* 1157 */  _AndL_iRegL_immL_255_rule,
  /* 1158 */  iRegL_rule,
  /* 1159 */  _AndL_iRegL_immL_65535_rule,
  /* 1160 */  iRegL_rule,
  /* 1161 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1162 */  iRegIorL2I_rule,
  /* 1163 */  iRegIorL2I_rule,
  /* 1164 */  iRegL_rule,
  /* 1165 */  iRegL_rule,
  /* 1166 */  iRegL_rule,
  /* 1167 */  iRegL_rule,
  /* 1168 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1169 */  iRegL_rule,
  /* 1170 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1171 */  iRegL_rule,
  /* 1172 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1173 */  iRegL_rule,
  /* 1174 */  iRegL_rule,
  /* 1175 */  iRegL_rule,
  /* 1176 */  iRegIorL2I_rule,
  /* 1177 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1178 */  iRegIorL2I_rule,
  /* 1179 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1180 */  iRegIorL2I_rule,
  /* 1181 */  iRegIorL2I_rule,
  /* 1182 */  iRegL_rule,
  /* 1183 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1184 */  iRegL_rule,
  /* 1185 */  iRegL_rule,
  /* 1186 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1187 */  iRegL_rule,
  /* 1188 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1189 */  iRegL_rule,
  /* 1190 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1191 */  iRegL_rule,
  /* 1192 */  iRegL_rule,
  /* 1193 */  iRegL_rule,
  /* 1194 */  iRegIorL2I_rule,
  /* 1195 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1196 */  iRegIorL2I_rule,
  /* 1197 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1198 */  iRegIorL2I_rule,
  /* 1199 */  iRegIorL2I_rule,
  /* 1200 */  vRegF_rule,
  /* 1201 */  vRegD_rule,
  /* 1202 */  vRegF_rule,
  /* 1203 */  vRegD_rule,
  /* 1204 */  vRegF_rule,
  /* 1205 */  vRegD_rule,
  /* 1206 */  vRegF_rule,
  /* 1207 */  vRegD_rule,
  /* 1208 */  vRegF_rule,
  /* 1209 */  vRegF_rule,
  /* 1210 */  vRegD_rule,
  /* 1211 */  vRegD_rule,
  /* 1212 */  _NegF_vRegF__rule,
  /* 1213 */  _NegF_vRegF__rule,
  /* 1214 */  _NegD_vRegD__rule,
  /* 1215 */  _NegD_vRegD__rule,
  /* 1216 */  _NegF_vRegF__rule,
  /* 1217 */  _NegD_vRegD__rule,
  /* 1218 */  vRegF_rule,
  /* 1219 */  vRegF_rule,
  /* 1220 */  vRegD_rule,
  /* 1221 */  vRegD_rule,
  /* 1222 */  vRegF_rule,
  /* 1223 */  vRegD_rule,
  /* 1224 */  iRegIorL2I_rule,
  /* 1225 */  iRegL_rule,
  /* 1226 */  _SubF_vRegF_vRegF_rule,
  /* 1227 */  _SubD_vRegD_vRegD_rule,
  /* 1228 */  vRegD_rule,
  /* 1229 */  vRegF_rule,
  /* 1230 */  vRegD_rule,
  /* 1231 */  vRegD_rule,
  /* 1232 */  vRegF_rule,
  /* 1233 */  vRegD_rule,
  /* 1234 */  vRegF_rule,
  /* 1235 */  0,
  /* 1236 */  iRegIorL2I_rule,
  /* 1237 */  iRegIorL2I_rule,
  /* 1238 */  iRegIorL2I_rule,
  /* 1239 */  iRegIorL2I_rule,
  /* 1240 */  iRegIorL2I_rule,
  /* 1241 */  iRegIorL2I_rule,
  /* 1242 */  iRegL_rule,
  /* 1243 */  iRegL_rule,
  /* 1244 */  iRegL_rule,
  /* 1245 */  iRegL_rule,
  /* 1246 */  iRegL_rule,
  /* 1247 */  iRegL_rule,
  /* 1248 */  iRegIorL2I_rule,
  /* 1249 */  _ConvI2L_iRegIorL2I__rule,
  /* 1250 */  iRegL_rule,
  /* 1251 */  iRegIorL2I_rule,
  /* 1252 */  iRegP_rule,
  /* 1253 */  vRegD_rule,
  /* 1254 */  vRegF_rule,
  /* 1255 */  vRegF_rule,
  /* 1256 */  vRegF_rule,
  /* 1257 */  iRegIorL2I_rule,
  /* 1258 */  iRegL_rule,
  /* 1259 */  vRegD_rule,
  /* 1260 */  vRegD_rule,
  /* 1261 */  iRegIorL2I_rule,
  /* 1262 */  iRegL_rule,
  /* 1263 */  vRegD_rule,
  /* 1264 */  vRegF_rule,
  /* 1265 */  vRegF_rule,
  /* 1266 */  iRegI_rule,
  /* 1267 */  vRegD_rule,
  /* 1268 */  iRegL_rule,
  /* 1269 */  iRegL_R11_rule,
  /* 1270 */  immL_rule,
  /* 1271 */  cmpOp_rule,
  /* 1272 */  cmpOp_rule,
  /* 1273 */  vRegF_rule,
  /* 1274 */  vRegD_rule,
  /* 1275 */  vRegF_rule,
  /* 1276 */  vRegD_rule,
  /* 1277 */  iRegIorL2I_rule,
  /* 1278 */  iRegIorL2I_rule,
  /* 1279 */  0,
  /* 1280 */  iRegI_rule,
  /* 1281 */  0,
  /* 1282 */  iRegI_rule,
  /* 1283 */  0,
  /* 1284 */  cmpOp_rule,
  /* 1285 */  cmpOpU_rule,
  /* 1286 */  cmpOpEqNe_rule,
  /* 1287 */  cmpOpEqNe_rule,
  /* 1288 */  cmpOpEqNe_rule,
  /* 1289 */  cmpOpEqNe_rule,
  /* 1290 */  cmpOpEqNe_rule,
  /* 1291 */  cmpOpUEqNeLtGe_rule,
  /* 1292 */  cmpOpUEqNeLtGe_rule,
  /* 1293 */  cmpOpLtGe_rule,
  /* 1294 */  cmpOpLtGe_rule,
  /* 1295 */  cmpOpEqNe_rule,
  /* 1296 */  cmpOpEqNe_rule,
  /* 1297 */  cmpOpLtGe_rule,
  /* 1298 */  cmpOpLtGe_rule,
  /* 1299 */  cmpOpEqNe_rule,
  /* 1300 */  cmpOpEqNe_rule,
  /* 1301 */  cmpOp_rule,
  /* 1302 */  cmpOpU_rule,
  /* 1303 */  iRegP_rule,
  /* 1304 */  0,
  /* 1305 */  0,
  /* 1306 */  0,
  /* 1307 */  0,
  /* 1308 */  0,
  /* 1309 */  iRegPNoSp_rule,
  /* 1310 */  iRegPNoSp_rule,
  /* 1311 */  0,
  /* 1312 */  0,
  /* 1313 */  0,
  /* 1314 */  0,
  /* 1315 */  iRegP_R4_rule,
  /* 1316 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1317 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1318 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1319 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1320 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1321 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1322 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1323 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1324 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1325 */  _Binary_iRegP_R1_iRegI_R4_rule,
  /* 1326 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1327 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1328 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1329 */  _Binary_iRegP_R1_iRegP_R3_rule,
  /* 1330 */  iRegP_R1_rule,
  /* 1331 */  iRegP_R1_rule,
  /* 1332 */  iRegP_R1_rule,
  /* 1333 */  iRegP_R2_rule,
  /* 1334 */  iRegP_R0_rule,
  /* 1335 */  iRegP_R2_rule,
  /* 1336 */  iRegP_R2_rule,
  /* 1337 */  vmem2_rule,
  /* 1338 */  vmem4_rule,
  /* 1339 */  vmem8_rule,
  /* 1340 */  vmem16_rule,
  /* 1341 */  vmem2_rule,
  /* 1342 */  vmem4_rule,
  /* 1343 */  vmem8_rule,
  /* 1344 */  vmem16_rule,
  /* 1345 */  vecX_rule,
  /* 1346 */  vecX_rule,
  /* 1347 */  vecD_rule,
  /* 1348 */  vecX_rule,
  /* 1349 */  vecX_rule,
  /* 1350 */  iRegIorL2I_rule,
  /* 1351 */  iRegIorL2I_rule,
  /* 1352 */  iRegIorL2I_rule,
  /* 1353 */  iRegIorL2I_rule,
  /* 1354 */  iRegL_rule,
  /* 1355 */  iRegIorL2I_rule,
  /* 1356 */  iRegIorL2I_rule,
  /* 1357 */  iRegIorL2I_rule,
  /* 1358 */  iRegIorL2I_rule,
  /* 1359 */  iRegL_rule,
  /* 1360 */  iRegIorL2I_rule,
  /* 1361 */  iRegIorL2I_rule,
  /* 1362 */  iRegIorL2I_rule,
  /* 1363 */  iRegIorL2I_rule,
  /* 1364 */  iRegIorL2I_rule,
  /* 1365 */  iRegIorL2I_rule,
  /* 1366 */  iRegIorL2I_rule,
  /* 1367 */  iRegIorL2I_rule,
  /* 1368 */  iRegIorL2I_rule,
  /* 1369 */  iRegIorL2I_rule,
  /* 1370 */  iRegIorL2I_rule,
  /* 1371 */  iRegIorL2I_rule,
  /* 1372 */  iRegL_rule,
  /* 1373 */  iRegL_rule,
  /* 1374 */  vRegF_rule,
  /* 1375 */  vRegF_rule,
  /* 1376 */  vRegD_rule,
  /* 1377 */  vRegF_rule,
  /* 1378 */  vRegF_rule,
  /* 1379 */  vRegD_rule,
  /* 1380 */  iRegIorL2I_rule,
  /* 1381 */  iRegIorL2I_rule,
  /* 1382 */  iRegIorL2I_rule,
  /* 1383 */  iRegIorL2I_rule,
  /* 1384 */  iRegIorL2I_rule,
  /* 1385 */  iRegIorL2I_rule,
  /* 1386 */  iRegIorL2I_rule,
  /* 1387 */  iRegIorL2I_rule,
  /* 1388 */  iRegIorL2I_rule,
  /* 1389 */  iRegIorL2I_rule,
  /* 1390 */  iRegIorL2I_rule,
  /* 1391 */  iRegIorL2I_rule,
  /* 1392 */  iRegIorL2I_rule,
  /* 1393 */  iRegIorL2I_rule,
  /* 1394 */  iRegIorL2I_rule,
  /* 1395 */  iRegIorL2I_rule,
  /* 1396 */  iRegIorL2I_rule,
  /* 1397 */  iRegIorL2I_rule,
  /* 1398 */  iRegL_rule,
  /* 1399 */  iRegL_rule,
  /* 1400 */  iRegL_rule,
  /* 1401 */  _Binary_vecD_iRegIorL2I_rule,
  /* 1402 */  _Binary_vecX_iRegIorL2I_rule,
  /* 1403 */  _Binary_vecX_iRegL_rule,
  /* 1404 */  _Binary_vecD_vRegF_rule,
  /* 1405 */  _Binary_vecX_vRegF_rule,
  /* 1406 */  _Binary_vecX_vRegD_rule,
  /* 1407 */  vecD_rule,
  /* 1408 */  vecX_rule,
  /* 1409 */  vecD_rule,
  /* 1410 */  vecX_rule,
  /* 1411 */  vecD_rule,
  /* 1412 */  vecX_rule,
  /* 1413 */  vecX_rule,
  /* 1414 */  vecD_rule,
  /* 1415 */  vecX_rule,
  /* 1416 */  vecX_rule,
  /* 1417 */  _Binary_vecD_vecD_rule,
  /* 1418 */  _Binary_vecX_vecX_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  vecD_rule,
  /* 1421 */  _ReplicateB_immI_M1__rule,
  /* 1422 */  vecD_rule,
  /* 1423 */  _ReplicateS_immI_M1__rule,
  /* 1424 */  vecD_rule,
  /* 1425 */  _ReplicateI_immI_M1__rule,
  /* 1426 */  vecX_rule,
  /* 1427 */  _ReplicateB_immI_M1__rule,
  /* 1428 */  vecX_rule,
  /* 1429 */  _ReplicateS_immI_M1__rule,
  /* 1430 */  vecX_rule,
  /* 1431 */  _ReplicateI_immI_M1__rule,
  /* 1432 */  vecX_rule,
  /* 1433 */  _ReplicateL_immL_M1__rule,
  /* 1434 */  vecD_rule,
  /* 1435 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1436 */  vecD_rule,
  /* 1437 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1438 */  vecD_rule,
  /* 1439 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1440 */  vecD_rule,
  /* 1441 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1442 */  vecD_rule,
  /* 1443 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1444 */  vecD_rule,
  /* 1445 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1446 */  vecX_rule,
  /* 1447 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1448 */  vecX_rule,
  /* 1449 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1450 */  vecX_rule,
  /* 1451 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1452 */  vecX_rule,
  /* 1453 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1454 */  vecX_rule,
  /* 1455 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1456 */  vecX_rule,
  /* 1457 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1458 */  vecX_rule,
  /* 1459 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1460 */  vecX_rule,
  /* 1461 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecX_rule,
  /* 1476 */  _Binary_vecD_vecD_rule,
  /* 1477 */  _Binary_vecX_vecX_rule,
  /* 1478 */  vecD_rule,
  /* 1479 */  vecX_rule,
  /* 1480 */  vecD_rule,
  /* 1481 */  vecX_rule,
  /* 1482 */  vecD_rule,
  /* 1483 */  vecX_rule,
  /* 1484 */  vecX_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecD_rule,
  /* 1488 */  vecX_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  _SubVF_vecD_vecD_rule,
  /* 1495 */  _SubVF_vecX_vecX_rule,
  /* 1496 */  _SubVD_vecX_vecX_rule,
  /* 1497 */  iRegIorL2I_rule,
  /* 1498 */  iRegIorL2I_rule,
  /* 1499 */  immI_rule,
  /* 1500 */  immI_rule,
  /* 1501 */  iRegIorL2I_rule,
  /* 1502 */  iRegIorL2I_rule,
  /* 1503 */  immI_rule,
  /* 1504 */  immI_rule,
  /* 1505 */  iRegIorL2I_rule,
  /* 1506 */  iRegIorL2I_rule,
  /* 1507 */  immI_rule,
  /* 1508 */  immI_rule,
  /* 1509 */  iRegL_rule,
  /* 1510 */  immL_rule,
  /* 1511 */  vRegF_rule,
  /* 1512 */  vRegF_rule,
  /* 1513 */  vRegD_rule,
  /* 1514 */  iRegIorL2I_rule,
  /* 1515 */  iRegIorL2I_rule,
  /* 1516 */  iRegIorL2I_rule,
  /* 1517 */  iRegIorL2I_rule,
  /* 1518 */  vRegF_rule,
  /* 1519 */  vRegF_rule,
  /* 1520 */  vRegF_rule,
  /* 1521 */  vRegF_rule,
  /* 1522 */  vRegD_rule,
  /* 1523 */  vRegD_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecX_rule,
  /* 1531 */  vecD_rule,
  /* 1532 */  vecX_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecD_rule,
  /* 1537 */  vecX_rule,
  /* 1538 */  vecD_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecX_rule,
  /* 1541 */  vecD_rule,
  /* 1542 */  vecX_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  vecD_rule,
  /* 1547 */  vecX_rule,
  /* 1548 */  vecD_rule,
  /* 1549 */  vecX_rule,
  /* 1550 */  vecD_rule,
  /* 1551 */  vecX_rule,
  /* 1552 */  vecX_rule,
  /* 1553 */  vecD_rule,
  /* 1554 */  _MulVS_vecD_vecD_rule,
  /* 1555 */  vecX_rule,
  /* 1556 */  _MulVS_vecX_vecX_rule,
  /* 1557 */  vecD_rule,
  /* 1558 */  _MulVI_vecD_vecD_rule,
  /* 1559 */  vecX_rule,
  /* 1560 */  _MulVI_vecX_vecX_rule,
  /* 1561 */  vecD_rule,
  /* 1562 */  vecX_rule,
  /* 1563 */  vecX_rule,
  /* 1564 */  vecD_rule,
  /* 1565 */  vecX_rule,
  /* 1566 */  vecD_rule,
  /* 1567 */  vecX_rule,
  /* 1568 */  vecD_rule,
  /* 1569 */  vecD_rule,
  /* 1570 */  vecX_rule,
  /* 1571 */  vecX_rule,
  /* 1572 */  vecX_rule,
  /* 1573 */  vecX_rule,
  /* 1574 */  vecX_rule,
  /* 1575 */  vecD_rule,
  /* 1576 */  vecX_rule,
  /* 1577 */  vecX_rule,
  /* 1578 */  vecD_rule,
  /* 1579 */  vecX_rule,
  /* 1580 */  vecD_rule,
  /* 1581 */  vecX_rule,
  /* 1582 */  vecD_rule,
  /* 1583 */  vecX_rule,
  /* 1584 */  vecD_rule,
  /* 1585 */  vecX_rule,
  /* 1586 */  vecD_rule,
  /* 1587 */  vecD_rule,
  /* 1588 */  vecX_rule,
  /* 1589 */  vecX_rule,
  /* 1590 */  vecD_rule,
  /* 1591 */  vecD_rule,
  /* 1592 */  vecX_rule,
  /* 1593 */  vecX_rule,
  /* 1594 */  vecD_rule,
  /* 1595 */  vecX_rule,
  /* 1596 */  vecD_rule,
  /* 1597 */  vecX_rule,
  /* 1598 */  vecD_rule,
  /* 1599 */  vecX_rule,
  /* 1600 */  vecD_rule,
  /* 1601 */  vecX_rule,
  /* 1602 */  vecD_rule,
  /* 1603 */  vecD_rule,
  /* 1604 */  vecX_rule,
  /* 1605 */  vecX_rule,
  /* 1606 */  vecD_rule,
  /* 1607 */  vecD_rule,
  /* 1608 */  vecX_rule,
  /* 1609 */  vecX_rule,
  /* 1610 */  vecD_rule,
  /* 1611 */  vecX_rule,
  /* 1612 */  vecD_rule,
  /* 1613 */  vecX_rule,
  /* 1614 */  vecD_rule,
  /* 1615 */  vecX_rule,
  /* 1616 */  vecD_rule,
  /* 1617 */  vecX_rule,
  /* 1618 */  vecD_rule,
  /* 1619 */  vecD_rule,
  /* 1620 */  vecX_rule,
  /* 1621 */  vecX_rule,
  /* 1622 */  vecD_rule,
  /* 1623 */  vecD_rule,
  /* 1624 */  vecX_rule,
  /* 1625 */  vecX_rule,
  /* 1626 */  vecD_rule,
  /* 1627 */  vecX_rule,
  /* 1628 */  vecD_rule,
  /* 1629 */  vecX_rule,
  /* 1630 */  vecD_rule,
  /* 1631 */  vecX_rule,
  /* 1632 */  vecX_rule,
  /* 1633 */  vecX_rule,
  /* 1634 */  vecX_rule,
  /* 1635 */  vecX_rule,
  /* 1636 */  vecX_rule,
  /* 1637 */  vecX_rule,
  /* 1638 */  vecX_rule,
  /* 1639 */  vecX_rule,
  /* 1640 */  vecD_rule,
  /* 1641 */  _RShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /* 1642 */  vecX_rule,
  /* 1643 */  _RShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /* 1644 */  vecD_rule,
  /* 1645 */  _RShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /* 1646 */  vecX_rule,
  /* 1647 */  _RShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /* 1648 */  vecD_rule,
  /* 1649 */  _RShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /* 1650 */  vecX_rule,
  /* 1651 */  _RShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /* 1652 */  vecX_rule,
  /* 1653 */  _RShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /* 1654 */  vecD_rule,
  /* 1655 */  _URShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /* 1656 */  vecX_rule,
  /* 1657 */  _URShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /* 1658 */  vecD_rule,
  /* 1659 */  _URShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /* 1660 */  vecX_rule,
  /* 1661 */  _URShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /* 1662 */  vecD_rule,
  /* 1663 */  _URShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /* 1664 */  vecX_rule,
  /* 1665 */  _URShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /* 1666 */  vecX_rule,
  /* 1667 */  _URShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /* 1668 */  vecD_rule,
  /* 1669 */  vecX_rule,
  /* 1670 */  vecX_rule,
  /* 1671 */  vecD_rule,
  /* 1672 */  vecX_rule,
  /* 1673 */  vecX_rule,
  /* 1674 */  vecX_rule,
  /* 1675 */  vecD_rule,
  /* 1676 */  vecX_rule,
  /* 1677 */  vecD_rule,
  /* 1678 */  vmemA_rule,
  /* 1679 */  vmemA_rule,
  /* 1680 */  vmem2_rule,
  /* 1681 */  vmem2_rule,
  /* 1682 */  vmem4_rule,
  /* 1683 */  vmem4_rule,
  /* 1684 */  vmem8_rule,
  /* 1685 */  vmem8_rule,
  /* 1686 */  vmem16_rule,
  /* 1687 */  vmem16_rule,
  /* 1688 */  vmemA_rule,
  /* 1689 */  vmemA_rule,
  /* 1690 */  vmemA_rule,
  /* 1691 */  vmemA_rule,
  /* 1692 */  pRegGov_rule,
  /* 1693 */  pRegGov_rule,
  /* 1694 */  pRegGov_rule,
  /* 1695 */  pRegGov_rule,
  /* 1696 */  pRegGov_rule,
  /* 1697 */  vReg_rule,
  /* 1698 */  pRegGov_rule,
  /* 1699 */  vReg_rule,
  /* 1700 */  vReg_rule,
  /* 1701 */  vReg_rule,
  /* 1702 */  vReg_rule,
  /* 1703 */  vReg_rule,
  /* 1704 */  vReg_rule,
  /* 1705 */  vReg_rule,
  /* 1706 */  vReg_rule,
  /* 1707 */  vReg_rule,
  /* 1708 */  vReg_rule,
  /* 1709 */  vReg_rule,
  /* 1710 */  vReg_rule,
  /* 1711 */  _Binary_vReg_vReg_rule,
  /* 1712 */  _Binary_vReg_vReg_rule,
  /* 1713 */  _Binary_vReg_vReg_rule,
  /* 1714 */  _Binary_vReg_vReg_rule,
  /* 1715 */  _Binary_vReg_vReg_rule,
  /* 1716 */  _Binary_vReg_vReg_rule,
  /* 1717 */  vReg_rule,
  /* 1718 */  _ReplicateB_immBAddSubV__rule,
  /* 1719 */  vReg_rule,
  /* 1720 */  _ReplicateS_immIAddSubV__rule,
  /* 1721 */  vReg_rule,
  /* 1722 */  _ReplicateI_immIAddSubV__rule,
  /* 1723 */  vReg_rule,
  /* 1724 */  _ReplicateL_immLAddSubV__rule,
  /* 1725 */  vReg_rule,
  /* 1726 */  _ReplicateB_immBLog__rule,
  /* 1727 */  vReg_rule,
  /* 1728 */  _ReplicateS_immSLog__rule,
  /* 1729 */  vReg_rule,
  /* 1730 */  _ReplicateI_immILog__rule,
  /* 1731 */  vReg_rule,
  /* 1732 */  _ReplicateL_immLLog__rule,
  /* 1733 */  vReg_rule,
  /* 1734 */  _ReplicateB_immBLog__rule,
  /* 1735 */  vReg_rule,
  /* 1736 */  _ReplicateS_immSLog__rule,
  /* 1737 */  vReg_rule,
  /* 1738 */  _ReplicateI_immILog__rule,
  /* 1739 */  vReg_rule,
  /* 1740 */  _ReplicateL_immLLog__rule,
  /* 1741 */  vReg_rule,
  /* 1742 */  _ReplicateB_immBLog__rule,
  /* 1743 */  vReg_rule,
  /* 1744 */  _ReplicateS_immSLog__rule,
  /* 1745 */  vReg_rule,
  /* 1746 */  _ReplicateI_immILog__rule,
  /* 1747 */  vReg_rule,
  /* 1748 */  _ReplicateL_immLLog__rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  _Binary_vReg_vReg_rule,
  /* 1753 */  _Binary_vReg_vReg_rule,
  /* 1754 */  _Binary_vReg_vReg_rule,
  /* 1755 */  vReg_rule,
  /* 1756 */  _ReplicateB_immI_M1__rule,
  /* 1757 */  vReg_rule,
  /* 1758 */  _ReplicateS_immI_M1__rule,
  /* 1759 */  vReg_rule,
  /* 1760 */  _ReplicateI_immI_M1__rule,
  /* 1761 */  vReg_rule,
  /* 1762 */  _ReplicateL_immL_M1__rule,
  /* 1763 */  _Binary_vReg__ReplicateB_immI_M1__rule,
  /* 1764 */  _Binary_vReg__ReplicateS_immI_M1__rule,
  /* 1765 */  _Binary_vReg__ReplicateI_immI_M1__rule,
  /* 1766 */  _Binary_vReg__ReplicateL_immL_M1__rule,
  /* 1767 */  vReg_rule,
  /* 1768 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1769 */  vReg_rule,
  /* 1770 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1771 */  vReg_rule,
  /* 1772 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1773 */  vReg_rule,
  /* 1774 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1775 */  vReg_rule,
  /* 1776 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1777 */  vReg_rule,
  /* 1778 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1779 */  vReg_rule,
  /* 1780 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1781 */  vReg_rule,
  /* 1782 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1783 */  _Binary_vReg__XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1784 */  _Binary_vReg__XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1785 */  _Binary_vReg__XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1786 */  _Binary_vReg__XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1787 */  _Binary_vReg__XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1788 */  _Binary_vReg__XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1789 */  _Binary_vReg__XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1790 */  _Binary_vReg__XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1791 */  vReg_rule,
  /* 1792 */  vReg_rule,
  /* 1793 */  _Binary_vReg_vReg_rule,
  /* 1794 */  _Binary_vReg_vReg_rule,
  /* 1795 */  vReg_rule,
  /* 1796 */  vReg_rule,
  /* 1797 */  _Binary_vReg_vReg_rule,
  /* 1798 */  _Binary_vReg_vReg_rule,
  /* 1799 */  vReg_rule,
  /* 1800 */  vReg_rule,
  /* 1801 */  _Binary_vReg_vReg_rule,
  /* 1802 */  _Binary_vReg_vReg_rule,
  /* 1803 */  vReg_rule,
  /* 1804 */  vReg_rule,
  /* 1805 */  vReg_rule,
  /* 1806 */  vReg_rule,
  /* 1807 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1808 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1809 */  _NegVF_vReg__rule,
  /* 1810 */  _NegVF_vReg__rule,
  /* 1811 */  _NegVD_vReg__rule,
  /* 1812 */  _NegVD_vReg__rule,
  /* 1813 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1814 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1815 */  _NegVF_vReg__rule,
  /* 1816 */  _NegVD_vReg__rule,
  /* 1817 */  _Binary_vReg_vReg_rule,
  /* 1818 */  _Binary_vReg_vReg_rule,
  /* 1819 */  vReg_rule,
  /* 1820 */  _MulVB_vReg_vReg_rule,
  /* 1821 */  vReg_rule,
  /* 1822 */  _MulVS_vReg_vReg_rule,
  /* 1823 */  vReg_rule,
  /* 1824 */  _MulVI_vReg_vReg_rule,
  /* 1825 */  vReg_rule,
  /* 1826 */  _MulVL_vReg_vReg_rule,
  /* 1827 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /* 1828 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /* 1829 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /* 1830 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /* 1831 */  vReg_rule,
  /* 1832 */  vReg_rule,
  /* 1833 */  vReg_rule,
  /* 1834 */  vReg_rule,
  /* 1835 */  _Binary_vReg__MulVB_vReg_vReg_rule,
  /* 1836 */  _Binary_vReg__MulVS_vReg_vReg_rule,
  /* 1837 */  _Binary_vReg__MulVI_vReg_vReg_rule,
  /* 1838 */  _Binary_vReg__MulVL_vReg_vReg_rule,
  /* 1839 */  vReg_rule,
  /* 1840 */  vReg_rule,
  /* 1841 */  vReg_rule,
  /* 1842 */  vReg_rule,
  /* 1843 */  vReg_rule,
  /* 1844 */  vReg_rule,
  /* 1845 */  _Binary_vReg_vReg_rule,
  /* 1846 */  _Binary_vReg_vReg_rule,
  /* 1847 */  _Binary_vReg_vReg_rule,
  /* 1848 */  _Binary_vReg_vReg_rule,
  /* 1849 */  _Binary_vReg_vReg_rule,
  /* 1850 */  _Binary_vReg_vReg_rule,
  /* 1851 */  vReg_rule,
  /* 1852 */  vReg_rule,
  /* 1853 */  vReg_rule,
  /* 1854 */  vReg_rule,
  /* 1855 */  vReg_rule,
  /* 1856 */  vReg_rule,
  /* 1857 */  vReg_rule,
  /* 1858 */  _Binary_vReg_vReg_rule,
  /* 1859 */  pRegGov_rule,
  /* 1860 */  pRegGov_rule,
  /* 1861 */  _LoadVector_indirect__rule,
  /* 1862 */  _LoadVector_indirect__rule,
  /* 1863 */  indirect_rule,
  /* 1864 */  indirect_rule,
  /* 1865 */  iRegIorL2I_rule,
  /* 1866 */  iRegL_rule,
  /* 1867 */  vRegF_rule,
  /* 1868 */  vRegD_rule,
  /* 1869 */  iRegIorL2I_rule,
  /* 1870 */  iRegL_rule,
  /* 1871 */  vRegF_rule,
  /* 1872 */  vRegD_rule,
  /* 1873 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1874 */  _Binary_iRegL_vReg_rule,
  /* 1875 */  _Binary_vRegF_vReg_rule,
  /* 1876 */  _Binary_vRegD_vReg_rule,
  /* 1877 */  iRegIorL2I_rule,
  /* 1878 */  iRegL_rule,
  /* 1879 */  iRegIorL2I_rule,
  /* 1880 */  iRegL_rule,
  /* 1881 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1882 */  _Binary_iRegL_vReg_rule,
  /* 1883 */  iRegIorL2I_rule,
  /* 1884 */  iRegL_rule,
  /* 1885 */  iRegIorL2I_rule,
  /* 1886 */  iRegL_rule,
  /* 1887 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1888 */  _Binary_iRegL_vReg_rule,
  /* 1889 */  iRegIorL2I_rule,
  /* 1890 */  iRegL_rule,
  /* 1891 */  iRegIorL2I_rule,
  /* 1892 */  iRegL_rule,
  /* 1893 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1894 */  _Binary_iRegL_vReg_rule,
  /* 1895 */  iRegIorL2I_rule,
  /* 1896 */  iRegL_rule,
  /* 1897 */  iRegIorL2I_rule,
  /* 1898 */  iRegL_rule,
  /* 1899 */  vRegF_rule,
  /* 1900 */  vRegF_rule,
  /* 1901 */  vRegD_rule,
  /* 1902 */  vRegD_rule,
  /* 1903 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1904 */  _Binary_iRegL_vReg_rule,
  /* 1905 */  _Binary_vRegF_vReg_rule,
  /* 1906 */  _Binary_vRegD_vReg_rule,
  /* 1907 */  iRegIorL2I_rule,
  /* 1908 */  iRegL_rule,
  /* 1909 */  iRegIorL2I_rule,
  /* 1910 */  iRegL_rule,
  /* 1911 */  vRegF_rule,
  /* 1912 */  vRegF_rule,
  /* 1913 */  vRegD_rule,
  /* 1914 */  vRegD_rule,
  /* 1915 */  _Binary_iRegIorL2I_vReg_rule,
  /* 1916 */  _Binary_iRegL_vReg_rule,
  /* 1917 */  _Binary_vRegF_vReg_rule,
  /* 1918 */  _Binary_vRegD_vReg_rule,
  /* 1919 */  vReg_rule,
  /* 1920 */  vReg_rule,
  /* 1921 */  vReg_rule,
  /* 1922 */  iRegIorL2I_rule,
  /* 1923 */  iRegIorL2I_rule,
  /* 1924 */  iRegIorL2I_rule,
  /* 1925 */  iRegL_rule,
  /* 1926 */  immI8_rule,
  /* 1927 */  immI8_shift8_rule,
  /* 1928 */  immI8_shift8_rule,
  /* 1929 */  immL8_shift8_rule,
  /* 1930 */  vRegF_rule,
  /* 1931 */  vRegD_rule,
  /* 1932 */  vReg_rule,
  /* 1933 */  vReg_rule,
  /* 1934 */  vReg_rule,
  /* 1935 */  vReg_rule,
  /* 1936 */  vReg_rule,
  /* 1937 */  vReg_rule,
  /* 1938 */  vReg_rule,
  /* 1939 */  vReg_rule,
  /* 1940 */  vReg_rule,
  /* 1941 */  vReg_rule,
  /* 1942 */  vReg_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  vReg_rule,
  /* 1945 */  vReg_rule,
  /* 1946 */  vReg_rule,
  /* 1947 */  vReg_rule,
  /* 1948 */  vReg_rule,
  /* 1949 */  vReg_rule,
  /* 1950 */  vReg_rule,
  /* 1951 */  vReg_rule,
  /* 1952 */  vReg_rule,
  /* 1953 */  vReg_rule,
  /* 1954 */  vReg_rule,
  /* 1955 */  vReg_rule,
  /* 1956 */  _Binary_vReg_vReg_rule,
  /* 1957 */  _Binary_vReg_vReg_rule,
  /* 1958 */  _Binary_vReg_vReg_rule,
  /* 1959 */  _Binary_vReg_vReg_rule,
  /* 1960 */  _Binary_vReg_vReg_rule,
  /* 1961 */  _Binary_vReg_vReg_rule,
  /* 1962 */  _Binary_vReg_vReg_rule,
  /* 1963 */  _Binary_vReg_vReg_rule,
  /* 1964 */  _Binary_vReg_vReg_rule,
  /* 1965 */  _Binary_vReg_vReg_rule,
  /* 1966 */  _Binary_vReg_vReg_rule,
  /* 1967 */  _Binary_vReg_vReg_rule,
  /* 1968 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1969 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1970 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1971 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1972 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1973 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1974 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1975 */  _Binary_vReg__RShiftCntV_immI__rule,
  /* 1976 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1977 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1978 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1979 */  _Binary_vReg__LShiftCntV_immI__rule,
  /* 1980 */  vReg_rule,
  /* 1981 */  vReg_rule,
  /* 1982 */  vReg_rule,
  /* 1983 */  vReg_rule,
  /* 1984 */  vReg_rule,
  /* 1985 */  vReg_rule,
  /* 1986 */  vReg_rule,
  /* 1987 */  vReg_rule,
  /* 1988 */  _Binary_vReg_vReg_rule,
  /* 1989 */  _Binary_vReg_vReg_rule,
  /* 1990 */  _Binary_vReg_vReg_rule,
  /* 1991 */  _Binary_vReg_vReg_rule,
  /* 1992 */  _Binary_vReg_vReg_rule,
  /* 1993 */  _Binary_vReg_vReg_rule,
  /* 1994 */  vReg_rule,
  /* 1995 */  vReg_rule,
  /* 1996 */  vReg_rule,
  /* 1997 */  vReg_rule,
  /* 1998 */  vReg_rule,
  /* 1999 */  vReg_rule,
  /* 2000 */  vReg_rule,
  /* 2001 */  vReg_rule,
  /* 2002 */  vReg_rule,
  /* 2003 */  vReg_rule,
  /* 2004 */  vReg_rule,
  /* 2005 */  vReg_rule,
  /* 2006 */  vReg_rule,
  /* 2007 */  vReg_rule,
  /* 2008 */  vReg_rule,
  /* 2009 */  vReg_rule,
  /* 2010 */  vReg_rule,
  /* 2011 */  vReg_rule,
  /* 2012 */  pRegGov_rule,
  /* 2013 */  pRegGov_rule,
  /* 2014 */  _Binary_vReg_iRegIorL2I_rule,
  /* 2015 */  _Binary_vReg_iRegIorL2I_rule,
  /* 2016 */  _Binary_vReg_iRegIorL2I_rule,
  /* 2017 */  _Binary_vReg_iRegL_rule,
  /* 2018 */  _Binary_vReg_iRegL_rule,
  /* 2019 */  _Binary_vReg_vRegF_rule,
  /* 2020 */  _Binary_vReg_vRegF_rule,
  /* 2021 */  _Binary_vReg_vRegF_rule,
  /* 2022 */  _Binary_vReg_vRegD_rule,
  /* 2023 */  _Binary_vReg_vRegD_rule,
  /* 2024 */  vReg_rule,
  /* 2025 */  indirect_rule,
  /* 2026 */  indirect_rule,
  /* 2027 */  indirect_rule,
  /* 2028 */  indirect_rule,
  /* 2029 */  indirect_rule,
  /* 2030 */  indirect_rule,
  /* 2031 */  indirect_rule,
  /* 2032 */  indirect_rule,
  /* 2033 */  indirect_rule,
  /* 2034 */  indirect_rule,
  /* 2035 */  indirect_rule,
  /* 2036 */  indirect_rule,
  /* 2037 */  iRegIorL2I_rule,
  /* 2038 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2039 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2040 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2041 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2042 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2043 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 2044 */  pReg_rule,
  /* 2045 */  pReg_rule,
  /* 2046 */  pReg_rule,
  /* 2047 */  immI_rule,
  /* 2048 */  iRegIorL2I_rule,
  /* 2049 */  immL_rule,
  /* 2050 */  iRegL_rule,
  /* 2051 */  _Binary_vReg_vReg_rule,
  /* 2052 */  _Binary_vReg_vReg_rule,
  /* 2053 */  vReg_rule,
  /* 2054 */  vReg_rule,
  /* 2055 */  pReg_rule,
  /* 2056 */  vReg_rule,
  /* 2057 */  vReg_rule,
  /* 2058 */  vReg_rule,
  /* 2059 */  vReg_rule,
  /* 2060 */  iRegL_rule,
  /* 2061 */  vReg_rule,
  /* 2062 */  vReg_rule,
  /* 2063 */  vReg_rule,
  /* 2064 */  vReg_rule,
  /* 2065 */  indirect_rule,
  /* 2066 */  indirect_rule,
  /* 2067 */  indirect_rule,
  /* 2068 */  indirect_rule,
  /* 2069 */  indirect_rule,
  /* 2070 */  indirect_rule,
  /* 2071 */  indirect_rule,
  /* 2072 */  indirect_rule,
  /* 2073 */  indirect_rule,
  /* 2074 */  indirect_rule,
  /* 2075 */  indirect_rule,
  /* 2076 */  indirect_rule,
  /* 2077 */  memory8_rule,
  /* 2078 */  indirect_rule,
  /* 2079 */  indirect_rule,
  /* 2080 */  indirect_rule,
  /* 2081 */  indirect_rule,
  /* 2082 */  indirect_rule,
  /* 2083 */  indirect_rule,
  /* 2084 */  indirect_rule,
  /* 2085 */  indirect_rule,
  /* 2086 */  indirect_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  0,
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  /*  133 */  0,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  0,
  /*  137 */  0,
  /*  138 */  0,
  /*  139 */  0,
  /*  140 */  0,
  /*  141 */  0,
  /*  142 */  0,
  /*  143 */  0,
  /*  144 */  0,
  /*  145 */  0,
  /*  146 */  0,
  /*  147 */  0,
  /*  148 */  0,
  /*  149 */  0,
  /*  150 */  0,
  /*  151 */  0,
  /*  152 */  0,
  /*  153 */  0,
  /*  154 */  0,
  /*  155 */  0,
  /*  156 */  0,
  /*  157 */  0,
  /*  158 */  0,
  /*  159 */  0,
  /*  160 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  161 */  _LShiftL_iRegL_immIScale_rule,
  /*  162 */  _ConvI2L_iRegI__rule,
  /*  163 */  iRegL_rule,
  /*  164 */  immIOffset_rule,
  /*  165 */  immIOffset1_rule,
  /*  166 */  immIOffset2_rule,
  /*  167 */  immIOffset4_rule,
  /*  168 */  immIOffset8_rule,
  /*  169 */  immIOffset16_rule,
  /*  170 */  immLoffset_rule,
  /*  171 */  immLoffset1_rule,
  /*  172 */  immLoffset2_rule,
  /*  173 */  immLoffset4_rule,
  /*  174 */  immLoffset8_rule,
  /*  175 */  immLoffset16_rule,
  /*  176 */  0,
  /*  177 */  _LShiftL__ConvI2L_iRegI__immIScale_rule,
  /*  178 */  _LShiftL_iRegL_immIScale_rule,
  /*  179 */  _ConvI2L_iRegI__rule,
  /*  180 */  iRegL_rule,
  /*  181 */  immIOffset_rule,
  /*  182 */  immLoffset_rule,
  /*  183 */  immL_pc_off_rule,
  /*  184 */  0,
  /*  185 */  0,
  /*  186 */  0,
  /*  187 */  0,
  /*  188 */  0,
  /*  189 */  0,
  /*  190 */  0,
  /*  191 */  0,
  /*  192 */  0,
  /*  193 */  0,
  /*  194 */  0,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  vmemA_immIOffset4_rule,
  /*  198 */  vmemA_immLOffset4_rule,
  // last operand
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  /*  207 */  0,
  /*  208 */  0,
  /*  209 */  0,
  // last operand class
  /*  210 */  0,
  /*  211 */  immIScale_rule,
  /*  212 */  immIScale_rule,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  0,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  0,
  /*  224 */  0,
  /*  225 */  0,
  /*  226 */  0,
  /*  227 */  0,
  /*  228 */  0,
  /*  229 */  iRegP_rule,
  /*  230 */  iRegLNoSp_rule,
  /*  231 */  iRegINoSp_rule,
  /*  232 */  iRegNNoSp_rule,
  /*  233 */  iRegI_rule,
  /*  234 */  iRegL_rule,
  /*  235 */  iRegN_rule,
  /*  236 */  rFlagsReg_rule,
  /*  237 */  iRegIorL2I_rule,
  /*  238 */  rFlagsRegU_rule,
  /*  239 */  iRegIorL2I_rule,
  /*  240 */  immI0_rule,
  /*  241 */  immI0_rule,
  /*  242 */  immL0_rule,
  /*  243 */  iRegL_rule,
  /*  244 */  immP0_rule,
  /*  245 */  iRegP_rule,
  /*  246 */  immN0_rule,
  /*  247 */  iRegN_rule,
  /*  248 */  vRegF_rule,
  /*  249 */  vRegD_rule,
  /*  250 */  0,
  /*  251 */  0,
  /*  252 */  immIScale_rule,
  /*  253 */  iRegIorL2I_rule,
  /*  254 */  iRegIorL2I_rule,
  /*  255 */  iRegL_rule,
  /*  256 */  iRegL_rule,
  /*  257 */  _ConvI2L_iRegIorL2I__rule,
  /*  258 */  _ConvI2L_iRegIorL2I__rule,
  /*  259 */  immI_rule,
  /*  260 */  immI_rule,
  /*  261 */  immI_rule,
  /*  262 */  immI_rule,
  /*  263 */  immI_rule,
  /*  264 */  immI_rule,
  /*  265 */  immI_M1_rule,
  /*  266 */  immL_M1_rule,
  /*  267 */  iRegIorL2I_rule,
  /*  268 */  iRegL_rule,
  /*  269 */  immI_M1_rule,
  /*  270 */  immL_M1_rule,
  /*  271 */  immI_M1_rule,
  /*  272 */  immL_M1_rule,
  /*  273 */  immI_rule,
  /*  274 */  immI_M1_rule,
  /*  275 */  immI_rule,
  /*  276 */  immL_M1_rule,
  /*  277 */  immI_M1_rule,
  /*  278 */  immL_M1_rule,
  /*  279 */  iRegIorL2I_rule,
  /*  280 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  281 */  iRegL_rule,
  /*  282 */  _URShiftL_iRegL_immI_rule,
  /*  283 */  iRegIorL2I_rule,
  /*  284 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  285 */  iRegL_rule,
  /*  286 */  _RShiftL_iRegL_immI_rule,
  /*  287 */  iRegIorL2I_rule,
  /*  288 */  _RotateRight_iRegIorL2I_immI_rule,
  /*  289 */  iRegL_rule,
  /*  290 */  _RotateRight_iRegL_immI_rule,
  /*  291 */  iRegIorL2I_rule,
  /*  292 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  293 */  iRegL_rule,
  /*  294 */  _LShiftL_iRegL_immI_rule,
  /*  295 */  immI_bitmask_rule,
  /*  296 */  immI_bitmask_rule,
  /*  297 */  immL_bitmask_rule,
  /*  298 */  immI_rule,
  /*  299 */  immL_positive_bitmaskI_rule,
  /*  300 */  immI_rule,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  immI_bitmask_rule,
  /*  304 */  immI_16_rule,
  /*  305 */  immI_16_rule,
  /*  306 */  immI_24_rule,
  /*  307 */  immI_24_rule,
  /*  308 */  immI_24_rule,
  /*  309 */  immI_48_rule,
  /*  310 */  immI_48_rule,
  /*  311 */  immI_32_rule,
  /*  312 */  immI_32_rule,
  /*  313 */  immI_56_rule,
  /*  314 */  immI_56_rule,
  /*  315 */  immI_56_rule,
  /*  316 */  immI_255_rule,
  /*  317 */  immI_65535_rule,
  /*  318 */  immL_255_rule,
  /*  319 */  immL_65535_rule,
  /*  320 */  immL_4294967295_rule,
  /*  321 */  immIExt_rule,
  /*  322 */  immIExt_rule,
  /*  323 */  immIExt_rule,
  /*  324 */  immIExt_rule,
  /*  325 */  immIExt_rule,
  /*  326 */  immIExt_rule,
  /*  327 */  immIExt_rule,
  /*  328 */  immIExt_rule,
  /*  329 */  immIExt_rule,
  /*  330 */  immIExt_rule,
  /*  331 */  immIExt_rule,
  /*  332 */  0,
  /*  333 */  vRegF_rule,
  /*  334 */  _NegF_vRegF__rule,
  /*  335 */  0,
  /*  336 */  vRegD_rule,
  /*  337 */  _NegD_vRegD__rule,
  /*  338 */  vRegF_rule,
  /*  339 */  vRegD_rule,
  /*  340 */  iRegIorL2I_rule,
  /*  341 */  iRegL_rule,
  /*  342 */  immI0_rule,
  /*  343 */  immL0_rule,
  /*  344 */  immP0_rule,
  /*  345 */  immN0_rule,
  /*  346 */  immP0_rule,
  /*  347 */  immI0_rule,
  /*  348 */  immL0_rule,
  /*  349 */  immL_rule,
  /*  350 */  immL0_rule,
  /*  351 */  immI_rule,
  /*  352 */  immI0_rule,
  /*  353 */  iRegL_rule,
  /*  354 */  iRegIorL2I_rule,
  /*  355 */  iRegP_R0_rule,
  /*  356 */  iRegI_R2_rule,
  /*  357 */  iRegI_R4_rule,
  /*  358 */  iRegI_R4_rule,
  /*  359 */  iRegI_R2_rule,
  /*  360 */  immI_le_4_rule,
  /*  361 */  immI_1_rule,
  /*  362 */  iRegP_R3_rule,
  /*  363 */  iRegI_R3_rule,
  /*  364 */  iRegIorL2I_rule,
  /*  365 */  iRegIorL2I_rule,
  /*  366 */  iRegL_rule,
  /*  367 */  vRegF_rule,
  /*  368 */  vRegF_rule,
  /*  369 */  vRegD_rule,
  /*  370 */  vecD_rule,
  /*  371 */  vecX_rule,
  /*  372 */  0,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  0,
  /*  376 */  _ReplicateB_immI_M1__rule,
  /*  377 */  vecD_rule,
  /*  378 */  _ReplicateS_immI_M1__rule,
  /*  379 */  vecD_rule,
  /*  380 */  _ReplicateI_immI_M1__rule,
  /*  381 */  vecD_rule,
  /*  382 */  _ReplicateB_immI_M1__rule,
  /*  383 */  vecX_rule,
  /*  384 */  _ReplicateS_immI_M1__rule,
  /*  385 */  vecX_rule,
  /*  386 */  _ReplicateI_immI_M1__rule,
  /*  387 */  vecX_rule,
  /*  388 */  _ReplicateL_immL_M1__rule,
  /*  389 */  vecX_rule,
  /*  390 */  vecD_rule,
  /*  391 */  vecX_rule,
  /*  392 */  vecX_rule,
  /*  393 */  vecD_rule,
  /*  394 */  vecX_rule,
  /*  395 */  vecD_rule,
  /*  396 */  vecX_rule,
  /*  397 */  0,
  /*  398 */  vecD_rule,
  /*  399 */  _NegVF_vecD__rule,
  /*  400 */  0,
  /*  401 */  vecX_rule,
  /*  402 */  _NegVF_vecX__rule,
  /*  403 */  0,
  /*  404 */  vecX_rule,
  /*  405 */  _NegVD_vecX__rule,
  /*  406 */  0,
  /*  407 */  0,
  /*  408 */  _RShiftCntV_immI_positive__rule,
  /*  409 */  _RShiftCntV_immI_positive__rule,
  /*  410 */  _RShiftCntV_immI_positive__rule,
  /*  411 */  _RShiftCntV_immI_positive__rule,
  /*  412 */  _RShiftCntV_immI_positive__rule,
  /*  413 */  _RShiftCntV_immI_positive__rule,
  /*  414 */  _RShiftCntV_immI_positive__rule,
  /*  415 */  _RShiftCntV_immI_positive__rule,
  /*  416 */  _RShiftCntV_immI_positive__rule,
  /*  417 */  _RShiftCntV_immI_positive__rule,
  /*  418 */  _RShiftCntV_immI_positive__rule,
  /*  419 */  _RShiftCntV_immI_positive__rule,
  /*  420 */  _RShiftCntV_immI_positive__rule,
  /*  421 */  _RShiftCntV_immI_positive__rule,
  /*  422 */  pRegGov_rule,
  /*  423 */  0,
  /*  424 */  _MaskAll_immI_M1__rule,
  /*  425 */  0,
  /*  426 */  _MaskAll_immL_M1__rule,
  /*  427 */  vReg_rule,
  /*  428 */  0,
  /*  429 */  0,
  /*  430 */  0,
  /*  431 */  0,
  /*  432 */  0,
  /*  433 */  0,
  /*  434 */  0,
  /*  435 */  0,
  /*  436 */  _ReplicateB_immI_M1__rule,
  /*  437 */  _ReplicateS_immI_M1__rule,
  /*  438 */  _ReplicateI_immI_M1__rule,
  /*  439 */  _ReplicateL_immL_M1__rule,
  /*  440 */  _ReplicateB_immI_M1__rule,
  /*  441 */  vReg_rule,
  /*  442 */  _ReplicateS_immI_M1__rule,
  /*  443 */  vReg_rule,
  /*  444 */  _ReplicateI_immI_M1__rule,
  /*  445 */  vReg_rule,
  /*  446 */  _ReplicateL_immL_M1__rule,
  /*  447 */  vReg_rule,
  /*  448 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /*  449 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /*  450 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /*  451 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /*  452 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /*  453 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /*  454 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /*  455 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /*  456 */  0,
  /*  457 */  vReg_rule,
  /*  458 */  _NegVF_vReg__rule,
  /*  459 */  0,
  /*  460 */  vReg_rule,
  /*  461 */  _NegVD_vReg__rule,
  /*  462 */  pRegGov_rule,
  /*  463 */  pRegGov_rule,
  /*  464 */  vReg_rule,
  /*  465 */  vReg_rule,
  /*  466 */  vReg_rule,
  /*  467 */  vReg_rule,
  /*  468 */  _MulVB_vReg_vReg_rule,
  /*  469 */  _MulVS_vReg_vReg_rule,
  /*  470 */  _MulVI_vReg_vReg_rule,
  /*  471 */  _MulVL_vReg_vReg_rule,
  /*  472 */  0,
  /*  473 */  immI_gt_1_rule,
  /*  474 */  vReg_rule,
  /*  475 */  vReg_rule,
  /*  476 */  vReg_rule,
  /*  477 */  vReg_rule,
  /*  478 */  0,
  /*  479 */  _RShiftCntV_immI__rule,
  /*  480 */  _LShiftCntV_immI__rule,
  /*  481 */  iRegIorL2I_rule,
  /*  482 */  iRegL_rule,
  /*  483 */  vRegF_rule,
  /*  484 */  vRegD_rule,
  /*  485 */  _Binary_vReg_pRegGov_rule,
  /*  486 */  pRegGov_rule,
  // last internally defined operand
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  0,
  /*  491 */  0,
  /*  492 */  0,
  /*  493 */  0,
  /*  494 */  0,
  /*  495 */  0,
  /*  496 */  0,
  /*  497 */  0,
  /*  498 */  0,
  /*  499 */  0,
  /*  500 */  0,
  /*  501 */  0,
  /*  502 */  0,
  /*  503 */  0,
  /*  504 */  0,
  /*  505 */  0,
  /*  506 */  0,
  /*  507 */  0,
  /*  508 */  0,
  /*  509 */  0,
  /*  510 */  0,
  /*  511 */  0,
  /*  512 */  0,
  /*  513 */  0,
  /*  514 */  0,
  /*  515 */  0,
  /*  516 */  _Binary_iRegP_iRegP_rule,
  /*  517 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  518 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  519 */  0,
  /*  520 */  0,
  /*  521 */  0,
  /*  522 */  0,
  /*  523 */  0,
  /*  524 */  0,
  /*  525 */  0,
  /*  526 */  0,
  /*  527 */  0,
  /*  528 */  0,
  /*  529 */  0,
  /*  530 */  0,
  /*  531 */  iRegIorL2I_rule,
  /*  532 */  immIAddSub_rule,
  /*  533 */  iRegL_rule,
  /*  534 */  immLAddSub_rule,
  /*  535 */  iRegIorL2I_rule,
  /*  536 */  immIAddSub_rule,
  /*  537 */  iRegL_rule,
  /*  538 */  immLAddSub_rule,
  /*  539 */  iRegIorL2I_rule,
  /*  540 */  iRegL_rule,
  /*  541 */  iRegIorL2I_rule,
  /*  542 */  iRegL_rule,
  /*  543 */  iRegI_rule,
  /*  544 */  immI0_rule,
  /*  545 */  immIAddSub_rule,
  /*  546 */  immI_rule,
  /*  547 */  iRegI_rule,
  /*  548 */  immI0_rule,
  /*  549 */  immIAddSub_rule,
  /*  550 */  immI_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  immL0_rule,
  /*  553 */  immLAddSub_rule,
  /*  554 */  immL_rule,
  /*  555 */  iRegL_rule,
  /*  556 */  immL0_rule,
  /*  557 */  immLAddSub_rule,
  /*  558 */  immL_rule,
  /*  559 */  iRegP_rule,
  /*  560 */  iRegN_rule,
  /*  561 */  immP0_rule,
  /*  562 */  immN0_rule,
  /*  563 */  vRegF_rule,
  /*  564 */  immF0_rule,
  /*  565 */  vRegD_rule,
  /*  566 */  immD0_rule,
  /*  567 */  immL0_rule,
  /*  568 */  immI0_rule,
  /*  569 */  immL0_rule,
  /*  570 */  immI0_rule,
  /*  571 */  iRegP_rule,
  /*  572 */  iRegP_rule,
  /*  573 */  immP0_rule,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  0,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  0,
  /*  587 */  0,
  /*  588 */  0,
  /*  589 */  0,
  /*  590 */  0,
  /*  591 */  0,
  /*  592 */  0,
  /*  593 */  0,
  /*  594 */  0,
  /*  595 */  0,
  /*  596 */  0,
  /*  597 */  0,
  /*  598 */  0,
  /*  599 */  0,
  /*  600 */  0,
  /*  601 */  0,
  /*  602 */  0,
  /*  603 */  0,
  /*  604 */  0,
  /*  605 */  0,
  /*  606 */  0,
  /*  607 */  0,
  /*  608 */  0,
  /*  609 */  0,
  /*  610 */  0,
  /*  611 */  0,
  /*  612 */  0,
  /*  613 */  0,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  0,
  /*  617 */  0,
  /*  618 */  0,
  /*  619 */  0,
  /*  620 */  0,
  /*  621 */  0,
  /*  622 */  0,
  /*  623 */  0,
  /*  624 */  0,
  /*  625 */  0,
  /*  626 */  0,
  /*  627 */  0,
  /*  628 */  0,
  /*  629 */  0,
  /*  630 */  0,
  /*  631 */  0,
  /*  632 */  0,
  /*  633 */  0,
  /*  634 */  0,
  /*  635 */  0,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  0,
  /*  641 */  0,
  /*  642 */  0,
  /*  643 */  0,
  /*  644 */  0,
  /*  645 */  0,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  0,
  /*  652 */  0,
  /*  653 */  0,
  /*  654 */  0,
  /*  655 */  0,
  /*  656 */  0,
  /*  657 */  0,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  0,
  /*  664 */  0,
  /*  665 */  0,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  0,
  /*  670 */  0,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  0,
  /*  682 */  0,
  /*  683 */  0,
  /*  684 */  0,
  /*  685 */  0,
  /*  686 */  0,
  /*  687 */  0,
  /*  688 */  0,
  /*  689 */  0,
  /*  690 */  0,
  /*  691 */  0,
  /*  692 */  0,
  /*  693 */  0,
  /*  694 */  0,
  /*  695 */  0,
  /*  696 */  0,
  /*  697 */  0,
  /*  698 */  0,
  /*  699 */  0,
  /*  700 */  0,
  /*  701 */  0,
  /*  702 */  0,
  /*  703 */  0,
  /*  704 */  0,
  /*  705 */  0,
  /*  706 */  0,
  /*  707 */  0,
  /*  708 */  0,
  /*  709 */  0,
  /*  710 */  0,
  /*  711 */  0,
  /*  712 */  0,
  /*  713 */  0,
  /*  714 */  0,
  /*  715 */  0,
  /*  716 */  0,
  /*  717 */  0,
  /*  718 */  immL_32bits_rule,
  /*  719 */  0,
  /*  720 */  0,
  /*  721 */  0,
  /*  722 */  0,
  /*  723 */  0,
  /*  724 */  0,
  /*  725 */  0,
  /*  726 */  0,
  /*  727 */  immI0_rule,
  /*  728 */  immI0_rule,
  /*  729 */  iRegIorL2I_rule,
  /*  730 */  immI0_rule,
  /*  731 */  iRegIorL2I_rule,
  /*  732 */  immI0_rule,
  /*  733 */  iRegIorL2I_rule,
  /*  734 */  immI0_rule,
  /*  735 */  iRegL_rule,
  /*  736 */  immL0_rule,
  /*  737 */  iRegP_rule,
  /*  738 */  immP0_rule,
  /*  739 */  iRegN_rule,
  /*  740 */  immN0_rule,
  /*  741 */  vRegF_rule,
  /*  742 */  vRegD_rule,
  /*  743 */  iRegN_rule,
  /*  744 */  0,
  /*  745 */  0,
  /*  746 */  0,
  /*  747 */  0,
  /*  748 */  0,
  /*  749 */  0,
  /*  750 */  0,
  /*  751 */  0,
  /*  752 */  0,
  /*  753 */  0,
  /*  754 */  immL_32bits_rule,
  /*  755 */  0,
  /*  756 */  0,
  /*  757 */  0,
  /*  758 */  0,
  /*  759 */  0,
  /*  760 */  iRegIorL2I_rule,
  /*  761 */  immI0_rule,
  /*  762 */  iRegIorL2I_rule,
  /*  763 */  immI0_rule,
  /*  764 */  iRegIorL2I_rule,
  /*  765 */  immI0_rule,
  /*  766 */  iRegL_rule,
  /*  767 */  immL0_rule,
  /*  768 */  iRegP_rule,
  /*  769 */  immP0_rule,
  /*  770 */  iRegN_rule,
  /*  771 */  immN0_rule,
  /*  772 */  vRegF_rule,
  /*  773 */  vRegD_rule,
  /*  774 */  0,
  /*  775 */  0,
  /*  776 */  0,
  /*  777 */  0,
  /*  778 */  0,
  /*  779 */  0,
  /*  780 */  0,
  /*  781 */  0,
  /*  782 */  0,
  /*  783 */  0,
  /*  784 */  0,
  /*  785 */  0,
  /*  786 */  0,
  /*  787 */  0,
  /*  788 */  0,
  /*  789 */  0,
  /*  790 */  0,
  /*  791 */  0,
  /*  792 */  0,
  /*  793 */  0,
  /*  794 */  0,
  /*  795 */  0,
  /*  796 */  0,
  /*  797 */  0,
  /*  798 */  0,
  /*  799 */  0,
  /*  800 */  0,
  /*  801 */  0,
  /*  802 */  0,
  /*  803 */  0,
  /*  804 */  0,
  /*  805 */  0,
  /*  806 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  807 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  808 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  809 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  810 */  _Binary_iRegP_iRegP_rule,
  /*  811 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  812 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  813 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  814 */  _Binary_iRegINoSp_iRegINoSp_rule,
  /*  815 */  _Binary_iRegLNoSp_iRegLNoSp_rule,
  /*  816 */  _Binary_iRegP_iRegP_rule,
  /*  817 */  _Binary_iRegNNoSp_iRegNNoSp_rule,
  /*  818 */  _Binary_iRegI_iRegI_rule,
  /*  819 */  _Binary_iRegI_iRegI_rule,
  /*  820 */  _Binary_iRegI_iRegI_rule,
  /*  821 */  _Binary_iRegL_iRegL_rule,
  /*  822 */  _Binary_iRegN_iRegN_rule,
  /*  823 */  _Binary_iRegP_iRegP_rule,
  /*  824 */  _Binary_iRegI_iRegI_rule,
  /*  825 */  _Binary_iRegI_iRegI_rule,
  /*  826 */  _Binary_iRegI_iRegI_rule,
  /*  827 */  _Binary_iRegL_iRegL_rule,
  /*  828 */  _Binary_iRegN_iRegN_rule,
  /*  829 */  _Binary_iRegP_iRegP_rule,
  /*  830 */  _Binary_iRegI_iRegI_rule,
  /*  831 */  _Binary_iRegI_iRegI_rule,
  /*  832 */  _Binary_iRegI_iRegI_rule,
  /*  833 */  _Binary_iRegL_iRegL_rule,
  /*  834 */  _Binary_iRegN_iRegN_rule,
  /*  835 */  _Binary_iRegP_iRegP_rule,
  /*  836 */  _Binary_iRegI_iRegI_rule,
  /*  837 */  _Binary_iRegI_iRegI_rule,
  /*  838 */  _Binary_iRegI_iRegI_rule,
  /*  839 */  _Binary_iRegL_iRegL_rule,
  /*  840 */  _Binary_iRegN_iRegN_rule,
  /*  841 */  _Binary_iRegP_iRegP_rule,
  /*  842 */  iRegI_rule,
  /*  843 */  iRegL_rule,
  /*  844 */  iRegN_rule,
  /*  845 */  iRegP_rule,
  /*  846 */  iRegI_rule,
  /*  847 */  iRegL_rule,
  /*  848 */  iRegN_rule,
  /*  849 */  iRegP_rule,
  /*  850 */  iRegL_rule,
  /*  851 */  iRegL_rule,
  /*  852 */  immLAddSub_rule,
  /*  853 */  immLAddSub_rule,
  /*  854 */  iRegIorL2I_rule,
  /*  855 */  iRegIorL2I_rule,
  /*  856 */  immIAddSub_rule,
  /*  857 */  immIAddSub_rule,
  /*  858 */  iRegL_rule,
  /*  859 */  iRegL_rule,
  /*  860 */  immLAddSub_rule,
  /*  861 */  immLAddSub_rule,
  /*  862 */  iRegIorL2I_rule,
  /*  863 */  iRegIorL2I_rule,
  /*  864 */  immIAddSub_rule,
  /*  865 */  immIAddSub_rule,
  /*  866 */  iRegL_rule,
  /*  867 */  immLAddSub_rule,
  /*  868 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  869 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  870 */  _Binary_immI0_iRegIorL2I_rule,
  /*  871 */  _Binary_immI0_iRegIorL2I_rule,
  /*  872 */  _Binary_iRegIorL2I_immI0_rule,
  /*  873 */  _Binary_iRegIorL2I_immI0_rule,
  /*  874 */  _Binary_immI_1_immI0_rule,
  /*  875 */  _Binary_immI_1_immI0_rule,
  /*  876 */  _Binary_iRegL_iRegL_rule,
  /*  877 */  _Binary_iRegL_iRegL_rule,
  /*  878 */  _Binary_iRegL_immL0_rule,
  /*  879 */  _Binary_iRegL_immL0_rule,
  /*  880 */  _Binary_immL0_iRegL_rule,
  /*  881 */  _Binary_immL0_iRegL_rule,
  /*  882 */  _Binary_iRegP_iRegP_rule,
  /*  883 */  _Binary_iRegP_iRegP_rule,
  /*  884 */  _Binary_iRegP_immP0_rule,
  /*  885 */  _Binary_iRegP_immP0_rule,
  /*  886 */  _Binary_immP0_iRegP_rule,
  /*  887 */  _Binary_immP0_iRegP_rule,
  /*  888 */  _Binary_iRegN_iRegN_rule,
  /*  889 */  _Binary_iRegN_iRegN_rule,
  /*  890 */  _Binary_iRegN_immN0_rule,
  /*  891 */  _Binary_iRegN_immN0_rule,
  /*  892 */  _Binary_immN0_iRegN_rule,
  /*  893 */  _Binary_immN0_iRegN_rule,
  /*  894 */  _Binary_vRegF_vRegF_rule,
  /*  895 */  _Binary_vRegF_vRegF_rule,
  /*  896 */  _Binary_vRegD_vRegD_rule,
  /*  897 */  _Binary_vRegD_vRegD_rule,
  /*  898 */  iRegIorL2I_rule,
  /*  899 */  immIAddSub_rule,
  /*  900 */  immIAddSub_rule,
  /*  901 */  iRegL_rule,
  /*  902 */  _ConvI2L_iRegIorL2I__rule,
  /*  903 */  _LShiftL_iRegL_immIScale_rule,
  /*  904 */  _LShiftL__ConvI2L_iRegIorL2I__immIScale_rule,
  /*  905 */  immI_rule,
  /*  906 */  immLAddSub_rule,
  /*  907 */  iRegL_rule,
  /*  908 */  immLAddSub_rule,
  /*  909 */  iRegIorL2I_rule,
  /*  910 */  immIAddSub_rule,
  /*  911 */  iRegL_rule,
  /*  912 */  immLAddSub_rule,
  /*  913 */  iRegIorL2I_rule,
  /*  914 */  iRegL_rule,
  /*  915 */  iRegIorL2I_rule,
  /*  916 */  _ConvI2L_iRegIorL2I__rule,
  /*  917 */  _ConvI2L_iRegIorL2I__rule,
  /*  918 */  iRegL_rule,
  /*  919 */  iRegL_rule,
  /*  920 */  iRegL_rule,
  /*  921 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  922 */  iRegIorL2I_rule,
  /*  923 */  _MulI_iRegIorL2I_iRegIorL2I_rule,
  /*  924 */  iRegIorL2I_rule,
  /*  925 */  _SubI_immI0_iRegIorL2I_rule,
  /*  926 */  _MulL_iRegL_iRegL_rule,
  /*  927 */  iRegL_rule,
  /*  928 */  _MulL_iRegL_iRegL_rule,
  /*  929 */  iRegL_rule,
  /*  930 */  _SubL_immL0_iRegL_rule,
  /*  931 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  932 */  iRegLNoSp_rule,
  /*  933 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  934 */  iRegLNoSp_rule,
  /*  935 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  936 */  _MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I__rule,
  /*  937 */  _ConvI2L_iRegIorL2I__rule,
  /*  938 */  _SubL_immL0__ConvI2L_iRegIorL2I__rule,
  /*  939 */  _Binary_iRegIorL2I_iRegIorL2I_rule,
  /*  940 */  iRegIorL2I_rule,
  /*  941 */  iRegL_rule,
  /*  942 */  iRegIorL2I_rule,
  /*  943 */  iRegL_rule,
  /*  944 */  iRegIorL2I_rule,
  /*  945 */  immI_rule,
  /*  946 */  iRegIorL2I_rule,
  /*  947 */  immI_rule,
  /*  948 */  iRegIorL2I_rule,
  /*  949 */  immI_rule,
  /*  950 */  iRegIorL2I_rule,
  /*  951 */  immI_rule,
  /*  952 */  iRegIorL2I_rule,
  /*  953 */  immI_rule,
  /*  954 */  immI_rule,
  /*  955 */  iRegIorL2I_rule,
  /*  956 */  immI_rule,
  /*  957 */  immL_M1_rule,
  /*  958 */  immI_M1_rule,
  /*  959 */  _URShiftI_iRegIorL2I_immI_rule,
  /*  960 */  _RShiftI_iRegIorL2I_immI_rule,
  /*  961 */  _LShiftI_iRegIorL2I_immI_rule,
  /*  962 */  _URShiftL_iRegL_immI_rule,
  /*  963 */  _RShiftL_iRegL_immI_rule,
  /*  964 */  _LShiftL_iRegL_immI_rule,
  /*  965 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  966 */  iRegIorL2I_rule,
  /*  967 */  _XorL_iRegL_immL_M1_rule,
  /*  968 */  iRegL_rule,
  /*  969 */  _XorI_iRegIorL2I_immI_M1_rule,
  /*  970 */  iRegIorL2I_rule,
  /*  971 */  _XorL_iRegL_immL_M1_rule,
  /*  972 */  iRegL_rule,
  /*  973 */  _XorI_iRegIorL2I_iRegIorL2I_rule,
  /*  974 */  immI_M1_rule,
  /*  975 */  _XorL_iRegL_iRegL_rule,
  /*  976 */  immL_M1_rule,
  /*  977 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  978 */  iRegIorL2I_rule,
  /*  979 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /*  980 */  iRegL_rule,
  /*  981 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  982 */  iRegIorL2I_rule,
  /*  983 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /*  984 */  iRegL_rule,
  /*  985 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /*  986 */  iRegIorL2I_rule,
  /*  987 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /*  988 */  iRegL_rule,
  /*  989 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /*  990 */  iRegIorL2I_rule,
  /*  991 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /*  992 */  iRegL_rule,
  /*  993 */  _XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /*  994 */  immI_M1_rule,
  /*  995 */  _XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI_rule,
  /*  996 */  immI_M1_rule,
  /*  997 */  _XorL__URShiftL_iRegL_immI_iRegL_rule,
  /*  998 */  immL_M1_rule,
  /*  999 */  _XorL_iRegL__URShiftL_iRegL_immI_rule,
  /* 1000 */  immL_M1_rule,
  /* 1001 */  _XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1002 */  immI_M1_rule,
  /* 1003 */  _XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI_rule,
  /* 1004 */  immI_M1_rule,
  /* 1005 */  _XorL__RShiftL_iRegL_immI_iRegL_rule,
  /* 1006 */  immL_M1_rule,
  /* 1007 */  _XorL_iRegL__RShiftL_iRegL_immI_rule,
  /* 1008 */  immL_M1_rule,
  /* 1009 */  _XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1010 */  immI_M1_rule,
  /* 1011 */  _XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI_rule,
  /* 1012 */  immI_M1_rule,
  /* 1013 */  _XorL__RotateRight_iRegL_immI_iRegL_rule,
  /* 1014 */  immL_M1_rule,
  /* 1015 */  _XorL_iRegL__RotateRight_iRegL_immI_rule,
  /* 1016 */  immL_M1_rule,
  /* 1017 */  _XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I_rule,
  /* 1018 */  immI_M1_rule,
  /* 1019 */  _XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI_rule,
  /* 1020 */  immI_M1_rule,
  /* 1021 */  _XorL__LShiftL_iRegL_immI_iRegL_rule,
  /* 1022 */  immL_M1_rule,
  /* 1023 */  _XorL_iRegL__LShiftL_iRegL_immI_rule,
  /* 1024 */  immL_M1_rule,
  /* 1025 */  _XorI__URShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1026 */  iRegIorL2I_rule,
  /* 1027 */  _XorL__URShiftL_iRegL_immI_immL_M1_rule,
  /* 1028 */  iRegL_rule,
  /* 1029 */  _XorI__RShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1030 */  iRegIorL2I_rule,
  /* 1031 */  _XorL__RShiftL_iRegL_immI_immL_M1_rule,
  /* 1032 */  iRegL_rule,
  /* 1033 */  _XorI__RotateRight_iRegIorL2I_immI_immI_M1_rule,
  /* 1034 */  iRegIorL2I_rule,
  /* 1035 */  _XorL__RotateRight_iRegL_immI_immL_M1_rule,
  /* 1036 */  iRegL_rule,
  /* 1037 */  _XorI__LShiftI_iRegIorL2I_immI_immI_M1_rule,
  /* 1038 */  iRegIorL2I_rule,
  /* 1039 */  _XorL__LShiftL_iRegL_immI_immL_M1_rule,
  /* 1040 */  iRegL_rule,
  /* 1041 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1042 */  iRegIorL2I_rule,
  /* 1043 */  _URShiftL_iRegL_immI_rule,
  /* 1044 */  iRegL_rule,
  /* 1045 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1046 */  iRegIorL2I_rule,
  /* 1047 */  _RShiftL_iRegL_immI_rule,
  /* 1048 */  iRegL_rule,
  /* 1049 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1050 */  iRegIorL2I_rule,
  /* 1051 */  _LShiftL_iRegL_immI_rule,
  /* 1052 */  iRegL_rule,
  /* 1053 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1054 */  iRegIorL2I_rule,
  /* 1055 */  _RotateRight_iRegL_immI_rule,
  /* 1056 */  iRegL_rule,
  /* 1057 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1058 */  iRegIorL2I_rule,
  /* 1059 */  _URShiftL_iRegL_immI_rule,
  /* 1060 */  iRegL_rule,
  /* 1061 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1062 */  iRegIorL2I_rule,
  /* 1063 */  _RShiftL_iRegL_immI_rule,
  /* 1064 */  iRegL_rule,
  /* 1065 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1066 */  iRegIorL2I_rule,
  /* 1067 */  _LShiftL_iRegL_immI_rule,
  /* 1068 */  iRegL_rule,
  /* 1069 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1070 */  iRegIorL2I_rule,
  /* 1071 */  _RotateRight_iRegL_immI_rule,
  /* 1072 */  iRegL_rule,
  /* 1073 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1074 */  iRegIorL2I_rule,
  /* 1075 */  _URShiftL_iRegL_immI_rule,
  /* 1076 */  iRegL_rule,
  /* 1077 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1078 */  iRegIorL2I_rule,
  /* 1079 */  _RShiftL_iRegL_immI_rule,
  /* 1080 */  iRegL_rule,
  /* 1081 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1082 */  iRegIorL2I_rule,
  /* 1083 */  _LShiftL_iRegL_immI_rule,
  /* 1084 */  iRegL_rule,
  /* 1085 */  _RotateRight_iRegIorL2I_immI_rule,
  /* 1086 */  iRegIorL2I_rule,
  /* 1087 */  _RotateRight_iRegL_immI_rule,
  /* 1088 */  iRegL_rule,
  /* 1089 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1090 */  iRegIorL2I_rule,
  /* 1091 */  _URShiftL_iRegL_immI_rule,
  /* 1092 */  iRegL_rule,
  /* 1093 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1094 */  iRegIorL2I_rule,
  /* 1095 */  _RShiftL_iRegL_immI_rule,
  /* 1096 */  iRegL_rule,
  /* 1097 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1098 */  iRegIorL2I_rule,
  /* 1099 */  _LShiftL_iRegL_immI_rule,
  /* 1100 */  iRegL_rule,
  /* 1101 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1102 */  _URShiftL_iRegL_immI_rule,
  /* 1103 */  _RShiftI_iRegIorL2I_immI_rule,
  /* 1104 */  _RShiftL_iRegL_immI_rule,
  /* 1105 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1106 */  _LShiftL_iRegL_immI_rule,
  /* 1107 */  immI_rule,
  /* 1108 */  immI_rule,
  /* 1109 */  immI_rule,
  /* 1110 */  immI_rule,
  /* 1111 */  immI_bitmask_rule,
  /* 1112 */  immL_bitmask_rule,
  /* 1113 */  0,
  /* 1114 */  immI_rule,
  /* 1115 */  immI_rule,
  /* 1116 */  0,
  /* 1117 */  0,
  /* 1118 */  immI_rule,
  /* 1119 */  immI_rule,
  /* 1120 */  0,
  /* 1121 */  _URShiftL_iRegL_immI_rule,
  /* 1122 */  _LShiftL_iRegL_immI_rule,
  /* 1123 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1124 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1125 */  _URShiftL_iRegL_immI_rule,
  /* 1126 */  _LShiftL_iRegL_immI_rule,
  /* 1127 */  _URShiftI_iRegIorL2I_immI_rule,
  /* 1128 */  _LShiftI_iRegIorL2I_immI_rule,
  /* 1129 */  immI_rule,
  /* 1130 */  immI_rule,
  /* 1131 */  iRegI_rule,
  /* 1132 */  iRegI_rule,
  /* 1133 */  iRegI_rule,
  /* 1134 */  iRegI_rule,
  /* 1135 */  _ConvI2L_iRegIorL2I__rule,
  /* 1136 */  iRegL_rule,
  /* 1137 */  _ConvI2L_iRegIorL2I__rule,
  /* 1138 */  _RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_rule,
  /* 1139 */  iRegIorL2I_rule,
  /* 1140 */  _RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1141 */  iRegIorL2I_rule,
  /* 1142 */  _URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_rule,
  /* 1143 */  iRegIorL2I_rule,
  /* 1144 */  _RShiftL__LShiftL_iRegL_immI_48_immI_48_rule,
  /* 1145 */  iRegL_rule,
  /* 1146 */  _RShiftL__LShiftL_iRegL_immI_32_immI_32_rule,
  /* 1147 */  iRegL_rule,
  /* 1148 */  _RShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1149 */  iRegL_rule,
  /* 1150 */  _URShiftL__LShiftL_iRegL_immI_56_immI_56_rule,
  /* 1151 */  iRegL_rule,
  /* 1152 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1153 */  iRegIorL2I_rule,
  /* 1154 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1155 */  iRegIorL2I_rule,
  /* 1156 */  _AndL_iRegL_immL_255_rule,
  /* 1157 */  iRegL_rule,
  /* 1158 */  _AndL_iRegL_immL_65535_rule,
  /* 1159 */  iRegL_rule,
  /* 1160 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1161 */  iRegL_rule,
  /* 1162 */  _AndI_iRegIorL2I_immI_255_rule,
  /* 1163 */  _AndI_iRegIorL2I_immI_65535_rule,
  /* 1164 */  _AndL_iRegL_immL_255_rule,
  /* 1165 */  _AndL_iRegL_immL_65535_rule,
  /* 1166 */  _AndL_iRegL_immL_4294967295_rule,
  /* 1167 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1168 */  iRegL_rule,
  /* 1169 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1170 */  iRegL_rule,
  /* 1171 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1172 */  iRegL_rule,
  /* 1173 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt_rule,
  /* 1174 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt_rule,
  /* 1175 */  _LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt_rule,
  /* 1176 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1177 */  iRegIorL2I_rule,
  /* 1178 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1179 */  iRegIorL2I_rule,
  /* 1180 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt_rule,
  /* 1181 */  _LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt_rule,
  /* 1182 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1183 */  iRegL_rule,
  /* 1184 */  _LShiftL__ConvI2L_iRegIorL2I__immIExt_rule,
  /* 1185 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1186 */  iRegL_rule,
  /* 1187 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1188 */  iRegL_rule,
  /* 1189 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1190 */  iRegL_rule,
  /* 1191 */  _LShiftL__AndL_iRegL_immL_255_immIExt_rule,
  /* 1192 */  _LShiftL__AndL_iRegL_immL_65535_immIExt_rule,
  /* 1193 */  _LShiftL__AndL_iRegL_immL_4294967295_immIExt_rule,
  /* 1194 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1195 */  iRegIorL2I_rule,
  /* 1196 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1197 */  iRegIorL2I_rule,
  /* 1198 */  _LShiftI__AndI_iRegIorL2I_immI_255_immIExt_rule,
  /* 1199 */  _LShiftI__AndI_iRegIorL2I_immI_65535_immIExt_rule,
  /* 1200 */  vRegF_rule,
  /* 1201 */  vRegD_rule,
  /* 1202 */  vRegF_rule,
  /* 1203 */  vRegD_rule,
  /* 1204 */  vRegF_rule,
  /* 1205 */  vRegD_rule,
  /* 1206 */  _Binary_vRegF_vRegF_rule,
  /* 1207 */  _Binary_vRegD_vRegD_rule,
  /* 1208 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1209 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1210 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1211 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1212 */  _Binary__NegF_vRegF__vRegF_rule,
  /* 1213 */  _Binary_vRegF__NegF_vRegF__rule,
  /* 1214 */  _Binary__NegD_vRegD__vRegD_rule,
  /* 1215 */  _Binary_vRegD__NegD_vRegD__rule,
  /* 1216 */  _Binary_vRegF_vRegF_rule,
  /* 1217 */  _Binary_vRegD_vRegD_rule,
  /* 1218 */  vRegF_rule,
  /* 1219 */  vRegF_rule,
  /* 1220 */  vRegD_rule,
  /* 1221 */  vRegD_rule,
  /* 1222 */  vRegF_rule,
  /* 1223 */  vRegD_rule,
  /* 1224 */  0,
  /* 1225 */  0,
  /* 1226 */  0,
  /* 1227 */  0,
  /* 1228 */  0,
  /* 1229 */  0,
  /* 1230 */  immI_rule,
  /* 1231 */  _Binary_vRegD_vRegD_rule,
  /* 1232 */  vRegF_rule,
  /* 1233 */  _Binary_vRegD_vRegD_rule,
  /* 1234 */  _Binary_vRegF_vRegF_rule,
  /* 1235 */  0,
  /* 1236 */  iRegIorL2I_rule,
  /* 1237 */  immILog_rule,
  /* 1238 */  iRegIorL2I_rule,
  /* 1239 */  immILog_rule,
  /* 1240 */  iRegIorL2I_rule,
  /* 1241 */  immILog_rule,
  /* 1242 */  iRegL_rule,
  /* 1243 */  immLLog_rule,
  /* 1244 */  iRegL_rule,
  /* 1245 */  immLLog_rule,
  /* 1246 */  iRegL_rule,
  /* 1247 */  immLLog_rule,
  /* 1248 */  0,
  /* 1249 */  immL_32bits_rule,
  /* 1250 */  0,
  /* 1251 */  0,
  /* 1252 */  0,
  /* 1253 */  0,
  /* 1254 */  0,
  /* 1255 */  0,
  /* 1256 */  0,
  /* 1257 */  0,
  /* 1258 */  0,
  /* 1259 */  0,
  /* 1260 */  0,
  /* 1261 */  0,
  /* 1262 */  0,
  /* 1263 */  0,
  /* 1264 */  0,
  /* 1265 */  0,
  /* 1266 */  0,
  /* 1267 */  0,
  /* 1268 */  0,
  /* 1269 */  iRegP_R10_rule,
  /* 1270 */  iRegP_R10_rule,
  /* 1271 */  _OverflowMulI_iRegIorL2I_iRegIorL2I_rule,
  /* 1272 */  _OverflowMulL_iRegL_iRegL_rule,
  /* 1273 */  vRegF_rule,
  /* 1274 */  vRegD_rule,
  /* 1275 */  immF0_rule,
  /* 1276 */  immD0_rule,
  /* 1277 */  iRegIorL2I_rule,
  /* 1278 */  immI0_rule,
  /* 1279 */  0,
  /* 1280 */  iRegI_rule,
  /* 1281 */  0,
  /* 1282 */  iRegI_rule,
  /* 1283 */  0,
  /* 1284 */  rFlagsReg_rule,
  /* 1285 */  rFlagsRegU_rule,
  /* 1286 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1287 */  _CmpL_iRegL_immL0_rule,
  /* 1288 */  _CmpP_iRegP_immP0_rule,
  /* 1289 */  _CmpN_iRegN_immN0_rule,
  /* 1290 */  _CmpP__DecodeN_iRegN__immP0_rule,
  /* 1291 */  _CmpU_iRegIorL2I_immI0_rule,
  /* 1292 */  _CmpUL_iRegL_immL0_rule,
  /* 1293 */  _CmpL_iRegL_immL0_rule,
  /* 1294 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1295 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1296 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1297 */  _CmpL_iRegL_immL0_rule,
  /* 1298 */  _CmpI_iRegIorL2I_immI0_rule,
  /* 1299 */  _CmpL__AndL_iRegL_immL_immL0_rule,
  /* 1300 */  _CmpI__AndI_iRegIorL2I_immI_immI0_rule,
  /* 1301 */  rFlagsReg_rule,
  /* 1302 */  rFlagsRegU_rule,
  /* 1303 */  0,
  /* 1304 */  0,
  /* 1305 */  0,
  /* 1306 */  0,
  /* 1307 */  0,
  /* 1308 */  0,
  /* 1309 */  inline_cache_RegP_rule,
  /* 1310 */  iRegP_R0_rule,
  /* 1311 */  0,
  /* 1312 */  0,
  /* 1313 */  0,
  /* 1314 */  0,
  /* 1315 */  iRegP_R0_rule,
  /* 1316 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1317 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1318 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1319 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 1320 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1321 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1322 */  _Binary_iRegP_R3_iRegI_R2_rule,
  /* 1323 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1324 */  _Binary_iRegP_R3_immI_le_4_rule,
  /* 1325 */  _Binary_iRegP_R3_immI_1_rule,
  /* 1326 */  iRegI_R3_rule,
  /* 1327 */  iRegI_R3_rule,
  /* 1328 */  iRegI_R4_rule,
  /* 1329 */  iRegI_R4_rule,
  /* 1330 */  iRegP_R2_rule,
  /* 1331 */  iRegP_R2_rule,
  /* 1332 */  iRegI_R2_rule,
  /* 1333 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1334 */  _Binary_iRegP_R1_iRegI_R2_rule,
  /* 1335 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1336 */  _Binary_iRegP_R1_iRegI_R3_rule,
  /* 1337 */  0,
  /* 1338 */  0,
  /* 1339 */  0,
  /* 1340 */  0,
  /* 1341 */  vecD_rule,
  /* 1342 */  vecD_rule,
  /* 1343 */  vecD_rule,
  /* 1344 */  vecX_rule,
  /* 1345 */  0,
  /* 1346 */  0,
  /* 1347 */  0,
  /* 1348 */  0,
  /* 1349 */  0,
  /* 1350 */  vecD_rule,
  /* 1351 */  vecX_rule,
  /* 1352 */  vecD_rule,
  /* 1353 */  vecX_rule,
  /* 1354 */  vecX_rule,
  /* 1355 */  vecD_rule,
  /* 1356 */  vecX_rule,
  /* 1357 */  vecD_rule,
  /* 1358 */  vecX_rule,
  /* 1359 */  vecX_rule,
  /* 1360 */  vecD_rule,
  /* 1361 */  vecX_rule,
  /* 1362 */  vecD_rule,
  /* 1363 */  vecX_rule,
  /* 1364 */  vecX_rule,
  /* 1365 */  vecD_rule,
  /* 1366 */  vecX_rule,
  /* 1367 */  vecD_rule,
  /* 1368 */  vecX_rule,
  /* 1369 */  vecX_rule,
  /* 1370 */  vecD_rule,
  /* 1371 */  vecD_rule,
  /* 1372 */  vecX_rule,
  /* 1373 */  vecX_rule,
  /* 1374 */  vecD_rule,
  /* 1375 */  vecX_rule,
  /* 1376 */  vecX_rule,
  /* 1377 */  vecD_rule,
  /* 1378 */  vecX_rule,
  /* 1379 */  vecX_rule,
  /* 1380 */  vecD_rule,
  /* 1381 */  vecD_rule,
  /* 1382 */  vecD_rule,
  /* 1383 */  vecX_rule,
  /* 1384 */  vecX_rule,
  /* 1385 */  vecX_rule,
  /* 1386 */  vecD_rule,
  /* 1387 */  vecD_rule,
  /* 1388 */  vecD_rule,
  /* 1389 */  vecX_rule,
  /* 1390 */  vecX_rule,
  /* 1391 */  vecX_rule,
  /* 1392 */  vecD_rule,
  /* 1393 */  vecD_rule,
  /* 1394 */  vecD_rule,
  /* 1395 */  vecX_rule,
  /* 1396 */  vecX_rule,
  /* 1397 */  vecX_rule,
  /* 1398 */  vecX_rule,
  /* 1399 */  vecX_rule,
  /* 1400 */  vecX_rule,
  /* 1401 */  immI_rule,
  /* 1402 */  immI_rule,
  /* 1403 */  immI_rule,
  /* 1404 */  immI_rule,
  /* 1405 */  immI_rule,
  /* 1406 */  immI_rule,
  /* 1407 */  immI_rule,
  /* 1408 */  immI_rule,
  /* 1409 */  immI_rule,
  /* 1410 */  immI_rule,
  /* 1411 */  immI_rule,
  /* 1412 */  immI_rule,
  /* 1413 */  immI_rule,
  /* 1414 */  immI_rule,
  /* 1415 */  immI_rule,
  /* 1416 */  immI_rule,
  /* 1417 */  immI_rule,
  /* 1418 */  immI_rule,
  /* 1419 */  vecX_rule,
  /* 1420 */  _ReplicateB_immI_M1__rule,
  /* 1421 */  vecD_rule,
  /* 1422 */  _ReplicateS_immI_M1__rule,
  /* 1423 */  vecD_rule,
  /* 1424 */  _ReplicateI_immI_M1__rule,
  /* 1425 */  vecD_rule,
  /* 1426 */  _ReplicateB_immI_M1__rule,
  /* 1427 */  vecX_rule,
  /* 1428 */  _ReplicateS_immI_M1__rule,
  /* 1429 */  vecX_rule,
  /* 1430 */  _ReplicateI_immI_M1__rule,
  /* 1431 */  vecX_rule,
  /* 1432 */  _ReplicateL_immL_M1__rule,
  /* 1433 */  vecX_rule,
  /* 1434 */  _XorV_vecD__ReplicateB_immI_M1__rule,
  /* 1435 */  vecD_rule,
  /* 1436 */  _XorV__ReplicateB_immI_M1__vecD_rule,
  /* 1437 */  vecD_rule,
  /* 1438 */  _XorV_vecD__ReplicateS_immI_M1__rule,
  /* 1439 */  vecD_rule,
  /* 1440 */  _XorV__ReplicateS_immI_M1__vecD_rule,
  /* 1441 */  vecD_rule,
  /* 1442 */  _XorV_vecD__ReplicateI_immI_M1__rule,
  /* 1443 */  vecD_rule,
  /* 1444 */  _XorV__ReplicateI_immI_M1__vecD_rule,
  /* 1445 */  vecD_rule,
  /* 1446 */  _XorV_vecX__ReplicateB_immI_M1__rule,
  /* 1447 */  vecX_rule,
  /* 1448 */  _XorV__ReplicateB_immI_M1__vecX_rule,
  /* 1449 */  vecX_rule,
  /* 1450 */  _XorV_vecX__ReplicateS_immI_M1__rule,
  /* 1451 */  vecX_rule,
  /* 1452 */  _XorV__ReplicateS_immI_M1__vecX_rule,
  /* 1453 */  vecX_rule,
  /* 1454 */  _XorV_vecX__ReplicateI_immI_M1__rule,
  /* 1455 */  vecX_rule,
  /* 1456 */  _XorV__ReplicateI_immI_M1__vecX_rule,
  /* 1457 */  vecX_rule,
  /* 1458 */  _XorV_vecX__ReplicateL_immL_M1__rule,
  /* 1459 */  vecX_rule,
  /* 1460 */  _XorV__ReplicateL_immL_M1__vecX_rule,
  /* 1461 */  vecX_rule,
  /* 1462 */  vecD_rule,
  /* 1463 */  vecX_rule,
  /* 1464 */  vecD_rule,
  /* 1465 */  vecX_rule,
  /* 1466 */  vecD_rule,
  /* 1467 */  vecX_rule,
  /* 1468 */  vecD_rule,
  /* 1469 */  vecX_rule,
  /* 1470 */  vecD_rule,
  /* 1471 */  vecX_rule,
  /* 1472 */  vecD_rule,
  /* 1473 */  vecX_rule,
  /* 1474 */  vecX_rule,
  /* 1475 */  vecX_rule,
  /* 1476 */  vecD_rule,
  /* 1477 */  vecX_rule,
  /* 1478 */  immI_1_rule,
  /* 1479 */  immI_1_rule,
  /* 1480 */  immI_2_rule,
  /* 1481 */  immI_2_rule,
  /* 1482 */  immI_4_rule,
  /* 1483 */  immI_4_rule,
  /* 1484 */  immI_8_rule,
  /* 1485 */  vecD_rule,
  /* 1486 */  vecX_rule,
  /* 1487 */  vecD_rule,
  /* 1488 */  vecX_rule,
  /* 1489 */  vecX_rule,
  /* 1490 */  vecD_rule,
  /* 1491 */  vecX_rule,
  /* 1492 */  vecD_rule,
  /* 1493 */  vecX_rule,
  /* 1494 */  0,
  /* 1495 */  0,
  /* 1496 */  0,
  /* 1497 */  0,
  /* 1498 */  0,
  /* 1499 */  0,
  /* 1500 */  0,
  /* 1501 */  0,
  /* 1502 */  0,
  /* 1503 */  0,
  /* 1504 */  0,
  /* 1505 */  0,
  /* 1506 */  0,
  /* 1507 */  0,
  /* 1508 */  0,
  /* 1509 */  0,
  /* 1510 */  0,
  /* 1511 */  0,
  /* 1512 */  0,
  /* 1513 */  0,
  /* 1514 */  vecD_rule,
  /* 1515 */  vecX_rule,
  /* 1516 */  vecD_rule,
  /* 1517 */  vecX_rule,
  /* 1518 */  vecD_rule,
  /* 1519 */  vecX_rule,
  /* 1520 */  vecD_rule,
  /* 1521 */  vecX_rule,
  /* 1522 */  vecX_rule,
  /* 1523 */  vecX_rule,
  /* 1524 */  vecD_rule,
  /* 1525 */  vecX_rule,
  /* 1526 */  vecD_rule,
  /* 1527 */  vecX_rule,
  /* 1528 */  vecD_rule,
  /* 1529 */  vecX_rule,
  /* 1530 */  vecX_rule,
  /* 1531 */  vecD_rule,
  /* 1532 */  vecX_rule,
  /* 1533 */  vecX_rule,
  /* 1534 */  vecD_rule,
  /* 1535 */  vecX_rule,
  /* 1536 */  vecD_rule,
  /* 1537 */  vecX_rule,
  /* 1538 */  vecD_rule,
  /* 1539 */  vecX_rule,
  /* 1540 */  vecX_rule,
  /* 1541 */  vecD_rule,
  /* 1542 */  vecX_rule,
  /* 1543 */  vecX_rule,
  /* 1544 */  vecD_rule,
  /* 1545 */  vecX_rule,
  /* 1546 */  vecD_rule,
  /* 1547 */  vecX_rule,
  /* 1548 */  vecD_rule,
  /* 1549 */  vecX_rule,
  /* 1550 */  vecD_rule,
  /* 1551 */  vecX_rule,
  /* 1552 */  vecX_rule,
  /* 1553 */  _MulVS_vecD_vecD_rule,
  /* 1554 */  vecD_rule,
  /* 1555 */  _MulVS_vecX_vecX_rule,
  /* 1556 */  vecX_rule,
  /* 1557 */  _MulVI_vecD_vecD_rule,
  /* 1558 */  vecD_rule,
  /* 1559 */  _MulVI_vecX_vecX_rule,
  /* 1560 */  vecX_rule,
  /* 1561 */  _Binary_vecD_vecD_rule,
  /* 1562 */  _Binary_vecX_vecX_rule,
  /* 1563 */  _Binary_vecX_vecX_rule,
  /* 1564 */  _MulVS_vecD_vecD_rule,
  /* 1565 */  _MulVS_vecX_vecX_rule,
  /* 1566 */  _MulVI_vecD_vecD_rule,
  /* 1567 */  _MulVI_vecX_vecX_rule,
  /* 1568 */  _Binary__NegVF_vecD__vecD_rule,
  /* 1569 */  _Binary_vecD__NegVF_vecD__rule,
  /* 1570 */  _Binary__NegVF_vecX__vecX_rule,
  /* 1571 */  _Binary_vecX__NegVF_vecX__rule,
  /* 1572 */  _Binary__NegVD_vecX__vecX_rule,
  /* 1573 */  _Binary_vecX__NegVD_vecX__rule,
  /* 1574 */  vecX_rule,
  /* 1575 */  vecD_rule,
  /* 1576 */  vecX_rule,
  /* 1577 */  vecX_rule,
  /* 1578 */  vecD_rule,
  /* 1579 */  vecX_rule,
  /* 1580 */  vecD_rule,
  /* 1581 */  vecX_rule,
  /* 1582 */  vecD_rule,
  /* 1583 */  vecX_rule,
  /* 1584 */  vecD_rule,
  /* 1585 */  vecX_rule,
  /* 1586 */  vecD_rule,
  /* 1587 */  vecD_rule,
  /* 1588 */  vecX_rule,
  /* 1589 */  vecX_rule,
  /* 1590 */  vecD_rule,
  /* 1591 */  vecD_rule,
  /* 1592 */  vecX_rule,
  /* 1593 */  vecX_rule,
  /* 1594 */  _LShiftCntV_immI__rule,
  /* 1595 */  _LShiftCntV_immI__rule,
  /* 1596 */  _RShiftCntV_immI_positive__rule,
  /* 1597 */  _RShiftCntV_immI_positive__rule,
  /* 1598 */  _RShiftCntV_immI_positive__rule,
  /* 1599 */  _RShiftCntV_immI_positive__rule,
  /* 1600 */  vecD_rule,
  /* 1601 */  vecX_rule,
  /* 1602 */  vecD_rule,
  /* 1603 */  vecD_rule,
  /* 1604 */  vecX_rule,
  /* 1605 */  vecX_rule,
  /* 1606 */  vecD_rule,
  /* 1607 */  vecD_rule,
  /* 1608 */  vecX_rule,
  /* 1609 */  vecX_rule,
  /* 1610 */  _LShiftCntV_immI__rule,
  /* 1611 */  _LShiftCntV_immI__rule,
  /* 1612 */  _RShiftCntV_immI_positive__rule,
  /* 1613 */  _RShiftCntV_immI_positive__rule,
  /* 1614 */  _RShiftCntV_immI_positive__rule,
  /* 1615 */  _RShiftCntV_immI_positive__rule,
  /* 1616 */  vecD_rule,
  /* 1617 */  vecX_rule,
  /* 1618 */  vecD_rule,
  /* 1619 */  vecD_rule,
  /* 1620 */  vecX_rule,
  /* 1621 */  vecX_rule,
  /* 1622 */  vecD_rule,
  /* 1623 */  vecD_rule,
  /* 1624 */  vecX_rule,
  /* 1625 */  vecX_rule,
  /* 1626 */  _LShiftCntV_immI__rule,
  /* 1627 */  _LShiftCntV_immI__rule,
  /* 1628 */  _RShiftCntV_immI_positive__rule,
  /* 1629 */  _RShiftCntV_immI_positive__rule,
  /* 1630 */  _RShiftCntV_immI_positive__rule,
  /* 1631 */  _RShiftCntV_immI_positive__rule,
  /* 1632 */  vecX_rule,
  /* 1633 */  vecX_rule,
  /* 1634 */  vecX_rule,
  /* 1635 */  vecX_rule,
  /* 1636 */  vecX_rule,
  /* 1637 */  _LShiftCntV_immI__rule,
  /* 1638 */  _RShiftCntV_immI_positive__rule,
  /* 1639 */  _RShiftCntV_immI_positive__rule,
  /* 1640 */  _RShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /* 1641 */  vecD_rule,
  /* 1642 */  _RShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /* 1643 */  vecX_rule,
  /* 1644 */  _RShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /* 1645 */  vecD_rule,
  /* 1646 */  _RShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /* 1647 */  vecX_rule,
  /* 1648 */  _RShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /* 1649 */  vecD_rule,
  /* 1650 */  _RShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /* 1651 */  vecX_rule,
  /* 1652 */  _RShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /* 1653 */  vecX_rule,
  /* 1654 */  _URShiftVB_vecD__RShiftCntV_immI_positive__rule,
  /* 1655 */  vecD_rule,
  /* 1656 */  _URShiftVB_vecX__RShiftCntV_immI_positive__rule,
  /* 1657 */  vecX_rule,
  /* 1658 */  _URShiftVS_vecD__RShiftCntV_immI_positive__rule,
  /* 1659 */  vecD_rule,
  /* 1660 */  _URShiftVS_vecX__RShiftCntV_immI_positive__rule,
  /* 1661 */  vecX_rule,
  /* 1662 */  _URShiftVI_vecD__RShiftCntV_immI_positive__rule,
  /* 1663 */  vecD_rule,
  /* 1664 */  _URShiftVI_vecX__RShiftCntV_immI_positive__rule,
  /* 1665 */  vecX_rule,
  /* 1666 */  _URShiftVL_vecX__RShiftCntV_immI_positive__rule,
  /* 1667 */  vecX_rule,
  /* 1668 */  vecD_rule,
  /* 1669 */  vecX_rule,
  /* 1670 */  vecX_rule,
  /* 1671 */  vecD_rule,
  /* 1672 */  vecX_rule,
  /* 1673 */  vecX_rule,
  /* 1674 */  immI_rule,
  /* 1675 */  0,
  /* 1676 */  0,
  /* 1677 */  0,
  /* 1678 */  0,
  /* 1679 */  vReg_rule,
  /* 1680 */  0,
  /* 1681 */  vReg_rule,
  /* 1682 */  0,
  /* 1683 */  vReg_rule,
  /* 1684 */  0,
  /* 1685 */  vReg_rule,
  /* 1686 */  0,
  /* 1687 */  vReg_rule,
  /* 1688 */  0,
  /* 1689 */  vReg_rule,
  /* 1690 */  pRegGov_rule,
  /* 1691 */  _Binary_vReg_pRegGov_rule,
  /* 1692 */  pRegGov_rule,
  /* 1693 */  pRegGov_rule,
  /* 1694 */  pRegGov_rule,
  /* 1695 */  _XorVMask_pRegGov__MaskAll_immI_M1__rule,
  /* 1696 */  _XorVMask_pRegGov__MaskAll_immL_M1__rule,
  /* 1697 */  0,
  /* 1698 */  0,
  /* 1699 */  pRegGov_rule,
  /* 1700 */  pRegGov_rule,
  /* 1701 */  pRegGov_rule,
  /* 1702 */  pRegGov_rule,
  /* 1703 */  pRegGov_rule,
  /* 1704 */  pRegGov_rule,
  /* 1705 */  vReg_rule,
  /* 1706 */  vReg_rule,
  /* 1707 */  vReg_rule,
  /* 1708 */  vReg_rule,
  /* 1709 */  vReg_rule,
  /* 1710 */  vReg_rule,
  /* 1711 */  pRegGov_rule,
  /* 1712 */  pRegGov_rule,
  /* 1713 */  pRegGov_rule,
  /* 1714 */  pRegGov_rule,
  /* 1715 */  pRegGov_rule,
  /* 1716 */  pRegGov_rule,
  /* 1717 */  _ReplicateB_immBAddSubV__rule,
  /* 1718 */  vReg_rule,
  /* 1719 */  _ReplicateS_immIAddSubV__rule,
  /* 1720 */  vReg_rule,
  /* 1721 */  _ReplicateI_immIAddSubV__rule,
  /* 1722 */  vReg_rule,
  /* 1723 */  _ReplicateL_immLAddSubV__rule,
  /* 1724 */  vReg_rule,
  /* 1725 */  _ReplicateB_immBLog__rule,
  /* 1726 */  vReg_rule,
  /* 1727 */  _ReplicateS_immSLog__rule,
  /* 1728 */  vReg_rule,
  /* 1729 */  _ReplicateI_immILog__rule,
  /* 1730 */  vReg_rule,
  /* 1731 */  _ReplicateL_immLLog__rule,
  /* 1732 */  vReg_rule,
  /* 1733 */  _ReplicateB_immBLog__rule,
  /* 1734 */  vReg_rule,
  /* 1735 */  _ReplicateS_immSLog__rule,
  /* 1736 */  vReg_rule,
  /* 1737 */  _ReplicateI_immILog__rule,
  /* 1738 */  vReg_rule,
  /* 1739 */  _ReplicateL_immLLog__rule,
  /* 1740 */  vReg_rule,
  /* 1741 */  _ReplicateB_immBLog__rule,
  /* 1742 */  vReg_rule,
  /* 1743 */  _ReplicateS_immSLog__rule,
  /* 1744 */  vReg_rule,
  /* 1745 */  _ReplicateI_immILog__rule,
  /* 1746 */  vReg_rule,
  /* 1747 */  _ReplicateL_immLLog__rule,
  /* 1748 */  vReg_rule,
  /* 1749 */  vReg_rule,
  /* 1750 */  vReg_rule,
  /* 1751 */  vReg_rule,
  /* 1752 */  pRegGov_rule,
  /* 1753 */  pRegGov_rule,
  /* 1754 */  pRegGov_rule,
  /* 1755 */  _ReplicateB_immI_M1__rule,
  /* 1756 */  vReg_rule,
  /* 1757 */  _ReplicateS_immI_M1__rule,
  /* 1758 */  vReg_rule,
  /* 1759 */  _ReplicateI_immI_M1__rule,
  /* 1760 */  vReg_rule,
  /* 1761 */  _ReplicateL_immL_M1__rule,
  /* 1762 */  vReg_rule,
  /* 1763 */  pRegGov_rule,
  /* 1764 */  pRegGov_rule,
  /* 1765 */  pRegGov_rule,
  /* 1766 */  pRegGov_rule,
  /* 1767 */  _XorV_vReg__ReplicateB_immI_M1__rule,
  /* 1768 */  vReg_rule,
  /* 1769 */  _XorV__ReplicateB_immI_M1__vReg_rule,
  /* 1770 */  vReg_rule,
  /* 1771 */  _XorV_vReg__ReplicateS_immI_M1__rule,
  /* 1772 */  vReg_rule,
  /* 1773 */  _XorV__ReplicateS_immI_M1__vReg_rule,
  /* 1774 */  vReg_rule,
  /* 1775 */  _XorV_vReg__ReplicateI_immI_M1__rule,
  /* 1776 */  vReg_rule,
  /* 1777 */  _XorV__ReplicateI_immI_M1__vReg_rule,
  /* 1778 */  vReg_rule,
  /* 1779 */  _XorV_vReg__ReplicateL_immL_M1__rule,
  /* 1780 */  vReg_rule,
  /* 1781 */  _XorV__ReplicateL_immL_M1__vReg_rule,
  /* 1782 */  vReg_rule,
  /* 1783 */  pRegGov_rule,
  /* 1784 */  pRegGov_rule,
  /* 1785 */  pRegGov_rule,
  /* 1786 */  pRegGov_rule,
  /* 1787 */  pRegGov_rule,
  /* 1788 */  pRegGov_rule,
  /* 1789 */  pRegGov_rule,
  /* 1790 */  pRegGov_rule,
  /* 1791 */  vReg_rule,
  /* 1792 */  vReg_rule,
  /* 1793 */  pRegGov_rule,
  /* 1794 */  pRegGov_rule,
  /* 1795 */  vReg_rule,
  /* 1796 */  vReg_rule,
  /* 1797 */  pRegGov_rule,
  /* 1798 */  pRegGov_rule,
  /* 1799 */  _Binary_vReg_vReg_rule,
  /* 1800 */  _Binary_vReg_vReg_rule,
  /* 1801 */  _Binary_vReg_pRegGov_rule,
  /* 1802 */  _Binary_vReg_pRegGov_rule,
  /* 1803 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1804 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1805 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1806 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1807 */  _Binary_vReg_pRegGov_rule,
  /* 1808 */  _Binary_vReg_pRegGov_rule,
  /* 1809 */  _Binary__NegVF_vReg__vReg_rule,
  /* 1810 */  _Binary_vReg__NegVF_vReg__rule,
  /* 1811 */  _Binary__NegVD_vReg__vReg_rule,
  /* 1812 */  _Binary_vReg__NegVD_vReg__rule,
  /* 1813 */  _Binary__NegVF_vReg__pRegGov_rule,
  /* 1814 */  _Binary__NegVD_vReg__pRegGov_rule,
  /* 1815 */  _Binary_vReg_vReg_rule,
  /* 1816 */  _Binary_vReg_vReg_rule,
  /* 1817 */  _Binary__NegVF_vReg__pRegGov_rule,
  /* 1818 */  _Binary__NegVD_vReg__pRegGov_rule,
  /* 1819 */  _MulVB_vReg_vReg_rule,
  /* 1820 */  vReg_rule,
  /* 1821 */  _MulVS_vReg_vReg_rule,
  /* 1822 */  vReg_rule,
  /* 1823 */  _MulVI_vReg_vReg_rule,
  /* 1824 */  vReg_rule,
  /* 1825 */  _MulVL_vReg_vReg_rule,
  /* 1826 */  vReg_rule,
  /* 1827 */  pRegGov_rule,
  /* 1828 */  pRegGov_rule,
  /* 1829 */  pRegGov_rule,
  /* 1830 */  pRegGov_rule,
  /* 1831 */  _MulVB_vReg_vReg_rule,
  /* 1832 */  _MulVS_vReg_vReg_rule,
  /* 1833 */  _MulVI_vReg_vReg_rule,
  /* 1834 */  _MulVL_vReg_vReg_rule,
  /* 1835 */  pRegGov_rule,
  /* 1836 */  pRegGov_rule,
  /* 1837 */  pRegGov_rule,
  /* 1838 */  pRegGov_rule,
  /* 1839 */  vReg_rule,
  /* 1840 */  vReg_rule,
  /* 1841 */  vReg_rule,
  /* 1842 */  vReg_rule,
  /* 1843 */  vReg_rule,
  /* 1844 */  vReg_rule,
  /* 1845 */  pRegGov_rule,
  /* 1846 */  pRegGov_rule,
  /* 1847 */  pRegGov_rule,
  /* 1848 */  pRegGov_rule,
  /* 1849 */  pRegGov_rule,
  /* 1850 */  pRegGov_rule,
  /* 1851 */  pRegGov_rule,
  /* 1852 */  pRegGov_rule,
  /* 1853 */  pRegGov_rule,
  /* 1854 */  pRegGov_rule,
  /* 1855 */  0,
  /* 1856 */  pRegGov_rule,
  /* 1857 */  pRegGov_rule,
  /* 1858 */  pRegGov_rule,
  /* 1859 */  immI_1_rule,
  /* 1860 */  immI_gt_1_rule,
  /* 1861 */  0,
  /* 1862 */  0,
  /* 1863 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /* 1864 */  _VectorStoreMask_pRegGov_immI_gt_1_rule,
  /* 1865 */  vReg_rule,
  /* 1866 */  vReg_rule,
  /* 1867 */  vReg_rule,
  /* 1868 */  vReg_rule,
  /* 1869 */  vReg_rule,
  /* 1870 */  vReg_rule,
  /* 1871 */  vReg_rule,
  /* 1872 */  vReg_rule,
  /* 1873 */  pRegGov_rule,
  /* 1874 */  pRegGov_rule,
  /* 1875 */  pRegGov_rule,
  /* 1876 */  pRegGov_rule,
  /* 1877 */  vReg_rule,
  /* 1878 */  vReg_rule,
  /* 1879 */  vReg_rule,
  /* 1880 */  vReg_rule,
  /* 1881 */  pRegGov_rule,
  /* 1882 */  pRegGov_rule,
  /* 1883 */  vReg_rule,
  /* 1884 */  vReg_rule,
  /* 1885 */  vReg_rule,
  /* 1886 */  vReg_rule,
  /* 1887 */  pRegGov_rule,
  /* 1888 */  pRegGov_rule,
  /* 1889 */  vReg_rule,
  /* 1890 */  vReg_rule,
  /* 1891 */  vReg_rule,
  /* 1892 */  vReg_rule,
  /* 1893 */  pRegGov_rule,
  /* 1894 */  pRegGov_rule,
  /* 1895 */  vReg_rule,
  /* 1896 */  vReg_rule,
  /* 1897 */  vReg_rule,
  /* 1898 */  vReg_rule,
  /* 1899 */  vReg_rule,
  /* 1900 */  vReg_rule,
  /* 1901 */  vReg_rule,
  /* 1902 */  vReg_rule,
  /* 1903 */  pRegGov_rule,
  /* 1904 */  pRegGov_rule,
  /* 1905 */  pRegGov_rule,
  /* 1906 */  pRegGov_rule,
  /* 1907 */  vReg_rule,
  /* 1908 */  vReg_rule,
  /* 1909 */  vReg_rule,
  /* 1910 */  vReg_rule,
  /* 1911 */  vReg_rule,
  /* 1912 */  vReg_rule,
  /* 1913 */  vReg_rule,
  /* 1914 */  vReg_rule,
  /* 1915 */  pRegGov_rule,
  /* 1916 */  pRegGov_rule,
  /* 1917 */  pRegGov_rule,
  /* 1918 */  pRegGov_rule,
  /* 1919 */  immI_rule,
  /* 1920 */  0,
  /* 1921 */  0,
  /* 1922 */  0,
  /* 1923 */  0,
  /* 1924 */  0,
  /* 1925 */  0,
  /* 1926 */  0,
  /* 1927 */  0,
  /* 1928 */  0,
  /* 1929 */  0,
  /* 1930 */  0,
  /* 1931 */  0,
  /* 1932 */  vReg_rule,
  /* 1933 */  vReg_rule,
  /* 1934 */  vReg_rule,
  /* 1935 */  vReg_rule,
  /* 1936 */  vReg_rule,
  /* 1937 */  vReg_rule,
  /* 1938 */  vReg_rule,
  /* 1939 */  vReg_rule,
  /* 1940 */  vReg_rule,
  /* 1941 */  vReg_rule,
  /* 1942 */  vReg_rule,
  /* 1943 */  vReg_rule,
  /* 1944 */  _RShiftCntV_immI__rule,
  /* 1945 */  _RShiftCntV_immI__rule,
  /* 1946 */  _RShiftCntV_immI__rule,
  /* 1947 */  _RShiftCntV_immI__rule,
  /* 1948 */  _RShiftCntV_immI__rule,
  /* 1949 */  _RShiftCntV_immI__rule,
  /* 1950 */  _RShiftCntV_immI__rule,
  /* 1951 */  _RShiftCntV_immI__rule,
  /* 1952 */  _LShiftCntV_immI__rule,
  /* 1953 */  _LShiftCntV_immI__rule,
  /* 1954 */  _LShiftCntV_immI__rule,
  /* 1955 */  _LShiftCntV_immI__rule,
  /* 1956 */  pRegGov_rule,
  /* 1957 */  pRegGov_rule,
  /* 1958 */  pRegGov_rule,
  /* 1959 */  pRegGov_rule,
  /* 1960 */  pRegGov_rule,
  /* 1961 */  pRegGov_rule,
  /* 1962 */  pRegGov_rule,
  /* 1963 */  pRegGov_rule,
  /* 1964 */  pRegGov_rule,
  /* 1965 */  pRegGov_rule,
  /* 1966 */  pRegGov_rule,
  /* 1967 */  pRegGov_rule,
  /* 1968 */  pRegGov_rule,
  /* 1969 */  pRegGov_rule,
  /* 1970 */  pRegGov_rule,
  /* 1971 */  pRegGov_rule,
  /* 1972 */  pRegGov_rule,
  /* 1973 */  pRegGov_rule,
  /* 1974 */  pRegGov_rule,
  /* 1975 */  pRegGov_rule,
  /* 1976 */  pRegGov_rule,
  /* 1977 */  pRegGov_rule,
  /* 1978 */  pRegGov_rule,
  /* 1979 */  pRegGov_rule,
  /* 1980 */  pRegGov_rule,
  /* 1981 */  pRegGov_rule,
  /* 1982 */  vReg_rule,
  /* 1983 */  vReg_rule,
  /* 1984 */  vReg_rule,
  /* 1985 */  vReg_rule,
  /* 1986 */  vReg_rule,
  /* 1987 */  vReg_rule,
  /* 1988 */  pRegGov_rule,
  /* 1989 */  pRegGov_rule,
  /* 1990 */  pRegGov_rule,
  /* 1991 */  pRegGov_rule,
  /* 1992 */  pRegGov_rule,
  /* 1993 */  pRegGov_rule,
  /* 1994 */  0,
  /* 1995 */  0,
  /* 1996 */  0,
  /* 1997 */  0,
  /* 1998 */  0,
  /* 1999 */  0,
  /* 2000 */  0,
  /* 2001 */  0,
  /* 2002 */  immI_rule,
  /* 2003 */  immI_rule,
  /* 2004 */  immI_rule,
  /* 2005 */  immI_rule,
  /* 2006 */  immI_rule,
  /* 2007 */  immI_rule,
  /* 2008 */  immI_rule,
  /* 2009 */  immI_rule,
  /* 2010 */  immI_rule,
  /* 2011 */  immI_rule,
  /* 2012 */  pRegGov_rule,
  /* 2013 */  pRegGov_rule,
  /* 2014 */  immI_rule,
  /* 2015 */  immI_rule,
  /* 2016 */  immI_rule,
  /* 2017 */  immI_rule,
  /* 2018 */  immI_rule,
  /* 2019 */  immI_rule,
  /* 2020 */  immI_rule,
  /* 2021 */  immI_rule,
  /* 2022 */  immI_rule,
  /* 2023 */  immI_rule,
  /* 2024 */  vReg_rule,
  /* 2025 */  vReg_rule,
  /* 2026 */  vReg_rule,
  /* 2027 */  vReg_rule,
  /* 2028 */  vReg_rule,
  /* 2029 */  _Binary_vReg_pRegGov_rule,
  /* 2030 */  _Binary_vReg_pRegGov_rule,
  /* 2031 */  _Binary_vReg_vReg_rule,
  /* 2032 */  _Binary_vReg_vReg_rule,
  /* 2033 */  _Binary_vReg_vReg_rule,
  /* 2034 */  _Binary_vReg_vReg_rule,
  /* 2035 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 2036 */  _Binary_vReg__Binary_vReg_pRegGov_rule,
  /* 2037 */  immI_rule,
  /* 2038 */  iRegI_R3_rule,
  /* 2039 */  iRegI_R3_rule,
  /* 2040 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 2041 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 2042 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 2043 */  _Binary_iRegP_R3_iRegI_R4_rule,
  /* 2044 */  0,
  /* 2045 */  0,
  /* 2046 */  0,
  /* 2047 */  0,
  /* 2048 */  0,
  /* 2049 */  0,
  /* 2050 */  0,
  /* 2051 */  immI_rule,
  /* 2052 */  _Binary_immI_pRegGov_rule,
  /* 2053 */  0,
  /* 2054 */  0,
  /* 2055 */  0,
  /* 2056 */  pRegGov_rule,
  /* 2057 */  pReg_rule,
  /* 2058 */  pReg_rule,
  /* 2059 */  pRegGov_rule,
  /* 2060 */  0,
  /* 2061 */  pRegGov_rule,
  /* 2062 */  pRegGov_rule,
  /* 2063 */  pRegGov_rule,
  /* 2064 */  pRegGov_rule,
  /* 2065 */  _Binary_iRegP_iRegP_rule,
  /* 2066 */  _Binary_iRegN_iRegN_rule,
  /* 2067 */  _Binary_iRegP_iRegP_rule,
  /* 2068 */  _Binary_iRegN_iRegN_rule,
  /* 2069 */  _Binary_iRegN_iRegN_rule,
  /* 2070 */  _Binary_iRegP_iRegP_rule,
  /* 2071 */  _Binary_iRegN_iRegN_rule,
  /* 2072 */  _Binary_iRegP_iRegP_rule,
  /* 2073 */  _Binary_iRegN_iRegN_rule,
  /* 2074 */  _Binary_iRegP_iRegP_rule,
  /* 2075 */  _Binary_iRegN_iRegN_rule,
  /* 2076 */  _Binary_iRegP_iRegP_rule,
  /* 2077 */  0,
  /* 2078 */  0,
  /* 2079 */  _Binary_iRegP_iRegP_rule,
  /* 2080 */  _Binary_iRegP_iRegP_rule,
  /* 2081 */  _Binary_iRegP_iRegP_rule,
  /* 2082 */  _Binary_iRegP_iRegP_rule,
  /* 2083 */  _Binary_iRegP_iRegP_rule,
  /* 2084 */  _Binary_iRegP_iRegP_rule,
  /* 2085 */  iRegP_rule,
  /* 2086 */  iRegP_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI0",
  /*   10 */  "IMMI_1",
  /*   11 */  "IMMI_M1",
  /*   12 */  "IMMIEXT",
  /*   13 */  "IMMI_GT_1",
  /*   14 */  "IMMI_LE_4",
  /*   15 */  "IMMI_31",
  /*   16 */  "IMMI_2",
  /*   17 */  "IMMI_4",
  /*   18 */  "IMMI_8",
  /*   19 */  "IMMI_16",
  /*   20 */  "IMMI_24",
  /*   21 */  "IMMI_32",
  /*   22 */  "IMMI_48",
  /*   23 */  "IMMI_56",
  /*   24 */  "IMMI_63",
  /*   25 */  "IMMI_64",
  /*   26 */  "IMMI_255",
  /*   27 */  "IMMI_65535",
  /*   28 */  "IMMI_POSITIVE",
  /*   29 */  "IMML_255",
  /*   30 */  "IMML_65535",
  /*   31 */  "IMML_4294967295",
  /*   32 */  "IMML_BITMASK",
  /*   33 */  "IMMI_BITMASK",
  /*   34 */  "IMML_POSITIVE_BITMASKI",
  /*   35 */  "IMMISCALE",
  /*   36 */  "IMMI26",
  /*   37 */  "IMMI19",
  /*   38 */  "IMMIU12",
  /*   39 */  "IMMLU12",
  /*   40 */  "IMMIOFFSET",
  /*   41 */  "IMMIOFFSET1",
  /*   42 */  "IMMIOFFSET2",
  /*   43 */  "IMMIOFFSET4",
  /*   44 */  "IMMIOFFSET8",
  /*   45 */  "IMMIOFFSET16",
  /*   46 */  "IMMLOFFSET",
  /*   47 */  "IMMLOFFSET1",
  /*   48 */  "IMMLOFFSET2",
  /*   49 */  "IMMLOFFSET4",
  /*   50 */  "IMMLOFFSET8",
  /*   51 */  "IMMLOFFSET16",
  /*   52 */  "IMMI8",
  /*   53 */  "IMMI8_SHIFT8",
  /*   54 */  "IMML8_SHIFT8",
  /*   55 */  "IMMBADDSUBV",
  /*   56 */  "IMMIADDSUB",
  /*   57 */  "IMMIADDSUBV",
  /*   58 */  "IMMBLOG",
  /*   59 */  "IMMSLOG",
  /*   60 */  "IMMILOG",
  /*   61 */  "IMML",
  /*   62 */  "IMML0",
  /*   63 */  "IMML_1",
  /*   64 */  "IMML_M1",
  /*   65 */  "IMML_PC_OFF",
  /*   66 */  "IMMLADDSUB",
  /*   67 */  "IMMLADDSUBV",
  /*   68 */  "IMMLLOG",
  /*   69 */  "IMML_32BITS",
  /*   70 */  "IMMP",
  /*   71 */  "IMMP0",
  /*   72 */  "IMMP_1",
  /*   73 */  "IMMBYTEMAPBASE",
  /*   74 */  "IMMP_M1",
  /*   75 */  "IMMP_M2",
  /*   76 */  "IMMD",
  /*   77 */  "IMMD0",
  /*   78 */  "IMMDPACKED",
  /*   79 */  "IMMF",
  /*   80 */  "IMMF0",
  /*   81 */  "IMMFPACKED",
  /*   82 */  "IMMN",
  /*   83 */  "IMMN0",
  /*   84 */  "IMMNKLASS",
  /*   85 */  "IREGI",
  /*   86 */  "IREGINOSP",
  /*   87 */  "IREGL",
  /*   88 */  "IREGLNOSP",
  /*   89 */  "IREGP",
  /*   90 */  "IREGPNOSP",
  /*   91 */  "IREGP_R0",
  /*   92 */  "IREGP_R1",
  /*   93 */  "IREGP_R2",
  /*   94 */  "IREGP_R3",
  /*   95 */  "IREGP_R4",
  /*   96 */  "IREGP_R5",
  /*   97 */  "IREGP_R10",
  /*   98 */  "IREGL_R0",
  /*   99 */  "IREGL_R2",
  /*  100 */  "IREGL_R3",
  /*  101 */  "IREGL_R11",
  /*  102 */  "IREGP_FP",
  /*  103 */  "IREGI_R0",
  /*  104 */  "IREGI_R2",
  /*  105 */  "IREGI_R3",
  /*  106 */  "IREGI_R4",
  /*  107 */  "IREGN",
  /*  108 */  "IREGN_R0",
  /*  109 */  "IREGN_R2",
  /*  110 */  "IREGN_R3",
  /*  111 */  "IREGNNOSP",
  /*  112 */  "IREGIHEAPBASE",
  /*  113 */  "VREGF",
  /*  114 */  "VREGD",
  /*  115 */  "VREG",
  /*  116 */  "VECD",
  /*  117 */  "VECX",
  /*  118 */  "VREGD_V0",
  /*  119 */  "VREGD_V1",
  /*  120 */  "VREGD_V2",
  /*  121 */  "VREGD_V3",
  /*  122 */  "VREGD_V4",
  /*  123 */  "VREGD_V5",
  /*  124 */  "VREGD_V6",
  /*  125 */  "VREGD_V7",
  /*  126 */  "VREGD_V8",
  /*  127 */  "VREGD_V9",
  /*  128 */  "VREGD_V10",
  /*  129 */  "VREGD_V11",
  /*  130 */  "VREGD_V12",
  /*  131 */  "VREGD_V13",
  /*  132 */  "VREGD_V14",
  /*  133 */  "VREGD_V15",
  /*  134 */  "VREGD_V16",
  /*  135 */  "VREGD_V17",
  /*  136 */  "VREGD_V18",
  /*  137 */  "VREGD_V19",
  /*  138 */  "VREGD_V20",
  /*  139 */  "VREGD_V21",
  /*  140 */  "VREGD_V22",
  /*  141 */  "VREGD_V23",
  /*  142 */  "VREGD_V24",
  /*  143 */  "VREGD_V25",
  /*  144 */  "VREGD_V26",
  /*  145 */  "VREGD_V27",
  /*  146 */  "VREGD_V28",
  /*  147 */  "VREGD_V29",
  /*  148 */  "VREGD_V30",
  /*  149 */  "VREGD_V31",
  /*  150 */  "PREG",
  /*  151 */  "PREGGOV",
  /*  152 */  "PREGGOV_P0",
  /*  153 */  "PREGGOV_P1",
  /*  154 */  "RFLAGSREG",
  /*  155 */  "RFLAGSREGU",
  /*  156 */  "INLINE_CACHE_REGP",
  /*  157 */  "THREAD_REGP",
  /*  158 */  "LR_REGP",
  /*  159 */  "INDIRECT",
  /*  160 */  "INDINDEXSCALEDI2L",
  /*  161 */  "INDINDEXSCALED",
  /*  162 */  "INDINDEXI2L",
  /*  163 */  "INDINDEX",
  /*  164 */  "INDOFFI",
  /*  165 */  "INDOFFI1",
  /*  166 */  "INDOFFI2",
  /*  167 */  "INDOFFI4",
  /*  168 */  "INDOFFI8",
  /*  169 */  "INDOFFI16",
  /*  170 */  "INDOFFL",
  /*  171 */  "INDOFFL1",
  /*  172 */  "INDOFFL2",
  /*  173 */  "INDOFFL4",
  /*  174 */  "INDOFFL8",
  /*  175 */  "INDOFFL16",
  /*  176 */  "INDIRECTN",
  /*  177 */  "INDINDEXSCALEDI2LN",
  /*  178 */  "INDINDEXSCALEDN",
  /*  179 */  "INDINDEXI2LN",
  /*  180 */  "INDINDEXN",
  /*  181 */  "INDOFFIN",
  /*  182 */  "INDOFFLN",
  /*  183 */  "THREAD_ANCHOR_PC",
  /*  184 */  "STACKSLOTP",
  /*  185 */  "STACKSLOTI",
  /*  186 */  "STACKSLOTF",
  /*  187 */  "STACKSLOTD",
  /*  188 */  "STACKSLOTL",
  /*  189 */  "CMPOP",
  /*  190 */  "CMPOPU",
  /*  191 */  "CMPOPEQNE",
  /*  192 */  "CMPOPLTGE",
  /*  193 */  "CMPOPUEQNELTGE",
  /*  194 */  "IREGL2I",
  /*  195 */  "VMEMA_IMMIOFFSET4",
  /*  196 */  "VMEMA_IMMLOFFSET4",
  /*  197 */  "VMEMA_INDOFFI4",
  /*  198 */  "VMEMA_INDOFFL4",
  // last operand
  /*  199 */  "VMEM2",
  /*  200 */  "VMEM4",
  /*  201 */  "VMEM8",
  /*  202 */  "VMEM16",
  /*  203 */  "MEMORY1",
  /*  204 */  "MEMORY2",
  /*  205 */  "MEMORY4",
  /*  206 */  "MEMORY8",
  /*  207 */  "MEMORY",
  /*  208 */  "IREGIORL2I",
  /*  209 */  "VMEMA",
  // last operand class
  /*  210 */  "_ConvI2L_iRegI_",
  /*  211 */  "_LShiftL__ConvI2L_iRegI__immIScale",
  /*  212 */  "_LShiftL_iRegL_immIScale",
  /*  213 */  "_DecodeN_iRegN_",
  /*  214 */  "_LoadB_memory1_",
  /*  215 */  "_LoadUB_memory1_",
  /*  216 */  "_LoadS_memory2_",
  /*  217 */  "_LoadUS_memory2_",
  /*  218 */  "_LoadI_memory4_",
  /*  219 */  "_ConvI2L__LoadI_memory4__",
  /*  220 */  "_LoadB_indirect_",
  /*  221 */  "_LoadUB_indirect_",
  /*  222 */  "_LoadUS_indirect_",
  /*  223 */  "_LoadS_indirect_",
  /*  224 */  "_LoadI_indirect_",
  /*  225 */  "_ConvI2L__LoadI_indirect__",
  /*  226 */  "_LoadL_memory8_",
  /*  227 */  "_CastP2X_iRegP_",
  /*  228 */  "_CastP2X__DecodeN_iRegN__",
  /*  229 */  "_Binary_iRegP_iRegP",
  /*  230 */  "_Binary_iRegLNoSp_iRegLNoSp",
  /*  231 */  "_Binary_iRegINoSp_iRegINoSp",
  /*  232 */  "_Binary_iRegNNoSp_iRegNNoSp",
  /*  233 */  "_Binary_iRegI_iRegI",
  /*  234 */  "_Binary_iRegL_iRegL",
  /*  235 */  "_Binary_iRegN_iRegN",
  /*  236 */  "_Binary_cmpOp_rFlagsReg",
  /*  237 */  "_Binary_iRegIorL2I_iRegIorL2I",
  /*  238 */  "_Binary_cmpOpU_rFlagsRegU",
  /*  239 */  "_Binary_immI0_iRegIorL2I",
  /*  240 */  "_Binary_iRegIorL2I_immI0",
  /*  241 */  "_Binary_immI_1_immI0",
  /*  242 */  "_Binary_iRegL_immL0",
  /*  243 */  "_Binary_immL0_iRegL",
  /*  244 */  "_Binary_iRegP_immP0",
  /*  245 */  "_Binary_immP0_iRegP",
  /*  246 */  "_Binary_iRegN_immN0",
  /*  247 */  "_Binary_immN0_iRegN",
  /*  248 */  "_Binary_vRegF_vRegF",
  /*  249 */  "_Binary_vRegD_vRegD",
  /*  250 */  "_ConvL2I_iRegL_",
  /*  251 */  "_ConvI2L_iRegIorL2I_",
  /*  252 */  "_LShiftL__ConvI2L_iRegIorL2I__immIScale",
  /*  253 */  "_MulI_iRegIorL2I_iRegIorL2I",
  /*  254 */  "_SubI_immI0_iRegIorL2I",
  /*  255 */  "_MulL_iRegL_iRegL",
  /*  256 */  "_SubL_immL0_iRegL",
  /*  257 */  "_MulL__ConvI2L_iRegIorL2I___ConvI2L_iRegIorL2I_",
  /*  258 */  "_SubL_immL0__ConvI2L_iRegIorL2I_",
  /*  259 */  "_URShiftI_iRegIorL2I_immI",
  /*  260 */  "_RShiftI_iRegIorL2I_immI",
  /*  261 */  "_LShiftI_iRegIorL2I_immI",
  /*  262 */  "_URShiftL_iRegL_immI",
  /*  263 */  "_RShiftL_iRegL_immI",
  /*  264 */  "_LShiftL_iRegL_immI",
  /*  265 */  "_XorI_iRegIorL2I_immI_M1",
  /*  266 */  "_XorL_iRegL_immL_M1",
  /*  267 */  "_XorI_iRegIorL2I_iRegIorL2I",
  /*  268 */  "_XorL_iRegL_iRegL",
  /*  269 */  "_XorI__URShiftI_iRegIorL2I_immI_immI_M1",
  /*  270 */  "_XorL__URShiftL_iRegL_immI_immL_M1",
  /*  271 */  "_XorI__RShiftI_iRegIorL2I_immI_immI_M1",
  /*  272 */  "_XorL__RShiftL_iRegL_immI_immL_M1",
  /*  273 */  "_RotateRight_iRegIorL2I_immI",
  /*  274 */  "_XorI__RotateRight_iRegIorL2I_immI_immI_M1",
  /*  275 */  "_RotateRight_iRegL_immI",
  /*  276 */  "_XorL__RotateRight_iRegL_immI_immL_M1",
  /*  277 */  "_XorI__LShiftI_iRegIorL2I_immI_immI_M1",
  /*  278 */  "_XorL__LShiftL_iRegL_immI_immL_M1",
  /*  279 */  "_XorI__URShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  280 */  "_XorI_iRegIorL2I__URShiftI_iRegIorL2I_immI",
  /*  281 */  "_XorL__URShiftL_iRegL_immI_iRegL",
  /*  282 */  "_XorL_iRegL__URShiftL_iRegL_immI",
  /*  283 */  "_XorI__RShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  284 */  "_XorI_iRegIorL2I__RShiftI_iRegIorL2I_immI",
  /*  285 */  "_XorL__RShiftL_iRegL_immI_iRegL",
  /*  286 */  "_XorL_iRegL__RShiftL_iRegL_immI",
  /*  287 */  "_XorI__RotateRight_iRegIorL2I_immI_iRegIorL2I",
  /*  288 */  "_XorI_iRegIorL2I__RotateRight_iRegIorL2I_immI",
  /*  289 */  "_XorL__RotateRight_iRegL_immI_iRegL",
  /*  290 */  "_XorL_iRegL__RotateRight_iRegL_immI",
  /*  291 */  "_XorI__LShiftI_iRegIorL2I_immI_iRegIorL2I",
  /*  292 */  "_XorI_iRegIorL2I__LShiftI_iRegIorL2I_immI",
  /*  293 */  "_XorL__LShiftL_iRegL_immI_iRegL",
  /*  294 */  "_XorL_iRegL__LShiftL_iRegL_immI",
  /*  295 */  "_AndI__URShiftI_iRegIorL2I_immI_immI_bitmask",
  /*  296 */  "_AndI_iRegIorL2I_immI_bitmask",
  /*  297 */  "_AndL_iRegL_immL_bitmask",
  /*  298 */  "_LShiftI__AndI_iRegIorL2I_immI_bitmask_immI",
  /*  299 */  "_AndL_iRegL_immL_positive_bitmaskI",
  /*  300 */  "_LShiftL__AndL_iRegL_immL_positive_bitmaskI_immI",
  /*  301 */  "_ConvI2L__AndI_iRegIorL2I_immI_bitmask_",
  /*  302 */  "_ConvL2I__AndL_iRegL_immL_positive_bitmaskI_",
  /*  303 */  "_AndI_iRegI_immI_bitmask",
  /*  304 */  "_LShiftI_iRegIorL2I_immI_16",
  /*  305 */  "_RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16",
  /*  306 */  "_LShiftI_iRegIorL2I_immI_24",
  /*  307 */  "_RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  308 */  "_URShiftI__LShiftI_iRegIorL2I_immI_24_immI_24",
  /*  309 */  "_LShiftL_iRegL_immI_48",
  /*  310 */  "_RShiftL__LShiftL_iRegL_immI_48_immI_48",
  /*  311 */  "_LShiftL_iRegL_immI_32",
  /*  312 */  "_RShiftL__LShiftL_iRegL_immI_32_immI_32",
  /*  313 */  "_LShiftL_iRegL_immI_56",
  /*  314 */  "_RShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  315 */  "_URShiftL__LShiftL_iRegL_immI_56_immI_56",
  /*  316 */  "_AndI_iRegIorL2I_immI_255",
  /*  317 */  "_AndI_iRegIorL2I_immI_65535",
  /*  318 */  "_AndL_iRegL_immL_255",
  /*  319 */  "_AndL_iRegL_immL_65535",
  /*  320 */  "_AndL_iRegL_immL_4294967295",
  /*  321 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_56_immI_56_immIExt",
  /*  322 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_48_immI_48_immIExt",
  /*  323 */  "_LShiftL__RShiftL__LShiftL_iRegL_immI_32_immI_32_immIExt",
  /*  324 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_24_immI_24_immIExt",
  /*  325 */  "_LShiftI__RShiftI__LShiftI_iRegIorL2I_immI_16_immI_16_immIExt",
  /*  326 */  "_LShiftL__ConvI2L_iRegIorL2I__immIExt",
  /*  327 */  "_LShiftL__AndL_iRegL_immL_255_immIExt",
  /*  328 */  "_LShiftL__AndL_iRegL_immL_65535_immIExt",
  /*  329 */  "_LShiftL__AndL_iRegL_immL_4294967295_immIExt",
  /*  330 */  "_LShiftI__AndI_iRegIorL2I_immI_255_immIExt",
  /*  331 */  "_LShiftI__AndI_iRegIorL2I_immI_65535_immIExt",
  /*  332 */  "_NegF_vRegF_",
  /*  333 */  "_Binary__NegF_vRegF__vRegF",
  /*  334 */  "_Binary_vRegF__NegF_vRegF_",
  /*  335 */  "_NegD_vRegD_",
  /*  336 */  "_Binary__NegD_vRegD__vRegD",
  /*  337 */  "_Binary_vRegD__NegD_vRegD_",
  /*  338 */  "_SubF_vRegF_vRegF",
  /*  339 */  "_SubD_vRegD_vRegD",
  /*  340 */  "_OverflowMulI_iRegIorL2I_iRegIorL2I",
  /*  341 */  "_OverflowMulL_iRegL_iRegL",
  /*  342 */  "_CmpI_iRegIorL2I_immI0",
  /*  343 */  "_CmpL_iRegL_immL0",
  /*  344 */  "_CmpP_iRegP_immP0",
  /*  345 */  "_CmpN_iRegN_immN0",
  /*  346 */  "_CmpP__DecodeN_iRegN__immP0",
  /*  347 */  "_CmpU_iRegIorL2I_immI0",
  /*  348 */  "_CmpUL_iRegL_immL0",
  /*  349 */  "_AndL_iRegL_immL",
  /*  350 */  "_CmpL__AndL_iRegL_immL_immL0",
  /*  351 */  "_AndI_iRegIorL2I_immI",
  /*  352 */  "_CmpI__AndI_iRegIorL2I_immI_immI0",
  /*  353 */  "_AndL_iRegL_iRegL",
  /*  354 */  "_AndI_iRegIorL2I_iRegIorL2I",
  /*  355 */  "_PartialSubtypeCheck_iRegP_R4_iRegP_R0",
  /*  356 */  "_Binary_iRegP_R1_iRegI_R2",
  /*  357 */  "_Binary_iRegP_R3_iRegI_R4",
  /*  358 */  "_Binary_iRegP_R1_iRegI_R4",
  /*  359 */  "_Binary_iRegP_R3_iRegI_R2",
  /*  360 */  "_Binary_iRegP_R3_immI_le_4",
  /*  361 */  "_Binary_iRegP_R3_immI_1",
  /*  362 */  "_Binary_iRegP_R1_iRegP_R3",
  /*  363 */  "_Binary_iRegP_R1_iRegI_R3",
  /*  364 */  "_Binary_vecD_iRegIorL2I",
  /*  365 */  "_Binary_vecX_iRegIorL2I",
  /*  366 */  "_Binary_vecX_iRegL",
  /*  367 */  "_Binary_vecD_vRegF",
  /*  368 */  "_Binary_vecX_vRegF",
  /*  369 */  "_Binary_vecX_vRegD",
  /*  370 */  "_Binary_vecD_vecD",
  /*  371 */  "_Binary_vecX_vecX",
  /*  372 */  "_ReplicateB_immI_M1_",
  /*  373 */  "_ReplicateS_immI_M1_",
  /*  374 */  "_ReplicateI_immI_M1_",
  /*  375 */  "_ReplicateL_immL_M1_",
  /*  376 */  "_XorV_vecD__ReplicateB_immI_M1_",
  /*  377 */  "_XorV__ReplicateB_immI_M1__vecD",
  /*  378 */  "_XorV_vecD__ReplicateS_immI_M1_",
  /*  379 */  "_XorV__ReplicateS_immI_M1__vecD",
  /*  380 */  "_XorV_vecD__ReplicateI_immI_M1_",
  /*  381 */  "_XorV__ReplicateI_immI_M1__vecD",
  /*  382 */  "_XorV_vecX__ReplicateB_immI_M1_",
  /*  383 */  "_XorV__ReplicateB_immI_M1__vecX",
  /*  384 */  "_XorV_vecX__ReplicateS_immI_M1_",
  /*  385 */  "_XorV__ReplicateS_immI_M1__vecX",
  /*  386 */  "_XorV_vecX__ReplicateI_immI_M1_",
  /*  387 */  "_XorV__ReplicateI_immI_M1__vecX",
  /*  388 */  "_XorV_vecX__ReplicateL_immL_M1_",
  /*  389 */  "_XorV__ReplicateL_immL_M1__vecX",
  /*  390 */  "_SubVF_vecD_vecD",
  /*  391 */  "_SubVF_vecX_vecX",
  /*  392 */  "_SubVD_vecX_vecX",
  /*  393 */  "_MulVS_vecD_vecD",
  /*  394 */  "_MulVS_vecX_vecX",
  /*  395 */  "_MulVI_vecD_vecD",
  /*  396 */  "_MulVI_vecX_vecX",
  /*  397 */  "_NegVF_vecD_",
  /*  398 */  "_Binary__NegVF_vecD__vecD",
  /*  399 */  "_Binary_vecD__NegVF_vecD_",
  /*  400 */  "_NegVF_vecX_",
  /*  401 */  "_Binary__NegVF_vecX__vecX",
  /*  402 */  "_Binary_vecX__NegVF_vecX_",
  /*  403 */  "_NegVD_vecX_",
  /*  404 */  "_Binary__NegVD_vecX__vecX",
  /*  405 */  "_Binary_vecX__NegVD_vecX_",
  /*  406 */  "_LShiftCntV_immI_",
  /*  407 */  "_RShiftCntV_immI_positive_",
  /*  408 */  "_RShiftVB_vecD__RShiftCntV_immI_positive_",
  /*  409 */  "_RShiftVB_vecX__RShiftCntV_immI_positive_",
  /*  410 */  "_RShiftVS_vecD__RShiftCntV_immI_positive_",
  /*  411 */  "_RShiftVS_vecX__RShiftCntV_immI_positive_",
  /*  412 */  "_RShiftVI_vecD__RShiftCntV_immI_positive_",
  /*  413 */  "_RShiftVI_vecX__RShiftCntV_immI_positive_",
  /*  414 */  "_RShiftVL_vecX__RShiftCntV_immI_positive_",
  /*  415 */  "_URShiftVB_vecD__RShiftCntV_immI_positive_",
  /*  416 */  "_URShiftVB_vecX__RShiftCntV_immI_positive_",
  /*  417 */  "_URShiftVS_vecD__RShiftCntV_immI_positive_",
  /*  418 */  "_URShiftVS_vecX__RShiftCntV_immI_positive_",
  /*  419 */  "_URShiftVI_vecD__RShiftCntV_immI_positive_",
  /*  420 */  "_URShiftVI_vecX__RShiftCntV_immI_positive_",
  /*  421 */  "_URShiftVL_vecX__RShiftCntV_immI_positive_",
  /*  422 */  "_Binary_vReg_pRegGov",
  /*  423 */  "_MaskAll_immI_M1_",
  /*  424 */  "_XorVMask_pRegGov__MaskAll_immI_M1_",
  /*  425 */  "_MaskAll_immL_M1_",
  /*  426 */  "_XorVMask_pRegGov__MaskAll_immL_M1_",
  /*  427 */  "_Binary_vReg_vReg",
  /*  428 */  "_ReplicateB_immBAddSubV_",
  /*  429 */  "_ReplicateS_immIAddSubV_",
  /*  430 */  "_ReplicateI_immIAddSubV_",
  /*  431 */  "_ReplicateL_immLAddSubV_",
  /*  432 */  "_ReplicateB_immBLog_",
  /*  433 */  "_ReplicateS_immSLog_",
  /*  434 */  "_ReplicateI_immILog_",
  /*  435 */  "_ReplicateL_immLLog_",
  /*  436 */  "_Binary_vReg__ReplicateB_immI_M1_",
  /*  437 */  "_Binary_vReg__ReplicateS_immI_M1_",
  /*  438 */  "_Binary_vReg__ReplicateI_immI_M1_",
  /*  439 */  "_Binary_vReg__ReplicateL_immL_M1_",
  /*  440 */  "_XorV_vReg__ReplicateB_immI_M1_",
  /*  441 */  "_XorV__ReplicateB_immI_M1__vReg",
  /*  442 */  "_XorV_vReg__ReplicateS_immI_M1_",
  /*  443 */  "_XorV__ReplicateS_immI_M1__vReg",
  /*  444 */  "_XorV_vReg__ReplicateI_immI_M1_",
  /*  445 */  "_XorV__ReplicateI_immI_M1__vReg",
  /*  446 */  "_XorV_vReg__ReplicateL_immL_M1_",
  /*  447 */  "_XorV__ReplicateL_immL_M1__vReg",
  /*  448 */  "_Binary_vReg__XorV_vReg__ReplicateB_immI_M1_",
  /*  449 */  "_Binary_vReg__XorV__ReplicateB_immI_M1__vReg",
  /*  450 */  "_Binary_vReg__XorV_vReg__ReplicateS_immI_M1_",
  /*  451 */  "_Binary_vReg__XorV__ReplicateS_immI_M1__vReg",
  /*  452 */  "_Binary_vReg__XorV_vReg__ReplicateI_immI_M1_",
  /*  453 */  "_Binary_vReg__XorV__ReplicateI_immI_M1__vReg",
  /*  454 */  "_Binary_vReg__XorV_vReg__ReplicateL_immL_M1_",
  /*  455 */  "_Binary_vReg__XorV__ReplicateL_immL_M1__vReg",
  /*  456 */  "_NegVF_vReg_",
  /*  457 */  "_Binary__NegVF_vReg__vReg",
  /*  458 */  "_Binary_vReg__NegVF_vReg_",
  /*  459 */  "_NegVD_vReg_",
  /*  460 */  "_Binary__NegVD_vReg__vReg",
  /*  461 */  "_Binary_vReg__NegVD_vReg_",
  /*  462 */  "_Binary__NegVF_vReg__pRegGov",
  /*  463 */  "_Binary__NegVD_vReg__pRegGov",
  /*  464 */  "_MulVB_vReg_vReg",
  /*  465 */  "_MulVS_vReg_vReg",
  /*  466 */  "_MulVI_vReg_vReg",
  /*  467 */  "_MulVL_vReg_vReg",
  /*  468 */  "_Binary_vReg__MulVB_vReg_vReg",
  /*  469 */  "_Binary_vReg__MulVS_vReg_vReg",
  /*  470 */  "_Binary_vReg__MulVI_vReg_vReg",
  /*  471 */  "_Binary_vReg__MulVL_vReg_vReg",
  /*  472 */  "_LoadVector_indirect_",
  /*  473 */  "_VectorStoreMask_pRegGov_immI_gt_1",
  /*  474 */  "_Binary_iRegIorL2I_vReg",
  /*  475 */  "_Binary_iRegL_vReg",
  /*  476 */  "_Binary_vRegF_vReg",
  /*  477 */  "_Binary_vRegD_vReg",
  /*  478 */  "_RShiftCntV_immI_",
  /*  479 */  "_Binary_vReg__RShiftCntV_immI_",
  /*  480 */  "_Binary_vReg__LShiftCntV_immI_",
  /*  481 */  "_Binary_vReg_iRegIorL2I",
  /*  482 */  "_Binary_vReg_iRegL",
  /*  483 */  "_Binary_vReg_vRegF",
  /*  484 */  "_Binary_vReg_vRegD",
  /*  485 */  "_Binary_vReg__Binary_vReg_pRegGov",
  /*  486 */  "_Binary_immI_pRegGov",
  // last internally defined operand
  /*  487 */  "loadConI",
  /*  488 */  "loadConL",
  /*  489 */  "loadConP",
  /*  490 */  "loadConP0",
  /*  491 */  "loadConP1",
  /*  492 */  "loadByteMapBase",
  /*  493 */  "loadConN",
  /*  494 */  "loadConN0",
  /*  495 */  "loadConNKlass",
  /*  496 */  "loadConF_packed",
  /*  497 */  "loadConF",
  /*  498 */  "loadConD_packed",
  /*  499 */  "loadConD",
  /*  500 */  "countLeadingZerosI",
  /*  501 */  "countLeadingZerosL",
  /*  502 */  "countTrailingZerosI",
  /*  503 */  "countTrailingZerosL",
  /*  504 */  "castX2P",
  /*  505 */  "castP2X",
  /*  506 */  "checkCastPP",
  /*  507 */  "castPP",
  /*  508 */  "castII",
  /*  509 */  "castLL",
  /*  510 */  "castFF",
  /*  511 */  "castDD",
  /*  512 */  "castVVD",
  /*  513 */  "castVVX",
  /*  514 */  "castVV",
  /*  515 */  "castVVMask",
  /*  516 */  "storePConditional",
  /*  517 */  "storeLConditional",
  /*  518 */  "storeIConditional",
  /*  519 */  "negF_reg_reg",
  /*  520 */  "negD_reg_reg",
  /*  521 */  "absF_reg",
  /*  522 */  "absD_reg",
  /*  523 */  "MoveF2I_stack_reg",
  /*  524 */  "MoveI2F_stack_reg",
  /*  525 */  "MoveD2L_stack_reg",
  /*  526 */  "MoveL2D_stack_reg",
  /*  527 */  "MoveF2I_reg_reg",
  /*  528 */  "MoveI2F_reg_reg",
  /*  529 */  "MoveD2L_reg_reg",
  /*  530 */  "MoveL2D_reg_reg",
  /*  531 */  "overflowAddI_reg_reg",
  /*  532 */  "overflowAddI_reg_imm",
  /*  533 */  "overflowAddL_reg_reg",
  /*  534 */  "overflowAddL_reg_imm",
  /*  535 */  "overflowSubI_reg_reg",
  /*  536 */  "overflowSubI_reg_imm",
  /*  537 */  "overflowSubL_reg_reg",
  /*  538 */  "overflowSubL_reg_imm",
  /*  539 */  "overflowNegI_reg",
  /*  540 */  "overflowNegL_reg",
  /*  541 */  "overflowMulI_reg",
  /*  542 */  "overflowMulL_reg",
  /*  543 */  "compI_reg_reg",
  /*  544 */  "compI_reg_immI0",
  /*  545 */  "compI_reg_immIAddSub",
  /*  546 */  "compI_reg_immI",
  /*  547 */  "compU_reg_reg",
  /*  548 */  "compU_reg_immI0",
  /*  549 */  "compU_reg_immIAddSub",
  /*  550 */  "compU_reg_immI",
  /*  551 */  "compL_reg_reg",
  /*  552 */  "compL_reg_immL0",
  /*  553 */  "compL_reg_immLAddSub",
  /*  554 */  "compL_reg_immL",
  /*  555 */  "compUL_reg_reg",
  /*  556 */  "compUL_reg_immL0",
  /*  557 */  "compUL_reg_immLAddSub",
  /*  558 */  "compUL_reg_immL",
  /*  559 */  "compP_reg_reg",
  /*  560 */  "compN_reg_reg",
  /*  561 */  "testP_reg",
  /*  562 */  "testN_reg",
  /*  563 */  "compF_reg_reg",
  /*  564 */  "compF_reg_zero",
  /*  565 */  "compD_reg_reg",
  /*  566 */  "compD_reg_zero",
  /*  567 */  "cmpL_and",
  /*  568 */  "cmpI_and",
  /*  569 */  "cmpL_and_reg",
  /*  570 */  "cmpI_and_reg",
  /*  571 */  "cmpFastLock",
  /*  572 */  "cmpFastUnlock",
  /*  573 */  "partialSubtypeCheckVsZero",
  /*  574 */  "tlsLoadP",
  /*  575 */  "reinterpretD",
  /*  576 */  "reinterpretX",
  /*  577 */  "reinterpretD2X",
  /*  578 */  "reinterpretX2D",
  /*  579 */  "reinterpretS2X",
  /*  580 */  "reinterpretX2S",
  /*  581 */  "reinterpretS2D",
  /*  582 */  "reinterpretD2S",
  /*  583 */  "vcvt8Bto8S",
  /*  584 */  "vcvt4Bto4S",
  /*  585 */  "vcvt8Sto8B",
  /*  586 */  "vcvt4Sto4B",
  /*  587 */  "vcvt4Sto4I",
  /*  588 */  "vcvt4Ito4S",
  /*  589 */  "vcvt2Ito2L",
  /*  590 */  "vcvt2Lto2I",
  /*  591 */  "vcvt4Ito4B",
  /*  592 */  "vcvt4Bto4I",
  /*  593 */  "vcvt2Ito2F",
  /*  594 */  "vcvt4Ito4F",
  /*  595 */  "vcvt2Lto2D",
  /*  596 */  "vcvt4Sto4F",
  /*  597 */  "vcvt2Ito2D",
  /*  598 */  "vcvt4Bto4F",
  /*  599 */  "vcvt2Fto2L",
  /*  600 */  "vcvt2Fto2I",
  /*  601 */  "vcvt4Fto4I",
  /*  602 */  "vcvt2Dto2L",
  /*  603 */  "vcvt4Fto4S",
  /*  604 */  "vcvt4Fto4B",
  /*  605 */  "vcvt2Fto2D",
  /*  606 */  "vcvt2Dto2F",
  /*  607 */  "loadmask8B",
  /*  608 */  "loadmask16B",
  /*  609 */  "loadmask4S",
  /*  610 */  "loadmask8S",
  /*  611 */  "loadmask2I",
  /*  612 */  "loadmask4I",
  /*  613 */  "loadmask2L",
  /*  614 */  "vmaskcastD",
  /*  615 */  "vmaskcastX",
  /*  616 */  "loadcon8B",
  /*  617 */  "loadcon16B",
  /*  618 */  "loadshuffle8B",
  /*  619 */  "loadshuffle16B",
  /*  620 */  "loadshuffle4S",
  /*  621 */  "loadshuffle8S",
  /*  622 */  "loadshuffle4I",
  /*  623 */  "vabs8B",
  /*  624 */  "vabs16B",
  /*  625 */  "vabs4S",
  /*  626 */  "vabs8S",
  /*  627 */  "vabs2I",
  /*  628 */  "vabs4I",
  /*  629 */  "vabs2L",
  /*  630 */  "vabs2F",
  /*  631 */  "vabs4F",
  /*  632 */  "vabs2D",
  /*  633 */  "vsqrt2F",
  /*  634 */  "vsqrt4F",
  /*  635 */  "vsqrt2D",
  /*  636 */  "vnegID",
  /*  637 */  "vnegIX",
  /*  638 */  "vneg2L",
  /*  639 */  "vneg2F",
  /*  640 */  "vneg4F",
  /*  641 */  "vneg2D",
  /*  642 */  "vslcnt8B",
  /*  643 */  "vslcnt16B",
  /*  644 */  "vsrcnt8B",
  /*  645 */  "vsrcnt16B",
  /*  646 */  "vpopcountID",
  /*  647 */  "vpopcountIX",
  /*  648 */  "vpopcountLD",
  /*  649 */  "vpopcountLX",
  /*  650 */  "vmask_firsttrue8B",
  /*  651 */  "vmask_firsttrue16B",
  /*  652 */  "vmask_lasttrue8B",
  /*  653 */  "vmask_lasttrue16B",
  /*  654 */  "vmask_tolong8B",
  /*  655 */  "vmask_tolong16B",
  /*  656 */  "countLeadingZerosVD",
  /*  657 */  "countLeadingZerosVX",
  /*  658 */  "countTrailingZerosVD",
  /*  659 */  "countTrailingZerosVX",
  /*  660 */  "vreverseD",
  /*  661 */  "vreverseX",
  /*  662 */  "vreverseBytesD",
  /*  663 */  "vreverseBytesX",
  /*  664 */  "reinterpret",
  /*  665 */  "vmask_reinterpret_same_esize",
  /*  666 */  "vabsB",
  /*  667 */  "vabsS",
  /*  668 */  "vabsI",
  /*  669 */  "vabsL",
  /*  670 */  "vabsF",
  /*  671 */  "vabsD",
  /*  672 */  "vnegI",
  /*  673 */  "vnegL",
  /*  674 */  "vnegF",
  /*  675 */  "vnegD",
  /*  676 */  "vpopcountI",
  /*  677 */  "vpopcountL",
  /*  678 */  "vshiftcntB",
  /*  679 */  "vshiftcntB_0",
  /*  680 */  "vshiftcntS",
  /*  681 */  "vshiftcntS_0",
  /*  682 */  "vshiftcntI",
  /*  683 */  "vshiftcntI_0",
  /*  684 */  "vshiftcntL",
  /*  685 */  "vshiftcntL_0",
  /*  686 */  "vsqrtF",
  /*  687 */  "vsqrtD",
  /*  688 */  "vmaskcast",
  /*  689 */  "vmaskcast_extend",
  /*  690 */  "vmaskcast_narrow",
  /*  691 */  "vcvtBtoX_extend",
  /*  692 */  "vcvtStoX_extend",
  /*  693 */  "vcvtItoL",
  /*  694 */  "vcvtItoF",
  /*  695 */  "vcvtItoD",
  /*  696 */  "vcvtLtoD",
  /*  697 */  "vcvtFtoI",
  /*  698 */  "vcvtFtoL",
  /*  699 */  "vcvtFtoD",
  /*  700 */  "vcvtDtoL",
  /*  701 */  "loadshuffle",
  /*  702 */  "loadconB",
  /*  703 */  "vmask_truecount",
  /*  704 */  "vcountLeadingZeros",
  /*  705 */  "vcountTrailingZeros",
  /*  706 */  "vreverse",
  /*  707 */  "vreverseBytes",
  /*  708 */  "loadB",
  /*  709 */  "loadB2L",
  /*  710 */  "loadUB",
  /*  711 */  "loadUB2L",
  /*  712 */  "loadS",
  /*  713 */  "loadS2L",
  /*  714 */  "loadUS",
  /*  715 */  "loadUS2L",
  /*  716 */  "loadI",
  /*  717 */  "loadI2L",
  /*  718 */  "loadUI2L",
  /*  719 */  "loadL",
  /*  720 */  "loadRange",
  /*  721 */  "loadP",
  /*  722 */  "loadN",
  /*  723 */  "loadKlass",
  /*  724 */  "loadNKlass",
  /*  725 */  "loadF",
  /*  726 */  "loadD",
  /*  727 */  "storeimmCM0",
  /*  728 */  "storeimmCM0_ordered",
  /*  729 */  "storeB",
  /*  730 */  "storeimmB0",
  /*  731 */  "storeC",
  /*  732 */  "storeimmC0",
  /*  733 */  "storeI",
  /*  734 */  "storeimmI0",
  /*  735 */  "storeL",
  /*  736 */  "storeimmL0",
  /*  737 */  "storeP",
  /*  738 */  "storeimmP0",
  /*  739 */  "storeN",
  /*  740 */  "storeImmN0",
  /*  741 */  "storeF",
  /*  742 */  "storeD",
  /*  743 */  "storeNKlass",
  /*  744 */  "prefetchalloc",
  /*  745 */  "loadB_volatile",
  /*  746 */  "loadB2L_volatile",
  /*  747 */  "loadUB_volatile",
  /*  748 */  "loadUB2L_volatile",
  /*  749 */  "loadS_volatile",
  /*  750 */  "loadUS_volatile",
  /*  751 */  "loadUS2L_volatile",
  /*  752 */  "loadS2L_volatile",
  /*  753 */  "loadI_volatile",
  /*  754 */  "loadUI2L_volatile",
  /*  755 */  "loadL_volatile",
  /*  756 */  "loadP_volatile",
  /*  757 */  "loadN_volatile",
  /*  758 */  "loadF_volatile",
  /*  759 */  "loadD_volatile",
  /*  760 */  "storeB_volatile",
  /*  761 */  "storeimmB0_volatile",
  /*  762 */  "storeC_volatile",
  /*  763 */  "storeimmC0_volatile",
  /*  764 */  "storeI_volatile",
  /*  765 */  "storeimmI0_volatile",
  /*  766 */  "storeL_volatile",
  /*  767 */  "storeimmL0_volatile",
  /*  768 */  "storeP_volatile",
  /*  769 */  "storeimmP0_volatile",
  /*  770 */  "storeN_volatile",
  /*  771 */  "storeimmN0_volatile",
  /*  772 */  "storeF_volatile",
  /*  773 */  "storeD_volatile",
  /*  774 */  "cacheWB",
  /*  775 */  "cacheWBPreSync",
  /*  776 */  "cacheWBPostSync",
  /*  777 */  "bytes_reverse_int",
  /*  778 */  "bytes_reverse_long",
  /*  779 */  "bytes_reverse_unsigned_short",
  /*  780 */  "bytes_reverse_short",
  /*  781 */  "popCountI",
  /*  782 */  "popCountI_mem",
  /*  783 */  "popCountL",
  /*  784 */  "popCountL_mem",
  /*  785 */  "load_fence",
  /*  786 */  "unnecessary_membar_acquire",
  /*  787 */  "membar_acquire",
  /*  788 */  "membar_acquire_lock",
  /*  789 */  "store_fence",
  /*  790 */  "unnecessary_membar_release",
  /*  791 */  "membar_release",
  /*  792 */  "membar_storestore",
  /*  793 */  "membar_storestore_0",
  /*  794 */  "membar_release_lock",
  /*  795 */  "unnecessary_membar_volatile",
  /*  796 */  "membar_volatile",
  /*  797 */  "convP2I",
  /*  798 */  "convN2I",
  /*  799 */  "encodeHeapOop",
  /*  800 */  "encodeHeapOop_not_null",
  /*  801 */  "decodeHeapOop",
  /*  802 */  "decodeHeapOop_not_null",
  /*  803 */  "encodeKlass_not_null",
  /*  804 */  "decodeKlass_not_null",
  /*  805 */  "loadPLocked",
  /*  806 */  "compareAndSwapB",
  /*  807 */  "compareAndSwapS",
  /*  808 */  "compareAndSwapI",
  /*  809 */  "compareAndSwapL",
  /*  810 */  "compareAndSwapP",
  /*  811 */  "compareAndSwapN",
  /*  812 */  "compareAndSwapBAcq",
  /*  813 */  "compareAndSwapSAcq",
  /*  814 */  "compareAndSwapIAcq",
  /*  815 */  "compareAndSwapLAcq",
  /*  816 */  "compareAndSwapPAcq",
  /*  817 */  "compareAndSwapNAcq",
  /*  818 */  "compareAndExchangeB",
  /*  819 */  "compareAndExchangeS",
  /*  820 */  "compareAndExchangeI",
  /*  821 */  "compareAndExchangeL",
  /*  822 */  "compareAndExchangeN",
  /*  823 */  "compareAndExchangeP",
  /*  824 */  "compareAndExchangeBAcq",
  /*  825 */  "compareAndExchangeSAcq",
  /*  826 */  "compareAndExchangeIAcq",
  /*  827 */  "compareAndExchangeLAcq",
  /*  828 */  "compareAndExchangeNAcq",
  /*  829 */  "compareAndExchangePAcq",
  /*  830 */  "weakCompareAndSwapB",
  /*  831 */  "weakCompareAndSwapS",
  /*  832 */  "weakCompareAndSwapI",
  /*  833 */  "weakCompareAndSwapL",
  /*  834 */  "weakCompareAndSwapN",
  /*  835 */  "weakCompareAndSwapP",
  /*  836 */  "weakCompareAndSwapBAcq",
  /*  837 */  "weakCompareAndSwapSAcq",
  /*  838 */  "weakCompareAndSwapIAcq",
  /*  839 */  "weakCompareAndSwapLAcq",
  /*  840 */  "weakCompareAndSwapNAcq",
  /*  841 */  "weakCompareAndSwapPAcq",
  /*  842 */  "get_and_setI",
  /*  843 */  "get_and_setL",
  /*  844 */  "get_and_setN",
  /*  845 */  "get_and_setP",
  /*  846 */  "get_and_setIAcq",
  /*  847 */  "get_and_setLAcq",
  /*  848 */  "get_and_setNAcq",
  /*  849 */  "get_and_setPAcq",
  /*  850 */  "get_and_addL",
  /*  851 */  "get_and_addL_no_res",
  /*  852 */  "get_and_addLi",
  /*  853 */  "get_and_addLi_no_res",
  /*  854 */  "get_and_addI",
  /*  855 */  "get_and_addI_no_res",
  /*  856 */  "get_and_addIi",
  /*  857 */  "get_and_addIi_no_res",
  /*  858 */  "get_and_addLAcq",
  /*  859 */  "get_and_addL_no_resAcq",
  /*  860 */  "get_and_addLiAcq",
  /*  861 */  "get_and_addLi_no_resAcq",
  /*  862 */  "get_and_addIAcq",
  /*  863 */  "get_and_addI_no_resAcq",
  /*  864 */  "get_and_addIiAcq",
  /*  865 */  "get_and_addIi_no_resAcq",
  /*  866 */  "cmpL3_reg_reg",
  /*  867 */  "cmpL3_reg_imm",
  /*  868 */  "cmovI_reg_reg",
  /*  869 */  "cmovUI_reg_reg",
  /*  870 */  "cmovI_zero_reg",
  /*  871 */  "cmovUI_zero_reg",
  /*  872 */  "cmovI_reg_zero",
  /*  873 */  "cmovUI_reg_zero",
  /*  874 */  "cmovI_reg_zero_one",
  /*  875 */  "cmovUI_reg_zero_one",
  /*  876 */  "cmovL_reg_reg",
  /*  877 */  "cmovUL_reg_reg",
  /*  878 */  "cmovL_reg_zero",
  /*  879 */  "cmovUL_reg_zero",
  /*  880 */  "cmovL_zero_reg",
  /*  881 */  "cmovUL_zero_reg",
  /*  882 */  "cmovP_reg_reg",
  /*  883 */  "cmovUP_reg_reg",
  /*  884 */  "cmovP_reg_zero",
  /*  885 */  "cmovUP_reg_zero",
  /*  886 */  "cmovP_zero_reg",
  /*  887 */  "cmovUP_zero_reg",
  /*  888 */  "cmovN_reg_reg",
  /*  889 */  "cmovUN_reg_reg",
  /*  890 */  "cmovN_reg_zero",
  /*  891 */  "cmovUN_reg_zero",
  /*  892 */  "cmovN_zero_reg",
  /*  893 */  "cmovUN_zero_reg",
  /*  894 */  "cmovF_reg",
  /*  895 */  "cmovUF_reg",
  /*  896 */  "cmovD_reg",
  /*  897 */  "cmovUD_reg",
  /*  898 */  "addI_reg_reg",
  /*  899 */  "addI_reg_imm",
  /*  900 */  "addI_reg_imm_i2l",
  /*  901 */  "addP_reg_reg",
  /*  902 */  "addP_reg_reg_ext",
  /*  903 */  "addP_reg_reg_lsl",
  /*  904 */  "addP_reg_reg_ext_shift",
  /*  905 */  "lshift_ext",
  /*  906 */  "addP_reg_imm",
  /*  907 */  "addL_reg_reg",
  /*  908 */  "addL_reg_imm",
  /*  909 */  "subI_reg_reg",
  /*  910 */  "subI_reg_imm",
  /*  911 */  "subL_reg_reg",
  /*  912 */  "subL_reg_imm",
  /*  913 */  "negI_reg",
  /*  914 */  "negL_reg",
  /*  915 */  "mulI",
  /*  916 */  "smulI",
  /*  917 */  "smulI_0",
  /*  918 */  "mulL",
  /*  919 */  "mulHiL_rReg",
  /*  920 */  "umulHiL_rReg",
  /*  921 */  "maddI",
  /*  922 */  "maddI_0",
  /*  923 */  "msubI",
  /*  924 */  "mnegI",
  /*  925 */  "mnegI_0",
  /*  926 */  "maddL",
  /*  927 */  "maddL_0",
  /*  928 */  "msubL",
  /*  929 */  "mnegL",
  /*  930 */  "mnegL_0",
  /*  931 */  "smaddL",
  /*  932 */  "smaddL_1",
  /*  933 */  "smaddL_0",
  /*  934 */  "smaddL_2",
  /*  935 */  "smsubL",
  /*  936 */  "smsubL_0",
  /*  937 */  "smnegL",
  /*  938 */  "smnegL_0",
  /*  939 */  "muladdS2I",
  /*  940 */  "divI",
  /*  941 */  "divL",
  /*  942 */  "modI",
  /*  943 */  "modL",
  /*  944 */  "lShiftI_reg_reg",
  /*  945 */  "lShiftI_reg_imm",
  /*  946 */  "urShiftI_reg_reg",
  /*  947 */  "urShiftI_reg_imm",
  /*  948 */  "rShiftI_reg_reg",
  /*  949 */  "rShiftI_reg_imm",
  /*  950 */  "lShiftL_reg_reg",
  /*  951 */  "lShiftL_reg_imm",
  /*  952 */  "urShiftL_reg_reg",
  /*  953 */  "urShiftL_reg_imm",
  /*  954 */  "urShiftP_reg_imm",
  /*  955 */  "rShiftL_reg_reg",
  /*  956 */  "rShiftL_reg_imm",
  /*  957 */  "regL_not_reg",
  /*  958 */  "regI_not_reg",
  /*  959 */  "NegI_reg_URShift_reg",
  /*  960 */  "NegI_reg_RShift_reg",
  /*  961 */  "NegI_reg_LShift_reg",
  /*  962 */  "NegL_reg_URShift_reg",
  /*  963 */  "NegL_reg_RShift_reg",
  /*  964 */  "NegL_reg_LShift_reg",
  /*  965 */  "AndI_reg_not_reg",
  /*  966 */  "AndI_reg_not_reg_0",
  /*  967 */  "AndL_reg_not_reg",
  /*  968 */  "AndL_reg_not_reg_0",
  /*  969 */  "OrI_reg_not_reg",
  /*  970 */  "OrI_reg_not_reg_0",
  /*  971 */  "OrL_reg_not_reg",
  /*  972 */  "OrL_reg_not_reg_0",
  /*  973 */  "XorI_reg_not_reg",
  /*  974 */  "XorI_reg_not_reg_0",
  /*  975 */  "XorL_reg_not_reg",
  /*  976 */  "XorL_reg_not_reg_0",
  /*  977 */  "AndI_reg_URShift_not_reg",
  /*  978 */  "AndI_reg_URShift_not_reg_0",
  /*  979 */  "AndL_reg_URShift_not_reg",
  /*  980 */  "AndL_reg_URShift_not_reg_0",
  /*  981 */  "AndI_reg_RShift_not_reg",
  /*  982 */  "AndI_reg_RShift_not_reg_0",
  /*  983 */  "AndL_reg_RShift_not_reg",
  /*  984 */  "AndL_reg_RShift_not_reg_0",
  /*  985 */  "AndI_reg_RotateRight_not_reg",
  /*  986 */  "AndI_reg_RotateRight_not_reg_0",
  /*  987 */  "AndL_reg_RotateRight_not_reg",
  /*  988 */  "AndL_reg_RotateRight_not_reg_0",
  /*  989 */  "AndI_reg_LShift_not_reg",
  /*  990 */  "AndI_reg_LShift_not_reg_0",
  /*  991 */  "AndL_reg_LShift_not_reg",
  /*  992 */  "AndL_reg_LShift_not_reg_0",
  /*  993 */  "XorI_reg_URShift_not_reg",
  /*  994 */  "XorI_reg_URShift_not_reg_1",
  /*  995 */  "XorI_reg_URShift_not_reg_0",
  /*  996 */  "XorI_reg_URShift_not_reg_2",
  /*  997 */  "XorL_reg_URShift_not_reg",
  /*  998 */  "XorL_reg_URShift_not_reg_1",
  /*  999 */  "XorL_reg_URShift_not_reg_0",
  /* 1000 */  "XorL_reg_URShift_not_reg_2",
  /* 1001 */  "XorI_reg_RShift_not_reg",
  /* 1002 */  "XorI_reg_RShift_not_reg_1",
  /* 1003 */  "XorI_reg_RShift_not_reg_0",
  /* 1004 */  "XorI_reg_RShift_not_reg_2",
  /* 1005 */  "XorL_reg_RShift_not_reg",
  /* 1006 */  "XorL_reg_RShift_not_reg_1",
  /* 1007 */  "XorL_reg_RShift_not_reg_0",
  /* 1008 */  "XorL_reg_RShift_not_reg_2",
  /* 1009 */  "XorI_reg_RotateRight_not_reg",
  /* 1010 */  "XorI_reg_RotateRight_not_reg_1",
  /* 1011 */  "XorI_reg_RotateRight_not_reg_0",
  /* 1012 */  "XorI_reg_RotateRight_not_reg_2",
  /* 1013 */  "XorL_reg_RotateRight_not_reg",
  /* 1014 */  "XorL_reg_RotateRight_not_reg_1",
  /* 1015 */  "XorL_reg_RotateRight_not_reg_0",
  /* 1016 */  "XorL_reg_RotateRight_not_reg_2",
  /* 1017 */  "XorI_reg_LShift_not_reg",
  /* 1018 */  "XorI_reg_LShift_not_reg_1",
  /* 1019 */  "XorI_reg_LShift_not_reg_0",
  /* 1020 */  "XorI_reg_LShift_not_reg_2",
  /* 1021 */  "XorL_reg_LShift_not_reg",
  /* 1022 */  "XorL_reg_LShift_not_reg_1",
  /* 1023 */  "XorL_reg_LShift_not_reg_0",
  /* 1024 */  "XorL_reg_LShift_not_reg_2",
  /* 1025 */  "OrI_reg_URShift_not_reg",
  /* 1026 */  "OrI_reg_URShift_not_reg_0",
  /* 1027 */  "OrL_reg_URShift_not_reg",
  /* 1028 */  "OrL_reg_URShift_not_reg_0",
  /* 1029 */  "OrI_reg_RShift_not_reg",
  /* 1030 */  "OrI_reg_RShift_not_reg_0",
  /* 1031 */  "OrL_reg_RShift_not_reg",
  /* 1032 */  "OrL_reg_RShift_not_reg_0",
  /* 1033 */  "OrI_reg_RotateRight_not_reg",
  /* 1034 */  "OrI_reg_RotateRight_not_reg_0",
  /* 1035 */  "OrL_reg_RotateRight_not_reg",
  /* 1036 */  "OrL_reg_RotateRight_not_reg_0",
  /* 1037 */  "OrI_reg_LShift_not_reg",
  /* 1038 */  "OrI_reg_LShift_not_reg_0",
  /* 1039 */  "OrL_reg_LShift_not_reg",
  /* 1040 */  "OrL_reg_LShift_not_reg_0",
  /* 1041 */  "AndI_reg_URShift_reg",
  /* 1042 */  "AndI_reg_URShift_reg_0",
  /* 1043 */  "AndL_reg_URShift_reg",
  /* 1044 */  "AndL_reg_URShift_reg_0",
  /* 1045 */  "AndI_reg_RShift_reg",
  /* 1046 */  "AndI_reg_RShift_reg_0",
  /* 1047 */  "AndL_reg_RShift_reg",
  /* 1048 */  "AndL_reg_RShift_reg_0",
  /* 1049 */  "AndI_reg_LShift_reg",
  /* 1050 */  "AndI_reg_LShift_reg_0",
  /* 1051 */  "AndL_reg_LShift_reg",
  /* 1052 */  "AndL_reg_LShift_reg_0",
  /* 1053 */  "AndI_reg_RotateRight_reg",
  /* 1054 */  "AndI_reg_RotateRight_reg_0",
  /* 1055 */  "AndL_reg_RotateRight_reg",
  /* 1056 */  "AndL_reg_RotateRight_reg_0",
  /* 1057 */  "XorI_reg_URShift_reg",
  /* 1058 */  "XorI_reg_URShift_reg_0",
  /* 1059 */  "XorL_reg_URShift_reg",
  /* 1060 */  "XorL_reg_URShift_reg_0",
  /* 1061 */  "XorI_reg_RShift_reg",
  /* 1062 */  "XorI_reg_RShift_reg_0",
  /* 1063 */  "XorL_reg_RShift_reg",
  /* 1064 */  "XorL_reg_RShift_reg_0",
  /* 1065 */  "XorI_reg_LShift_reg",
  /* 1066 */  "XorI_reg_LShift_reg_0",
  /* 1067 */  "XorL_reg_LShift_reg",
  /* 1068 */  "XorL_reg_LShift_reg_0",
  /* 1069 */  "XorI_reg_RotateRight_reg",
  /* 1070 */  "XorI_reg_RotateRight_reg_0",
  /* 1071 */  "XorL_reg_RotateRight_reg",
  /* 1072 */  "XorL_reg_RotateRight_reg_0",
  /* 1073 */  "OrI_reg_URShift_reg",
  /* 1074 */  "OrI_reg_URShift_reg_0",
  /* 1075 */  "OrL_reg_URShift_reg",
  /* 1076 */  "OrL_reg_URShift_reg_0",
  /* 1077 */  "OrI_reg_RShift_reg",
  /* 1078 */  "OrI_reg_RShift_reg_0",
  /* 1079 */  "OrL_reg_RShift_reg",
  /* 1080 */  "OrL_reg_RShift_reg_0",
  /* 1081 */  "OrI_reg_LShift_reg",
  /* 1082 */  "OrI_reg_LShift_reg_0",
  /* 1083 */  "OrL_reg_LShift_reg",
  /* 1084 */  "OrL_reg_LShift_reg_0",
  /* 1085 */  "OrI_reg_RotateRight_reg",
  /* 1086 */  "OrI_reg_RotateRight_reg_0",
  /* 1087 */  "OrL_reg_RotateRight_reg",
  /* 1088 */  "OrL_reg_RotateRight_reg_0",
  /* 1089 */  "AddI_reg_URShift_reg",
  /* 1090 */  "AddI_reg_URShift_reg_0",
  /* 1091 */  "AddL_reg_URShift_reg",
  /* 1092 */  "AddL_reg_URShift_reg_0",
  /* 1093 */  "AddI_reg_RShift_reg",
  /* 1094 */  "AddI_reg_RShift_reg_0",
  /* 1095 */  "AddL_reg_RShift_reg",
  /* 1096 */  "AddL_reg_RShift_reg_0",
  /* 1097 */  "AddI_reg_LShift_reg",
  /* 1098 */  "AddI_reg_LShift_reg_0",
  /* 1099 */  "AddL_reg_LShift_reg",
  /* 1100 */  "AddL_reg_LShift_reg_0",
  /* 1101 */  "SubI_reg_URShift_reg",
  /* 1102 */  "SubL_reg_URShift_reg",
  /* 1103 */  "SubI_reg_RShift_reg",
  /* 1104 */  "SubL_reg_RShift_reg",
  /* 1105 */  "SubI_reg_LShift_reg",
  /* 1106 */  "SubL_reg_LShift_reg",
  /* 1107 */  "sbfmL",
  /* 1108 */  "sbfmwI",
  /* 1109 */  "ubfmL",
  /* 1110 */  "ubfmwI",
  /* 1111 */  "ubfxwI",
  /* 1112 */  "ubfxL",
  /* 1113 */  "ubfxIConvI2L",
  /* 1114 */  "ubfizwI",
  /* 1115 */  "ubfizL",
  /* 1116 */  "ubfizwIConvI2L",
  /* 1117 */  "ubfizLConvL2I",
  /* 1118 */  "ubfizIConvI2L",
  /* 1119 */  "ubfizLConvL2Ix",
  /* 1120 */  "ubfizIConvI2LAndI",
  /* 1121 */  "extrOrL",
  /* 1122 */  "extrOrL_0",
  /* 1123 */  "extrOrI",
  /* 1124 */  "extrOrI_0",
  /* 1125 */  "extrAddL",
  /* 1126 */  "extrAddL_0",
  /* 1127 */  "extrAddI",
  /* 1128 */  "extrAddI_0",
  /* 1129 */  "rorI_imm",
  /* 1130 */  "rorL_imm",
  /* 1131 */  "rorI_reg",
  /* 1132 */  "rorL_reg",
  /* 1133 */  "rolI_reg",
  /* 1134 */  "rolL_reg",
  /* 1135 */  "AddExtI",
  /* 1136 */  "AddExtI_0",
  /* 1137 */  "SubExtI",
  /* 1138 */  "AddExtI_sxth",
  /* 1139 */  "AddExtI_sxth_0",
  /* 1140 */  "AddExtI_sxtb",
  /* 1141 */  "AddExtI_sxtb_0",
  /* 1142 */  "AddExtI_uxtb",
  /* 1143 */  "AddExtI_uxtb_0",
  /* 1144 */  "AddExtL_sxth",
  /* 1145 */  "AddExtL_sxth_0",
  /* 1146 */  "AddExtL_sxtw",
  /* 1147 */  "AddExtL_sxtw_0",
  /* 1148 */  "AddExtL_sxtb",
  /* 1149 */  "AddExtL_sxtb_0",
  /* 1150 */  "AddExtL_uxtb",
  /* 1151 */  "AddExtL_uxtb_0",
  /* 1152 */  "AddExtI_uxtb_and",
  /* 1153 */  "AddExtI_uxtb_and_0",
  /* 1154 */  "AddExtI_uxth_and",
  /* 1155 */  "AddExtI_uxth_and_0",
  /* 1156 */  "AddExtL_uxtb_and",
  /* 1157 */  "AddExtL_uxtb_and_0",
  /* 1158 */  "AddExtL_uxth_and",
  /* 1159 */  "AddExtL_uxth_and_0",
  /* 1160 */  "AddExtL_uxtw_and",
  /* 1161 */  "AddExtL_uxtw_and_0",
  /* 1162 */  "SubExtI_uxtb_and",
  /* 1163 */  "SubExtI_uxth_and",
  /* 1164 */  "SubExtL_uxtb_and",
  /* 1165 */  "SubExtL_uxth_and",
  /* 1166 */  "SubExtL_uxtw_and",
  /* 1167 */  "AddExtL_sxtb_shift",
  /* 1168 */  "AddExtL_sxtb_shift_0",
  /* 1169 */  "AddExtL_sxth_shift",
  /* 1170 */  "AddExtL_sxth_shift_0",
  /* 1171 */  "AddExtL_sxtw_shift",
  /* 1172 */  "AddExtL_sxtw_shift_0",
  /* 1173 */  "SubExtL_sxtb_shift",
  /* 1174 */  "SubExtL_sxth_shift",
  /* 1175 */  "SubExtL_sxtw_shift",
  /* 1176 */  "AddExtI_sxtb_shift",
  /* 1177 */  "AddExtI_sxtb_shift_0",
  /* 1178 */  "AddExtI_sxth_shift",
  /* 1179 */  "AddExtI_sxth_shift_0",
  /* 1180 */  "SubExtI_sxtb_shift",
  /* 1181 */  "SubExtI_sxth_shift",
  /* 1182 */  "AddExtI_shift",
  /* 1183 */  "AddExtI_shift_0",
  /* 1184 */  "SubExtI_shift",
  /* 1185 */  "AddExtL_uxtb_and_shift",
  /* 1186 */  "AddExtL_uxtb_and_shift_0",
  /* 1187 */  "AddExtL_uxth_and_shift",
  /* 1188 */  "AddExtL_uxth_and_shift_0",
  /* 1189 */  "AddExtL_uxtw_and_shift",
  /* 1190 */  "AddExtL_uxtw_and_shift_0",
  /* 1191 */  "SubExtL_uxtb_and_shift",
  /* 1192 */  "SubExtL_uxth_and_shift",
  /* 1193 */  "SubExtL_uxtw_and_shift",
  /* 1194 */  "AddExtI_uxtb_and_shift",
  /* 1195 */  "AddExtI_uxtb_and_shift_0",
  /* 1196 */  "AddExtI_uxth_and_shift",
  /* 1197 */  "AddExtI_uxth_and_shift_0",
  /* 1198 */  "SubExtI_uxtb_and_shift",
  /* 1199 */  "SubExtI_uxth_and_shift",
  /* 1200 */  "addF_reg_reg",
  /* 1201 */  "addD_reg_reg",
  /* 1202 */  "subF_reg_reg",
  /* 1203 */  "subD_reg_reg",
  /* 1204 */  "mulF_reg_reg",
  /* 1205 */  "mulD_reg_reg",
  /* 1206 */  "maddF_reg_reg",
  /* 1207 */  "maddD_reg_reg",
  /* 1208 */  "msubF_reg_reg",
  /* 1209 */  "msubF_reg_reg_0",
  /* 1210 */  "msubD_reg_reg",
  /* 1211 */  "msubD_reg_reg_0",
  /* 1212 */  "mnaddF_reg_reg",
  /* 1213 */  "mnaddF_reg_reg_0",
  /* 1214 */  "mnaddD_reg_reg",
  /* 1215 */  "mnaddD_reg_reg_0",
  /* 1216 */  "mnsubF_reg_reg",
  /* 1217 */  "mnsubD_reg_reg",
  /* 1218 */  "maxF_reg_reg",
  /* 1219 */  "minF_reg_reg",
  /* 1220 */  "maxD_reg_reg",
  /* 1221 */  "minD_reg_reg",
  /* 1222 */  "divF_reg_reg",
  /* 1223 */  "divD_reg_reg",
  /* 1224 */  "absI_reg",
  /* 1225 */  "absL_reg",
  /* 1226 */  "absdF_reg",
  /* 1227 */  "absdD_reg",
  /* 1228 */  "sqrtD_reg",
  /* 1229 */  "sqrtF_reg",
  /* 1230 */  "roundD_reg",
  /* 1231 */  "copySignD_reg",
  /* 1232 */  "copySignF_reg",
  /* 1233 */  "signumD_reg",
  /* 1234 */  "signumF_reg",
  /* 1235 */  "onspinwait",
  /* 1236 */  "andI_reg_reg",
  /* 1237 */  "andI_reg_imm",
  /* 1238 */  "orI_reg_reg",
  /* 1239 */  "orI_reg_imm",
  /* 1240 */  "xorI_reg_reg",
  /* 1241 */  "xorI_reg_imm",
  /* 1242 */  "andL_reg_reg",
  /* 1243 */  "andL_reg_imm",
  /* 1244 */  "orL_reg_reg",
  /* 1245 */  "orL_reg_imm",
  /* 1246 */  "xorL_reg_reg",
  /* 1247 */  "xorL_reg_imm",
  /* 1248 */  "convI2L_reg_reg",
  /* 1249 */  "convUI2L_reg_reg",
  /* 1250 */  "convL2I_reg",
  /* 1251 */  "convI2B",
  /* 1252 */  "convP2B",
  /* 1253 */  "convD2F_reg",
  /* 1254 */  "convF2D_reg",
  /* 1255 */  "convF2I_reg_reg",
  /* 1256 */  "convF2L_reg_reg",
  /* 1257 */  "convI2F_reg_reg",
  /* 1258 */  "convL2F_reg_reg",
  /* 1259 */  "convD2I_reg_reg",
  /* 1260 */  "convD2L_reg_reg",
  /* 1261 */  "convI2D_reg_reg",
  /* 1262 */  "convL2D_reg_reg",
  /* 1263 */  "round_double_reg",
  /* 1264 */  "round_float_reg",
  /* 1265 */  "MoveF2I_reg_stack",
  /* 1266 */  "MoveI2F_reg_stack",
  /* 1267 */  "MoveD2L_reg_stack",
  /* 1268 */  "MoveL2D_reg_stack",
  /* 1269 */  "clearArray_reg_reg",
  /* 1270 */  "clearArray_imm_reg",
  /* 1271 */  "overflowMulI_reg_branch",
  /* 1272 */  "overflowMulL_reg_branch",
  /* 1273 */  "compF3_reg_reg",
  /* 1274 */  "compD3_reg_reg",
  /* 1275 */  "compF3_reg_immF0",
  /* 1276 */  "compD3_reg_immD0",
  /* 1277 */  "cmpLTMask_reg_reg",
  /* 1278 */  "cmpLTMask_reg_zero",
  /* 1279 */  "cmovI_reg_reg_lt",
  /* 1280 */  "minI_rReg",
  /* 1281 */  "cmovI_reg_reg_gt",
  /* 1282 */  "maxI_rReg",
  /* 1283 */  "branch",
  /* 1284 */  "branchCon",
  /* 1285 */  "branchConU",
  /* 1286 */  "cmpI_imm0_branch",
  /* 1287 */  "cmpL_imm0_branch",
  /* 1288 */  "cmpP_imm0_branch",
  /* 1289 */  "cmpN_imm0_branch",
  /* 1290 */  "cmpP_narrowOop_imm0_branch",
  /* 1291 */  "cmpUI_imm0_branch",
  /* 1292 */  "cmpUL_imm0_branch",
  /* 1293 */  "cmpL_branch_sign",
  /* 1294 */  "cmpI_branch_sign",
  /* 1295 */  "cmpL_branch_bit",
  /* 1296 */  "cmpI_branch_bit",
  /* 1297 */  "far_cmpL_branch_sign",
  /* 1298 */  "far_cmpI_branch_sign",
  /* 1299 */  "far_cmpL_branch_bit",
  /* 1300 */  "far_cmpI_branch_bit",
  /* 1301 */  "branchLoopEnd",
  /* 1302 */  "branchLoopEndU",
  /* 1303 */  "safePoint",
  /* 1304 */  "CallStaticJavaDirect",
  /* 1305 */  "CallDynamicJavaDirect",
  /* 1306 */  "CallRuntimeDirect",
  /* 1307 */  "CallLeafDirect",
  /* 1308 */  "CallLeafNoFPDirect",
  /* 1309 */  "TailCalljmpInd",
  /* 1310 */  "TailjmpInd",
  /* 1311 */  "CreateException",
  /* 1312 */  "RethrowException",
  /* 1313 */  "Ret",
  /* 1314 */  "ShouldNotReachHere",
  /* 1315 */  "partialSubtypeCheck",
  /* 1316 */  "string_compareU",
  /* 1317 */  "string_compareL",
  /* 1318 */  "string_compareUL",
  /* 1319 */  "string_compareLU",
  /* 1320 */  "string_indexofUU",
  /* 1321 */  "string_indexofLL",
  /* 1322 */  "string_indexofUL",
  /* 1323 */  "string_indexof_conUU",
  /* 1324 */  "string_indexof_conLL",
  /* 1325 */  "string_indexof_conUL",
  /* 1326 */  "string_indexof_char",
  /* 1327 */  "stringL_indexof_char",
  /* 1328 */  "string_equalsL",
  /* 1329 */  "string_equalsU",
  /* 1330 */  "array_equalsB",
  /* 1331 */  "array_equalsC",
  /* 1332 */  "count_positives",
  /* 1333 */  "string_compress",
  /* 1334 */  "string_inflate",
  /* 1335 */  "encode_iso_array",
  /* 1336 */  "encode_ascii_array",
  /* 1337 */  "loadV2",
  /* 1338 */  "loadV4",
  /* 1339 */  "loadV8",
  /* 1340 */  "loadV16",
  /* 1341 */  "storeV2",
  /* 1342 */  "storeV4",
  /* 1343 */  "storeV8",
  /* 1344 */  "storeV16",
  /* 1345 */  "vcvt2Lto2F",
  /* 1346 */  "vcvt2Dto2I",
  /* 1347 */  "vroundvecD2Fto2I",
  /* 1348 */  "vroundvecX4Fto4I",
  /* 1349 */  "vroundvecX2Dto2L",
  /* 1350 */  "reduce_add8B",
  /* 1351 */  "reduce_add16B",
  /* 1352 */  "reduce_add4S",
  /* 1353 */  "reduce_add8S",
  /* 1354 */  "reduce_add2L",
  /* 1355 */  "reduce_mul8B",
  /* 1356 */  "reduce_mul16B",
  /* 1357 */  "reduce_mul4S",
  /* 1358 */  "reduce_mul8S",
  /* 1359 */  "reduce_mul2L",
  /* 1360 */  "reduce_max8B",
  /* 1361 */  "reduce_max16B",
  /* 1362 */  "reduce_max4S",
  /* 1363 */  "reduce_max8S",
  /* 1364 */  "reduce_max4I",
  /* 1365 */  "reduce_min8B",
  /* 1366 */  "reduce_min16B",
  /* 1367 */  "reduce_min4S",
  /* 1368 */  "reduce_min8S",
  /* 1369 */  "reduce_min4I",
  /* 1370 */  "reduce_max2I",
  /* 1371 */  "reduce_min2I",
  /* 1372 */  "reduce_max2L",
  /* 1373 */  "reduce_min2L",
  /* 1374 */  "reduce_max2F",
  /* 1375 */  "reduce_max4F",
  /* 1376 */  "reduce_max2D",
  /* 1377 */  "reduce_min2F",
  /* 1378 */  "reduce_min4F",
  /* 1379 */  "reduce_min2D",
  /* 1380 */  "reduce_and8B",
  /* 1381 */  "reduce_orr8B",
  /* 1382 */  "reduce_eor8B",
  /* 1383 */  "reduce_and16B",
  /* 1384 */  "reduce_orr16B",
  /* 1385 */  "reduce_eor16B",
  /* 1386 */  "reduce_and4S",
  /* 1387 */  "reduce_orr4S",
  /* 1388 */  "reduce_eor4S",
  /* 1389 */  "reduce_and8S",
  /* 1390 */  "reduce_orr8S",
  /* 1391 */  "reduce_eor8S",
  /* 1392 */  "reduce_and2I",
  /* 1393 */  "reduce_orr2I",
  /* 1394 */  "reduce_eor2I",
  /* 1395 */  "reduce_and4I",
  /* 1396 */  "reduce_orr4I",
  /* 1397 */  "reduce_eor4I",
  /* 1398 */  "reduce_and2L",
  /* 1399 */  "reduce_orr2L",
  /* 1400 */  "reduce_eor2L",
  /* 1401 */  "insertID",
  /* 1402 */  "insertIX",
  /* 1403 */  "insert2L",
  /* 1404 */  "insert2F",
  /* 1405 */  "insert4F",
  /* 1406 */  "insert2D",
  /* 1407 */  "extract8B",
  /* 1408 */  "extract16B",
  /* 1409 */  "extract4S",
  /* 1410 */  "extract8S",
  /* 1411 */  "extract2I",
  /* 1412 */  "extract4I",
  /* 1413 */  "extract2L",
  /* 1414 */  "extract2F",
  /* 1415 */  "extract4F",
  /* 1416 */  "extract2D",
  /* 1417 */  "vcmpD",
  /* 1418 */  "vcmpX",
  /* 1419 */  "vmul2L",
  /* 1420 */  "vnot2I",
  /* 1421 */  "vnot2I_0",
  /* 1422 */  "vnot2I_1",
  /* 1423 */  "vnot2I_2",
  /* 1424 */  "vnot2I_3",
  /* 1425 */  "vnot2I_4",
  /* 1426 */  "vnot4I",
  /* 1427 */  "vnot4I_0",
  /* 1428 */  "vnot4I_1",
  /* 1429 */  "vnot4I_2",
  /* 1430 */  "vnot4I_3",
  /* 1431 */  "vnot4I_4",
  /* 1432 */  "vnot2L",
  /* 1433 */  "vnot2L_0",
  /* 1434 */  "vand_not2I",
  /* 1435 */  "vand_not2I_1",
  /* 1436 */  "vand_not2I_0",
  /* 1437 */  "vand_not2I_2",
  /* 1438 */  "vand_not2I_3",
  /* 1439 */  "vand_not2I_5",
  /* 1440 */  "vand_not2I_4",
  /* 1441 */  "vand_not2I_6",
  /* 1442 */  "vand_not2I_7",
  /* 1443 */  "vand_not2I_9",
  /* 1444 */  "vand_not2I_8",
  /* 1445 */  "vand_not2I_10",
  /* 1446 */  "vand_not4I",
  /* 1447 */  "vand_not4I_1",
  /* 1448 */  "vand_not4I_0",
  /* 1449 */  "vand_not4I_2",
  /* 1450 */  "vand_not4I_3",
  /* 1451 */  "vand_not4I_5",
  /* 1452 */  "vand_not4I_4",
  /* 1453 */  "vand_not4I_6",
  /* 1454 */  "vand_not4I_7",
  /* 1455 */  "vand_not4I_9",
  /* 1456 */  "vand_not4I_8",
  /* 1457 */  "vand_not4I_10",
  /* 1458 */  "vand_not2L",
  /* 1459 */  "vand_not2L_1",
  /* 1460 */  "vand_not2L_0",
  /* 1461 */  "vand_not2L_2",
  /* 1462 */  "vmax8B",
  /* 1463 */  "vmax16B",
  /* 1464 */  "vmax4S",
  /* 1465 */  "vmax8S",
  /* 1466 */  "vmax2I",
  /* 1467 */  "vmax4I",
  /* 1468 */  "vmin8B",
  /* 1469 */  "vmin16B",
  /* 1470 */  "vmin4S",
  /* 1471 */  "vmin8S",
  /* 1472 */  "vmin2I",
  /* 1473 */  "vmin4I",
  /* 1474 */  "vmax2L",
  /* 1475 */  "vmin2L",
  /* 1476 */  "vbsl8B",
  /* 1477 */  "vbsl16B",
  /* 1478 */  "storemask8B",
  /* 1479 */  "storemask16B",
  /* 1480 */  "storemask4S",
  /* 1481 */  "storemask8S",
  /* 1482 */  "storemask2I",
  /* 1483 */  "storemask4I",
  /* 1484 */  "storemask2L",
  /* 1485 */  "rearrange8B",
  /* 1486 */  "rearrange16B",
  /* 1487 */  "rearrange4S",
  /* 1488 */  "rearrange8S",
  /* 1489 */  "rearrange4I",
  /* 1490 */  "anytrue_in_mask8B",
  /* 1491 */  "anytrue_in_mask16B",
  /* 1492 */  "alltrue_in_mask8B",
  /* 1493 */  "alltrue_in_mask16B",
  /* 1494 */  "vabd2F",
  /* 1495 */  "vabd4F",
  /* 1496 */  "vabd2D",
  /* 1497 */  "replicate8B",
  /* 1498 */  "replicate16B",
  /* 1499 */  "replicate8B_imm",
  /* 1500 */  "replicate16B_imm",
  /* 1501 */  "replicate4S",
  /* 1502 */  "replicate8S",
  /* 1503 */  "replicate4S_imm",
  /* 1504 */  "replicate8S_imm",
  /* 1505 */  "replicate2I",
  /* 1506 */  "replicate4I",
  /* 1507 */  "replicate2I_imm",
  /* 1508 */  "replicate4I_imm",
  /* 1509 */  "replicate2L",
  /* 1510 */  "replicate2L_imm",
  /* 1511 */  "replicate2F",
  /* 1512 */  "replicate4F",
  /* 1513 */  "replicate2D",
  /* 1514 */  "reduce_add2I",
  /* 1515 */  "reduce_add4I",
  /* 1516 */  "reduce_mul2I",
  /* 1517 */  "reduce_mul4I",
  /* 1518 */  "reduce_add2F",
  /* 1519 */  "reduce_add4F",
  /* 1520 */  "reduce_mul2F",
  /* 1521 */  "reduce_mul4F",
  /* 1522 */  "reduce_add2D",
  /* 1523 */  "reduce_mul2D",
  /* 1524 */  "vadd8B",
  /* 1525 */  "vadd16B",
  /* 1526 */  "vadd4S",
  /* 1527 */  "vadd8S",
  /* 1528 */  "vadd2I",
  /* 1529 */  "vadd4I",
  /* 1530 */  "vadd2L",
  /* 1531 */  "vadd2F",
  /* 1532 */  "vadd4F",
  /* 1533 */  "vadd2D",
  /* 1534 */  "vsub8B",
  /* 1535 */  "vsub16B",
  /* 1536 */  "vsub4S",
  /* 1537 */  "vsub8S",
  /* 1538 */  "vsub2I",
  /* 1539 */  "vsub4I",
  /* 1540 */  "vsub2L",
  /* 1541 */  "vsub2F",
  /* 1542 */  "vsub4F",
  /* 1543 */  "vsub2D",
  /* 1544 */  "vmul8B",
  /* 1545 */  "vmul16B",
  /* 1546 */  "vmul4S",
  /* 1547 */  "vmul8S",
  /* 1548 */  "vmul2I",
  /* 1549 */  "vmul4I",
  /* 1550 */  "vmul2F",
  /* 1551 */  "vmul4F",
  /* 1552 */  "vmul2D",
  /* 1553 */  "vmla4S",
  /* 1554 */  "vmla4S_0",
  /* 1555 */  "vmla8S",
  /* 1556 */  "vmla8S_0",
  /* 1557 */  "vmla2I",
  /* 1558 */  "vmla2I_0",
  /* 1559 */  "vmla4I",
  /* 1560 */  "vmla4I_0",
  /* 1561 */  "vmla2F",
  /* 1562 */  "vmla4F",
  /* 1563 */  "vmla2D",
  /* 1564 */  "vmls4S",
  /* 1565 */  "vmls8S",
  /* 1566 */  "vmls2I",
  /* 1567 */  "vmls4I",
  /* 1568 */  "vmls2F",
  /* 1569 */  "vmls2F_0",
  /* 1570 */  "vmls4F",
  /* 1571 */  "vmls4F_0",
  /* 1572 */  "vmls2D",
  /* 1573 */  "vmls2D_0",
  /* 1574 */  "vmuladdS2I",
  /* 1575 */  "vdiv2F",
  /* 1576 */  "vdiv4F",
  /* 1577 */  "vdiv2D",
  /* 1578 */  "vand8B",
  /* 1579 */  "vand16B",
  /* 1580 */  "vor8B",
  /* 1581 */  "vor16B",
  /* 1582 */  "vxor8B",
  /* 1583 */  "vxor16B",
  /* 1584 */  "vsll8B",
  /* 1585 */  "vsll16B",
  /* 1586 */  "vsra8B",
  /* 1587 */  "vsra8B_var",
  /* 1588 */  "vsra16B",
  /* 1589 */  "vsra16B_var",
  /* 1590 */  "vsrl8B",
  /* 1591 */  "vsrl8B_var",
  /* 1592 */  "vsrl16B",
  /* 1593 */  "vsrl16B_var",
  /* 1594 */  "vsll8B_imm",
  /* 1595 */  "vsll16B_imm",
  /* 1596 */  "vsra8B_imm",
  /* 1597 */  "vsra16B_imm",
  /* 1598 */  "vsrl8B_imm",
  /* 1599 */  "vsrl16B_imm",
  /* 1600 */  "vsll4S",
  /* 1601 */  "vsll8S",
  /* 1602 */  "vsra4S",
  /* 1603 */  "vsra4S_var",
  /* 1604 */  "vsra8S",
  /* 1605 */  "vsra8S_var",
  /* 1606 */  "vsrl4S",
  /* 1607 */  "vsrl4S_var",
  /* 1608 */  "vsrl8S",
  /* 1609 */  "vsrl8S_var",
  /* 1610 */  "vsll4S_imm",
  /* 1611 */  "vsll8S_imm",
  /* 1612 */  "vsra4S_imm",
  /* 1613 */  "vsra8S_imm",
  /* 1614 */  "vsrl4S_imm",
  /* 1615 */  "vsrl8S_imm",
  /* 1616 */  "vsll2I",
  /* 1617 */  "vsll4I",
  /* 1618 */  "vsra2I",
  /* 1619 */  "vsra2I_var",
  /* 1620 */  "vsra4I",
  /* 1621 */  "vsra4I_var",
  /* 1622 */  "vsrl2I",
  /* 1623 */  "vsrl2I_var",
  /* 1624 */  "vsrl4I",
  /* 1625 */  "vsrl4I_var",
  /* 1626 */  "vsll2I_imm",
  /* 1627 */  "vsll4I_imm",
  /* 1628 */  "vsra2I_imm",
  /* 1629 */  "vsra4I_imm",
  /* 1630 */  "vsrl2I_imm",
  /* 1631 */  "vsrl4I_imm",
  /* 1632 */  "vsll2L",
  /* 1633 */  "vsra2L",
  /* 1634 */  "vsra2L_var",
  /* 1635 */  "vsrl2L",
  /* 1636 */  "vsrl2L_var",
  /* 1637 */  "vsll2L_imm",
  /* 1638 */  "vsra2L_imm",
  /* 1639 */  "vsrl2L_imm",
  /* 1640 */  "vsraa8B_imm",
  /* 1641 */  "vsraa8B_imm_0",
  /* 1642 */  "vsraa16B_imm",
  /* 1643 */  "vsraa16B_imm_0",
  /* 1644 */  "vsraa4S_imm",
  /* 1645 */  "vsraa4S_imm_0",
  /* 1646 */  "vsraa8S_imm",
  /* 1647 */  "vsraa8S_imm_0",
  /* 1648 */  "vsraa2I_imm",
  /* 1649 */  "vsraa2I_imm_0",
  /* 1650 */  "vsraa4I_imm",
  /* 1651 */  "vsraa4I_imm_0",
  /* 1652 */  "vsraa2L_imm",
  /* 1653 */  "vsraa2L_imm_0",
  /* 1654 */  "vsrla8B_imm",
  /* 1655 */  "vsrla8B_imm_0",
  /* 1656 */  "vsrla16B_imm",
  /* 1657 */  "vsrla16B_imm_0",
  /* 1658 */  "vsrla4S_imm",
  /* 1659 */  "vsrla4S_imm_0",
  /* 1660 */  "vsrla8S_imm",
  /* 1661 */  "vsrla8S_imm_0",
  /* 1662 */  "vsrla2I_imm",
  /* 1663 */  "vsrla2I_imm_0",
  /* 1664 */  "vsrla4I_imm",
  /* 1665 */  "vsrla4I_imm_0",
  /* 1666 */  "vsrla2L_imm",
  /* 1667 */  "vsrla2L_imm_0",
  /* 1668 */  "vmax2F",
  /* 1669 */  "vmax4F",
  /* 1670 */  "vmax2D",
  /* 1671 */  "vmin2F",
  /* 1672 */  "vmin4F",
  /* 1673 */  "vmin2D",
  /* 1674 */  "vround2D_reg",
  /* 1675 */  "vmask_truecount8B",
  /* 1676 */  "vmask_truecount16B",
  /* 1677 */  "vmask_firsttrue_LT8B",
  /* 1678 */  "loadV",
  /* 1679 */  "storeV",
  /* 1680 */  "loadV2_vreg",
  /* 1681 */  "storeV2_vreg",
  /* 1682 */  "loadV4_vreg",
  /* 1683 */  "storeV4_vreg",
  /* 1684 */  "loadV8_vreg",
  /* 1685 */  "storeV8_vreg",
  /* 1686 */  "loadV16_vreg",
  /* 1687 */  "storeV16_vreg",
  /* 1688 */  "loadV_partial",
  /* 1689 */  "storeV_partial",
  /* 1690 */  "loadV_masked",
  /* 1691 */  "storeV_masked",
  /* 1692 */  "vmask_and",
  /* 1693 */  "vmask_or",
  /* 1694 */  "vmask_xor",
  /* 1695 */  "vmask_and_notI",
  /* 1696 */  "vmask_and_notL",
  /* 1697 */  "reinterpretResize",
  /* 1698 */  "vmask_reinterpret_diff_esize",
  /* 1699 */  "vabsB_masked",
  /* 1700 */  "vabsS_masked",
  /* 1701 */  "vabsI_masked",
  /* 1702 */  "vabsL_masked",
  /* 1703 */  "vabsF_masked",
  /* 1704 */  "vabsD_masked",
  /* 1705 */  "vaddB",
  /* 1706 */  "vaddS",
  /* 1707 */  "vaddI",
  /* 1708 */  "vaddL",
  /* 1709 */  "vaddF",
  /* 1710 */  "vaddD",
  /* 1711 */  "vaddB_masked",
  /* 1712 */  "vaddS_masked",
  /* 1713 */  "vaddI_masked",
  /* 1714 */  "vaddL_masked",
  /* 1715 */  "vaddF_masked",
  /* 1716 */  "vaddD_masked",
  /* 1717 */  "vaddImmB",
  /* 1718 */  "vaddImmB_0",
  /* 1719 */  "vaddImmS",
  /* 1720 */  "vaddImmS_0",
  /* 1721 */  "vaddImmI",
  /* 1722 */  "vaddImmI_0",
  /* 1723 */  "vaddImmL",
  /* 1724 */  "vaddImmL_0",
  /* 1725 */  "vandB",
  /* 1726 */  "vandB_0",
  /* 1727 */  "vandH",
  /* 1728 */  "vandH_0",
  /* 1729 */  "vandS",
  /* 1730 */  "vandS_0",
  /* 1731 */  "vandD",
  /* 1732 */  "vandD_0",
  /* 1733 */  "vorB",
  /* 1734 */  "vorB_0",
  /* 1735 */  "vorH",
  /* 1736 */  "vorH_0",
  /* 1737 */  "vorS",
  /* 1738 */  "vorS_0",
  /* 1739 */  "vorD",
  /* 1740 */  "vorD_0",
  /* 1741 */  "vxorB",
  /* 1742 */  "vxorB_0",
  /* 1743 */  "vxorH",
  /* 1744 */  "vxorH_0",
  /* 1745 */  "vxorS",
  /* 1746 */  "vxorS_0",
  /* 1747 */  "vxorD",
  /* 1748 */  "vxorD_0",
  /* 1749 */  "vand",
  /* 1750 */  "vor",
  /* 1751 */  "vxor",
  /* 1752 */  "vand_masked",
  /* 1753 */  "vor_masked",
  /* 1754 */  "vxor_masked",
  /* 1755 */  "vnotI",
  /* 1756 */  "vnotI_0",
  /* 1757 */  "vnotI_1",
  /* 1758 */  "vnotI_2",
  /* 1759 */  "vnotI_3",
  /* 1760 */  "vnotI_4",
  /* 1761 */  "vnotL",
  /* 1762 */  "vnotL_0",
  /* 1763 */  "vnotI_masked",
  /* 1764 */  "vnotI_masked_0",
  /* 1765 */  "vnotI_masked_1",
  /* 1766 */  "vnotL_masked",
  /* 1767 */  "vand_notI",
  /* 1768 */  "vand_notI_1",
  /* 1769 */  "vand_notI_0",
  /* 1770 */  "vand_notI_2",
  /* 1771 */  "vand_notI_3",
  /* 1772 */  "vand_notI_5",
  /* 1773 */  "vand_notI_4",
  /* 1774 */  "vand_notI_6",
  /* 1775 */  "vand_notI_7",
  /* 1776 */  "vand_notI_9",
  /* 1777 */  "vand_notI_8",
  /* 1778 */  "vand_notI_10",
  /* 1779 */  "vand_notL",
  /* 1780 */  "vand_notL_1",
  /* 1781 */  "vand_notL_0",
  /* 1782 */  "vand_notL_2",
  /* 1783 */  "vand_notI_masked",
  /* 1784 */  "vand_notI_masked_0",
  /* 1785 */  "vand_notI_masked_1",
  /* 1786 */  "vand_notI_masked_2",
  /* 1787 */  "vand_notI_masked_3",
  /* 1788 */  "vand_notI_masked_4",
  /* 1789 */  "vand_notL_masked",
  /* 1790 */  "vand_notL_masked_0",
  /* 1791 */  "vdivF",
  /* 1792 */  "vdivD",
  /* 1793 */  "vfdivF_masked",
  /* 1794 */  "vfdivD_masked",
  /* 1795 */  "vmin",
  /* 1796 */  "vmax",
  /* 1797 */  "vmin_masked",
  /* 1798 */  "vmax_masked",
  /* 1799 */  "vfmlaF",
  /* 1800 */  "vfmlaD",
  /* 1801 */  "vfmadF_masked",
  /* 1802 */  "vfmadD_masked",
  /* 1803 */  "vfmlsF1",
  /* 1804 */  "vfmlsF2",
  /* 1805 */  "vfmlsD1",
  /* 1806 */  "vfmlsD2",
  /* 1807 */  "vfmsbF_masked",
  /* 1808 */  "vfmsbD_masked",
  /* 1809 */  "vfnmlaF1",
  /* 1810 */  "vfnmlaF2",
  /* 1811 */  "vfnmlaD1",
  /* 1812 */  "vfnmlaD2",
  /* 1813 */  "vfnmadF_masked",
  /* 1814 */  "vfnmadD_masked",
  /* 1815 */  "vfnmlsF",
  /* 1816 */  "vfnmlsD",
  /* 1817 */  "vfnmsbF_masked",
  /* 1818 */  "vfnmsbD_masked",
  /* 1819 */  "vmlaB",
  /* 1820 */  "vmlaB_0",
  /* 1821 */  "vmlaS",
  /* 1822 */  "vmlaS_0",
  /* 1823 */  "vmlaI",
  /* 1824 */  "vmlaI_0",
  /* 1825 */  "vmlaL",
  /* 1826 */  "vmlaL_0",
  /* 1827 */  "vmlaB_masked",
  /* 1828 */  "vmlaS_masked",
  /* 1829 */  "vmlaI_masked",
  /* 1830 */  "vmlaL_masked",
  /* 1831 */  "vmlsB",
  /* 1832 */  "vmlsS",
  /* 1833 */  "vmlsI",
  /* 1834 */  "vmlsL",
  /* 1835 */  "vmlsB_masked",
  /* 1836 */  "vmlsS_masked",
  /* 1837 */  "vmlsI_masked",
  /* 1838 */  "vmlsL_masked",
  /* 1839 */  "vmulB",
  /* 1840 */  "vmulS",
  /* 1841 */  "vmulI",
  /* 1842 */  "vmulL",
  /* 1843 */  "vmulF",
  /* 1844 */  "vmulD",
  /* 1845 */  "vmulB_masked",
  /* 1846 */  "vmulS_masked",
  /* 1847 */  "vmulI_masked",
  /* 1848 */  "vmulL_masked",
  /* 1849 */  "vmulF_masked",
  /* 1850 */  "vmulD_masked",
  /* 1851 */  "vnegI_masked",
  /* 1852 */  "vnegL_masked",
  /* 1853 */  "vnegF_masked",
  /* 1854 */  "vnegD_masked",
  /* 1855 */  "vpopcountLI",
  /* 1856 */  "vpopcountI_masked",
  /* 1857 */  "vpopcountL_masked",
  /* 1858 */  "vblend",
  /* 1859 */  "vstoremaskB",
  /* 1860 */  "vstoremask_narrow",
  /* 1861 */  "vloadmask_loadV",
  /* 1862 */  "vloadmask_loadV_partial",
  /* 1863 */  "storeV_vstoremask",
  /* 1864 */  "storeV_vstoremask_partial",
  /* 1865 */  "reduce_addI",
  /* 1866 */  "reduce_addL",
  /* 1867 */  "reduce_addF",
  /* 1868 */  "reduce_addD",
  /* 1869 */  "reduce_addI_partial",
  /* 1870 */  "reduce_addL_partial",
  /* 1871 */  "reduce_addF_partial",
  /* 1872 */  "reduce_addD_partial",
  /* 1873 */  "reduce_addI_masked",
  /* 1874 */  "reduce_addL_masked",
  /* 1875 */  "reduce_addF_masked",
  /* 1876 */  "reduce_addD_masked",
  /* 1877 */  "reduce_andI",
  /* 1878 */  "reduce_andL",
  /* 1879 */  "reduce_andI_partial",
  /* 1880 */  "reduce_andL_partial",
  /* 1881 */  "reduce_andI_masked",
  /* 1882 */  "reduce_andL_masked",
  /* 1883 */  "reduce_orI",
  /* 1884 */  "reduce_orL",
  /* 1885 */  "reduce_orI_partial",
  /* 1886 */  "reduce_orL_partial",
  /* 1887 */  "reduce_orI_masked",
  /* 1888 */  "reduce_orL_masked",
  /* 1889 */  "reduce_eorI",
  /* 1890 */  "reduce_eorL",
  /* 1891 */  "reduce_eorI_partial",
  /* 1892 */  "reduce_eorL_partial",
  /* 1893 */  "reduce_eorI_masked",
  /* 1894 */  "reduce_eorL_masked",
  /* 1895 */  "reduce_maxI",
  /* 1896 */  "reduce_maxL",
  /* 1897 */  "reduce_maxI_partial",
  /* 1898 */  "reduce_maxL_partial",
  /* 1899 */  "reduce_maxF",
  /* 1900 */  "reduce_maxF_partial",
  /* 1901 */  "reduce_maxD",
  /* 1902 */  "reduce_maxD_partial",
  /* 1903 */  "reduce_maxI_masked",
  /* 1904 */  "reduce_maxL_masked",
  /* 1905 */  "reduce_maxF_masked",
  /* 1906 */  "reduce_maxD_masked",
  /* 1907 */  "reduce_minI",
  /* 1908 */  "reduce_minL",
  /* 1909 */  "reduce_minI_partial",
  /* 1910 */  "reduce_minL_partial",
  /* 1911 */  "reduce_minF",
  /* 1912 */  "reduce_minF_partial",
  /* 1913 */  "reduce_minD",
  /* 1914 */  "reduce_minD_partial",
  /* 1915 */  "reduce_minI_masked",
  /* 1916 */  "reduce_minL_masked",
  /* 1917 */  "reduce_minF_masked",
  /* 1918 */  "reduce_minD_masked",
  /* 1919 */  "vroundD",
  /* 1920 */  "vroundFtoI",
  /* 1921 */  "vroundDtoL",
  /* 1922 */  "replicateB",
  /* 1923 */  "replicateS",
  /* 1924 */  "replicateI",
  /* 1925 */  "replicateL",
  /* 1926 */  "replicateB_imm8",
  /* 1927 */  "replicateS_imm8",
  /* 1928 */  "replicateI_imm8",
  /* 1929 */  "replicateL_imm8",
  /* 1930 */  "replicateF",
  /* 1931 */  "replicateD",
  /* 1932 */  "vasrB",
  /* 1933 */  "vasrS",
  /* 1934 */  "vasrI",
  /* 1935 */  "vasrL",
  /* 1936 */  "vlslB",
  /* 1937 */  "vlslS",
  /* 1938 */  "vlslI",
  /* 1939 */  "vlslL",
  /* 1940 */  "vlsrB",
  /* 1941 */  "vlsrS",
  /* 1942 */  "vlsrI",
  /* 1943 */  "vlsrL",
  /* 1944 */  "vasrB_imm",
  /* 1945 */  "vasrS_imm",
  /* 1946 */  "vasrI_imm",
  /* 1947 */  "vasrL_imm",
  /* 1948 */  "vlsrB_imm",
  /* 1949 */  "vlsrS_imm",
  /* 1950 */  "vlsrI_imm",
  /* 1951 */  "vlsrL_imm",
  /* 1952 */  "vlslB_imm",
  /* 1953 */  "vlslS_imm",
  /* 1954 */  "vlslI_imm",
  /* 1955 */  "vlslL_imm",
  /* 1956 */  "vasrB_masked",
  /* 1957 */  "vasrS_masked",
  /* 1958 */  "vasrI_masked",
  /* 1959 */  "vasrL_masked",
  /* 1960 */  "vlslB_masked",
  /* 1961 */  "vlslS_masked",
  /* 1962 */  "vlslI_masked",
  /* 1963 */  "vlslL_masked",
  /* 1964 */  "vlsrB_masked",
  /* 1965 */  "vlsrS_masked",
  /* 1966 */  "vlsrI_masked",
  /* 1967 */  "vlsrL_masked",
  /* 1968 */  "vasrB_imm_masked",
  /* 1969 */  "vasrS_imm_masked",
  /* 1970 */  "vasrI_imm_masked",
  /* 1971 */  "vasrL_imm_masked",
  /* 1972 */  "vlsrB_imm_masked",
  /* 1973 */  "vlsrS_imm_masked",
  /* 1974 */  "vlsrI_imm_masked",
  /* 1975 */  "vlsrL_imm_masked",
  /* 1976 */  "vlslB_imm_masked",
  /* 1977 */  "vlslS_imm_masked",
  /* 1978 */  "vlslI_imm_masked",
  /* 1979 */  "vlslL_imm_masked",
  /* 1980 */  "vsqrtF_masked",
  /* 1981 */  "vsqrtD_masked",
  /* 1982 */  "vsubB",
  /* 1983 */  "vsubS",
  /* 1984 */  "vsubI",
  /* 1985 */  "vsubL",
  /* 1986 */  "vsubF",
  /* 1987 */  "vsubD",
  /* 1988 */  "vsubB_masked",
  /* 1989 */  "vsubS_masked",
  /* 1990 */  "vsubI_masked",
  /* 1991 */  "vsubL_masked",
  /* 1992 */  "vsubF_masked",
  /* 1993 */  "vsubD_masked",
  /* 1994 */  "vcvtStoB",
  /* 1995 */  "vcvtItoB",
  /* 1996 */  "vcvtItoS",
  /* 1997 */  "vcvtLtoX_narrow",
  /* 1998 */  "vcvtLtoF",
  /* 1999 */  "vcvtFtoX_narrow",
  /* 2000 */  "vcvtDtoX_narrow",
  /* 2001 */  "vcvtDtoF",
  /* 2002 */  "extractB",
  /* 2003 */  "extractS",
  /* 2004 */  "extractI",
  /* 2005 */  "extractL",
  /* 2006 */  "extractB_LT16",
  /* 2007 */  "extractS_LT8",
  /* 2008 */  "extractI_LT4",
  /* 2009 */  "extractL_LT2",
  /* 2010 */  "extractF",
  /* 2011 */  "extractD",
  /* 2012 */  "vtest_alltrue",
  /* 2013 */  "vtest_anytrue",
  /* 2014 */  "insertI_le128bits",
  /* 2015 */  "insertI_small_index",
  /* 2016 */  "insertI",
  /* 2017 */  "insertL_128bits",
  /* 2018 */  "insertL",
  /* 2019 */  "insertF_le128bits",
  /* 2020 */  "insertF_small_index",
  /* 2021 */  "insertF",
  /* 2022 */  "insertD_128bits",
  /* 2023 */  "insertD",
  /* 2024 */  "rearrange",
  /* 2025 */  "gatherI",
  /* 2026 */  "gatherL",
  /* 2027 */  "gatherI_partial",
  /* 2028 */  "gatherL_partial",
  /* 2029 */  "gatherI_masked",
  /* 2030 */  "gatherL_masked",
  /* 2031 */  "scatterI",
  /* 2032 */  "scatterL",
  /* 2033 */  "scatterI_partial",
  /* 2034 */  "scatterL_partial",
  /* 2035 */  "scatterI_masked",
  /* 2036 */  "scatterL_masked",
  /* 2037 */  "populateindex",
  /* 2038 */  "stringL_indexof_char_sve",
  /* 2039 */  "stringU_indexof_char_sve",
  /* 2040 */  "string_compareLL_sve",
  /* 2041 */  "string_compareLU_sve",
  /* 2042 */  "string_compareUL_sve",
  /* 2043 */  "string_compareUU_sve",
  /* 2044 */  "vmask_firsttrue",
  /* 2045 */  "vmask_lasttrue",
  /* 2046 */  "vmask_tolong",
  /* 2047 */  "vmaskAll_immI",
  /* 2048 */  "vmaskAllI",
  /* 2049 */  "vmaskAll_immL",
  /* 2050 */  "vmaskAllL",
  /* 2051 */  "vmaskcmp",
  /* 2052 */  "vmaskcmp_masked",
  /* 2053 */  "vloadmaskB",
  /* 2054 */  "vloadmask_extend",
  /* 2055 */  "mcompress",
  /* 2056 */  "vcompress",
  /* 2057 */  "vcompressB",
  /* 2058 */  "vcompressS",
  /* 2059 */  "vexpand",
  /* 2060 */  "vmask_gen",
  /* 2061 */  "vcountLeadingZeros_masked",
  /* 2062 */  "vcountTrailingZeros_masked",
  /* 2063 */  "vreverse_masked",
  /* 2064 */  "vreverseBytes_masked",
  /* 2065 */  "compareAndSwapP_shenandoah",
  /* 2066 */  "compareAndSwapN_shenandoah",
  /* 2067 */  "compareAndSwapPAcq_shenandoah",
  /* 2068 */  "compareAndSwapNAcq_shenandoah",
  /* 2069 */  "compareAndExchangeN_shenandoah",
  /* 2070 */  "compareAndExchangeP_shenandoah",
  /* 2071 */  "compareAndExchangeNAcq_shenandoah",
  /* 2072 */  "compareAndExchangePAcq_shenandoah",
  /* 2073 */  "weakCompareAndSwapN_shenandoah",
  /* 2074 */  "weakCompareAndSwapP_shenandoah",
  /* 2075 */  "weakCompareAndSwapNAcq_shenandoah",
  /* 2076 */  "weakCompareAndSwapPAcq_shenandoah",
  /* 2077 */  "zLoadP",
  /* 2078 */  "zLoadPVolatile",
  /* 2079 */  "zCompareAndSwapP",
  /* 2080 */  "zCompareAndSwapP_0",
  /* 2081 */  "zCompareAndSwapPAcq",
  /* 2082 */  "zCompareAndSwapPAcq_0",
  /* 2083 */  "zCompareAndExchangeP",
  /* 2084 */  "zCompareAndExchangePAcq",
  /* 2085 */  "zGetAndSetP",
  /* 2086 */  "zGetAndSetPAcq",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  true,
  /*   62 */  true,
  /*   63 */  true,
  /*   64 */  true,
  /*   65 */  true,
  /*   66 */  true,
  /*   67 */  true,
  /*   68 */  true,
  /*   69 */  true,
  /*   70 */  true,
  /*   71 */  true,
  /*   72 */  true,
  /*   73 */  true,
  /*   74 */  true,
  /*   75 */  true,
  /*   76 */  true,
  /*   77 */  true,
  /*   78 */  true,
  /*   79 */  true,
  /*   80 */  true,
  /*   81 */  true,
  /*   82 */  true,
  /*   83 */  true,
  /*   84 */  true,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  true,
  /*  190 */  true,
  /*  191 */  true,
  /*  192 */  true,
  /*  193 */  true,
  /*  194 */  false,
  /*  195 */  true,
  /*  196 */  true,
  /*  197 */  false,
  /*  198 */  false,
  // last operand
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  // last operand class
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  // last internally defined operand
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  /*  797 */  false,
  /*  798 */  false,
  /*  799 */  false,
  /*  800 */  false,
  /*  801 */  false,
  /*  802 */  false,
  /*  803 */  false,
  /*  804 */  false,
  /*  805 */  false,
  /*  806 */  false,
  /*  807 */  false,
  /*  808 */  false,
  /*  809 */  false,
  /*  810 */  false,
  /*  811 */  false,
  /*  812 */  false,
  /*  813 */  false,
  /*  814 */  false,
  /*  815 */  false,
  /*  816 */  false,
  /*  817 */  false,
  /*  818 */  false,
  /*  819 */  false,
  /*  820 */  false,
  /*  821 */  false,
  /*  822 */  false,
  /*  823 */  false,
  /*  824 */  false,
  /*  825 */  false,
  /*  826 */  false,
  /*  827 */  false,
  /*  828 */  false,
  /*  829 */  false,
  /*  830 */  false,
  /*  831 */  false,
  /*  832 */  false,
  /*  833 */  false,
  /*  834 */  false,
  /*  835 */  false,
  /*  836 */  false,
  /*  837 */  false,
  /*  838 */  false,
  /*  839 */  false,
  /*  840 */  false,
  /*  841 */  false,
  /*  842 */  false,
  /*  843 */  false,
  /*  844 */  false,
  /*  845 */  false,
  /*  846 */  false,
  /*  847 */  false,
  /*  848 */  false,
  /*  849 */  false,
  /*  850 */  false,
  /*  851 */  false,
  /*  852 */  false,
  /*  853 */  false,
  /*  854 */  false,
  /*  855 */  false,
  /*  856 */  false,
  /*  857 */  false,
  /*  858 */  false,
  /*  859 */  false,
  /*  860 */  false,
  /*  861 */  false,
  /*  862 */  false,
  /*  863 */  false,
  /*  864 */  false,
  /*  865 */  false,
  /*  866 */  false,
  /*  867 */  false,
  /*  868 */  false,
  /*  869 */  false,
  /*  870 */  false,
  /*  871 */  false,
  /*  872 */  false,
  /*  873 */  false,
  /*  874 */  false,
  /*  875 */  false,
  /*  876 */  false,
  /*  877 */  false,
  /*  878 */  false,
  /*  879 */  false,
  /*  880 */  false,
  /*  881 */  false,
  /*  882 */  false,
  /*  883 */  false,
  /*  884 */  false,
  /*  885 */  false,
  /*  886 */  false,
  /*  887 */  false,
  /*  888 */  false,
  /*  889 */  false,
  /*  890 */  false,
  /*  891 */  false,
  /*  892 */  false,
  /*  893 */  false,
  /*  894 */  false,
  /*  895 */  false,
  /*  896 */  false,
  /*  897 */  false,
  /*  898 */  false,
  /*  899 */  false,
  /*  900 */  false,
  /*  901 */  false,
  /*  902 */  false,
  /*  903 */  false,
  /*  904 */  false,
  /*  905 */  false,
  /*  906 */  false,
  /*  907 */  false,
  /*  908 */  false,
  /*  909 */  false,
  /*  910 */  false,
  /*  911 */  false,
  /*  912 */  false,
  /*  913 */  false,
  /*  914 */  false,
  /*  915 */  false,
  /*  916 */  false,
  /*  917 */  false,
  /*  918 */  false,
  /*  919 */  false,
  /*  920 */  false,
  /*  921 */  false,
  /*  922 */  false,
  /*  923 */  false,
  /*  924 */  false,
  /*  925 */  false,
  /*  926 */  false,
  /*  927 */  false,
  /*  928 */  false,
  /*  929 */  false,
  /*  930 */  false,
  /*  931 */  false,
  /*  932 */  false,
  /*  933 */  false,
  /*  934 */  false,
  /*  935 */  false,
  /*  936 */  false,
  /*  937 */  false,
  /*  938 */  false,
  /*  939 */  false,
  /*  940 */  false,
  /*  941 */  false,
  /*  942 */  false,
  /*  943 */  false,
  /*  944 */  false,
  /*  945 */  false,
  /*  946 */  false,
  /*  947 */  false,
  /*  948 */  false,
  /*  949 */  false,
  /*  950 */  false,
  /*  951 */  false,
  /*  952 */  false,
  /*  953 */  false,
  /*  954 */  false,
  /*  955 */  false,
  /*  956 */  false,
  /*  957 */  false,
  /*  958 */  false,
  /*  959 */  false,
  /*  960 */  false,
  /*  961 */  false,
  /*  962 */  false,
  /*  963 */  false,
  /*  964 */  false,
  /*  965 */  false,
  /*  966 */  false,
  /*  967 */  false,
  /*  968 */  false,
  /*  969 */  false,
  /*  970 */  false,
  /*  971 */  false,
  /*  972 */  false,
  /*  973 */  false,
  /*  974 */  false,
  /*  975 */  false,
  /*  976 */  false,
  /*  977 */  false,
  /*  978 */  false,
  /*  979 */  false,
  /*  980 */  false,
  /*  981 */  false,
  /*  982 */  false,
  /*  983 */  false,
  /*  984 */  false,
  /*  985 */  false,
  /*  986 */  false,
  /*  987 */  false,
  /*  988 */  false,
  /*  989 */  false,
  /*  990 */  false,
  /*  991 */  false,
  /*  992 */  false,
  /*  993 */  false,
  /*  994 */  false,
  /*  995 */  false,
  /*  996 */  false,
  /*  997 */  false,
  /*  998 */  false,
  /*  999 */  false,
  /* 1000 */  false,
  /* 1001 */  false,
  /* 1002 */  false,
  /* 1003 */  false,
  /* 1004 */  false,
  /* 1005 */  false,
  /* 1006 */  false,
  /* 1007 */  false,
  /* 1008 */  false,
  /* 1009 */  false,
  /* 1010 */  false,
  /* 1011 */  false,
  /* 1012 */  false,
  /* 1013 */  false,
  /* 1014 */  false,
  /* 1015 */  false,
  /* 1016 */  false,
  /* 1017 */  false,
  /* 1018 */  false,
  /* 1019 */  false,
  /* 1020 */  false,
  /* 1021 */  false,
  /* 1022 */  false,
  /* 1023 */  false,
  /* 1024 */  false,
  /* 1025 */  false,
  /* 1026 */  false,
  /* 1027 */  false,
  /* 1028 */  false,
  /* 1029 */  false,
  /* 1030 */  false,
  /* 1031 */  false,
  /* 1032 */  false,
  /* 1033 */  false,
  /* 1034 */  false,
  /* 1035 */  false,
  /* 1036 */  false,
  /* 1037 */  false,
  /* 1038 */  false,
  /* 1039 */  false,
  /* 1040 */  false,
  /* 1041 */  false,
  /* 1042 */  false,
  /* 1043 */  false,
  /* 1044 */  false,
  /* 1045 */  false,
  /* 1046 */  false,
  /* 1047 */  false,
  /* 1048 */  false,
  /* 1049 */  false,
  /* 1050 */  false,
  /* 1051 */  false,
  /* 1052 */  false,
  /* 1053 */  false,
  /* 1054 */  false,
  /* 1055 */  false,
  /* 1056 */  false,
  /* 1057 */  false,
  /* 1058 */  false,
  /* 1059 */  false,
  /* 1060 */  false,
  /* 1061 */  false,
  /* 1062 */  false,
  /* 1063 */  false,
  /* 1064 */  false,
  /* 1065 */  false,
  /* 1066 */  false,
  /* 1067 */  false,
  /* 1068 */  false,
  /* 1069 */  false,
  /* 1070 */  false,
  /* 1071 */  false,
  /* 1072 */  false,
  /* 1073 */  false,
  /* 1074 */  false,
  /* 1075 */  false,
  /* 1076 */  false,
  /* 1077 */  false,
  /* 1078 */  false,
  /* 1079 */  false,
  /* 1080 */  false,
  /* 1081 */  false,
  /* 1082 */  false,
  /* 1083 */  false,
  /* 1084 */  false,
  /* 1085 */  false,
  /* 1086 */  false,
  /* 1087 */  false,
  /* 1088 */  false,
  /* 1089 */  false,
  /* 1090 */  false,
  /* 1091 */  false,
  /* 1092 */  false,
  /* 1093 */  false,
  /* 1094 */  false,
  /* 1095 */  false,
  /* 1096 */  false,
  /* 1097 */  false,
  /* 1098 */  false,
  /* 1099 */  false,
  /* 1100 */  false,
  /* 1101 */  false,
  /* 1102 */  false,
  /* 1103 */  false,
  /* 1104 */  false,
  /* 1105 */  false,
  /* 1106 */  false,
  /* 1107 */  false,
  /* 1108 */  false,
  /* 1109 */  false,
  /* 1110 */  false,
  /* 1111 */  false,
  /* 1112 */  false,
  /* 1113 */  false,
  /* 1114 */  false,
  /* 1115 */  false,
  /* 1116 */  false,
  /* 1117 */  false,
  /* 1118 */  false,
  /* 1119 */  false,
  /* 1120 */  false,
  /* 1121 */  false,
  /* 1122 */  false,
  /* 1123 */  false,
  /* 1124 */  false,
  /* 1125 */  false,
  /* 1126 */  false,
  /* 1127 */  false,
  /* 1128 */  false,
  /* 1129 */  false,
  /* 1130 */  false,
  /* 1131 */  false,
  /* 1132 */  false,
  /* 1133 */  false,
  /* 1134 */  false,
  /* 1135 */  false,
  /* 1136 */  false,
  /* 1137 */  false,
  /* 1138 */  false,
  /* 1139 */  false,
  /* 1140 */  false,
  /* 1141 */  false,
  /* 1142 */  false,
  /* 1143 */  false,
  /* 1144 */  false,
  /* 1145 */  false,
  /* 1146 */  false,
  /* 1147 */  false,
  /* 1148 */  false,
  /* 1149 */  false,
  /* 1150 */  false,
  /* 1151 */  false,
  /* 1152 */  false,
  /* 1153 */  false,
  /* 1154 */  false,
  /* 1155 */  false,
  /* 1156 */  false,
  /* 1157 */  false,
  /* 1158 */  false,
  /* 1159 */  false,
  /* 1160 */  false,
  /* 1161 */  false,
  /* 1162 */  false,
  /* 1163 */  false,
  /* 1164 */  false,
  /* 1165 */  false,
  /* 1166 */  false,
  /* 1167 */  false,
  /* 1168 */  false,
  /* 1169 */  false,
  /* 1170 */  false,
  /* 1171 */  false,
  /* 1172 */  false,
  /* 1173 */  false,
  /* 1174 */  false,
  /* 1175 */  false,
  /* 1176 */  false,
  /* 1177 */  false,
  /* 1178 */  false,
  /* 1179 */  false,
  /* 1180 */  false,
  /* 1181 */  false,
  /* 1182 */  false,
  /* 1183 */  false,
  /* 1184 */  false,
  /* 1185 */  false,
  /* 1186 */  false,
  /* 1187 */  false,
  /* 1188 */  false,
  /* 1189 */  false,
  /* 1190 */  false,
  /* 1191 */  false,
  /* 1192 */  false,
  /* 1193 */  false,
  /* 1194 */  false,
  /* 1195 */  false,
  /* 1196 */  false,
  /* 1197 */  false,
  /* 1198 */  false,
  /* 1199 */  false,
  /* 1200 */  false,
  /* 1201 */  false,
  /* 1202 */  false,
  /* 1203 */  false,
  /* 1204 */  false,
  /* 1205 */  false,
  /* 1206 */  false,
  /* 1207 */  false,
  /* 1208 */  false,
  /* 1209 */  false,
  /* 1210 */  false,
  /* 1211 */  false,
  /* 1212 */  false,
  /* 1213 */  false,
  /* 1214 */  false,
  /* 1215 */  false,
  /* 1216 */  false,
  /* 1217 */  false,
  /* 1218 */  false,
  /* 1219 */  false,
  /* 1220 */  false,
  /* 1221 */  false,
  /* 1222 */  false,
  /* 1223 */  false,
  /* 1224 */  false,
  /* 1225 */  false,
  /* 1226 */  false,
  /* 1227 */  false,
  /* 1228 */  false,
  /* 1229 */  false,
  /* 1230 */  false,
  /* 1231 */  false,
  /* 1232 */  false,
  /* 1233 */  false,
  /* 1234 */  false,
  /* 1235 */  false,
  /* 1236 */  false,
  /* 1237 */  false,
  /* 1238 */  false,
  /* 1239 */  false,
  /* 1240 */  false,
  /* 1241 */  false,
  /* 1242 */  false,
  /* 1243 */  false,
  /* 1244 */  false,
  /* 1245 */  false,
  /* 1246 */  false,
  /* 1247 */  false,
  /* 1248 */  false,
  /* 1249 */  false,
  /* 1250 */  false,
  /* 1251 */  false,
  /* 1252 */  false,
  /* 1253 */  false,
  /* 1254 */  false,
  /* 1255 */  false,
  /* 1256 */  false,
  /* 1257 */  false,
  /* 1258 */  false,
  /* 1259 */  false,
  /* 1260 */  false,
  /* 1261 */  false,
  /* 1262 */  false,
  /* 1263 */  false,
  /* 1264 */  false,
  /* 1265 */  false,
  /* 1266 */  false,
  /* 1267 */  false,
  /* 1268 */  false,
  /* 1269 */  false,
  /* 1270 */  false,
  /* 1271 */  false,
  /* 1272 */  false,
  /* 1273 */  false,
  /* 1274 */  false,
  /* 1275 */  false,
  /* 1276 */  false,
  /* 1277 */  false,
  /* 1278 */  false,
  /* 1279 */  false,
  /* 1280 */  false,
  /* 1281 */  false,
  /* 1282 */  false,
  /* 1283 */  false,
  /* 1284 */  false,
  /* 1285 */  false,
  /* 1286 */  false,
  /* 1287 */  false,
  /* 1288 */  false,
  /* 1289 */  false,
  /* 1290 */  false,
  /* 1291 */  false,
  /* 1292 */  false,
  /* 1293 */  false,
  /* 1294 */  false,
  /* 1295 */  false,
  /* 1296 */  false,
  /* 1297 */  false,
  /* 1298 */  false,
  /* 1299 */  false,
  /* 1300 */  false,
  /* 1301 */  false,
  /* 1302 */  false,
  /* 1303 */  false,
  /* 1304 */  false,
  /* 1305 */  false,
  /* 1306 */  false,
  /* 1307 */  false,
  /* 1308 */  false,
  /* 1309 */  false,
  /* 1310 */  false,
  /* 1311 */  false,
  /* 1312 */  false,
  /* 1313 */  false,
  /* 1314 */  false,
  /* 1315 */  false,
  /* 1316 */  false,
  /* 1317 */  false,
  /* 1318 */  false,
  /* 1319 */  false,
  /* 1320 */  false,
  /* 1321 */  false,
  /* 1322 */  false,
  /* 1323 */  false,
  /* 1324 */  false,
  /* 1325 */  false,
  /* 1326 */  false,
  /* 1327 */  false,
  /* 1328 */  false,
  /* 1329 */  false,
  /* 1330 */  false,
  /* 1331 */  false,
  /* 1332 */  false,
  /* 1333 */  false,
  /* 1334 */  false,
  /* 1335 */  false,
  /* 1336 */  false,
  /* 1337 */  false,
  /* 1338 */  false,
  /* 1339 */  false,
  /* 1340 */  false,
  /* 1341 */  false,
  /* 1342 */  false,
  /* 1343 */  false,
  /* 1344 */  false,
  /* 1345 */  false,
  /* 1346 */  false,
  /* 1347 */  false,
  /* 1348 */  false,
  /* 1349 */  false,
  /* 1350 */  false,
  /* 1351 */  false,
  /* 1352 */  false,
  /* 1353 */  false,
  /* 1354 */  false,
  /* 1355 */  false,
  /* 1356 */  false,
  /* 1357 */  false,
  /* 1358 */  false,
  /* 1359 */  false,
  /* 1360 */  false,
  /* 1361 */  false,
  /* 1362 */  false,
  /* 1363 */  false,
  /* 1364 */  false,
  /* 1365 */  false,
  /* 1366 */  false,
  /* 1367 */  false,
  /* 1368 */  false,
  /* 1369 */  false,
  /* 1370 */  false,
  /* 1371 */  false,
  /* 1372 */  false,
  /* 1373 */  false,
  /* 1374 */  false,
  /* 1375 */  false,
  /* 1376 */  false,
  /* 1377 */  false,
  /* 1378 */  false,
  /* 1379 */  false,
  /* 1380 */  false,
  /* 1381 */  false,
  /* 1382 */  false,
  /* 1383 */  false,
  /* 1384 */  false,
  /* 1385 */  false,
  /* 1386 */  false,
  /* 1387 */  false,
  /* 1388 */  false,
  /* 1389 */  false,
  /* 1390 */  false,
  /* 1391 */  false,
  /* 1392 */  false,
  /* 1393 */  false,
  /* 1394 */  false,
  /* 1395 */  false,
  /* 1396 */  false,
  /* 1397 */  false,
  /* 1398 */  false,
  /* 1399 */  false,
  /* 1400 */  false,
  /* 1401 */  false,
  /* 1402 */  false,
  /* 1403 */  false,
  /* 1404 */  false,
  /* 1405 */  false,
  /* 1406 */  false,
  /* 1407 */  false,
  /* 1408 */  false,
  /* 1409 */  false,
  /* 1410 */  false,
  /* 1411 */  false,
  /* 1412 */  false,
  /* 1413 */  false,
  /* 1414 */  false,
  /* 1415 */  false,
  /* 1416 */  false,
  /* 1417 */  false,
  /* 1418 */  false,
  /* 1419 */  false,
  /* 1420 */  false,
  /* 1421 */  false,
  /* 1422 */  false,
  /* 1423 */  false,
  /* 1424 */  false,
  /* 1425 */  false,
  /* 1426 */  false,
  /* 1427 */  false,
  /* 1428 */  false,
  /* 1429 */  false,
  /* 1430 */  false,
  /* 1431 */  false,
  /* 1432 */  false,
  /* 1433 */  false,
  /* 1434 */  false,
  /* 1435 */  false,
  /* 1436 */  false,
  /* 1437 */  false,
  /* 1438 */  false,
  /* 1439 */  false,
  /* 1440 */  false,
  /* 1441 */  false,
  /* 1442 */  false,
  /* 1443 */  false,
  /* 1444 */  false,
  /* 1445 */  false,
  /* 1446 */  false,
  /* 1447 */  false,
  /* 1448 */  false,
  /* 1449 */  false,
  /* 1450 */  false,
  /* 1451 */  false,
  /* 1452 */  false,
  /* 1453 */  false,
  /* 1454 */  false,
  /* 1455 */  false,
  /* 1456 */  false,
  /* 1457 */  false,
  /* 1458 */  false,
  /* 1459 */  false,
  /* 1460 */  false,
  /* 1461 */  false,
  /* 1462 */  false,
  /* 1463 */  false,
  /* 1464 */  false,
  /* 1465 */  false,
  /* 1466 */  false,
  /* 1467 */  false,
  /* 1468 */  false,
  /* 1469 */  false,
  /* 1470 */  false,
  /* 1471 */  false,
  /* 1472 */  false,
  /* 1473 */  false,
  /* 1474 */  false,
  /* 1475 */  false,
  /* 1476 */  false,
  /* 1477 */  false,
  /* 1478 */  false,
  /* 1479 */  false,
  /* 1480 */  false,
  /* 1481 */  false,
  /* 1482 */  false,
  /* 1483 */  false,
  /* 1484 */  false,
  /* 1485 */  false,
  /* 1486 */  false,
  /* 1487 */  false,
  /* 1488 */  false,
  /* 1489 */  false,
  /* 1490 */  false,
  /* 1491 */  false,
  /* 1492 */  false,
  /* 1493 */  false,
  /* 1494 */  false,
  /* 1495 */  false,
  /* 1496 */  false,
  /* 1497 */  false,
  /* 1498 */  false,
  /* 1499 */  false,
  /* 1500 */  false,
  /* 1501 */  false,
  /* 1502 */  false,
  /* 1503 */  false,
  /* 1504 */  false,
  /* 1505 */  false,
  /* 1506 */  false,
  /* 1507 */  false,
  /* 1508 */  false,
  /* 1509 */  false,
  /* 1510 */  false,
  /* 1511 */  false,
  /* 1512 */  false,
  /* 1513 */  false,
  /* 1514 */  false,
  /* 1515 */  false,
  /* 1516 */  false,
  /* 1517 */  false,
  /* 1518 */  false,
  /* 1519 */  false,
  /* 1520 */  false,
  /* 1521 */  false,
  /* 1522 */  false,
  /* 1523 */  false,
  /* 1524 */  false,
  /* 1525 */  false,
  /* 1526 */  false,
  /* 1527 */  false,
  /* 1528 */  false,
  /* 1529 */  false,
  /* 1530 */  false,
  /* 1531 */  false,
  /* 1532 */  false,
  /* 1533 */  false,
  /* 1534 */  false,
  /* 1535 */  false,
  /* 1536 */  false,
  /* 1537 */  false,
  /* 1538 */  false,
  /* 1539 */  false,
  /* 1540 */  false,
  /* 1541 */  false,
  /* 1542 */  false,
  /* 1543 */  false,
  /* 1544 */  false,
  /* 1545 */  false,
  /* 1546 */  false,
  /* 1547 */  false,
  /* 1548 */  false,
  /* 1549 */  false,
  /* 1550 */  false,
  /* 1551 */  false,
  /* 1552 */  false,
  /* 1553 */  false,
  /* 1554 */  false,
  /* 1555 */  false,
  /* 1556 */  false,
  /* 1557 */  false,
  /* 1558 */  false,
  /* 1559 */  false,
  /* 1560 */  false,
  /* 1561 */  false,
  /* 1562 */  false,
  /* 1563 */  false,
  /* 1564 */  false,
  /* 1565 */  false,
  /* 1566 */  false,
  /* 1567 */  false,
  /* 1568 */  false,
  /* 1569 */  false,
  /* 1570 */  false,
  /* 1571 */  false,
  /* 1572 */  false,
  /* 1573 */  false,
  /* 1574 */  false,
  /* 1575 */  false,
  /* 1576 */  false,
  /* 1577 */  false,
  /* 1578 */  false,
  /* 1579 */  false,
  /* 1580 */  false,
  /* 1581 */  false,
  /* 1582 */  false,
  /* 1583 */  false,
  /* 1584 */  false,
  /* 1585 */  false,
  /* 1586 */  false,
  /* 1587 */  false,
  /* 1588 */  false,
  /* 1589 */  false,
  /* 1590 */  false,
  /* 1591 */  false,
  /* 1592 */  false,
  /* 1593 */  false,
  /* 1594 */  false,
  /* 1595 */  false,
  /* 1596 */  false,
  /* 1597 */  false,
  /* 1598 */  false,
  /* 1599 */  false,
  /* 1600 */  false,
  /* 1601 */  false,
  /* 1602 */  false,
  /* 1603 */  false,
  /* 1604 */  false,
  /* 1605 */  false,
  /* 1606 */  false,
  /* 1607 */  false,
  /* 1608 */  false,
  /* 1609 */  false,
  /* 1610 */  false,
  /* 1611 */  false,
  /* 1612 */  false,
  /* 1613 */  false,
  /* 1614 */  false,
  /* 1615 */  false,
  /* 1616 */  false,
  /* 1617 */  false,
  /* 1618 */  false,
  /* 1619 */  false,
  /* 1620 */  false,
  /* 1621 */  false,
  /* 1622 */  false,
  /* 1623 */  false,
  /* 1624 */  false,
  /* 1625 */  false,
  /* 1626 */  false,
  /* 1627 */  false,
  /* 1628 */  false,
  /* 1629 */  false,
  /* 1630 */  false,
  /* 1631 */  false,
  /* 1632 */  false,
  /* 1633 */  false,
  /* 1634 */  false,
  /* 1635 */  false,
  /* 1636 */  false,
  /* 1637 */  false,
  /* 1638 */  false,
  /* 1639 */  false,
  /* 1640 */  false,
  /* 1641 */  false,
  /* 1642 */  false,
  /* 1643 */  false,
  /* 1644 */  false,
  /* 1645 */  false,
  /* 1646 */  false,
  /* 1647 */  false,
  /* 1648 */  false,
  /* 1649 */  false,
  /* 1650 */  false,
  /* 1651 */  false,
  /* 1652 */  false,
  /* 1653 */  false,
  /* 1654 */  false,
  /* 1655 */  false,
  /* 1656 */  false,
  /* 1657 */  false,
  /* 1658 */  false,
  /* 1659 */  false,
  /* 1660 */  false,
  /* 1661 */  false,
  /* 1662 */  false,
  /* 1663 */  false,
  /* 1664 */  false,
  /* 1665 */  false,
  /* 1666 */  false,
  /* 1667 */  false,
  /* 1668 */  false,
  /* 1669 */  false,
  /* 1670 */  false,
  /* 1671 */  false,
  /* 1672 */  false,
  /* 1673 */  false,
  /* 1674 */  false,
  /* 1675 */  false,
  /* 1676 */  false,
  /* 1677 */  false,
  /* 1678 */  false,
  /* 1679 */  false,
  /* 1680 */  false,
  /* 1681 */  false,
  /* 1682 */  false,
  /* 1683 */  false,
  /* 1684 */  false,
  /* 1685 */  false,
  /* 1686 */  false,
  /* 1687 */  false,
  /* 1688 */  false,
  /* 1689 */  false,
  /* 1690 */  false,
  /* 1691 */  false,
  /* 1692 */  false,
  /* 1693 */  false,
  /* 1694 */  false,
  /* 1695 */  false,
  /* 1696 */  false,
  /* 1697 */  false,
  /* 1698 */  false,
  /* 1699 */  false,
  /* 1700 */  false,
  /* 1701 */  false,
  /* 1702 */  false,
  /* 1703 */  false,
  /* 1704 */  false,
  /* 1705 */  false,
  /* 1706 */  false,
  /* 1707 */  false,
  /* 1708 */  false,
  /* 1709 */  false,
  /* 1710 */  false,
  /* 1711 */  false,
  /* 1712 */  false,
  /* 1713 */  false,
  /* 1714 */  false,
  /* 1715 */  false,
  /* 1716 */  false,
  /* 1717 */  false,
  /* 1718 */  false,
  /* 1719 */  false,
  /* 1720 */  false,
  /* 1721 */  false,
  /* 1722 */  false,
  /* 1723 */  false,
  /* 1724 */  false,
  /* 1725 */  false,
  /* 1726 */  false,
  /* 1727 */  false,
  /* 1728 */  false,
  /* 1729 */  false,
  /* 1730 */  false,
  /* 1731 */  false,
  /* 1732 */  false,
  /* 1733 */  false,
  /* 1734 */  false,
  /* 1735 */  false,
  /* 1736 */  false,
  /* 1737 */  false,
  /* 1738 */  false,
  /* 1739 */  false,
  /* 1740 */  false,
  /* 1741 */  false,
  /* 1742 */  false,
  /* 1743 */  false,
  /* 1744 */  false,
  /* 1745 */  false,
  /* 1746 */  false,
  /* 1747 */  false,
  /* 1748 */  false,
  /* 1749 */  false,
  /* 1750 */  false,
  /* 1751 */  false,
  /* 1752 */  false,
  /* 1753 */  false,
  /* 1754 */  false,
  /* 1755 */  false,
  /* 1756 */  false,
  /* 1757 */  false,
  /* 1758 */  false,
  /* 1759 */  false,
  /* 1760 */  false,
  /* 1761 */  false,
  /* 1762 */  false,
  /* 1763 */  false,
  /* 1764 */  false,
  /* 1765 */  false,
  /* 1766 */  false,
  /* 1767 */  false,
  /* 1768 */  false,
  /* 1769 */  false,
  /* 1770 */  false,
  /* 1771 */  false,
  /* 1772 */  false,
  /* 1773 */  false,
  /* 1774 */  false,
  /* 1775 */  false,
  /* 1776 */  false,
  /* 1777 */  false,
  /* 1778 */  false,
  /* 1779 */  false,
  /* 1780 */  false,
  /* 1781 */  false,
  /* 1782 */  false,
  /* 1783 */  false,
  /* 1784 */  false,
  /* 1785 */  false,
  /* 1786 */  false,
  /* 1787 */  false,
  /* 1788 */  false,
  /* 1789 */  false,
  /* 1790 */  false,
  /* 1791 */  false,
  /* 1792 */  false,
  /* 1793 */  false,
  /* 1794 */  false,
  /* 1795 */  false,
  /* 1796 */  false,
  /* 1797 */  false,
  /* 1798 */  false,
  /* 1799 */  false,
  /* 1800 */  false,
  /* 1801 */  false,
  /* 1802 */  false,
  /* 1803 */  false,
  /* 1804 */  false,
  /* 1805 */  false,
  /* 1806 */  false,
  /* 1807 */  false,
  /* 1808 */  false,
  /* 1809 */  false,
  /* 1810 */  false,
  /* 1811 */  false,
  /* 1812 */  false,
  /* 1813 */  false,
  /* 1814 */  false,
  /* 1815 */  false,
  /* 1816 */  false,
  /* 1817 */  false,
  /* 1818 */  false,
  /* 1819 */  false,
  /* 1820 */  false,
  /* 1821 */  false,
  /* 1822 */  false,
  /* 1823 */  false,
  /* 1824 */  false,
  /* 1825 */  false,
  /* 1826 */  false,
  /* 1827 */  false,
  /* 1828 */  false,
  /* 1829 */  false,
  /* 1830 */  false,
  /* 1831 */  false,
  /* 1832 */  false,
  /* 1833 */  false,
  /* 1834 */  false,
  /* 1835 */  false,
  /* 1836 */  false,
  /* 1837 */  false,
  /* 1838 */  false,
  /* 1839 */  false,
  /* 1840 */  false,
  /* 1841 */  false,
  /* 1842 */  false,
  /* 1843 */  false,
  /* 1844 */  false,
  /* 1845 */  false,
  /* 1846 */  false,
  /* 1847 */  false,
  /* 1848 */  false,
  /* 1849 */  false,
  /* 1850 */  false,
  /* 1851 */  false,
  /* 1852 */  false,
  /* 1853 */  false,
  /* 1854 */  false,
  /* 1855 */  false,
  /* 1856 */  false,
  /* 1857 */  false,
  /* 1858 */  false,
  /* 1859 */  false,
  /* 1860 */  false,
  /* 1861 */  false,
  /* 1862 */  false,
  /* 1863 */  false,
  /* 1864 */  false,
  /* 1865 */  false,
  /* 1866 */  false,
  /* 1867 */  false,
  /* 1868 */  false,
  /* 1869 */  false,
  /* 1870 */  false,
  /* 1871 */  false,
  /* 1872 */  false,
  /* 1873 */  false,
  /* 1874 */  false,
  /* 1875 */  false,
  /* 1876 */  false,
  /* 1877 */  false,
  /* 1878 */  false,
  /* 1879 */  false,
  /* 1880 */  false,
  /* 1881 */  false,
  /* 1882 */  false,
  /* 1883 */  false,
  /* 1884 */  false,
  /* 1885 */  false,
  /* 1886 */  false,
  /* 1887 */  false,
  /* 1888 */  false,
  /* 1889 */  false,
  /* 1890 */  false,
  /* 1891 */  false,
  /* 1892 */  false,
  /* 1893 */  false,
  /* 1894 */  false,
  /* 1895 */  false,
  /* 1896 */  false,
  /* 1897 */  false,
  /* 1898 */  false,
  /* 1899 */  false,
  /* 1900 */  false,
  /* 1901 */  false,
  /* 1902 */  false,
  /* 1903 */  false,
  /* 1904 */  false,
  /* 1905 */  false,
  /* 1906 */  false,
  /* 1907 */  false,
  /* 1908 */  false,
  /* 1909 */  false,
  /* 1910 */  false,
  /* 1911 */  false,
  /* 1912 */  false,
  /* 1913 */  false,
  /* 1914 */  false,
  /* 1915 */  false,
  /* 1916 */  false,
  /* 1917 */  false,
  /* 1918 */  false,
  /* 1919 */  false,
  /* 1920 */  false,
  /* 1921 */  false,
  /* 1922 */  false,
  /* 1923 */  false,
  /* 1924 */  false,
  /* 1925 */  false,
  /* 1926 */  false,
  /* 1927 */  false,
  /* 1928 */  false,
  /* 1929 */  false,
  /* 1930 */  false,
  /* 1931 */  false,
  /* 1932 */  false,
  /* 1933 */  false,
  /* 1934 */  false,
  /* 1935 */  false,
  /* 1936 */  false,
  /* 1937 */  false,
  /* 1938 */  false,
  /* 1939 */  false,
  /* 1940 */  false,
  /* 1941 */  false,
  /* 1942 */  false,
  /* 1943 */  false,
  /* 1944 */  false,
  /* 1945 */  false,
  /* 1946 */  false,
  /* 1947 */  false,
  /* 1948 */  false,
  /* 1949 */  false,
  /* 1950 */  false,
  /* 1951 */  false,
  /* 1952 */  false,
  /* 1953 */  false,
  /* 1954 */  false,
  /* 1955 */  false,
  /* 1956 */  false,
  /* 1957 */  false,
  /* 1958 */  false,
  /* 1959 */  false,
  /* 1960 */  false,
  /* 1961 */  false,
  /* 1962 */  false,
  /* 1963 */  false,
  /* 1964 */  false,
  /* 1965 */  false,
  /* 1966 */  false,
  /* 1967 */  false,
  /* 1968 */  false,
  /* 1969 */  false,
  /* 1970 */  false,
  /* 1971 */  false,
  /* 1972 */  false,
  /* 1973 */  false,
  /* 1974 */  false,
  /* 1975 */  false,
  /* 1976 */  false,
  /* 1977 */  false,
  /* 1978 */  false,
  /* 1979 */  false,
  /* 1980 */  false,
  /* 1981 */  false,
  /* 1982 */  false,
  /* 1983 */  false,
  /* 1984 */  false,
  /* 1985 */  false,
  /* 1986 */  false,
  /* 1987 */  false,
  /* 1988 */  false,
  /* 1989 */  false,
  /* 1990 */  false,
  /* 1991 */  false,
  /* 1992 */  false,
  /* 1993 */  false,
  /* 1994 */  false,
  /* 1995 */  false,
  /* 1996 */  false,
  /* 1997 */  false,
  /* 1998 */  false,
  /* 1999 */  false,
  /* 2000 */  false,
  /* 2001 */  false,
  /* 2002 */  false,
  /* 2003 */  false,
  /* 2004 */  false,
  /* 2005 */  false,
  /* 2006 */  false,
  /* 2007 */  false,
  /* 2008 */  false,
  /* 2009 */  false,
  /* 2010 */  false,
  /* 2011 */  false,
  /* 2012 */  false,
  /* 2013 */  false,
  /* 2014 */  false,
  /* 2015 */  false,
  /* 2016 */  false,
  /* 2017 */  false,
  /* 2018 */  false,
  /* 2019 */  false,
  /* 2020 */  false,
  /* 2021 */  false,
  /* 2022 */  false,
  /* 2023 */  false,
  /* 2024 */  false,
  /* 2025 */  false,
  /* 2026 */  false,
  /* 2027 */  false,
  /* 2028 */  false,
  /* 2029 */  false,
  /* 2030 */  false,
  /* 2031 */  false,
  /* 2032 */  false,
  /* 2033 */  false,
  /* 2034 */  false,
  /* 2035 */  false,
  /* 2036 */  false,
  /* 2037 */  false,
  /* 2038 */  false,
  /* 2039 */  false,
  /* 2040 */  false,
  /* 2041 */  false,
  /* 2042 */  false,
  /* 2043 */  false,
  /* 2044 */  false,
  /* 2045 */  false,
  /* 2046 */  false,
  /* 2047 */  false,
  /* 2048 */  false,
  /* 2049 */  false,
  /* 2050 */  false,
  /* 2051 */  false,
  /* 2052 */  false,
  /* 2053 */  false,
  /* 2054 */  false,
  /* 2055 */  false,
  /* 2056 */  false,
  /* 2057 */  false,
  /* 2058 */  false,
  /* 2059 */  false,
  /* 2060 */  false,
  /* 2061 */  false,
  /* 2062 */  false,
  /* 2063 */  false,
  /* 2064 */  false,
  /* 2065 */  false,
  /* 2066 */  false,
  /* 2067 */  false,
  /* 2068 */  false,
  /* 2069 */  false,
  /* 2070 */  false,
  /* 2071 */  false,
  /* 2072 */  false,
  /* 2073 */  false,
  /* 2074 */  false,
  /* 2075 */  false,
  /* 2076 */  false,
  /* 2077 */  false,
  /* 2078 */  false,
  /* 2079 */  false,
  /* 2080 */  false,
  /* 2081 */  false,
  /* 2082 */  false,
  /* 2083 */  false,
  /* 2084 */  false,
  /* 2085 */  false,
  /* 2086 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVectMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  0, // Blackhole: 34
  1, // Bool: 35
  0, // BoxLock: 36
  0, // ReverseBytesI: 37
  0, // ReverseBytesL: 38
  0, // ReverseBytesUS: 39
  0, // ReverseBytesS: 40
  0, // ReverseBytesV: 41
  0, // CProj: 42
  0, // CacheWB: 43
  0, // CacheWBPreSync: 44
  0, // CacheWBPostSync: 45
  0, // CallDynamicJava: 46
  0, // CallJava: 47
  0, // CallLeaf: 48
  0, // CallLeafNoFP: 49
  0, // CallLeafVector: 50
  0, // CallRuntime: 51
  0, // CallStaticJava: 52
  0, // CastDD: 53
  0, // CastFF: 54
  0, // CastII: 55
  0, // CastLL: 56
  0, // CastVV: 57
  0, // CastX2P: 58
  0, // CastP2X: 59
  0, // CastPP: 60
  0, // Catch: 61
  0, // CatchProj: 62
  0, // CheckCastPP: 63
  0, // ClearArray: 64
  0, // CompressBits: 65
  0, // ExpandBits: 66
  0, // ConstraintCast: 67
  0, // CMoveD: 68
  0, // CMoveVD: 69
  0, // CMoveF: 70
  0, // CMoveVF: 71
  0, // CMoveI: 72
  0, // CMoveL: 73
  0, // CMoveP: 74
  0, // CMoveN: 75
  1, // CmpN: 76
  1, // CmpD: 77
  0, // CmpD3: 78
  1, // CmpF: 79
  0, // CmpF3: 80
  1, // CmpI: 81
  1, // CmpL: 82
  0, // CmpL3: 83
  0, // CmpLTMask: 84
  1, // CmpP: 85
  1, // CmpU: 86
  1, // CmpUL: 87
  0, // CompareAndSwapB: 88
  0, // CompareAndSwapS: 89
  0, // CompareAndSwapI: 90
  0, // CompareAndSwapL: 91
  0, // CompareAndSwapP: 92
  0, // CompareAndSwapN: 93
  0, // WeakCompareAndSwapB: 94
  0, // WeakCompareAndSwapS: 95
  0, // WeakCompareAndSwapI: 96
  0, // WeakCompareAndSwapL: 97
  0, // WeakCompareAndSwapP: 98
  0, // WeakCompareAndSwapN: 99
  0, // CompareAndExchangeB: 100
  0, // CompareAndExchangeS: 101
  0, // CompareAndExchangeI: 102
  0, // CompareAndExchangeL: 103
  0, // CompareAndExchangeP: 104
  0, // CompareAndExchangeN: 105
  0, // GetAndAddB: 106
  0, // GetAndAddS: 107
  0, // GetAndAddI: 108
  0, // GetAndAddL: 109
  0, // GetAndSetB: 110
  0, // GetAndSetS: 111
  0, // GetAndSetI: 112
  0, // GetAndSetL: 113
  0, // GetAndSetP: 114
  0, // GetAndSetN: 115
  0, // Con: 116
  0, // ConN: 117
  0, // ConNKlass: 118
  0, // ConD: 119
  0, // ConF: 120
  0, // ConI: 121
  0, // ConL: 122
  0, // ConP: 123
  0, // Conv2B: 124
  0, // ConvD2F: 125
  0, // ConvD2I: 126
  0, // ConvD2L: 127
  0, // ConvF2D: 128
  0, // ConvF2I: 129
  0, // ConvF2L: 130
  0, // ConvI2D: 131
  0, // ConvI2F: 132
  0, // ConvI2L: 133
  0, // ConvL2D: 134
  0, // ConvL2F: 135
  0, // ConvL2I: 136
  0, // CountedLoop: 137
  0, // CountedLoopEnd: 138
  0, // OuterStripMinedLoop: 139
  0, // OuterStripMinedLoopEnd: 140
  0, // LongCountedLoop: 141
  0, // LongCountedLoopEnd: 142
  0, // CountLeadingZerosI: 143
  0, // CountLeadingZerosL: 144
  0, // CountLeadingZerosV: 145
  0, // CountTrailingZerosI: 146
  0, // CountTrailingZerosL: 147
  0, // CountTrailingZerosV: 148
  0, // CreateEx: 149
  0, // DecodeN: 150
  0, // DecodeNKlass: 151
  0, // DivD: 152
  0, // DivF: 153
  0, // DivI: 154
  0, // DivL: 155
  0, // UDivI: 156
  0, // UDivL: 157
  0, // DivMod: 158
  0, // DivModI: 159
  0, // DivModL: 160
  0, // UDivModI: 161
  0, // UDivModL: 162
  0, // EncodeISOArray: 163
  0, // EncodeP: 164
  0, // EncodePKlass: 165
  1, // FastLock: 166
  1, // FastUnlock: 167
  0, // FmaD: 168
  0, // FmaF: 169
  0, // Goto: 170
  0, // Halt: 171
  0, // CountPositives: 172
  0, // If: 173
  0, // RangeCheck: 174
  0, // IfFalse: 175
  0, // IfTrue: 176
  0, // Initialize: 177
  0, // JProj: 178
  0, // Jump: 179
  0, // JumpProj: 180
  0, // LShiftI: 181
  0, // LShiftL: 182
  0, // LoadB: 183
  0, // LoadUB: 184
  0, // LoadUS: 185
  0, // LoadD: 186
  0, // LoadD_unaligned: 187
  0, // LoadF: 188
  0, // LoadI: 189
  0, // LoadKlass: 190
  0, // LoadNKlass: 191
  0, // LoadL: 192
  0, // LoadL_unaligned: 193
  0, // LoadPLocked: 194
  0, // LoadP: 195
  0, // LoadN: 196
  0, // LoadRange: 197
  0, // LoadS: 198
  0, // Lock: 199
  0, // Loop: 200
  0, // LoopLimit: 201
  0, // Mach: 202
  0, // MachNullCheck: 203
  0, // MachProj: 204
  0, // MulAddS2I: 205
  0, // MaxI: 206
  0, // MaxL: 207
  0, // MaxD: 208
  0, // MaxF: 209
  0, // MemBarAcquire: 210
  0, // LoadFence: 211
  0, // MemBarAcquireLock: 212
  0, // MemBarCPUOrder: 213
  0, // MemBarRelease: 214
  0, // StoreFence: 215
  0, // StoreStoreFence: 216
  0, // MemBarReleaseLock: 217
  0, // MemBarVolatile: 218
  0, // MemBarStoreStore: 219
  0, // MergeMem: 220
  0, // MinI: 221
  0, // MinL: 222
  0, // MinF: 223
  0, // MinD: 224
  0, // ModD: 225
  0, // ModF: 226
  0, // ModI: 227
  0, // ModL: 228
  0, // UModI: 229
  0, // UModL: 230
  0, // MoveI2F: 231
  0, // MoveF2I: 232
  0, // MoveL2D: 233
  0, // MoveD2L: 234
  0, // IsInfiniteF: 235
  0, // IsInfiniteD: 236
  0, // MulD: 237
  0, // MulF: 238
  0, // MulHiL: 239
  0, // UMulHiL: 240
  0, // MulI: 241
  0, // MulL: 242
  0, // Multi: 243
  0, // NegI: 244
  0, // NegL: 245
  0, // NegD: 246
  0, // NegF: 247
  0, // NeverBranch: 248
  0, // OnSpinWait: 249
  0, // Opaque1: 250
  0, // OpaqueLoopInit: 251
  0, // OpaqueLoopStride: 252
  0, // Opaque2: 253
  0, // Opaque3: 254
  0, // Opaque4: 255
  0, // ProfileBoolean: 256
  0, // OrI: 257
  0, // OrL: 258
  1, // OverflowAddI: 259
  1, // OverflowSubI: 260
  1, // OverflowMulI: 261
  1, // OverflowAddL: 262
  1, // OverflowSubL: 263
  1, // OverflowMulL: 264
  0, // PCTable: 265
  0, // Parm: 266
  0, // PartialSubtypeCheck: 267
  0, // SubTypeCheck: 268
  0, // Phi: 269
  0, // PopCountI: 270
  0, // PopCountL: 271
  0, // PopCountVI: 272
  0, // PopCountVL: 273
  0, // PopulateIndex: 274
  0, // PrefetchAllocation: 275
  0, // Proj: 276
  0, // RShiftI: 277
  0, // RShiftL: 278
  0, // Region: 279
  0, // Rethrow: 280
  0, // Return: 281
  0, // ReverseI: 282
  0, // ReverseL: 283
  0, // ReverseV: 284
  0, // Root: 285
  0, // RoundDouble: 286
  0, // RoundDoubleMode: 287
  0, // RoundDoubleModeV: 288
  0, // RoundFloat: 289
  0, // RotateLeft: 290
  0, // RotateLeftV: 291
  0, // RotateRight: 292
  0, // RotateRightV: 293
  0, // SafePoint: 294
  0, // SafePointScalarObject: 295
  0, // ShenandoahCompareAndExchangeP: 296
  0, // ShenandoahCompareAndExchangeN: 297
  0, // ShenandoahCompareAndSwapN: 298
  0, // ShenandoahCompareAndSwapP: 299
  0, // ShenandoahWeakCompareAndSwapN: 300
  0, // ShenandoahWeakCompareAndSwapP: 301
  0, // ShenandoahIUBarrier: 302
  0, // ShenandoahLoadReferenceBarrier: 303
  0, // SCMemProj: 304
  0, // CopySignD: 305
  0, // CopySignF: 306
  0, // SignumD: 307
  0, // SignumF: 308
  0, // SignumVF: 309
  0, // SignumVD: 310
  0, // SqrtD: 311
  0, // SqrtF: 312
  0, // RoundF: 313
  0, // RoundD: 314
  0, // Start: 315
  0, // StartOSR: 316
  0, // StoreB: 317
  0, // StoreC: 318
  0, // StoreCM: 319
  0, // StorePConditional: 320
  0, // StoreIConditional: 321
  0, // StoreLConditional: 322
  0, // StoreD: 323
  0, // StoreF: 324
  0, // StoreI: 325
  0, // StoreL: 326
  0, // StoreP: 327
  0, // StoreN: 328
  0, // StoreNKlass: 329
  0, // StrComp: 330
  0, // StrCompressedCopy: 331
  0, // StrEquals: 332
  0, // StrIndexOf: 333
  0, // StrIndexOfChar: 334
  0, // StrInflatedCopy: 335
  0, // SubD: 336
  0, // SubF: 337
  0, // SubI: 338
  0, // SubL: 339
  0, // TailCall: 340
  0, // TailJump: 341
  0, // MacroLogicV: 342
  0, // ThreadLocal: 343
  0, // Unlock: 344
  0, // URShiftB: 345
  0, // URShiftS: 346
  0, // URShiftI: 347
  0, // URShiftL: 348
  0, // XorI: 349
  0, // XorL: 350
  0, // Vector: 351
  0, // AddVB: 352
  0, // AddVS: 353
  0, // AddVI: 354
  0, // AddReductionVI: 355
  0, // AddVL: 356
  0, // AddReductionVL: 357
  0, // AddVF: 358
  0, // AddReductionVF: 359
  0, // AddVD: 360
  0, // AddReductionVD: 361
  0, // SubVB: 362
  0, // SubVS: 363
  0, // SubVI: 364
  0, // SubVL: 365
  0, // SubVF: 366
  0, // SubVD: 367
  0, // MulVB: 368
  0, // MulVS: 369
  0, // MulVI: 370
  0, // MulReductionVI: 371
  0, // MulVL: 372
  0, // MulReductionVL: 373
  0, // MulVF: 374
  0, // MulReductionVF: 375
  0, // MulVD: 376
  0, // MulReductionVD: 377
  0, // MulAddVS2VI: 378
  0, // FmaVD: 379
  0, // FmaVF: 380
  0, // DivVF: 381
  0, // DivVD: 382
  0, // AbsVB: 383
  0, // AbsVS: 384
  0, // AbsVI: 385
  0, // AbsVL: 386
  0, // AbsVF: 387
  0, // AbsVD: 388
  0, // NegVI: 389
  0, // NegVL: 390
  0, // NegVF: 391
  0, // NegVD: 392
  0, // SqrtVD: 393
  0, // SqrtVF: 394
  0, // LShiftCntV: 395
  0, // RShiftCntV: 396
  0, // LShiftVB: 397
  0, // LShiftVS: 398
  0, // LShiftVI: 399
  0, // LShiftVL: 400
  0, // RShiftVB: 401
  0, // RShiftVS: 402
  0, // RShiftVI: 403
  0, // RShiftVL: 404
  0, // URShiftVB: 405
  0, // URShiftVS: 406
  0, // URShiftVI: 407
  0, // URShiftVL: 408
  0, // AndV: 409
  0, // AndReductionV: 410
  0, // OrV: 411
  0, // OrReductionV: 412
  0, // XorV: 413
  0, // XorReductionV: 414
  0, // MinV: 415
  0, // MaxV: 416
  0, // MinReductionV: 417
  0, // MaxReductionV: 418
  0, // CompressV: 419
  0, // CompressM: 420
  0, // ExpandV: 421
  0, // LoadVector: 422
  0, // LoadVectorGather: 423
  0, // LoadVectorGatherMasked: 424
  0, // StoreVector: 425
  0, // StoreVectorScatter: 426
  0, // StoreVectorScatterMasked: 427
  0, // LoadVectorMasked: 428
  0, // StoreVectorMasked: 429
  0, // VectorCmpMasked: 430
  0, // VectorMaskGen: 431
  0, // VectorMaskOp: 432
  0, // VectorMaskTrueCount: 433
  0, // VectorMaskFirstTrue: 434
  0, // VectorMaskLastTrue: 435
  0, // VectorMaskToLong: 436
  0, // VectorLongToMask: 437
  0, // Pack: 438
  0, // PackB: 439
  0, // PackS: 440
  0, // PackI: 441
  0, // PackL: 442
  0, // PackF: 443
  0, // PackD: 444
  0, // Pack2L: 445
  0, // Pack2D: 446
  0, // ReplicateB: 447
  0, // ReplicateS: 448
  0, // ReplicateI: 449
  0, // ReplicateL: 450
  0, // ReplicateF: 451
  0, // ReplicateD: 452
  0, // RoundVF: 453
  0, // RoundVD: 454
  0, // Extract: 455
  0, // ExtractB: 456
  0, // ExtractUB: 457
  0, // ExtractC: 458
  0, // ExtractS: 459
  0, // ExtractI: 460
  0, // ExtractL: 461
  0, // ExtractF: 462
  0, // ExtractD: 463
  0, // Digit: 464
  0, // LowerCase: 465
  0, // UpperCase: 466
  0, // Whitespace: 467
  0, // VectorBox: 468
  0, // VectorBoxAllocate: 469
  0, // VectorUnbox: 470
  0, // VectorMaskWrapper: 471
  0, // VectorMaskCmp: 472
  0, // VectorMaskCast: 473
  0, // VectorTest: 474
  0, // VectorBlend: 475
  0, // VectorRearrange: 476
  0, // VectorLoadMask: 477
  0, // VectorLoadShuffle: 478
  0, // VectorLoadConst: 479
  0, // VectorStoreMask: 480
  0, // VectorReinterpret: 481
  0, // VectorCast: 482
  0, // VectorCastB2X: 483
  0, // VectorCastS2X: 484
  0, // VectorCastI2X: 485
  0, // VectorCastL2X: 486
  0, // VectorCastF2X: 487
  0, // VectorCastD2X: 488
  0, // VectorUCastB2X: 489
  0, // VectorUCastS2X: 490
  0, // VectorUCastI2X: 491
  0, // VectorInsert: 492
  0, // MaskAll: 493
  0, // AndVMask: 494
  0, // OrVMask: 495
  0 // no trailing comma // XorVMask: 496
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R10",
  "R10_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R13",
  "R13_H",
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R16",
  "R16_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R0",
  "R0_H",
  "R1",
  "R1_H",
  "R2",
  "R2_H",
  "R3",
  "R3_H",
  "R4",
  "R4_H",
  "R5",
  "R5_H",
  "R6",
  "R6_H",
  "R7",
  "R7_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R8",
  "R8_H",
  "R9",
  "R9_H",
  "V16",
  "V16_H",
  "V16_J",
  "V16_K",
  "V16_L",
  "V16_M",
  "V16_N",
  "V16_O",
  "V17",
  "V17_H",
  "V17_J",
  "V17_K",
  "V17_L",
  "V17_M",
  "V17_N",
  "V17_O",
  "V18",
  "V18_H",
  "V18_J",
  "V18_K",
  "V18_L",
  "V18_M",
  "V18_N",
  "V18_O",
  "V19",
  "V19_H",
  "V19_J",
  "V19_K",
  "V19_L",
  "V19_M",
  "V19_N",
  "V19_O",
  "V20",
  "V20_H",
  "V20_J",
  "V20_K",
  "V20_L",
  "V20_M",
  "V20_N",
  "V20_O",
  "V21",
  "V21_H",
  "V21_J",
  "V21_K",
  "V21_L",
  "V21_M",
  "V21_N",
  "V21_O",
  "V22",
  "V22_H",
  "V22_J",
  "V22_K",
  "V22_L",
  "V22_M",
  "V22_N",
  "V22_O",
  "V23",
  "V23_H",
  "V23_J",
  "V23_K",
  "V23_L",
  "V23_M",
  "V23_N",
  "V23_O",
  "V24",
  "V24_H",
  "V24_J",
  "V24_K",
  "V24_L",
  "V24_M",
  "V24_N",
  "V24_O",
  "V25",
  "V25_H",
  "V25_J",
  "V25_K",
  "V25_L",
  "V25_M",
  "V25_N",
  "V25_O",
  "V26",
  "V26_H",
  "V26_J",
  "V26_K",
  "V26_L",
  "V26_M",
  "V26_N",
  "V26_O",
  "V27",
  "V27_H",
  "V27_J",
  "V27_K",
  "V27_L",
  "V27_M",
  "V27_N",
  "V27_O",
  "V28",
  "V28_H",
  "V28_J",
  "V28_K",
  "V28_L",
  "V28_M",
  "V28_N",
  "V28_O",
  "V29",
  "V29_H",
  "V29_J",
  "V29_K",
  "V29_L",
  "V29_M",
  "V29_N",
  "V29_O",
  "V30",
  "V30_H",
  "V30_J",
  "V30_K",
  "V30_L",
  "V30_M",
  "V30_N",
  "V30_O",
  "V31",
  "V31_H",
  "V31_J",
  "V31_K",
  "V31_L",
  "V31_M",
  "V31_N",
  "V31_O",
  "V0",
  "V0_H",
  "V0_J",
  "V0_K",
  "V0_L",
  "V0_M",
  "V0_N",
  "V0_O",
  "V1",
  "V1_H",
  "V1_J",
  "V1_K",
  "V1_L",
  "V1_M",
  "V1_N",
  "V1_O",
  "V2",
  "V2_H",
  "V2_J",
  "V2_K",
  "V2_L",
  "V2_M",
  "V2_N",
  "V2_O",
  "V3",
  "V3_H",
  "V3_J",
  "V3_K",
  "V3_L",
  "V3_M",
  "V3_N",
  "V3_O",
  "V4",
  "V4_H",
  "V4_J",
  "V4_K",
  "V4_L",
  "V4_M",
  "V4_N",
  "V4_O",
  "V5",
  "V5_H",
  "V5_J",
  "V5_K",
  "V5_L",
  "V5_M",
  "V5_N",
  "V5_O",
  "V6",
  "V6_H",
  "V6_J",
  "V6_K",
  "V6_L",
  "V6_M",
  "V6_N",
  "V6_O",
  "V7",
  "V7_H",
  "V7_J",
  "V7_K",
  "V7_L",
  "V7_M",
  "V7_N",
  "V7_O",
  "V8",
  "V8_H",
  "V8_J",
  "V8_K",
  "V8_L",
  "V8_M",
  "V8_N",
  "V8_O",
  "V9",
  "V9_H",
  "V9_J",
  "V9_K",
  "V9_L",
  "V9_M",
  "V9_N",
  "V9_O",
  "V10",
  "V10_H",
  "V10_J",
  "V10_K",
  "V10_L",
  "V10_M",
  "V10_N",
  "V10_O",
  "V11",
  "V11_H",
  "V11_J",
  "V11_K",
  "V11_L",
  "V11_M",
  "V11_N",
  "V11_O",
  "V12",
  "V12_H",
  "V12_J",
  "V12_K",
  "V12_L",
  "V12_M",
  "V12_N",
  "V12_O",
  "V13",
  "V13_H",
  "V13_J",
  "V13_K",
  "V13_L",
  "V13_M",
  "V13_N",
  "V13_O",
  "V14",
  "V14_H",
  "V14_J",
  "V14_K",
  "V14_L",
  "V14_M",
  "V14_N",
  "V14_O",
  "V15",
  "V15_H",
  "V15_J",
  "V15_K",
  "V15_L",
  "V15_M",
  "V15_N",
  "V15_O",
  "P0",
  "P1",
  "P2",
  "P3",
  "P4",
  "P5",
  "P6",
  "P7",
  "P8",
  "P9",
  "P10",
  "P11",
  "P12",
  "P13",
  "P14",
  "P15",
  "RFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	r10->as_VMReg()        ,
	r10->as_VMReg()->next(),
	r11->as_VMReg()        ,
	r11->as_VMReg()->next(),
	r12->as_VMReg()        ,
	r12->as_VMReg()->next(),
	r13->as_VMReg()        ,
	r13->as_VMReg()->next(),
	r14->as_VMReg()        ,
	r14->as_VMReg()->next(),
	r15->as_VMReg()        ,
	r15->as_VMReg()->next(),
	r16->as_VMReg()        ,
	r16->as_VMReg()->next(),
	r17->as_VMReg()        ,
	r17->as_VMReg()->next(),
	r18_tls->as_VMReg()        ,
	r18_tls->as_VMReg()->next(),
	r0->as_VMReg()         ,
	r0->as_VMReg()->next() ,
	r1->as_VMReg()         ,
	r1->as_VMReg()->next() ,
	r2->as_VMReg()         ,
	r2->as_VMReg()->next() ,
	r3->as_VMReg()         ,
	r3->as_VMReg()->next() ,
	r4->as_VMReg()         ,
	r4->as_VMReg()->next() ,
	r5->as_VMReg()         ,
	r5->as_VMReg()->next() ,
	r6->as_VMReg()         ,
	r6->as_VMReg()->next() ,
	r7->as_VMReg()         ,
	r7->as_VMReg()->next() ,
	r19->as_VMReg()        ,
	r19->as_VMReg()->next(),
	r20->as_VMReg()        ,
	r20->as_VMReg()->next(),
	r21->as_VMReg()        ,
	r21->as_VMReg()->next(),
	r22->as_VMReg()        ,
	r22->as_VMReg()->next(),
	r23->as_VMReg()        ,
	r23->as_VMReg()->next(),
	r24->as_VMReg()        ,
	r24->as_VMReg()->next(),
	r25->as_VMReg()        ,
	r25->as_VMReg()->next(),
	r26->as_VMReg()        ,
	r26->as_VMReg()->next(),
	r27->as_VMReg()        ,
	r27->as_VMReg()->next(),
	r28->as_VMReg()        ,
	r28->as_VMReg()->next(),
	r29->as_VMReg()        ,
	r29->as_VMReg()->next(),
	r30->as_VMReg()        ,
	r30->as_VMReg()->next(),
	r31_sp->as_VMReg()     ,
	r31_sp->as_VMReg()->next(),
	r8->as_VMReg()         ,
	r8->as_VMReg()->next() ,
	r9->as_VMReg()         ,
	r9->as_VMReg()->next() ,
	v16->as_VMReg()          ,
	v16->as_VMReg()->next()  ,
	v16->as_VMReg()->next(2) ,
	v16->as_VMReg()->next(3) ,
	v16->as_VMReg()->next(4) ,
	v16->as_VMReg()->next(5) ,
	v16->as_VMReg()->next(6) ,
	v16->as_VMReg()->next(7) ,
	v17->as_VMReg()          ,
	v17->as_VMReg()->next()  ,
	v17->as_VMReg()->next(2) ,
	v17->as_VMReg()->next(3) ,
	v17->as_VMReg()->next(4) ,
	v17->as_VMReg()->next(5) ,
	v17->as_VMReg()->next(6) ,
	v17->as_VMReg()->next(7) ,
	v18->as_VMReg()          ,
	v18->as_VMReg()->next()  ,
	v18->as_VMReg()->next(2) ,
	v18->as_VMReg()->next(3) ,
	v18->as_VMReg()->next(4) ,
	v18->as_VMReg()->next(5) ,
	v18->as_VMReg()->next(6) ,
	v18->as_VMReg()->next(7) ,
	v19->as_VMReg()          ,
	v19->as_VMReg()->next()  ,
	v19->as_VMReg()->next(2) ,
	v19->as_VMReg()->next(3) ,
	v19->as_VMReg()->next(4) ,
	v19->as_VMReg()->next(5) ,
	v19->as_VMReg()->next(6) ,
	v19->as_VMReg()->next(7) ,
	v20->as_VMReg()          ,
	v20->as_VMReg()->next()  ,
	v20->as_VMReg()->next(2) ,
	v20->as_VMReg()->next(3) ,
	v20->as_VMReg()->next(4) ,
	v20->as_VMReg()->next(5) ,
	v20->as_VMReg()->next(6) ,
	v20->as_VMReg()->next(7) ,
	v21->as_VMReg()          ,
	v21->as_VMReg()->next()  ,
	v21->as_VMReg()->next(2) ,
	v21->as_VMReg()->next(3) ,
	v21->as_VMReg()->next(4) ,
	v21->as_VMReg()->next(5) ,
	v21->as_VMReg()->next(6) ,
	v21->as_VMReg()->next(7) ,
	v22->as_VMReg()          ,
	v22->as_VMReg()->next()  ,
	v22->as_VMReg()->next(2) ,
	v22->as_VMReg()->next(3) ,
	v22->as_VMReg()->next(4) ,
	v22->as_VMReg()->next(5) ,
	v22->as_VMReg()->next(6) ,
	v22->as_VMReg()->next(7) ,
	v23->as_VMReg()          ,
	v23->as_VMReg()->next()  ,
	v23->as_VMReg()->next(2) ,
	v23->as_VMReg()->next(3) ,
	v23->as_VMReg()->next(4) ,
	v23->as_VMReg()->next(5) ,
	v23->as_VMReg()->next(6) ,
	v23->as_VMReg()->next(7) ,
	v24->as_VMReg()          ,
	v24->as_VMReg()->next()  ,
	v24->as_VMReg()->next(2) ,
	v24->as_VMReg()->next(3) ,
	v24->as_VMReg()->next(4) ,
	v24->as_VMReg()->next(5) ,
	v24->as_VMReg()->next(6) ,
	v24->as_VMReg()->next(7) ,
	v25->as_VMReg()          ,
	v25->as_VMReg()->next()  ,
	v25->as_VMReg()->next(2) ,
	v25->as_VMReg()->next(3) ,
	v25->as_VMReg()->next(4) ,
	v25->as_VMReg()->next(5) ,
	v25->as_VMReg()->next(6) ,
	v25->as_VMReg()->next(7) ,
	v26->as_VMReg()          ,
	v26->as_VMReg()->next()  ,
	v26->as_VMReg()->next(2) ,
	v26->as_VMReg()->next(3) ,
	v26->as_VMReg()->next(4) ,
	v26->as_VMReg()->next(5) ,
	v26->as_VMReg()->next(6) ,
	v26->as_VMReg()->next(7) ,
	v27->as_VMReg()          ,
	v27->as_VMReg()->next()  ,
	v27->as_VMReg()->next(2) ,
	v27->as_VMReg()->next(3) ,
	v27->as_VMReg()->next(4) ,
	v27->as_VMReg()->next(5) ,
	v27->as_VMReg()->next(6) ,
	v27->as_VMReg()->next(7) ,
	v28->as_VMReg()          ,
	v28->as_VMReg()->next()  ,
	v28->as_VMReg()->next(2) ,
	v28->as_VMReg()->next(3) ,
	v28->as_VMReg()->next(4) ,
	v28->as_VMReg()->next(5) ,
	v28->as_VMReg()->next(6) ,
	v28->as_VMReg()->next(7) ,
	v29->as_VMReg()          ,
	v29->as_VMReg()->next()  ,
	v29->as_VMReg()->next(2) ,
	v29->as_VMReg()->next(3) ,
	v29->as_VMReg()->next(4) ,
	v29->as_VMReg()->next(5) ,
	v29->as_VMReg()->next(6) ,
	v29->as_VMReg()->next(7) ,
	v30->as_VMReg()          ,
	v30->as_VMReg()->next()  ,
	v30->as_VMReg()->next(2) ,
	v30->as_VMReg()->next(3) ,
	v30->as_VMReg()->next(4) ,
	v30->as_VMReg()->next(5) ,
	v30->as_VMReg()->next(6) ,
	v30->as_VMReg()->next(7) ,
	v31->as_VMReg()          ,
	v31->as_VMReg()->next()  ,
	v31->as_VMReg()->next(2) ,
	v31->as_VMReg()->next(3) ,
	v31->as_VMReg()->next(4) ,
	v31->as_VMReg()->next(5) ,
	v31->as_VMReg()->next(6) ,
	v31->as_VMReg()->next(7) ,
	v0->as_VMReg()          ,
	v0->as_VMReg()->next()  ,
	v0->as_VMReg()->next(2) ,
	v0->as_VMReg()->next(3) ,
	v0->as_VMReg()->next(4) ,
	v0->as_VMReg()->next(5) ,
	v0->as_VMReg()->next(6) ,
	v0->as_VMReg()->next(7) ,
	v1->as_VMReg()          ,
	v1->as_VMReg()->next()  ,
	v1->as_VMReg()->next(2) ,
	v1->as_VMReg()->next(3) ,
	v1->as_VMReg()->next(4) ,
	v1->as_VMReg()->next(5) ,
	v1->as_VMReg()->next(6) ,
	v1->as_VMReg()->next(7) ,
	v2->as_VMReg()          ,
	v2->as_VMReg()->next()  ,
	v2->as_VMReg()->next(2) ,
	v2->as_VMReg()->next(3) ,
	v2->as_VMReg()->next(4) ,
	v2->as_VMReg()->next(5) ,
	v2->as_VMReg()->next(6) ,
	v2->as_VMReg()->next(7) ,
	v3->as_VMReg()          ,
	v3->as_VMReg()->next()  ,
	v3->as_VMReg()->next(2) ,
	v3->as_VMReg()->next(3) ,
	v3->as_VMReg()->next(4) ,
	v3->as_VMReg()->next(5) ,
	v3->as_VMReg()->next(6) ,
	v3->as_VMReg()->next(7) ,
	v4->as_VMReg()          ,
	v4->as_VMReg()->next()  ,
	v4->as_VMReg()->next(2) ,
	v4->as_VMReg()->next(3) ,
	v4->as_VMReg()->next(4) ,
	v4->as_VMReg()->next(5) ,
	v4->as_VMReg()->next(6) ,
	v4->as_VMReg()->next(7) ,
	v5->as_VMReg()          ,
	v5->as_VMReg()->next()  ,
	v5->as_VMReg()->next(2) ,
	v5->as_VMReg()->next(3) ,
	v5->as_VMReg()->next(4) ,
	v5->as_VMReg()->next(5) ,
	v5->as_VMReg()->next(6) ,
	v5->as_VMReg()->next(7) ,
	v6->as_VMReg()          ,
	v6->as_VMReg()->next()  ,
	v6->as_VMReg()->next(2) ,
	v6->as_VMReg()->next(3) ,
	v6->as_VMReg()->next(4) ,
	v6->as_VMReg()->next(5) ,
	v6->as_VMReg()->next(6) ,
	v6->as_VMReg()->next(7) ,
	v7->as_VMReg()          ,
	v7->as_VMReg()->next()  ,
	v7->as_VMReg()->next(2) ,
	v7->as_VMReg()->next(3) ,
	v7->as_VMReg()->next(4) ,
	v7->as_VMReg()->next(5) ,
	v7->as_VMReg()->next(6) ,
	v7->as_VMReg()->next(7) ,
	v8->as_VMReg()          ,
	v8->as_VMReg()->next()  ,
	v8->as_VMReg()->next(2) ,
	v8->as_VMReg()->next(3) ,
	v8->as_VMReg()->next(4) ,
	v8->as_VMReg()->next(5) ,
	v8->as_VMReg()->next(6) ,
	v8->as_VMReg()->next(7) ,
	v9->as_VMReg()          ,
	v9->as_VMReg()->next()  ,
	v9->as_VMReg()->next(2) ,
	v9->as_VMReg()->next(3) ,
	v9->as_VMReg()->next(4) ,
	v9->as_VMReg()->next(5) ,
	v9->as_VMReg()->next(6) ,
	v9->as_VMReg()->next(7) ,
	v10->as_VMReg()          ,
	v10->as_VMReg()->next()  ,
	v10->as_VMReg()->next(2) ,
	v10->as_VMReg()->next(3) ,
	v10->as_VMReg()->next(4) ,
	v10->as_VMReg()->next(5) ,
	v10->as_VMReg()->next(6) ,
	v10->as_VMReg()->next(7) ,
	v11->as_VMReg()          ,
	v11->as_VMReg()->next()  ,
	v11->as_VMReg()->next(2) ,
	v11->as_VMReg()->next(3) ,
	v11->as_VMReg()->next(4) ,
	v11->as_VMReg()->next(5) ,
	v11->as_VMReg()->next(6) ,
	v11->as_VMReg()->next(7) ,
	v12->as_VMReg()          ,
	v12->as_VMReg()->next()  ,
	v12->as_VMReg()->next(2) ,
	v12->as_VMReg()->next(3) ,
	v12->as_VMReg()->next(4) ,
	v12->as_VMReg()->next(5) ,
	v12->as_VMReg()->next(6) ,
	v12->as_VMReg()->next(7) ,
	v13->as_VMReg()          ,
	v13->as_VMReg()->next()  ,
	v13->as_VMReg()->next(2) ,
	v13->as_VMReg()->next(3) ,
	v13->as_VMReg()->next(4) ,
	v13->as_VMReg()->next(5) ,
	v13->as_VMReg()->next(6) ,
	v13->as_VMReg()->next(7) ,
	v14->as_VMReg()          ,
	v14->as_VMReg()->next()  ,
	v14->as_VMReg()->next(2) ,
	v14->as_VMReg()->next(3) ,
	v14->as_VMReg()->next(4) ,
	v14->as_VMReg()->next(5) ,
	v14->as_VMReg()->next(6) ,
	v14->as_VMReg()->next(7) ,
	v15->as_VMReg()          ,
	v15->as_VMReg()->next()  ,
	v15->as_VMReg()->next(2) ,
	v15->as_VMReg()->next(3) ,
	v15->as_VMReg()->next(4) ,
	v15->as_VMReg()->next(5) ,
	v15->as_VMReg()->next(6) ,
	v15->as_VMReg()->next(7) ,
	p0->as_VMReg(),
	p1->as_VMReg(),
	p2->as_VMReg(),
	p3->as_VMReg(),
	p4->as_VMReg(),
	p5->as_VMReg(),
	p6->as_VMReg(),
	p7->as_VMReg(),
	p8->as_VMReg(),
	p9->as_VMReg(),
	p10->as_VMReg(),
	p11->as_VMReg(),
	p12->as_VMReg(),
	p13->as_VMReg(),
	p14->as_VMReg(),
	p15->as_VMReg(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xA',  // R10
  (unsigned char)'\xA',  // R10_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\xB',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\xC',  // R12_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\xD',  // R13_H
  (unsigned char)'\xE',  // R14
  (unsigned char)'\xE',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\xF',  // R15_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x10',  // R16_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x11',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x12',  // R18_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x0',  // R0_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x1',  // R1_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x2',  // R2_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x3',  // R3_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x4',  // R4_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x5',  // R5_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x6',  // R6_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x7',  // R7_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x13',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x14',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x15',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x16',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x17',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x18',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x19',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x1A',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x1B',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x1C',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x1D',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x1E',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x1F',  // R31_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x8',  // R8_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x9',  // R9_H
  (unsigned char)'\x10',  // V16
  (unsigned char)'\x10',  // V16_H
  (unsigned char)'\x10',  // V16_J
  (unsigned char)'\x10',  // V16_K
  (unsigned char)'\x10',  // V16_L
  (unsigned char)'\x10',  // V16_M
  (unsigned char)'\x10',  // V16_N
  (unsigned char)'\x10',  // V16_O
  (unsigned char)'\x11',  // V17
  (unsigned char)'\x11',  // V17_H
  (unsigned char)'\x11',  // V17_J
  (unsigned char)'\x11',  // V17_K
  (unsigned char)'\x11',  // V17_L
  (unsigned char)'\x11',  // V17_M
  (unsigned char)'\x11',  // V17_N
  (unsigned char)'\x11',  // V17_O
  (unsigned char)'\x12',  // V18
  (unsigned char)'\x12',  // V18_H
  (unsigned char)'\x12',  // V18_J
  (unsigned char)'\x12',  // V18_K
  (unsigned char)'\x12',  // V18_L
  (unsigned char)'\x12',  // V18_M
  (unsigned char)'\x12',  // V18_N
  (unsigned char)'\x12',  // V18_O
  (unsigned char)'\x13',  // V19
  (unsigned char)'\x13',  // V19_H
  (unsigned char)'\x13',  // V19_J
  (unsigned char)'\x13',  // V19_K
  (unsigned char)'\x13',  // V19_L
  (unsigned char)'\x13',  // V19_M
  (unsigned char)'\x13',  // V19_N
  (unsigned char)'\x13',  // V19_O
  (unsigned char)'\x14',  // V20
  (unsigned char)'\x14',  // V20_H
  (unsigned char)'\x14',  // V20_J
  (unsigned char)'\x14',  // V20_K
  (unsigned char)'\x14',  // V20_L
  (unsigned char)'\x14',  // V20_M
  (unsigned char)'\x14',  // V20_N
  (unsigned char)'\x14',  // V20_O
  (unsigned char)'\x15',  // V21
  (unsigned char)'\x15',  // V21_H
  (unsigned char)'\x15',  // V21_J
  (unsigned char)'\x15',  // V21_K
  (unsigned char)'\x15',  // V21_L
  (unsigned char)'\x15',  // V21_M
  (unsigned char)'\x15',  // V21_N
  (unsigned char)'\x15',  // V21_O
  (unsigned char)'\x16',  // V22
  (unsigned char)'\x16',  // V22_H
  (unsigned char)'\x16',  // V22_J
  (unsigned char)'\x16',  // V22_K
  (unsigned char)'\x16',  // V22_L
  (unsigned char)'\x16',  // V22_M
  (unsigned char)'\x16',  // V22_N
  (unsigned char)'\x16',  // V22_O
  (unsigned char)'\x17',  // V23
  (unsigned char)'\x17',  // V23_H
  (unsigned char)'\x17',  // V23_J
  (unsigned char)'\x17',  // V23_K
  (unsigned char)'\x17',  // V23_L
  (unsigned char)'\x17',  // V23_M
  (unsigned char)'\x17',  // V23_N
  (unsigned char)'\x17',  // V23_O
  (unsigned char)'\x18',  // V24
  (unsigned char)'\x18',  // V24_H
  (unsigned char)'\x18',  // V24_J
  (unsigned char)'\x18',  // V24_K
  (unsigned char)'\x18',  // V24_L
  (unsigned char)'\x18',  // V24_M
  (unsigned char)'\x18',  // V24_N
  (unsigned char)'\x18',  // V24_O
  (unsigned char)'\x19',  // V25
  (unsigned char)'\x19',  // V25_H
  (unsigned char)'\x19',  // V25_J
  (unsigned char)'\x19',  // V25_K
  (unsigned char)'\x19',  // V25_L
  (unsigned char)'\x19',  // V25_M
  (unsigned char)'\x19',  // V25_N
  (unsigned char)'\x19',  // V25_O
  (unsigned char)'\x1A',  // V26
  (unsigned char)'\x1A',  // V26_H
  (unsigned char)'\x1A',  // V26_J
  (unsigned char)'\x1A',  // V26_K
  (unsigned char)'\x1A',  // V26_L
  (unsigned char)'\x1A',  // V26_M
  (unsigned char)'\x1A',  // V26_N
  (unsigned char)'\x1A',  // V26_O
  (unsigned char)'\x1B',  // V27
  (unsigned char)'\x1B',  // V27_H
  (unsigned char)'\x1B',  // V27_J
  (unsigned char)'\x1B',  // V27_K
  (unsigned char)'\x1B',  // V27_L
  (unsigned char)'\x1B',  // V27_M
  (unsigned char)'\x1B',  // V27_N
  (unsigned char)'\x1B',  // V27_O
  (unsigned char)'\x1C',  // V28
  (unsigned char)'\x1C',  // V28_H
  (unsigned char)'\x1C',  // V28_J
  (unsigned char)'\x1C',  // V28_K
  (unsigned char)'\x1C',  // V28_L
  (unsigned char)'\x1C',  // V28_M
  (unsigned char)'\x1C',  // V28_N
  (unsigned char)'\x1C',  // V28_O
  (unsigned char)'\x1D',  // V29
  (unsigned char)'\x1D',  // V29_H
  (unsigned char)'\x1D',  // V29_J
  (unsigned char)'\x1D',  // V29_K
  (unsigned char)'\x1D',  // V29_L
  (unsigned char)'\x1D',  // V29_M
  (unsigned char)'\x1D',  // V29_N
  (unsigned char)'\x1D',  // V29_O
  (unsigned char)'\x1E',  // V30
  (unsigned char)'\x1E',  // V30_H
  (unsigned char)'\x1E',  // V30_J
  (unsigned char)'\x1E',  // V30_K
  (unsigned char)'\x1E',  // V30_L
  (unsigned char)'\x1E',  // V30_M
  (unsigned char)'\x1E',  // V30_N
  (unsigned char)'\x1E',  // V30_O
  (unsigned char)'\x1F',  // V31
  (unsigned char)'\x1F',  // V31_H
  (unsigned char)'\x1F',  // V31_J
  (unsigned char)'\x1F',  // V31_K
  (unsigned char)'\x1F',  // V31_L
  (unsigned char)'\x1F',  // V31_M
  (unsigned char)'\x1F',  // V31_N
  (unsigned char)'\x1F',  // V31_O
  (unsigned char)'\x0',  // V0
  (unsigned char)'\x0',  // V0_H
  (unsigned char)'\x0',  // V0_J
  (unsigned char)'\x0',  // V0_K
  (unsigned char)'\x0',  // V0_L
  (unsigned char)'\x0',  // V0_M
  (unsigned char)'\x0',  // V0_N
  (unsigned char)'\x0',  // V0_O
  (unsigned char)'\x1',  // V1
  (unsigned char)'\x1',  // V1_H
  (unsigned char)'\x1',  // V1_J
  (unsigned char)'\x1',  // V1_K
  (unsigned char)'\x1',  // V1_L
  (unsigned char)'\x1',  // V1_M
  (unsigned char)'\x1',  // V1_N
  (unsigned char)'\x1',  // V1_O
  (unsigned char)'\x2',  // V2
  (unsigned char)'\x2',  // V2_H
  (unsigned char)'\x2',  // V2_J
  (unsigned char)'\x2',  // V2_K
  (unsigned char)'\x2',  // V2_L
  (unsigned char)'\x2',  // V2_M
  (unsigned char)'\x2',  // V2_N
  (unsigned char)'\x2',  // V2_O
  (unsigned char)'\x3',  // V3
  (unsigned char)'\x3',  // V3_H
  (unsigned char)'\x3',  // V3_J
  (unsigned char)'\x3',  // V3_K
  (unsigned char)'\x3',  // V3_L
  (unsigned char)'\x3',  // V3_M
  (unsigned char)'\x3',  // V3_N
  (unsigned char)'\x3',  // V3_O
  (unsigned char)'\x4',  // V4
  (unsigned char)'\x4',  // V4_H
  (unsigned char)'\x4',  // V4_J
  (unsigned char)'\x4',  // V4_K
  (unsigned char)'\x4',  // V4_L
  (unsigned char)'\x4',  // V4_M
  (unsigned char)'\x4',  // V4_N
  (unsigned char)'\x4',  // V4_O
  (unsigned char)'\x5',  // V5
  (unsigned char)'\x5',  // V5_H
  (unsigned char)'\x5',  // V5_J
  (unsigned char)'\x5',  // V5_K
  (unsigned char)'\x5',  // V5_L
  (unsigned char)'\x5',  // V5_M
  (unsigned char)'\x5',  // V5_N
  (unsigned char)'\x5',  // V5_O
  (unsigned char)'\x6',  // V6
  (unsigned char)'\x6',  // V6_H
  (unsigned char)'\x6',  // V6_J
  (unsigned char)'\x6',  // V6_K
  (unsigned char)'\x6',  // V6_L
  (unsigned char)'\x6',  // V6_M
  (unsigned char)'\x6',  // V6_N
  (unsigned char)'\x6',  // V6_O
  (unsigned char)'\x7',  // V7
  (unsigned char)'\x7',  // V7_H
  (unsigned char)'\x7',  // V7_J
  (unsigned char)'\x7',  // V7_K
  (unsigned char)'\x7',  // V7_L
  (unsigned char)'\x7',  // V7_M
  (unsigned char)'\x7',  // V7_N
  (unsigned char)'\x7',  // V7_O
  (unsigned char)'\x8',  // V8
  (unsigned char)'\x8',  // V8_H
  (unsigned char)'\x8',  // V8_J
  (unsigned char)'\x8',  // V8_K
  (unsigned char)'\x8',  // V8_L
  (unsigned char)'\x8',  // V8_M
  (unsigned char)'\x8',  // V8_N
  (unsigned char)'\x8',  // V8_O
  (unsigned char)'\x9',  // V9
  (unsigned char)'\x9',  // V9_H
  (unsigned char)'\x9',  // V9_J
  (unsigned char)'\x9',  // V9_K
  (unsigned char)'\x9',  // V9_L
  (unsigned char)'\x9',  // V9_M
  (unsigned char)'\x9',  // V9_N
  (unsigned char)'\x9',  // V9_O
  (unsigned char)'\xA',  // V10
  (unsigned char)'\xA',  // V10_H
  (unsigned char)'\xA',  // V10_J
  (unsigned char)'\xA',  // V10_K
  (unsigned char)'\xA',  // V10_L
  (unsigned char)'\xA',  // V10_M
  (unsigned char)'\xA',  // V10_N
  (unsigned char)'\xA',  // V10_O
  (unsigned char)'\xB',  // V11
  (unsigned char)'\xB',  // V11_H
  (unsigned char)'\xB',  // V11_J
  (unsigned char)'\xB',  // V11_K
  (unsigned char)'\xB',  // V11_L
  (unsigned char)'\xB',  // V11_M
  (unsigned char)'\xB',  // V11_N
  (unsigned char)'\xB',  // V11_O
  (unsigned char)'\xC',  // V12
  (unsigned char)'\xC',  // V12_H
  (unsigned char)'\xC',  // V12_J
  (unsigned char)'\xC',  // V12_K
  (unsigned char)'\xC',  // V12_L
  (unsigned char)'\xC',  // V12_M
  (unsigned char)'\xC',  // V12_N
  (unsigned char)'\xC',  // V12_O
  (unsigned char)'\xD',  // V13
  (unsigned char)'\xD',  // V13_H
  (unsigned char)'\xD',  // V13_J
  (unsigned char)'\xD',  // V13_K
  (unsigned char)'\xD',  // V13_L
  (unsigned char)'\xD',  // V13_M
  (unsigned char)'\xD',  // V13_N
  (unsigned char)'\xD',  // V13_O
  (unsigned char)'\xE',  // V14
  (unsigned char)'\xE',  // V14_H
  (unsigned char)'\xE',  // V14_J
  (unsigned char)'\xE',  // V14_K
  (unsigned char)'\xE',  // V14_L
  (unsigned char)'\xE',  // V14_M
  (unsigned char)'\xE',  // V14_N
  (unsigned char)'\xE',  // V14_O
  (unsigned char)'\xF',  // V15
  (unsigned char)'\xF',  // V15_H
  (unsigned char)'\xF',  // V15_J
  (unsigned char)'\xF',  // V15_K
  (unsigned char)'\xF',  // V15_L
  (unsigned char)'\xF',  // V15_M
  (unsigned char)'\xF',  // V15_N
  (unsigned char)'\xF',  // V15_O
  (unsigned char)'\x0',  // P0
  (unsigned char)'\x1',  // P1
  (unsigned char)'\x2',  // P2
  (unsigned char)'\x3',  // P3
  (unsigned char)'\x4',  // P4
  (unsigned char)'\x5',  // P5
  (unsigned char)'\x6',  // P6
  (unsigned char)'\x7',  // P7
  (unsigned char)'\x8',  // P8
  (unsigned char)'\x9',  // P9
  (unsigned char)'\xA',  // P10
  (unsigned char)'\xB',  // P11
  (unsigned char)'\xC',  // P12
  (unsigned char)'\xD',  // P13
  (unsigned char)'\xE',  // P14
  (unsigned char)'\xF',  // P15
  (unsigned char)'\x20' // no trailing comma  // RFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegINoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *iRegLNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *iRegPNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_PTR_REG_mask();
}

const RegMask *iRegP_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegP_R1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REG_mask();
}

const RegMask *iRegP_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegP_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegP_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R4_REG_mask();
}

const RegMask *iRegP_R5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R5_REG_mask();
}

const RegMask *iRegP_R10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R10_REG_mask();
}

const RegMask *iRegL_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegL_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegL_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegL_R11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R11_REG_mask();
}

const RegMask *iRegP_FPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FP_REG_mask();
}

const RegMask *iRegI_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R0_REG_mask();
}

const RegMask *iRegI_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R2_REG_mask();
}

const RegMask *iRegI_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R3_REG_mask();
}

const RegMask *iRegI_R4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_R4_REG_mask();
}

const RegMask *iRegNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *iRegN_R0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REG_mask();
}

const RegMask *iRegN_R2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REG_mask();
}

const RegMask *iRegN_R3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REG_mask();
}

const RegMask *iRegNNoSpOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NO_SPECIAL_REG32_mask();
}

const RegMask *iRegIHeapbaseOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &HEAPBASE_REG_mask();
}

const RegMask *vRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_REG_mask();
}

const RegMask *vRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DOUBLE_REG_mask();
}

const RegMask *vRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORA_REG_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORD_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *vRegD_V0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V0_REG_mask();
}

const RegMask *vRegD_V1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V1_REG_mask();
}

const RegMask *vRegD_V2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V2_REG_mask();
}

const RegMask *vRegD_V3Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V3_REG_mask();
}

const RegMask *vRegD_V4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V4_REG_mask();
}

const RegMask *vRegD_V5Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V5_REG_mask();
}

const RegMask *vRegD_V6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V6_REG_mask();
}

const RegMask *vRegD_V7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V7_REG_mask();
}

const RegMask *vRegD_V8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V8_REG_mask();
}

const RegMask *vRegD_V9Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V9_REG_mask();
}

const RegMask *vRegD_V10Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V10_REG_mask();
}

const RegMask *vRegD_V11Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V11_REG_mask();
}

const RegMask *vRegD_V12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V12_REG_mask();
}

const RegMask *vRegD_V13Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V13_REG_mask();
}

const RegMask *vRegD_V14Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V14_REG_mask();
}

const RegMask *vRegD_V15Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V15_REG_mask();
}

const RegMask *vRegD_V16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V16_REG_mask();
}

const RegMask *vRegD_V17Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V17_REG_mask();
}

const RegMask *vRegD_V18Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V18_REG_mask();
}

const RegMask *vRegD_V19Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V19_REG_mask();
}

const RegMask *vRegD_V20Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V20_REG_mask();
}

const RegMask *vRegD_V21Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V21_REG_mask();
}

const RegMask *vRegD_V22Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V22_REG_mask();
}

const RegMask *vRegD_V23Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V23_REG_mask();
}

const RegMask *vRegD_V24Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V24_REG_mask();
}

const RegMask *vRegD_V25Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V25_REG_mask();
}

const RegMask *vRegD_V26Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V26_REG_mask();
}

const RegMask *vRegD_V27Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V27_REG_mask();
}

const RegMask *vRegD_V28Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V28_REG_mask();
}

const RegMask *vRegD_V29Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V29_REG_mask();
}

const RegMask *vRegD_V30Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V30_REG_mask();
}

const RegMask *vRegD_V31Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &V31_REG_mask();
}

const RegMask *pRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PR_REG_mask();
}

const RegMask *pRegGovOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &GOV_PR_mask();
}

const RegMask *pRegGov_P0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P0_REG_mask();
}

const RegMask *pRegGov_P1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P1_REG_mask();
}

const RegMask *rFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *rFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *inline_cache_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &METHOD_REG_mask();
}

const RegMask *thread_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_REG_mask();
}

const RegMask *lr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indIndexScaledI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaledOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG32_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffI16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indOffL16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *indirectNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexScaledNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexI2LNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indIndexNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &ANY_REG32_mask();
  case 1: return &ANY_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indOffINOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *indOffLNOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG32_mask();
}

const RegMask *thread_anchor_pcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *iRegL2IOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *vmemA_indOffI4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *vmemA_indOffL4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

//------------------Define members for classes derived from MachNode----------
// Build short branch version of this instruction
MachNode *far_cmpL_branch_signNode::short_branch_version() {
  cmpL_branch_signNode *node = new cmpL_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_signNode::short_branch_version() {
  cmpI_branch_signNode *node = new cmpI_branch_signNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpL_branch_bitNode::short_branch_version() {
  cmpL_branch_bitNode *node = new cmpL_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}

// Build short branch version of this instruction
MachNode *far_cmpI_branch_bitNode::short_branch_version() {
  cmpI_branch_bitNode *node = new cmpI_branch_bitNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node);
  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone();
  }
}

void overflowMulI_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulI_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void overflowMulL_reg_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void overflowMulL_reg_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpN_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpN_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpP_narrowOop_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpP_narrowOop_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUI_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUI_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpUL_imm0_branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpUL_imm0_branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_signNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_signNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpL_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpL_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void far_cmpI_branch_bitNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void far_cmpI_branch_bitNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(5));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP0Node::reloc() const {
  return 1;
}

int loadConP1Node::reloc() const {
  return 1;
}

int loadByteMapBaseNode::reloc() const {
  return 1;
}

int loadConF_packedNode::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_packedNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int storeimmCM0Node::reloc() const {
  return 2;
}

int storeimmCM0_orderedNode::reloc() const {
  return 2;
}

int storeBNode::reloc() const {
  return 3;
}

int storeimmB0Node::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 3;
}

int storeimmC0Node::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 3;
}

int storeimmI0Node::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeimmL0Node::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeimmP0Node::reloc() const {
  return 3;
}

int storeNNode::reloc() const {
  return 2;
}

int storeImmN0Node::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeNKlassNode::reloc() const {
  return 2;
}

int prefetchallocNode::reloc() const {
  return 1;
}

int storeB_volatileNode::reloc() const {
  return 1;
}

int storeC_volatileNode::reloc() const {
  return 1;
}

int storeI_volatileNode::reloc() const {
  return 1;
}

int storeimmP0_volatileNode::reloc() const {
  return 1;
}

int bytes_reverse_intNode::reloc() const {
  return 1;
}

int bytes_reverse_unsigned_shortNode::reloc() const {
  return 1;
}

int bytes_reverse_shortNode::reloc() const {
  return 1;
}

int countLeadingZerosINode::reloc() const {
  return 1;
}

int countTrailingZerosINode::reloc() const {
  return 1;
}

int popCountINode::reloc() const {
  return 1;
}

int popCountI_memNode::reloc() const {
  return 1;
}

int popCountL_memNode::reloc() const {
  return 1;
}

int storePConditionalNode::reloc() const {
  return 1;
}

int get_and_addINode::reloc() const {
  return 1;
}

int get_and_addI_no_resNode::reloc() const {
  return 1;
}

int get_and_addIAcqNode::reloc() const {
  return 1;
}

int get_and_addI_no_resAcqNode::reloc() const {
  return 1;
}

int cmovI_reg_regNode::reloc() const {
  return 2;
}

int cmovUI_reg_regNode::reloc() const {
  return 2;
}

int cmovI_zero_regNode::reloc() const {
  return 1;
}

int cmovUI_zero_regNode::reloc() const {
  return 1;
}

int cmovI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUI_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovUP_reg_zeroNode::reloc() const {
  return 1;
}

int cmovP_zero_regNode::reloc() const {
  return 1;
}

int cmovUP_zero_regNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addI_reg_immNode::reloc() const {
  return 1;
}

int addP_reg_reg_extNode::reloc() const {
  return 1;
}

int addP_reg_reg_ext_shiftNode::reloc() const {
  return 1;
}

int lshift_extNode::reloc() const {
  return 1;
}

int subI_reg_regNode::reloc() const {
  return 2;
}

int subI_reg_immNode::reloc() const {
  return 1;
}

int negI_regNode::reloc() const {
  return 1;
}

int mulINode::reloc() const {
  return 2;
}

int smulINode::reloc() const {
  return 2;
}

int smulI_0Node::reloc() const {
  return 2;
}

int maddINode::reloc() const {
  return 3;
}

int maddI_0Node::reloc() const {
  return 3;
}

int msubINode::reloc() const {
  return 3;
}

int mnegINode::reloc() const {
  return 2;
}

int mnegI_0Node::reloc() const {
  return 2;
}

int smaddLNode::reloc() const {
  return 2;
}

int smaddL_1Node::reloc() const {
  return 2;
}

int smaddL_0Node::reloc() const {
  return 2;
}

int smaddL_2Node::reloc() const {
  return 2;
}

int smsubLNode::reloc() const {
  return 2;
}

int smsubL_0Node::reloc() const {
  return 2;
}

int smnegLNode::reloc() const {
  return 2;
}

int smnegL_0Node::reloc() const {
  return 2;
}

int muladdS2INode::reloc() const {
  return 4;
}

int divINode::reloc() const {
  return 2;
}

int modINode::reloc() const {
  return 2;
}

int lShiftI_reg_regNode::reloc() const {
  return 2;
}

int lShiftI_reg_immNode::reloc() const {
  return 1;
}

int urShiftI_reg_regNode::reloc() const {
  return 2;
}

int urShiftI_reg_immNode::reloc() const {
  return 1;
}

int rShiftI_reg_regNode::reloc() const {
  return 2;
}

int rShiftI_reg_immNode::reloc() const {
  return 1;
}

int lShiftL_reg_regNode::reloc() const {
  return 1;
}

int urShiftL_reg_regNode::reloc() const {
  return 1;
}

int rShiftL_reg_regNode::reloc() const {
  return 1;
}

int regI_not_regNode::reloc() const {
  return 1;
}

int NegI_reg_URShift_regNode::reloc() const {
  return 1;
}

int NegI_reg_RShift_regNode::reloc() const {
  return 1;
}

int NegI_reg_LShift_regNode::reloc() const {
  return 1;
}

int AndI_reg_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_not_reg_2Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_1Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_not_reg_2Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_not_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_not_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AndI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int AndI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_URShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_LShift_regNode::reloc() const {
  return 2;
}

int XorI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int XorI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_URShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_LShift_regNode::reloc() const {
  return 2;
}

int OrI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_regNode::reloc() const {
  return 2;
}

int OrI_reg_RotateRight_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_URShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_URShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_RShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_RShift_reg_0Node::reloc() const {
  return 2;
}

int AddI_reg_LShift_regNode::reloc() const {
  return 2;
}

int AddI_reg_LShift_reg_0Node::reloc() const {
  return 2;
}

int SubI_reg_URShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_RShift_regNode::reloc() const {
  return 2;
}

int SubI_reg_LShift_regNode::reloc() const {
  return 2;
}

int sbfmwINode::reloc() const {
  return 1;
}

int ubfmwINode::reloc() const {
  return 1;
}

int ubfxwINode::reloc() const {
  return 1;
}

int ubfxIConvI2LNode::reloc() const {
  return 1;
}

int ubfizwINode::reloc() const {
  return 1;
}

int ubfizwIConvI2LNode::reloc() const {
  return 1;
}

int ubfizIConvI2LNode::reloc() const {
  return 1;
}

int extrOrINode::reloc() const {
  return 2;
}

int extrOrI_0Node::reloc() const {
  return 2;
}

int extrAddINode::reloc() const {
  return 2;
}

int extrAddI_0Node::reloc() const {
  return 2;
}

int AddExtINode::reloc() const {
  return 1;
}

int AddExtI_0Node::reloc() const {
  return 1;
}

int SubExtINode::reloc() const {
  return 1;
}

int AddExtI_sxthNode::reloc() const {
  return 2;
}

int AddExtI_sxth_0Node::reloc() const {
  return 2;
}

int AddExtI_sxtbNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtbNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_0Node::reloc() const {
  return 2;
}

int AddExtI_uxtb_andNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_andNode::reloc() const {
  return 2;
}

int SubExtI_uxth_andNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxtb_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_sxth_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_sxtb_shiftNode::reloc() const {
  return 2;
}

int SubExtI_sxth_shiftNode::reloc() const {
  return 2;
}

int AddExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_shift_0Node::reloc() const {
  return 1;
}

int SubExtI_shiftNode::reloc() const {
  return 1;
}

int AddExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxtb_and_shift_0Node::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int AddExtI_uxth_and_shift_0Node::reloc() const {
  return 2;
}

int SubExtI_uxtb_and_shiftNode::reloc() const {
  return 2;
}

int SubExtI_uxth_and_shiftNode::reloc() const {
  return 2;
}

int mnsubF_reg_regNode::reloc() const {
  return 1;
}

int mnsubD_reg_regNode::reloc() const {
  return 1;
}

int absI_regNode::reloc() const {
  return 1;
}

int andI_reg_regNode::reloc() const {
  return 2;
}

int andI_reg_immNode::reloc() const {
  return 1;
}

int orI_reg_regNode::reloc() const {
  return 2;
}

int orI_reg_immNode::reloc() const {
  return 1;
}

int xorI_reg_regNode::reloc() const {
  return 2;
}

int xorI_reg_immNode::reloc() const {
  return 1;
}

int convI2L_reg_regNode::reloc() const {
  return 1;
}

int convUI2L_reg_regNode::reloc() const {
  return 1;
}

int convI2BNode::reloc() const {
  return 1;
}

int convI2F_reg_regNode::reloc() const {
  return 1;
}

int convI2D_reg_regNode::reloc() const {
  return 1;
}

int overflowAddI_reg_regNode::reloc() const {
  return 2;
}

int overflowAddI_reg_immNode::reloc() const {
  return 1;
}

int overflowSubI_reg_regNode::reloc() const {
  return 2;
}

int overflowSubI_reg_immNode::reloc() const {
  return 1;
}

int overflowNegI_regNode::reloc() const {
  return 1;
}

int overflowMulI_regNode::reloc() const {
  return 2;
}

int overflowMulI_reg_branchNode::reloc() const {
  return 2;
}

int testP_regNode::reloc() const {
  return 1;
}

int compF_reg_zeroNode::reloc() const {
  return 1;
}

int compD_reg_zeroNode::reloc() const {
  return 1;
}

int compF3_reg_immF0Node::reloc() const {
  return 1;
}

int compD3_reg_immD0Node::reloc() const {
  return 1;
}

int cmpLTMask_reg_regNode::reloc() const {
  return 2;
}

int cmpLTMask_reg_zeroNode::reloc() const {
  return 1;
}

int cmpI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_imm0_branchNode::reloc() const {
  return 1;
}

int cmpP_narrowOop_imm0_branchNode::reloc() const {
  return 1;
}

int cmpUI_imm0_branchNode::reloc() const {
  return 1;
}

int cmpI_branch_signNode::reloc() const {
  return 1;
}

int cmpI_branch_bitNode::reloc() const {
  return 1;
}

int far_cmpI_branch_signNode::reloc() const {
  return 1;
}

int far_cmpI_branch_bitNode::reloc() const {
  return 1;
}

int cmpI_andNode::reloc() const {
  return 1;
}

int cmpI_and_regNode::reloc() const {
  return 2;
}

int safePointNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int TailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int partialSubtypeCheckVsZeroNode::reloc() const {
  return 1;
}

int loadV2Node::reloc() const {
  return 1;
}

int loadV4Node::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV2Node::reloc() const {
  return 2;
}

int storeV4Node::reloc() const {
  return 2;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int reduce_add8BNode::reloc() const {
  return 1;
}

int reduce_add16BNode::reloc() const {
  return 1;
}

int reduce_add4SNode::reloc() const {
  return 1;
}

int reduce_add8SNode::reloc() const {
  return 1;
}

int reduce_mul8BNode::reloc() const {
  return 1;
}

int reduce_mul16BNode::reloc() const {
  return 1;
}

int reduce_mul4SNode::reloc() const {
  return 1;
}

int reduce_mul8SNode::reloc() const {
  return 1;
}

int reduce_max8BNode::reloc() const {
  return 1;
}

int reduce_max16BNode::reloc() const {
  return 1;
}

int reduce_max4SNode::reloc() const {
  return 1;
}

int reduce_max8SNode::reloc() const {
  return 1;
}

int reduce_max4INode::reloc() const {
  return 1;
}

int reduce_min8BNode::reloc() const {
  return 1;
}

int reduce_min16BNode::reloc() const {
  return 1;
}

int reduce_min4SNode::reloc() const {
  return 1;
}

int reduce_min8SNode::reloc() const {
  return 1;
}

int reduce_min4INode::reloc() const {
  return 1;
}

int reduce_max2INode::reloc() const {
  return 1;
}

int reduce_min2INode::reloc() const {
  return 1;
}

int reduce_and8BNode::reloc() const {
  return 1;
}

int reduce_orr8BNode::reloc() const {
  return 1;
}

int reduce_eor8BNode::reloc() const {
  return 1;
}

int reduce_and16BNode::reloc() const {
  return 1;
}

int reduce_orr16BNode::reloc() const {
  return 1;
}

int reduce_eor16BNode::reloc() const {
  return 1;
}

int reduce_and4SNode::reloc() const {
  return 1;
}

int reduce_orr4SNode::reloc() const {
  return 1;
}

int reduce_eor4SNode::reloc() const {
  return 1;
}

int reduce_and8SNode::reloc() const {
  return 1;
}

int reduce_orr8SNode::reloc() const {
  return 1;
}

int reduce_eor8SNode::reloc() const {
  return 1;
}

int reduce_and2INode::reloc() const {
  return 1;
}

int reduce_orr2INode::reloc() const {
  return 1;
}

int reduce_eor2INode::reloc() const {
  return 1;
}

int reduce_and4INode::reloc() const {
  return 1;
}

int reduce_orr4INode::reloc() const {
  return 1;
}

int reduce_eor4INode::reloc() const {
  return 1;
}

int insertIDNode::reloc() const {
  return 1;
}

int insertIXNode::reloc() const {
  return 1;
}

int replicate8BNode::reloc() const {
  return 1;
}

int replicate16BNode::reloc() const {
  return 1;
}

int replicate4SNode::reloc() const {
  return 1;
}

int replicate8SNode::reloc() const {
  return 1;
}

int replicate2INode::reloc() const {
  return 1;
}

int replicate4INode::reloc() const {
  return 1;
}

int reduce_add2INode::reloc() const {
  return 1;
}

int reduce_add4INode::reloc() const {
  return 1;
}

int reduce_mul2INode::reloc() const {
  return 1;
}

int reduce_mul4INode::reloc() const {
  return 1;
}

int vslcnt8BNode::reloc() const {
  return 1;
}

int vslcnt16BNode::reloc() const {
  return 1;
}

int vsrcnt8BNode::reloc() const {
  return 1;
}

int vsrcnt16BNode::reloc() const {
  return 1;
}

int loadVNode::reloc() const {
  return 1;
}

int storeVNode::reloc() const {
  return 2;
}

int loadV2_vregNode::reloc() const {
  return 1;
}

int storeV2_vregNode::reloc() const {
  return 2;
}

int loadV4_vregNode::reloc() const {
  return 1;
}

int storeV4_vregNode::reloc() const {
  return 2;
}

int loadV8_vregNode::reloc() const {
  return 1;
}

int storeV8_vregNode::reloc() const {
  return 2;
}

int loadV16_vregNode::reloc() const {
  return 1;
}

int storeV16_vregNode::reloc() const {
  return 2;
}

int loadV_partialNode::reloc() const {
  return 1;
}

int storeV_partialNode::reloc() const {
  return 2;
}

int loadV_maskedNode::reloc() const {
  return 1;
}

int storeV_maskedNode::reloc() const {
  return 2;
}

int reduce_addINode::reloc() const {
  return 1;
}

int reduce_addI_partialNode::reloc() const {
  return 1;
}

int reduce_addI_maskedNode::reloc() const {
  return 1;
}

int reduce_andINode::reloc() const {
  return 1;
}

int reduce_andI_partialNode::reloc() const {
  return 1;
}

int reduce_andI_maskedNode::reloc() const {
  return 1;
}

int reduce_orINode::reloc() const {
  return 1;
}

int reduce_orI_partialNode::reloc() const {
  return 1;
}

int reduce_orI_maskedNode::reloc() const {
  return 1;
}

int reduce_eorINode::reloc() const {
  return 1;
}

int reduce_eorI_partialNode::reloc() const {
  return 1;
}

int reduce_eorI_maskedNode::reloc() const {
  return 1;
}

int reduce_maxINode::reloc() const {
  return 1;
}

int reduce_maxI_partialNode::reloc() const {
  return 1;
}

int reduce_maxI_maskedNode::reloc() const {
  return 1;
}

int reduce_minINode::reloc() const {
  return 1;
}

int reduce_minI_partialNode::reloc() const {
  return 1;
}

int reduce_minI_maskedNode::reloc() const {
  return 1;
}

int replicateBNode::reloc() const {
  return 1;
}

int replicateSNode::reloc() const {
  return 1;
}

int replicateINode::reloc() const {
  return 1;
}

int vshiftcntBNode::reloc() const {
  return 1;
}

int vshiftcntB_0Node::reloc() const {
  return 1;
}

int vshiftcntSNode::reloc() const {
  return 1;
}

int vshiftcntS_0Node::reloc() const {
  return 1;
}

int vshiftcntINode::reloc() const {
  return 1;
}

int vshiftcntI_0Node::reloc() const {
  return 1;
}

int vshiftcntLNode::reloc() const {
  return 1;
}

int vshiftcntL_0Node::reloc() const {
  return 1;
}

int insertI_le128bitsNode::reloc() const {
  return 1;
}

int insertI_small_indexNode::reloc() const {
  return 1;
}

int insertINode::reloc() const {
  return 1;
}

int populateindexNode::reloc() const {
  return 1;
}

int vmaskAllINode::reloc() const {
  return 1;
}

int zLoadPNode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2953 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsbw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17248 "ad_aarch64.cpp"
  }
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2961 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17265 "ad_aarch64.cpp"
  }
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2977 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17282 "ad_aarch64.cpp"
  }
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2977 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrb, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17299 "ad_aarch64.cpp"
  }
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2985 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrshw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17316 "ad_aarch64.cpp"
  }
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2993 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17333 "ad_aarch64.cpp"
  }
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3009 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17350 "ad_aarch64.cpp"
  }
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3009 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrh, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17367 "ad_aarch64.cpp"
  }
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17384 "ad_aarch64.cpp"
  }
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3033 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrsw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17401 "ad_aarch64.cpp"
  }
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17419 "ad_aarch64.cpp"
  }
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3041 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17436 "ad_aarch64.cpp"
  }
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17453 "ad_aarch64.cpp"
  }
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3041 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17470 "ad_aarch64.cpp"
  }
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17487 "ad_aarch64.cpp"
  }
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3041 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17504 "ad_aarch64.cpp"
  }
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrw, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17521 "ad_aarch64.cpp"
  }
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3049 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17538 "ad_aarch64.cpp"
  }
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3057 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, dst_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 17555 "ad_aarch64.cpp"
  }
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3517 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    uint32_t con = (uint32_t)opnd_array(1)->constant();
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (con == 0) {
      __ movw(dst_reg, zr);
    } else {
      __ movw(dst_reg, con);
    }
  
#line 17577 "ad_aarch64.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3528 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    uint64_t con = (uint64_t)opnd_array(1)->constantL();
    if (con == 0) {
      __ mov(dst_reg, zr);
    } else {
      __ mov(dst_reg, con);
    }
  
#line 17599 "ad_aarch64.cpp"
  }
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3539 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL || con == (address)1) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      if (rtype == relocInfo::oop_type) {
        __ movoop(dst_reg, (jobject)con, /*immediate*/true);
      } else if (rtype == relocInfo::metadata_type) {
        __ mov_metadata(dst_reg, (Metadata*)con);
      } else {
        assert(rtype == relocInfo::none, "unexpected reloc type");
        if (con < (address)(uintptr_t)os::vm_page_size()) {
          __ mov(dst_reg, con);
        } else {
          uint64_t offset;
          __ adrp(dst_reg, con, offset);
          __ add(dst_reg, dst_reg, offset);
        }
      }
    }
  
#line 17635 "ad_aarch64.cpp"
  }
}

void loadConP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3564 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 17652 "ad_aarch64.cpp"
  }
}

void loadConP1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3570 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, (uint64_t)1);
  
#line 17669 "ad_aarch64.cpp"
  }
}

void loadByteMapBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3576 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ load_byte_map_base(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 17685 "ad_aarch64.cpp"
  }
}

void loadConNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3581 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::oop_type, "unexpected reloc type");
      __ set_narrow_oop(dst_reg, (jobject)con);
    }
  
#line 17709 "ad_aarch64.cpp"
  }
}

void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3594 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ mov(dst_reg, zr);
  
#line 17726 "ad_aarch64.cpp"
  }
}

void loadConNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {

#line 3600 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    address con = (address)opnd_array(1)->constant();
    if (con == NULL) {
      ShouldNotReachHere();
    } else {
      relocInfo::relocType rtype = opnd_array(1)->constant_reloc();
      assert(rtype == relocInfo::metadata_type, "unexpected reloc type");
      __ set_narrow_klass(dst_reg, (Klass *)con);
    }
  
#line 17750 "ad_aarch64.cpp"
  }
}

void loadConF_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7823 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), (double)opnd_array(1)->constantF());
  
#line 17766 "ad_aarch64.cpp"
  }
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7841 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 17782 "ad_aarch64.cpp"
  }
}

void loadConFNode::eval_constant(Compile* C) {
  {

#line 7842 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 17791 "ad_aarch64.cpp"
  }
}
void loadConD_packedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7854 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantD());
  
#line 17806 "ad_aarch64.cpp"
  }
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7871 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 17822 "ad_aarch64.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 7872 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 17831 "ad_aarch64.cpp"
  }
}
void storeimmCM0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3073 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17848 "ad_aarch64.cpp"
  }
}

void storeimmCM0_orderedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3153 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

      C2_MacroAssembler _masm(&cbuf);
      __ membar(Assembler::StoreStore);
      loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17867 "ad_aarch64.cpp"
  }
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3065 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strb, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17885 "ad_aarch64.cpp"
  }
}

void storeimmB0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3073 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strb, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 1);
  
#line 17903 "ad_aarch64.cpp"
  }
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3081 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strh, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17921 "ad_aarch64.cpp"
  }
}

void storeimmC0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3089 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strh, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 2);
  
#line 17939 "ad_aarch64.cpp"
  }
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3097 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17957 "ad_aarch64.cpp"
  }
}

void storeimmI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3105 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 17975 "ad_aarch64.cpp"
  }
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3113 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 18001 "ad_aarch64.cpp"
  }
}

void storeimmL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3129 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 18019 "ad_aarch64.cpp"
  }
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3113 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 18045 "ad_aarch64.cpp"
  }
}

void storeimmP0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3129 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::str, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 18063 "ad_aarch64.cpp"
  }
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3097 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 18081 "ad_aarch64.cpp"
  }
}

void storeImmN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3105 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    loadStore(_masm, &MacroAssembler::strw, zr, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 18099 "ad_aarch64.cpp"
  }
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3137 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strs, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 18117 "ad_aarch64.cpp"
  }
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strd, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
  
#line 18135 "ad_aarch64.cpp"
  }
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3097 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::strw, src_reg, opnd_array(1)->opcode(),
               as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
  
#line 18153 "ad_aarch64.cpp"
  }
}

void prefetchallocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {

#line 3496 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
      __ prfm(Address(base, disp), PSTL1KEEP);
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ prfm(Address(base, index_reg, Address::lsl(scale)), PSTL1KEEP);
      } else {
        __ lea(rscratch1, Address(base, disp));
	__ prfm(Address(rscratch1, index_reg, Address::lsl(scale)), PSTL1KEEP);
      }
    }
  
#line 18183 "ad_aarch64.cpp"
  }
}

void loadB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3250 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 18201 "ad_aarch64.cpp"
  }
}

void loadB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3250 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
    __ sxtb(dst_reg, dst_reg);
  
#line 18219 "ad_aarch64.cpp"
  }
}

void loadUB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3262 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 18235 "ad_aarch64.cpp"
  }
}

void loadUB2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3262 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarb);
  
#line 18251 "ad_aarch64.cpp"
  }
}

void loadS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3267 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxthw(dst_reg, dst_reg);
  
#line 18269 "ad_aarch64.cpp"
  }
}

void loadUS_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 18285 "ad_aarch64.cpp"
  }
}

void loadUS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3286 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
  
#line 18301 "ad_aarch64.cpp"
  }
}

void loadS2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3274 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    MOV_VOLATILE(dst_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarh);
    __ sxth(dst_reg, dst_reg);
  
#line 18319 "ad_aarch64.cpp"
  }
}

void loadI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3296 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 18335 "ad_aarch64.cpp"
  }
}

void loadUI2L_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 3296 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 18352 "ad_aarch64.cpp"
  }
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3301 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 18368 "ad_aarch64.cpp"
  }
}

void loadP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3301 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
  
#line 18384 "ad_aarch64.cpp"
  }
}

void loadN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3296 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
  
#line 18400 "ad_aarch64.cpp"
  }
}

void loadF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3306 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldarw);
    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 18417 "ad_aarch64.cpp"
  }
}

void loadD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3312 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(rscratch1, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
             rscratch1, ldar);
    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 18434 "ad_aarch64.cpp"
  }
}

void storeB_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3213 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 18451 "ad_aarch64.cpp"
  }
}

void storeimmB0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3218 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrb);
  
#line 18468 "ad_aarch64.cpp"
  }
}

void storeC_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3223 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 18485 "ad_aarch64.cpp"
  }
}

void storeimmC0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3228 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrh);
  
#line 18502 "ad_aarch64.cpp"
  }
}

void storeI_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18519 "ad_aarch64.cpp"
  }
}

void storeimmI0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3238 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18536 "ad_aarch64.cpp"
  }
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3318 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18562 "ad_aarch64.cpp"
  }
}

void storeimmL0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3332 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18579 "ad_aarch64.cpp"
  }
}

void storeP_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3318 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    // we sometimes get asked to store the stack pointer into the
    // current thread -- we cannot do that directly on AArch64
    if (src_reg == r31_sp) {
      C2_MacroAssembler _masm(&cbuf);
      assert(as_Register(opnd_array(1)->base(ra_,this,idx1)) == rthread, "unexpected store for sp");
      __ mov(rscratch2, sp);
      src_reg = rscratch2;
    }
    MOV_VOLATILE(src_reg, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18605 "ad_aarch64.cpp"
  }
}

void storeimmP0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3332 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18622 "ad_aarch64.cpp"
  }
}

void storeN_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */), opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18639 "ad_aarch64.cpp"
  }
}

void storeimmN0_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3238 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    MOV_VOLATILE(zr, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18656 "ad_aarch64.cpp"
  }
}

void storeF_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3337 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovs(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlrw);
  
#line 18678 "ad_aarch64.cpp"
  }
}

void storeD_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3347 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    {
      C2_MacroAssembler _masm(&cbuf);
      FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
      __ fmovd(rscratch2, src_reg);
    }
    MOV_VOLATILE(rscratch2, opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1),
                 rscratch1, stlr);
  
#line 18700 "ad_aarch64.cpp"
  }
}

void cacheWBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8524 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    assert(opnd_array(1)->index_position() < 0, "should be");
    assert(opnd_array(1)->disp(ra_,this,idx1)== 0, "should be");
    __ cache_wb(Address(as_Register(opnd_array(1)->base(ra_,this,idx1)), 0));
  
#line 18718 "ad_aarch64.cpp"
  }
}

void cacheWBPreSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8539 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(true);
  
#line 18734 "ad_aarch64.cpp"
  }
}

void cacheWBPostSyncNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8552 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cache_wbsync(false);
  
#line 18750 "ad_aarch64.cpp"
  }
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8567 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ revw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18766 "ad_aarch64.cpp"
  }
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8580 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18782 "ad_aarch64.cpp"
  }
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8593 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18798 "ad_aarch64.cpp"
  }
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8607 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ rev16w(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */), 0U, 15U);
  
#line 18815 "ad_aarch64.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8623 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18831 "ad_aarch64.cpp"
  }
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8635 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 18847 "ad_aarch64.cpp"
  }
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8648 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbitw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clzw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 18864 "ad_aarch64.cpp"
  }
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8662 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ rbit(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 18881 "ad_aarch64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8683 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */); // ensure top 32 bits 0
    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 18902 "ad_aarch64.cpp"
  }
}

void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrs, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 4);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 18924 "ad_aarch64.cpp"
  }
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8725 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mov(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 18944 "ad_aarch64.cpp"
  }
}

void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8744 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister tmp_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldrd, tmp_reg, opnd_array(1)->opcode(),
              as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), 8);
    __ cnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ addv(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ T8B, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, __ D, 0);
  
#line 18966 "ad_aarch64.cpp"
  }
}

void load_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8765 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 18982 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8778 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire (elided)");
  
#line 18998 "ad_aarch64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8792 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire");
    __ membar(Assembler::LoadLoad|Assembler::LoadStore);
  
#line 19015 "ad_aarch64.cpp"
  }
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8807 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_acquire_lock (elided)");
  
#line 19031 "ad_aarch64.cpp"
  }
}

void store_fenceNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8820 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 19047 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8833 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release (elided)");
  
#line 19063 "ad_aarch64.cpp"
  }
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8846 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release");
    __ membar(Assembler::LoadStore|Assembler::StoreStore);
  
#line 19080 "ad_aarch64.cpp"
  }
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8860 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 19096 "ad_aarch64.cpp"
  }
}

void membar_storestore_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8860 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ membar(Assembler::StoreStore);
  
#line 19112 "ad_aarch64.cpp"
  }
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8872 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_release_lock (elided)");
  
#line 19128 "ad_aarch64.cpp"
  }
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8886 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile (elided)");
  
#line 19144 "ad_aarch64.cpp"
  }
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8900 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ block_comment("membar_volatile");
    __ membar(Assembler::StoreLoad);
  
#line 19161 "ad_aarch64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8917 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 19179 "ad_aarch64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8932 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    if (opnd_array(0)->reg(ra_,this)/* dst */!= opnd_array(1)->reg(ra_,this,idx1)/* src */) {
      __ mov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 19197 "ad_aarch64.cpp"
  }
}

void convP2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8947 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 19213 "ad_aarch64.cpp"
  }
}

void convN2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8963 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 19229 "ad_aarch64.cpp"
  }
}

void encodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8978 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ encode_heap_oop(d, s);
  
#line 19247 "ad_aarch64.cpp"
  }
}

void encodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8991 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_heap_oop_not_null(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 19263 "ad_aarch64.cpp"
  }
}

void decodeHeapOopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9003 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop(d, s);
  
#line 19281 "ad_aarch64.cpp"
  }
}

void decodeHeapOop_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9017 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register s = opnd_array(1)->as_Register(ra_,this,idx1)/* src */;
    Register d = opnd_array(0)->as_Register(ra_,this)/* dst */;
    __ decode_heap_oop_not_null(d, s);
  
#line 19299 "ad_aarch64.cpp"
  }
}

void encodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9035 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ encode_klass_not_null(dst_reg, src_reg);
  
#line 19317 "ad_aarch64.cpp"
  }
}

void decodeKlass_not_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9050 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    if (dst_reg != src_reg) {
      __ decode_klass_not_null(dst_reg, src_reg);
    } else {
      __ decode_klass_not_null(dst_reg);
    }
  
#line 19339 "ad_aarch64.cpp"
  }
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castLLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castFFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castFFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castDDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castDDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castVVMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castVVMaskNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3359 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch1, Address(base, disp));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ ldaxr(dst_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch1, Address(base, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      } else {
        __ lea(rscratch1, Address(base, disp));
        __ lea(rscratch1, Address(rscratch1, index_reg, Address::lsl(scale)));
        __ ldaxr(dst_reg, rscratch1);
      }
    }
  
#line 19509 "ad_aarch64.cpp"
  }
}

void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// heap_top_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3388 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register src_reg = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* newval */);
    Register base = as_Register(opnd_array(1)->base(ra_,this,idx1));
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int disp = opnd_array(1)->disp(ra_,this,idx1);
    if (index == -1) {
       if (disp != 0) {
        __ lea(rscratch2, Address(base, disp));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        // TODO
        // should we ever get anything other than this case?
        __ stlxr(rscratch1, src_reg, base);
      }
    } else {
      Register index_reg = as_Register(index);
      if (disp == 0) {
        __ lea(rscratch2, Address(base, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      } else {
        __ lea(rscratch2, Address(base, disp));
        __ lea(rscratch2, Address(rscratch2, index_reg, Address::lsl(scale)));
        __ stlxr(rscratch1, src_reg, rscratch2);
      }
    }
    __ cmpw(rscratch1, zr);
  
#line 19552 "ad_aarch64.cpp"
  }
}

void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3455 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19573 "ad_aarch64.cpp"
  }
}

void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3463 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19594 "ad_aarch64.cpp"
  }
}

void compareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3442 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19615 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19625 "ad_aarch64.cpp"
  }
}

void compareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3434 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19646 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19656 "ad_aarch64.cpp"
  }
}

void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3426 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19677 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19687 "ad_aarch64.cpp"
  }
}

void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19708 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19718 "ad_aarch64.cpp"
  }
}

void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19739 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19749 "ad_aarch64.cpp"
  }
}

void compareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3426 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19770 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19780 "ad_aarch64.cpp"
  }
}

void compareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3479 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19801 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19811 "ad_aarch64.cpp"
  }
}

void compareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3471 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19832 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19842 "ad_aarch64.cpp"
  }
}

void compareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3463 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19863 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19873 "ad_aarch64.cpp"
  }
}

void compareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3455 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19894 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19904 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3455 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19925 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19935 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {

#line 3463 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    __ cmpxchg(as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, noreg);
  
#line 19956 "ad_aarch64.cpp"
  }
  {

#line 3488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register res_reg = as_Register(opnd_array(0)->reg(ra_,this)/* res */);
    __ cset(res_reg, Assembler::EQ);
  
#line 19966 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9529 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 19988 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9548 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20010 "ad_aarch64.cpp"
  }
}

void compareAndExchangeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9567 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20031 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9585 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20052 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9603 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20073 "ad_aarch64.cpp"
  }
}

void compareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9621 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20094 "ad_aarch64.cpp"
  }
}

void compareAndExchangeBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9639 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxtbw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20116 "ad_aarch64.cpp"
  }
}

void compareAndExchangeSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9658 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    __ sxthw(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20138 "ad_aarch64.cpp"
  }
}

void compareAndExchangeIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9677 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20159 "ad_aarch64.cpp"
  }
}

void compareAndExchangeLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9695 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20180 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9713 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20201 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9731 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ false, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 20222 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9750 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20243 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9770 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20264 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9790 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20285 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9810 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20306 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9830 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20327 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9850 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ false, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20348 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapBAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9870 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::byte, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20369 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapSAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9890 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::halfword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20390 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9910 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20411 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9930 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20432 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9950 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::word, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20453 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9970 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
               Assembler::xword, /*acquire*/ true, /*release*/ true,
               /*weak*/ true, noreg);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* res */, Assembler::EQ);
  
#line 20474 "ad_aarch64.cpp"
  }
}

void get_and_setINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9986 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20491 "ad_aarch64.cpp"
  }
}

void get_and_setLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9996 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20508 "ad_aarch64.cpp"
  }
}

void get_and_setNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10006 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20525 "ad_aarch64.cpp"
  }
}

void get_and_setPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10017 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchg(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20542 "ad_aarch64.cpp"
  }
}

void get_and_setIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10028 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20559 "ad_aarch64.cpp"
  }
}

void get_and_setLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10039 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20576 "ad_aarch64.cpp"
  }
}

void get_and_setNAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10050 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgalw(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20593 "ad_aarch64.cpp"
  }
}

void get_and_setPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10061 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_xchgal(opnd_array(0)->as_Register(ra_,this)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20610 "ad_aarch64.cpp"
  }
}

void get_and_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10072 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20627 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10083 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20644 "ad_aarch64.cpp"
  }
}

void get_and_addLiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10093 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20661 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10104 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_add(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20678 "ad_aarch64.cpp"
  }
}

void get_and_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10114 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20695 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10125 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20712 "ad_aarch64.cpp"
  }
}

void get_and_addIiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10135 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20729 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10146 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20746 "ad_aarch64.cpp"
  }
}

void get_and_addLAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10157 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20763 "ad_aarch64.cpp"
  }
}

void get_and_addL_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10168 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20780 "ad_aarch64.cpp"
  }
}

void get_and_addLiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10179 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20797 "ad_aarch64.cpp"
  }
}

void get_and_addLi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10190 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addal(noreg, opnd_array(2)->constantL(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20814 "ad_aarch64.cpp"
  }
}

void get_and_addIAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10201 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20831 "ad_aarch64.cpp"
  }
}

void get_and_addI_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10212 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->as_Register(ra_,this,idx2)/* incr */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20848 "ad_aarch64.cpp"
  }
}

void get_and_addIiAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10223 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(opnd_array(0)->as_Register(ra_,this)/* newval */, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20865 "ad_aarch64.cpp"
  }
}

void get_and_addIi_no_resAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// incr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10234 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ atomic_addalw(noreg, opnd_array(2)->constant(), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 20882 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10254 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 20901 "ad_aarch64.cpp"
  }
}

void cmpL3_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10274 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int32_t con = (int32_t)opnd_array(2)->constantL();
     if (con < 0) {
      __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -con);
    } else {
      __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, con);
    }
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
    __ cnegw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LT);
  
#line 20925 "ad_aarch64.cpp"
  }
}

void cmovI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10307 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20947 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10323 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20969 "ad_aarch64.cpp"
  }
}

void cmovI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10348 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 20991 "ad_aarch64.cpp"
  }
}

void cmovUI_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10364 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21013 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10380 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21035 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10396 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21057 "ad_aarch64.cpp"
  }
}

void cmovI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10417 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21082 "ad_aarch64.cpp"
  }
}

void cmovUI_reg_zero_oneNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10436 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // equivalently
    // cset(as_Register($dst$$reg),
    //      negate_condition((Assembler::Condition)$cmp$$cmpcode));
    __ csincw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21107 "ad_aarch64.cpp"
  }
}

void cmovL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10455 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21129 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10471 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21151 "ad_aarch64.cpp"
  }
}

void cmovL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10489 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21173 "ad_aarch64.cpp"
  }
}

void cmovUL_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10505 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21195 "ad_aarch64.cpp"
  }
}

void cmovL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10521 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21217 "ad_aarch64.cpp"
  }
}

void cmovUL_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10537 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21239 "ad_aarch64.cpp"
  }
}

void cmovP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10553 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21261 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10569 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21283 "ad_aarch64.cpp"
  }
}

void cmovP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10587 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21305 "ad_aarch64.cpp"
  }
}

void cmovUP_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10603 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            zr,
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21327 "ad_aarch64.cpp"
  }
}

void cmovP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10619 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21349 "ad_aarch64.cpp"
  }
}

void cmovUP_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10635 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ csel(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
            zr,
            (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21371 "ad_aarch64.cpp"
  }
}

void cmovN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10651 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21393 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10667 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21415 "ad_aarch64.cpp"
  }
}

void cmovN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10685 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21437 "ad_aarch64.cpp"
  }
}

void cmovUN_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10701 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             zr,
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src */),
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21459 "ad_aarch64.cpp"
  }
}

void cmovN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10717 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21481 "ad_aarch64.cpp"
  }
}

void cmovUN_zero_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10733 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src */),
             zr,
             (Assembler::Condition)opnd_array(1)->ccode());
  
#line 21503 "ad_aarch64.cpp"
  }
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10750 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 21526 "ad_aarch64.cpp"
  }
}

void cmovUF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10768 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcsels(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 21549 "ad_aarch64.cpp"
  }
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10786 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 21572 "ad_aarch64.cpp"
  }
}

void cmovUD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cr
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10804 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ fcseld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* src2 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              cond);
  
#line 21595 "ad_aarch64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10833 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21614 "ad_aarch64.cpp"
  }
}

void addI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3615 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21640 "ad_aarch64.cpp"
  }
}

void addI_reg_imm_i2lNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3615 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21666 "ad_aarch64.cpp"
  }
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10877 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21685 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10892 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
  
#line 21704 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_lslNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10907 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::lsl(opnd_array(3)->constant())));
  
#line 21724 "ad_aarch64.cpp"
  }
}

void addP_reg_reg_ext_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10922 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lea(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           Address(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                   Address::sxtw(opnd_array(3)->constant())));
  
#line 21744 "ad_aarch64.cpp"
  }
}

void lshift_extNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// scale
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10937 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
          opnd_array(2)->constant()& 63, MIN2(32, (int)((-opnd_array(2)->constant()) & 63)));
  
#line 21763 "ad_aarch64.cpp"
  }
}

void addP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21789 "ad_aarch64.cpp"
  }
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10971 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21808 "ad_aarch64.cpp"
  }
}

void addL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x0 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21834 "ad_aarch64.cpp"
  }
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11002 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21853 "ad_aarch64.cpp"
  }
}

void subI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3615 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constant();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ subw(dst_reg, src_reg, -con);
    } else {
      __ addw(dst_reg, src_reg, con);
    }
  
#line 21879 "ad_aarch64.cpp"
  }
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21898 "ad_aarch64.cpp"
  }
}

void subL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    Register src_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    int32_t con = (int32_t)opnd_array(2)->constantL();
    // add has primary == 0, subtract has primary == 1
    if ((0x1 /*primary()*/)) { con = -con; }
    if (con < 0) {
      __ sub(dst_reg, src_reg, -con);
    } else {
      __ add(dst_reg, src_reg, con);
    }
  
#line 21924 "ad_aarch64.cpp"
  }
}

void negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11066 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 21942 "ad_aarch64.cpp"
  }
}

void negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11082 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 21960 "ad_aarch64.cpp"
  }
}

void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11098 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21979 "ad_aarch64.cpp"
  }
}

void smulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11113 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 21998 "ad_aarch64.cpp"
  }
}

void smulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11113 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 22017 "ad_aarch64.cpp"
  }
}

void mulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11130 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22036 "ad_aarch64.cpp"
  }
}

void mulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11146 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22055 "ad_aarch64.cpp"
  }
}

void umulHiL_rRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11162 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ umulh(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22074 "ad_aarch64.cpp"
  }
}

void maddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11179 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22095 "ad_aarch64.cpp"
  }
}

void maddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11179 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 22116 "ad_aarch64.cpp"
  }
}

void msubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11195 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ msubw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22137 "ad_aarch64.cpp"
  }
}

void mnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11213 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 22157 "ad_aarch64.cpp"
  }
}

void mnegI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11213 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 22177 "ad_aarch64.cpp"
  }
}

void maddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11230 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22198 "ad_aarch64.cpp"
  }
}

void maddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11230 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ madd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 22219 "ad_aarch64.cpp"
  }
}

void msubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11246 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ msub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22240 "ad_aarch64.cpp"
  }
}

void mnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 22260 "ad_aarch64.cpp"
  }
}

void mnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 22280 "ad_aarch64.cpp"
  }
}

void smaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22301 "ad_aarch64.cpp"
  }
}

void smaddL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 22322 "ad_aarch64.cpp"
  }
}

void smaddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22343 "ad_aarch64.cpp"
  }
}

void smaddL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smaddl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 22364 "ad_aarch64.cpp"
  }
}

void smsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11297 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22385 "ad_aarch64.cpp"
  }
}

void smsubL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11297 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smsubl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 22406 "ad_aarch64.cpp"
  }
}

void smnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11313 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 22426 "ad_aarch64.cpp"
  }
}

void smnegL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11313 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smnegl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 22446 "ad_aarch64.cpp"
  }
}

void muladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11331 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mulw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ maddw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src3 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src4 */), rscratch1); 
#line 22465 "ad_aarch64.cpp"
  }
}

void divINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3643 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 22485 "ad_aarch64.cpp"
  }
}

void divLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3651 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, false, rscratch1);
  
#line 22505 "ad_aarch64.cpp"
  }
}

void modINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3659 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivl(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 22525 "ad_aarch64.cpp"
  }
}

void modLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {

#line 3667 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
   Register dst_reg = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
   Register src1_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
   Register src2_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ corrected_idivq(dst_reg, src1_reg, src2_reg, true, rscratch1);
  
#line 22545 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11397 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22564 "ad_aarch64.cpp"
  }
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11413 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 22583 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11429 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22602 "ad_aarch64.cpp"
  }
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11445 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 22621 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11461 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22640 "ad_aarch64.cpp"
  }
}

void rShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11477 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x1f);
  
#line 22659 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11498 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lslv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22678 "ad_aarch64.cpp"
  }
}

void lShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11514 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsl(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            opnd_array(2)->constant()& 0x3f);
  
#line 22697 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11530 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22716 "ad_aarch64.cpp"
  }
}

void urShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11546 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22735 "ad_aarch64.cpp"
  }
}

void urShiftP_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11562 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ lsr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22754 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11578 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 22773 "ad_aarch64.cpp"
  }
}

void rShiftL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11594 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ asr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           opnd_array(2)->constant()& 0x3f);
  
#line 22792 "ad_aarch64.cpp"
  }
}

void regL_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11616 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 22812 "ad_aarch64.cpp"
  }
}

void regI_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11635 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              zr,
              Assembler::LSL, 0);
  
#line 22832 "ad_aarch64.cpp"
  }
}

void NegI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11654 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSR, opnd_array(3)->constant()& 0x1f);
  
#line 22851 "ad_aarch64.cpp"
  }
}

void NegI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11671 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::ASR, opnd_array(3)->constant()& 0x1f);
  
#line 22870 "ad_aarch64.cpp"
  }
}

void NegI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11688 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ negw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSL, opnd_array(3)->constant()& 0x1f);
  
#line 22889 "ad_aarch64.cpp"
  }
}

void NegL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11705 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSR, opnd_array(3)->constant()& 0x3f);
  
#line 22908 "ad_aarch64.cpp"
  }
}

void NegL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11722 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::ASR, opnd_array(3)->constant()& 0x3f);
  
#line 22927 "ad_aarch64.cpp"
  }
}

void NegL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11739 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ neg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            Assembler::LSL, opnd_array(3)->constant()& 0x3f);
  
#line 22946 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11755 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 22967 "ad_aarch64.cpp"
  }
}

void AndI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11755 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 22988 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11773 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 23009 "ad_aarch64.cpp"
  }
}

void AndL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11773 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 23030 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11791 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 23051 "ad_aarch64.cpp"
  }
}

void OrI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11791 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 23072 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11809 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 23093 "ad_aarch64.cpp"
  }
}

void OrL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11809 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 23114 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11827 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 23135 "ad_aarch64.cpp"
  }
}

void XorI_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11827 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 23156 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11845 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL, 0);
  
#line 23177 "ad_aarch64.cpp"
  }
}

void XorL_reg_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11845 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL, 0);
  
#line 23198 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11865 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23221 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11865 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23244 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11886 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23267 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11886 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23290 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11907 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23313 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11907 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23336 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11928 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23359 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11928 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23382 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11949 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23405 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11949 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23428 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11970 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23451 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11970 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23474 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11991 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 23497 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11991 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bicw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 23520 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12012 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 23543 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12012 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ bic(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 23566 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12033 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23589 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12033 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23612 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12033 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x1f);
  
#line 23635 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12033 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23658 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23681 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23704 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSR,
              opnd_array(4)->constant()& 0x3f);
  
#line 23727 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23750 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12075 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23773 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12075 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23796 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12075 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x1f);
  
#line 23819 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12075 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23842 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12096 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23865 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12096 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 23888 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12096 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ASR,
              opnd_array(4)->constant()& 0x3f);
  
#line 23911 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12096 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 23934 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12117 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 23957 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12117 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 23980 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12117 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x1f);
  
#line 24003 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12117 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24026 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12138 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24049 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12138 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24072 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12138 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::ROR,
              opnd_array(4)->constant()& 0x3f);
  
#line 24095 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12138 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24118 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12159 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24141 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12159 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24164 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12159 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x1f);
  
#line 24187 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12159 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eonw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24210 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12180 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24233 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12180 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24256 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src4
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12180 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              Assembler::LSL,
              opnd_array(4)->constant()& 0x3f);
  
#line 24279 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_not_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12180 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eon(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24302 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12201 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24325 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12201 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24348 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12222 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24371 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12222 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24394 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12243 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24417 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12243 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24440 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24463 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24486 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12285 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24509 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12285 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24532 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12306 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24555 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12306 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24578 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12327 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24601 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12327 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ornw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24624 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12348 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24647 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_not_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src4
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12348 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orn(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24670 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12369 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24692 "ad_aarch64.cpp"
  }
}

void AndI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12369 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24714 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12390 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24736 "ad_aarch64.cpp"
  }
}

void AndL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12390 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24758 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12411 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24780 "ad_aarch64.cpp"
  }
}

void AndI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12411 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24802 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 24824 "ad_aarch64.cpp"
  }
}

void AndL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 24846 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12453 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 24868 "ad_aarch64.cpp"
  }
}

void AndI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12453 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 24890 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12474 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 24912 "ad_aarch64.cpp"
  }
}

void AndL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12474 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 24934 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12495 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 24956 "ad_aarch64.cpp"
  }
}

void AndI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12495 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 24978 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12516 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25000 "ad_aarch64.cpp"
  }
}

void AndL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12516 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25022 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12537 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25044 "ad_aarch64.cpp"
  }
}

void XorI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12537 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25066 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12558 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25088 "ad_aarch64.cpp"
  }
}

void XorL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12558 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25110 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12579 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25132 "ad_aarch64.cpp"
  }
}

void XorI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12579 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25154 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12600 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25176 "ad_aarch64.cpp"
  }
}

void XorL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12600 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25198 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12621 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 25220 "ad_aarch64.cpp"
  }
}

void XorI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12621 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 25242 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12642 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 25264 "ad_aarch64.cpp"
  }
}

void XorL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12642 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 25286 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12663 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25308 "ad_aarch64.cpp"
  }
}

void XorI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12663 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25330 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25352 "ad_aarch64.cpp"
  }
}

void XorL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25374 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12705 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25396 "ad_aarch64.cpp"
  }
}

void OrI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12705 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25418 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12726 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25440 "ad_aarch64.cpp"
  }
}

void OrL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12726 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25462 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12747 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25484 "ad_aarch64.cpp"
  }
}

void OrI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12747 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25506 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12768 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25528 "ad_aarch64.cpp"
  }
}

void OrL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12768 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25550 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12789 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 25572 "ad_aarch64.cpp"
  }
}

void OrI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12789 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 25594 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12810 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 25616 "ad_aarch64.cpp"
  }
}

void OrL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12810 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 25638 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12831 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25660 "ad_aarch64.cpp"
  }
}

void OrI_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12831 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25682 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12852 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ROR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25704 "ad_aarch64.cpp"
  }
}

void OrL_reg_RotateRight_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12852 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ROR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25726 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12873 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25748 "ad_aarch64.cpp"
  }
}

void AddI_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12873 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25770 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12894 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25792 "ad_aarch64.cpp"
  }
}

void AddL_reg_URShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12894 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25814 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12915 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 25836 "ad_aarch64.cpp"
  }
}

void AddI_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12915 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x1f);
  
#line 25858 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12936 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 25880 "ad_aarch64.cpp"
  }
}

void AddL_reg_RShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12936 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::ASR,
              opnd_array(2)->constant()& 0x3f);
  
#line 25902 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 25924 "ad_aarch64.cpp"
  }
}

void AddI_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x1f);
  
#line 25946 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12978 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 25968 "ad_aarch64.cpp"
  }
}

void AddL_reg_LShift_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12978 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
              Assembler::LSL,
              opnd_array(2)->constant()& 0x3f);
  
#line 25990 "ad_aarch64.cpp"
  }
}

void SubI_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 12999 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x1f);
  
#line 26012 "ad_aarch64.cpp"
  }
}

void SubL_reg_URShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13020 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSR,
              opnd_array(3)->constant()& 0x3f);
  
#line 26034 "ad_aarch64.cpp"
  }
}

void SubI_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13041 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x1f);
  
#line 26056 "ad_aarch64.cpp"
  }
}

void SubL_reg_RShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13062 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::ASR,
              opnd_array(3)->constant()& 0x3f);
  
#line 26078 "ad_aarch64.cpp"
  }
}

void SubI_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13083 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x1f);
  
#line 26100 "ad_aarch64.cpp"
  }
}

void SubL_reg_LShift_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13104 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
              as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
              Assembler::LSL,
              opnd_array(3)->constant()& 0x3f);
  
#line 26122 "ad_aarch64.cpp"
  }
}

void sbfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13125 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ sbfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 26146 "ad_aarch64.cpp"
  }
}

void sbfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13148 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ sbfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 26170 "ad_aarch64.cpp"
  }
}

void ubfmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13171 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 63;
    int rshift = opnd_array(3)->constant()& 63;
    int s = 63 - lshift;
    int r = (rshift - lshift) & 63;
    __ ubfm(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 26194 "ad_aarch64.cpp"
  }
}

void ubfmwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift_count
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift_count
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13194 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(2)->constant()& 31;
    int rshift = opnd_array(3)->constant()& 31;
    int s = 31 - lshift;
    int r = (rshift - lshift) & 31;
    __ ubfmw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            r, s);
  
#line 26218 "ad_aarch64.cpp"
  }
}

void ubfxwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13219 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfxw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 26240 "ad_aarch64.cpp"
  }
}

void ubfxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13239 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 63;
    intptr_t mask = opnd_array(3)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 26262 "ad_aarch64.cpp"
  }
}

void ubfxIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13263 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int rshift = opnd_array(2)->constant()& 31;
    intptr_t mask = opnd_array(3)->constant();
    int width = exact_log2(mask+1);
    __ ubfx(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rshift, width);
  
#line 26284 "ad_aarch64.cpp"
  }
}

void ubfizwINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13286 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26306 "ad_aarch64.cpp"
  }
}

void ubfizLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13308 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26328 "ad_aarch64.cpp"
  }
}

void ubfizwIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13330 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfizw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26350 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13352 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2_long(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
          as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26372 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13374 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 63;
    intptr_t mask = opnd_array(2)->constant();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26394 "ad_aarch64.cpp"
  }
}

void ubfizLConvL2IxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13395 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int lshift = opnd_array(3)->constant()& 31;
    intptr_t mask = opnd_array(2)->constantL();
    int width = exact_log2(mask+1);
    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), lshift, width);
  
#line 26416 "ad_aarch64.cpp"
  }
}

void ubfizIConvI2LAndINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// msk
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13414 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfiz(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, exact_log2(opnd_array(2)->constant()+ 1));
  
#line 26433 "ad_aarch64.cpp"
  }
}

void extrOrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 26453 "ad_aarch64.cpp"
  }
}

void extrOrL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 26473 "ad_aarch64.cpp"
  }
}

void extrOrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13450 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 26493 "ad_aarch64.cpp"
  }
}

void extrOrI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13450 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 26513 "ad_aarch64.cpp"
  }
}

void extrAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13468 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 63);
  
#line 26533 "ad_aarch64.cpp"
  }
}

void extrAddL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13468 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 63);
  
#line 26553 "ad_aarch64.cpp"
  }
}

void extrAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13486 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
            opnd_array(4)->constant()& 31);
  
#line 26573 "ad_aarch64.cpp"
  }
}

void extrAddI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13486 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */),
            opnd_array(2)->constant()& 31);
  
#line 26593 "ad_aarch64.cpp"
  }
}

void rorI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13503 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ extrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x1f);
  
#line 26611 "ad_aarch64.cpp"
  }
}

void rorL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13519 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ extr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               opnd_array(2)->constant()& 0x3f);
  
#line 26629 "ad_aarch64.cpp"
  }
}

void rorI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13535 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 26646 "ad_aarch64.cpp"
  }
}

void rorL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13550 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 26663 "ad_aarch64.cpp"
  }
}

void rolI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13565 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorvw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 26681 "ad_aarch64.cpp"
  }
}

void rolL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13581 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(rscratch1, zr, as_Register(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
     __ rorv(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), rscratch1);
  
#line 26699 "ad_aarch64.cpp"
  }
}

void AddExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13599 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 26717 "ad_aarch64.cpp"
  }
}

void AddExtI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13599 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 26735 "ad_aarch64.cpp"
  }
}

void SubExtINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13614 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 26753 "ad_aarch64.cpp"
  }
}

void AddExtI_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 26773 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 26793 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13644 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 26813 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13644 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 26833 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13659 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 26853 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13659 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 26873 "ad_aarch64.cpp"
  }
}

void AddExtL_sxthNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13674 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth);
   
#line 26893 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13674 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth);
   
#line 26913 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13689 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw);
   
#line 26933 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13689 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw);
   
#line 26953 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13704 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb);
   
#line 26973 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13704 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb);
   
#line 26993 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtbNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13719 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 27013 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13719 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 27033 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13734 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 27052 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13734 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 27071 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13749 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 27090 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13749 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 27109 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13764 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 27128 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13764 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb);
   
#line 27147 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13779 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 27166 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13779 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth);
   
#line 27185 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13794 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 27204 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13794 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw);
   
#line 27223 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13809 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 27242 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13824 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 27261 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13839 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb);
   
#line 27280 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13854 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth);
   
#line 27299 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13869 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw);
   
#line 27318 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13885 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 27339 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13885 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 27360 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13900 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 27381 "ad_aarch64.cpp"
  }
}

void AddExtL_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13900 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 27402 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13915 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 27423 "ad_aarch64.cpp"
  }
}

void AddExtL_sxtw_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13915 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(4)->constant()));
   
#line 27444 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13930 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 27465 "ad_aarch64.cpp"
  }
}

void SubExtL_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13945 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 27486 "ad_aarch64.cpp"
  }
}

void SubExtL_sxtw_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13960 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(5)->constant()));
   
#line 27507 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13975 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 27528 "ad_aarch64.cpp"
  }
}

void AddExtI_sxtb_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13975 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtb, (opnd_array(4)->constant()));
   
#line 27549 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13990 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 27570 "ad_aarch64.cpp"
  }
}

void AddExtI_sxth_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 13990 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(5)->reg(ra_,this,idx5)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxth, (opnd_array(4)->constant()));
   
#line 27591 "ad_aarch64.cpp"
  }
}

void SubExtI_sxtb_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14005 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtb, (opnd_array(5)->constant()));
   
#line 27612 "ad_aarch64.cpp"
  }
}

void SubExtI_sxth_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// rshift1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// lshift2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14020 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxth, (opnd_array(5)->constant()));
   
#line 27633 "ad_aarch64.cpp"
  }
}

void AddExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14035 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 27652 "ad_aarch64.cpp"
  }
}

void AddExtI_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14035 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::sxtw, (opnd_array(2)->constant()));
   
#line 27671 "ad_aarch64.cpp"
  }
}

void SubExtI_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14050 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::sxtw, (opnd_array(3)->constant()));
   
#line 27690 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14065 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27710 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14065 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 27730 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14080 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27750 "ad_aarch64.cpp"
  }
}

void AddExtL_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14080 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 27770 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14095 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 27790 "ad_aarch64.cpp"
  }
}

void AddExtL_uxtw_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14095 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ add(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtw, (opnd_array(3)->constant()));
   
#line 27810 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14110 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27830 "ad_aarch64.cpp"
  }
}

void SubExtL_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14125 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27850 "ad_aarch64.cpp"
  }
}

void SubExtL_uxtw_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14140 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ sub(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtw, (opnd_array(4)->constant()));
   
#line 27870 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14155 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27890 "ad_aarch64.cpp"
  }
}

void AddExtI_uxtb_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14155 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxtb, (opnd_array(3)->constant()));
   
#line 27910 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14170 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27930 "ad_aarch64.cpp"
  }
}

void AddExtI_uxth_and_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14170 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ addw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* src1 */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), ext::uxth, (opnd_array(3)->constant()));
   
#line 27950 "ad_aarch64.cpp"
  }
}

void SubExtI_uxtb_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14185 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxtb, (opnd_array(4)->constant()));
   
#line 27970 "ad_aarch64.cpp"
  }
}

void SubExtI_uxth_and_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// mask
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// lshift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14200 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), ext::uxth, (opnd_array(4)->constant()));
   
#line 27990 "ad_aarch64.cpp"
  }
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14221 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28009 "ad_aarch64.cpp"
  }
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14236 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ faddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28028 "ad_aarch64.cpp"
  }
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14251 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28047 "ad_aarch64.cpp"
  }
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14266 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28066 "ad_aarch64.cpp"
  }
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuls(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28085 "ad_aarch64.cpp"
  }
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14296 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmuld(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28104 "ad_aarch64.cpp"
  }
}

void maddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14312 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28125 "ad_aarch64.cpp"
  }
}

void maddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14329 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28146 "ad_aarch64.cpp"
  }
}

void msubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14347 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28167 "ad_aarch64.cpp"
  }
}

void msubF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14347 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28188 "ad_aarch64.cpp"
  }
}

void msubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14365 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28209 "ad_aarch64.cpp"
  }
}

void msubD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14365 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmsubd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28230 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14383 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28251 "ad_aarch64.cpp"
  }
}

void mnaddF_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14383 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmadds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28272 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14401 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28293 "ad_aarch64.cpp"
  }
}

void mnaddD_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14401 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmaddd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28314 "ad_aarch64.cpp"
  }
}

void mnsubF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnmsubs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28335 "ad_aarch64.cpp"
  }
}

void mnsubD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14435 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

  // n.b. insn name should be fnmsubd
    __ fnmsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
              as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */),
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src3 */));
  
#line 28357 "ad_aarch64.cpp"
  }
}

void maxF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14452 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28376 "ad_aarch64.cpp"
  }
}

void minF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14466 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28395 "ad_aarch64.cpp"
  }
}

void maxD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14480 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmaxd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28414 "ad_aarch64.cpp"
  }
}

void minD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14494 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmind(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28433 "ad_aarch64.cpp"
  }
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14510 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28452 "ad_aarch64.cpp"
  }
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14525 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fdivd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28471 "ad_aarch64.cpp"
  }
}

void negF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14540 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28488 "ad_aarch64.cpp"
  }
}

void negD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14554 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fnegd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28505 "ad_aarch64.cpp"
  }
}

void absI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14572 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cnegw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 28522 "ad_aarch64.cpp"
  }
}

void absL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14589 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cneg(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), Assembler::LT);
  
#line 28539 "ad_aarch64.cpp"
  }
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14601 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabss(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28556 "ad_aarch64.cpp"
  }
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14614 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabsd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28573 "ad_aarch64.cpp"
  }
}

void absdF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14627 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabds(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28592 "ad_aarch64.cpp"
  }
}

void absdD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14641 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fabdd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28611 "ad_aarch64.cpp"
  }
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14655 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28628 "ad_aarch64.cpp"
  }
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14668 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fsqrts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 28645 "ad_aarch64.cpp"
  }
}

void roundD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14680 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintnd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintmd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintpd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 28675 "ad_aarch64.cpp"
  }
}

void copySignD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                  zero = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* zero */);
    __ fnegd(dst, zero);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 28699 "ad_aarch64.cpp"
  }
}

void copySignF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14718 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
                  src1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                  src2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    __ movi(dst, __ T2S, 0x80, 24);
    __ bsl(dst, __ T8B, src2, src1);
  
#line 28721 "ad_aarch64.cpp"
  }
}

void signumD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14732 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgtd(dst, src, zero); // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushrd(dst, dst, 1);     // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 28751 "ad_aarch64.cpp"
  }
}

void signumF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// one
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14753 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                  dst = as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */),
                  zero = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* zero */),
                  one = as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* one */);
    __ facgts(dst, src, zero);    // dst=0 for +-0.0 and NaN. 0xFFF..F otherwise
    __ ushr(dst, __ T2S, dst, 1); // dst=0 for +-0.0 and NaN. 0x7FF..F otherwise
    // Bit selection instruction gets bit from "one" for each enabled bit in
    // "dst", otherwise gets a bit from "src". For "src" that contains +-0.0 or
    // NaN the whole "src" will be copied because "dst" is zero. For all other
    // "src" values dst is 0x7FF..F, which means only the sign bit is copied
    // from "src", and all other bits are copied from 1.0.
    __ bsl(dst, __ T8B, one, src);
  
#line 28781 "ad_aarch64.cpp"
  }
}

void onspinwaitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14776 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ spin_wait();
  
#line 28797 "ad_aarch64.cpp"
  }
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14796 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28816 "ad_aarch64.cpp"
  }
}

void andI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14811 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28835 "ad_aarch64.cpp"
  }
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14828 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28854 "ad_aarch64.cpp"
  }
}

void orI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14843 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28873 "ad_aarch64.cpp"
  }
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14860 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28892 "ad_aarch64.cpp"
  }
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14875 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eorw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constant()));
  
#line 28911 "ad_aarch64.cpp"
  }
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14893 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28930 "ad_aarch64.cpp"
  }
}

void andL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14908 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ andr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
            as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            (uint64_t)(opnd_array(2)->constantL()));
  
#line 28949 "ad_aarch64.cpp"
  }
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14925 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 28968 "ad_aarch64.cpp"
  }
}

void orL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14940 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 28987 "ad_aarch64.cpp"
  }
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 29006 "ad_aarch64.cpp"
  }
}

void xorL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14972 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ eor(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
           (uint64_t)(opnd_array(2)->constantL()));
  
#line 29025 "ad_aarch64.cpp"
  }
}

void convI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 14987 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ sbfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 29041 "ad_aarch64.cpp"
  }
}

void convUI2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15000 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ubfm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0, 31);
  
#line 29058 "ad_aarch64.cpp"
  }
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15013 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ movw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29074 "ad_aarch64.cpp"
  }
}

void convI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15030 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 29091 "ad_aarch64.cpp"
  }
}

void convP2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15048 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), zr);
    __ cset(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 29108 "ad_aarch64.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15062 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29124 "ad_aarch64.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15075 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvts(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29140 "ad_aarch64.cpp"
  }
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15088 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzsw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29156 "ad_aarch64.cpp"
  }
}

void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15101 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzs(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29172 "ad_aarch64.cpp"
  }
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15114 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfws(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29188 "ad_aarch64.cpp"
  }
}

void convL2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15127 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29204 "ad_aarch64.cpp"
  }
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15140 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzdw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29220 "ad_aarch64.cpp"
  }
}

void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15153 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcvtzd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29236 "ad_aarch64.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15166 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfwd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29252 "ad_aarch64.cpp"
  }
}

void convL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15179 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ scvtfd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29268 "ad_aarch64.cpp"
  }
}

void round_double_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ftmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15191 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ java_round_double(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* ftmp */));
  
#line 29287 "ad_aarch64.cpp"
  }
}

void round_float_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ftmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ java_round_float(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                        as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* ftmp */));
  
#line 29306 "ad_aarch64.cpp"
  }
}

void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15222 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrw(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29322 "ad_aarch64.cpp"
  }
}

void MoveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15240 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29338 "ad_aarch64.cpp"
  }
}

void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15258 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29354 "ad_aarch64.cpp"
  }
}

void MoveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15276 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Address(sp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 29370 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15294 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ strs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 29386 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15312 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ strw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 29402 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15330 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ strd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 29418 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15348 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ str(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Address(sp, opnd_array(0)->disp(ra_,this,0)));
  
#line 29434 "ad_aarch64.cpp"
  }
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15366 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29450 "ad_aarch64.cpp"
  }
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15384 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29466 "ad_aarch64.cpp"
  }
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15402 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 29482 "ad_aarch64.cpp"
  }
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15420 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 29498 "ad_aarch64.cpp"
  }
}

void clearArray_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15439 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29519 "ad_aarch64.cpp"
  }
}

void clearArray_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// temp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15460 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ zero_words(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, (uint64_t)opnd_array(1)->constantL());
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 29541 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15480 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 29558 "ad_aarch64.cpp"
  }
}

void overflowAddI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15493 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmnw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 29575 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15506 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmn(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 29592 "ad_aarch64.cpp"
  }
}

void overflowAddL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15519 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ adds(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 29609 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15532 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 29626 "ad_aarch64.cpp"
  }
}

void overflowSubI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15545 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 29643 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15558 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 29660 "ad_aarch64.cpp"
  }
}

void overflowSubL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15571 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ subs(zr, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 29677 "ad_aarch64.cpp"
  }
}

void overflowNegI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15584 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 29694 "ad_aarch64.cpp"
  }
}

void overflowNegL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15597 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmp(zr, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */);
  
#line 29711 "ad_aarch64.cpp"
  }
}

void overflowMulI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15614 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ smull(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 29732 "ad_aarch64.cpp"
  }
}

void overflowMulI_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15636 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ smull(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);
    __ subs(zr, rscratch1, rscratch1, ext::sxtw);      // NE => overflow
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 29755 "ad_aarch64.cpp"
  }
}

void overflowMulL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15658 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ mul(rscratch1, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ movw(rscratch1, 0x80000000);                    // Develop 0 (EQ),
    __ cselw(rscratch1, rscratch1, zr, Assembler::NE); // or 0x80000000 (NE)
    __ cmpw(rscratch1, 1);                             // 0x80000000 - 1 => VS
  
#line 29777 "ad_aarch64.cpp"
  }
}

void overflowMulL_reg_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15682 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    __ mul(rscratch1, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */);   // Result bits 0..63
    __ smulh(rscratch2, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* op2 */); // Result bits 64..127
    __ cmp(rscratch2, rscratch1, Assembler::ASR, 63);    // Top is pure sign ext
    __ br(cond == Assembler::VS ? Assembler::NE : Assembler::EQ, *L);
  
#line 29801 "ad_aarch64.cpp"
  }
}

void compI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3677 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 29820 "ad_aarch64.cpp"
  }
}

void compI_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29843 "ad_aarch64.cpp"
  }
}

void compI_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29866 "ad_aarch64.cpp"
  }
}

void compI_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3695 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 29886 "ad_aarch64.cpp"
  }
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3677 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 29905 "ad_aarch64.cpp"
  }
}

void compU_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29928 "ad_aarch64.cpp"
  }
}

void compU_reg_immIAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int32_t val = opnd_array(2)->constant();
    if (val >= 0) {
      __ subsw(zr, reg, val);
    } else {
      __ addsw(zr, reg, -val);
    }
  
#line 29951 "ad_aarch64.cpp"
  }
}

void compU_reg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3695 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint32_t val = (uint32_t)opnd_array(2)->constant();
    __ movw(rscratch1, val);
    __ cmpw(reg1, rscratch1);
  
#line 29971 "ad_aarch64.cpp"
  }
}

void compL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 29990 "ad_aarch64.cpp"
  }
}

void compL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 30017 "ad_aarch64.cpp"
  }
}

void compL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 30044 "ad_aarch64.cpp"
  }
}

void compL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3725 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 30064 "ad_aarch64.cpp"
  }
}

void compUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 30083 "ad_aarch64.cpp"
  }
}

void compUL_reg_immL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 30110 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLAddSubNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    int64_t val = opnd_array(2)->constantL();
    if (val >= 0) {
      __ subs(zr, reg, val);
    } else if (val != -val) {
      __ adds(zr, reg, -val);
    } else {
    // aargh, Long.MIN_VALUE is a special case
      __ orr(rscratch1, zr, (uint64_t)val);
      __ subs(zr, reg, rscratch1);
    }
  
#line 30137 "ad_aarch64.cpp"
  }
}

void compUL_reg_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3725 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    uint64_t val = (uint64_t)opnd_array(2)->constantL();
    __ mov(rscratch1, val);
    __ cmp(reg1, rscratch1);
  
#line 30157 "ad_aarch64.cpp"
  }
}

void compP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3733 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmp(reg1, reg2);
  
#line 30176 "ad_aarch64.cpp"
  }
}

void compN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {

#line 3740 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg1 = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    Register reg2 = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* op2 */);
    __ cmpw(reg1, reg2);
  
#line 30195 "ad_aarch64.cpp"
  }
}

void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3747 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmp(reg, zr);
  
#line 30213 "ad_aarch64.cpp"
  }
}

void testN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {

#line 3753 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* op1 */);
    __ cmpw(reg, zr);
  
#line 30231 "ad_aarch64.cpp"
  }
}

void compF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 15993 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30248 "ad_aarch64.cpp"
  }
}

void compF_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16007 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmps(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 30265 "ad_aarch64.cpp"
  }
}

void compD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16022 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 30282 "ad_aarch64.cpp"
  }
}

void compD_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16036 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ fcmpd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), 0.0);
  
#line 30299 "ad_aarch64.cpp"
  }
}

void compF3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 30325 "ad_aarch64.cpp"
  }
}

void compD3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16082 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    FloatRegister s2 = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, s2);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 30351 "ad_aarch64.cpp"
  }
}

void compF3_reg_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16109 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmps(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 30376 "ad_aarch64.cpp"
  }
}

void compD3_reg_immD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16136 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label done;
    FloatRegister s1 = as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */);
    Register d = as_Register(opnd_array(0)->reg(ra_,this)/* dst */);
    __ fcmpd(s1, 0.0);
    // installs 0 if EQ else -1
    __ csinvw(d, zr, zr, Assembler::EQ);
    // keeps -1 if less or unordered else installs 1
    __ csnegw(d, d, d, Assembler::LT);
    __ bind(done);
  
#line 30401 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16163 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cmpw(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* p */), as_Register(opnd_array(2)->reg(ra_,this,idx2)/* q */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::LT);
    __ subw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), zr, as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 30420 "ad_aarch64.cpp"
  }
}

void cmpLTMask_reg_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16181 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ asrw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */), 31);
  
#line 30437 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16198 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::LT);
  
#line 30458 "ad_aarch64.cpp"
  }
}

void cmovI_reg_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16229 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ cselw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
             as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
             as_Register(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
             Assembler::GT);
  
#line 30479 "ad_aarch64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3759 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(1)->label();
    __ b(*L);
  
#line 30496 "ad_aarch64.cpp"
  }
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3765 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30515 "ad_aarch64.cpp"
  }
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3771 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30534 "ad_aarch64.cpp"
  }
}

void cmpI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16320 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30558 "ad_aarch64.cpp"
  }
}

void cmpL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16337 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30582 "ad_aarch64.cpp"
  }
}

void cmpP_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16354 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30606 "ad_aarch64.cpp"
  }
}

void cmpN_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16371 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30630 "ad_aarch64.cpp"
  }
}

void cmpP_narrowOop_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16388 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* oop */, *L);
  
#line 30654 "ad_aarch64.cpp"
  }
}

void cmpUI_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16405 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnzw(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30678 "ad_aarch64.cpp"
  }
}

void cmpUL_imm0_branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16422 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    if (cond == Assembler::EQ || cond == Assembler::LS)
      __ cbz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
    else
      __ cbnz(opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, *L);
  
#line 30702 "ad_aarch64.cpp"
  }
}

void cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16442 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L);
  
#line 30724 "ad_aarch64.cpp"
  }
}

void cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16458 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L);
  
#line 30746 "ad_aarch64.cpp"
  }
}

void cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16475 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 30769 "ad_aarch64.cpp"
  }
}

void cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16492 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L);
  
#line 30792 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16509 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 63, *L, /*far*/true);
  
#line 30814 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_signNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16524 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(4)->label();
    Assembler::Condition cond =
      ((Assembler::Condition)opnd_array(1)->ccode()== Assembler::LT) ? Assembler::NE : Assembler::EQ;
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, 31, *L, /*far*/true);
  
#line 30836 "ad_aarch64.cpp"
  }
}

void far_cmpL_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16540 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2_long(opnd_array(3)->constantL());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 30859 "ad_aarch64.cpp"
  }
}

void far_cmpI_branch_bitNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// labl
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16556 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    Label* L = opnd_array(5)->label();
    Assembler::Condition cond = (Assembler::Condition)opnd_array(1)->ccode();
    int bit = exact_log2((juint)opnd_array(3)->constant());
    __ tbr(cond, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, bit, *L, /*far*/true);
  
#line 30882 "ad_aarch64.cpp"
  }
}

void cmpL_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16574 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
  
#line 30900 "ad_aarch64.cpp"
  }
}

void cmpI_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16587 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 30918 "ad_aarch64.cpp"
  }
}

void cmpL_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16598 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30936 "ad_aarch64.cpp"
  }
}

void cmpI_and_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16609 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ tstw(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 30954 "ad_aarch64.cpp"
  }
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3765 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30973 "ad_aarch64.cpp"
  }
}

void branchLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3771 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Label *L = opnd_array(3)->label();
    __ br ((Assembler::Condition)opnd_array(1)->ccode(), *L);
  
#line 30992 "ad_aarch64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 3920 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;
    Label cas_failed;

    assert_different_registers(oop, box, tmp, disp_hdr);

    // Load markWord from object into displaced_header.
    __ ldr(disp_hdr, Address(oop, oopDesc::mark_offset_in_bytes()));

    if (DiagnoseSyncOnValueBasedClasses != 0) {
      __ load_klass(tmp, oop);
      __ ldrw(tmp, Address(tmp, Klass::access_flags_offset()));
      __ tstw(tmp, JVM_ACC_IS_VALUE_BASED_CLASS);
      __ br(Assembler::NE, cont);
    }

    // Check for existing monitor
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Set tmp to be (markWord of object | UNLOCK_VALUE).
      __ orr(tmp, disp_hdr, markWord::unlocked_value);

      // Initialize the box. (Must happen before we update the object mark!)
      __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // Compare object markWord with an unlocked value (tmp) and if
      // equal exchange the stack address of our box with object markWord.
      // On failure disp_hdr contains the possibly locked markWord.
      __ cmpxchg(oop, tmp, box, Assembler::xword, /*acquire*/ true,
                 /*release*/ true, /*weak*/ false, disp_hdr);
      __ br(Assembler::EQ, cont);

      assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

      // If the compare-and-exchange succeeded, then we found an unlocked
      // object, will have now locked it will continue at label cont

      __ bind(cas_failed);
      // We did not see an unlocked object so try the fast recursive case.

      // Check if the owner is self by comparing the value in the
      // markWord of object (disp_hdr) with the stack pointer.
      __ mov(rscratch1, sp);
      __ sub(disp_hdr, disp_hdr, rscratch1);
      __ mov(tmp, (address) (~(os::vm_page_size()-1) | markWord::lock_mask_in_place));
      // If condition is true we are cont and hence we can store 0 as the
      // displaced header in the box, which indicates that it is a recursive lock.
      __ ands(tmp/*==0?*/, disp_hdr, tmp);   // Sets flags for result
      __ str(tmp/*==0, perhaps*/, Address(box, BasicLock::displaced_header_offset_in_bytes()));
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    // Handle existing monitor.
    __ bind(object_has_monitor);

    // The object's monitor m is unlocked iff m->owner == NULL,
    // otherwise m->owner may contain a thread or a stack address.
    //
    // Try to CAS m->owner from NULL to current thread.
    __ add(tmp, disp_hdr, (ObjectMonitor::owner_offset_in_bytes()-markWord::monitor_value));
    __ cmpxchg(tmp, zr, rthread, Assembler::xword, /*acquire*/ true,
               /*release*/ true, /*weak*/ false, rscratch1); // Sets flags for result

    // Store a non-null value into the box to avoid looking like a re-entrant
    // lock. The fast-path monitor unlock code checks for
    // markWord::monitor_value so use markWord::unused_mark which has the
    // relevant bit set, and also matches ObjectSynchronizer::enter.
    __ mov(tmp, (address)markWord::unused_mark().value());
    __ str(tmp, Address(box, BasicLock::displaced_header_offset_in_bytes()));

    __ br(Assembler::EQ, cont); // CAS success means locking succeeded

    __ cmp(rscratch1, rthread);
    __ br(Assembler::NE, cont); // Check for recursive locking

    // Recursive lock case
    __ increment(Address(disp_hdr, ObjectMonitor::recursions_offset_in_bytes() - markWord::monitor_value), 1);
    // flag == EQ still from the cmp above, checking if this is a reentrant lock

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 31099 "ad_aarch64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {

#line 4013 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register oop = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* object */);
    Register box = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* box */);
    Register disp_hdr = as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp */);
    Register tmp = as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */);
    Label cont;
    Label object_has_monitor;

    assert_different_registers(oop, box, tmp, disp_hdr);

    if (!UseHeavyMonitors) {
      // Find the lock address and load the displaced header from the stack.
      __ ldr(disp_hdr, Address(box, BasicLock::displaced_header_offset_in_bytes()));

      // If the displaced header is 0, we have a recursive unlock.
      __ cmp(disp_hdr, zr);
      __ br(Assembler::EQ, cont);
    }

    // Handle existing monitor.
    __ ldr(tmp, Address(oop, oopDesc::mark_offset_in_bytes()));
    __ tbnz(disp_hdr, exact_log2(markWord::monitor_value), object_has_monitor);

    if (!UseHeavyMonitors) {
      // Check if it is still a light weight lock, this is is true if we
      // see the stack address of the basicLock in the markWord of the
      // object.

      __ cmpxchg(oop, box, disp_hdr, Assembler::xword, /*acquire*/ false,
                 /*release*/ true, /*weak*/ false, tmp);
    } else {
      __ tst(oop, oop); // Set NE to indicate 'failure' -> take slow-path. We know that oop != 0.
    }
    __ b(cont);

    assert(oopDesc::mark_offset_in_bytes() == 0, "offset of _mark is not 0");

    // Handle existing monitor.
    __ bind(object_has_monitor);
    STATIC_ASSERT(markWord::monitor_value <= INT_MAX);
    __ add(tmp, tmp, -(int)markWord::monitor_value); // monitor
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));

    Label notRecursive;
    __ cbz(disp_hdr, notRecursive);

    // Recursive lock
    __ sub(disp_hdr, disp_hdr, 1u);
    __ str(disp_hdr, Address(tmp, ObjectMonitor::recursions_offset_in_bytes()));
    __ cmp(disp_hdr, disp_hdr); // Sets flags for result
    __ b(cont);

    __ bind(notRecursive);
    __ ldr(rscratch1, Address(tmp, ObjectMonitor::EntryList_offset_in_bytes()));
    __ ldr(disp_hdr, Address(tmp, ObjectMonitor::cxq_offset_in_bytes()));
    __ orr(rscratch1, rscratch1, disp_hdr); // Will be 0 if both are 0.
    __ cmp(rscratch1, zr); // Sets flags for result
    __ cbnz(rscratch1, cont);
    // need a release store here
    __ lea(tmp, Address(tmp, ObjectMonitor::owner_offset_in_bytes()));
    __ stlr(zr, tmp); // set unowned

    __ bind(cont);
    // flag == EQ indicates success
    // flag == NE indicates failure
  
#line 31181 "ad_aarch64.cpp"
  }
}

void safePointNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// cr
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16704 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ read_polling_page(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* poll */), relocInfo::poll_type);
  
#line 31197 "ad_aarch64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3795 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    address addr = (address)opnd_array(1)->method();
    address call;
    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      call = __ trampoline_call(Address(addr, relocInfo::runtime_call_type), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      call = __ trampoline_call(Address(addr, rspec), &cbuf);
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      // Emit stub for static call
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }

    _masm.clear_inst_mark();
    __ post_call_nop();

    // Only non uncommon_trap calls need to reinitialize ptrue.
    if (Compile::current()->max_vector_size() > 0 && uncommon_trap_request() == 0) {
      __ reinitialize_ptrue();
    }
  
#line 31246 "ad_aarch64.cpp"
  }
  {

#line 3848 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 31258 "ad_aarch64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3833 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    int method_index = resolved_method_index(cbuf);
    address call = __ ic_call((address)opnd_array(1)->method(), method_index);
    if (call == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
    _masm.clear_inst_mark();
    __ post_call_nop();
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 31284 "ad_aarch64.cpp"
  }
  {

#line 3848 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      __ call_Unimplemented();
    }
  
#line 31296 "ad_aarch64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3856 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      _masm.clear_inst_mark();
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 31340 "ad_aarch64.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3856 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      _masm.clear_inst_mark();
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 31384 "ad_aarch64.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3856 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);

    // some calls to generated routines (arraycopy code) are scheduled
    // by C2 as runtime calls. if so we can call them using a br (they
    // will be in a reachable segment) otherwise we have to use a blr
    // which loads the absolute address into a register.
    address entry = (address)opnd_array(1)->method();
    CodeBlob *cb = CodeCache::find_blob(entry);
    if (cb) {
      address call = __ trampoline_call(Address(entry, relocInfo::runtime_call_type));
      if (call == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
      _masm.clear_inst_mark();
      __ post_call_nop();
    } else {
      Label retaddr;
      __ adr(rscratch2, retaddr);
      __ lea(rscratch1, RuntimeAddress(entry));
      // Leave a breadcrumb for JavaFrameAnchor::capture_last_Java_pc()
      __ stp(zr, rscratch2, Address(__ pre(sp, -2 * wordSize)));
      __ blr(rscratch1);
      __ bind(retaddr);
      __ post_call_nop();
      __ add(sp, sp, 2 * wordSize);
    }
    if (Compile::current()->max_vector_size() > 0) {
      __ reinitialize_ptrue();
    }
  
#line 31428 "ad_aarch64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3904 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    __ br(target_reg);
  
#line 31446 "ad_aarch64.cpp"
  }
}

void TailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {

#line 3910 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register target_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* jump_target */);
    // exception oop should be in r0
    // ret addr has been popped into lr
    // callee expects it in r3
    __ mov(r3, lr);
    __ br(target_reg);
  
#line 31468 "ad_aarch64.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3889 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ far_jump(RuntimeAddress(OptoRuntime::rethrow_stub()));
  
#line 31497 "ad_aarch64.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3894 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    C2_MacroAssembler _masm(&cbuf);
#ifdef ASSERT
    if (Compile::current()->max_vector_size() > 0) {
      __ verify_ptrue();
    }
#endif
    __ ret(lr);
  
#line 31518 "ad_aarch64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16884 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    if (is_reachable()) {
      __ stop(_halt_reason);
    }
  
#line 31536 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {

#line 3778 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(opnd_array(0)->reg(ra_,this)/* result */);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x1 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 31565 "ad_aarch64.cpp"
  }
}

void partialSubtypeCheckVsZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {

#line 3778 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

     Register sub_reg = as_Register(opnd_array(1)->reg(ra_,this,idx1)/* sub */);
     Register super_reg = as_Register(opnd_array(2)->reg(ra_,this,idx2)/* super */);
     Register temp_reg = as_Register(R2_enc);
     Register result_reg = as_Register(R5_enc);

     Label miss;
     C2_MacroAssembler _masm(&cbuf);
     __ check_klass_subtype_slow_path(sub_reg, super_reg, temp_reg, result_reg,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
     if ((0x0 /*primary()*/)) {
       __ mov(result_reg, zr);
     }
     __ bind(miss);
  
#line 31595 "ad_aarch64.cpp"
  }
}

void string_compareUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16939 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, pnoreg, pnoreg, StrIntrinsicNode::UU);
  
#line 31618 "ad_aarch64.cpp"
  }
}

void string_compareLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      fnoreg, fnoreg, fnoreg, pnoreg, pnoreg, StrIntrinsicNode::LL);
  
#line 31640 "ad_aarch64.cpp"
  }
}

void string_compareULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16976 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), pnoreg, pnoreg, StrIntrinsicNode::UL);
  
#line 31663 "ad_aarch64.cpp"
  }
}

void string_compareLUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 16996 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      as_Register(R10_enc), as_Register(R11_enc),
                      as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                      as_FloatRegister(V2_enc), pnoreg, pnoreg, StrIntrinsicNode::LU);
  
#line 31686 "ad_aarch64.cpp"
  }
}

void string_indexofUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17016 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 31716 "ad_aarch64.cpp"
  }
}

void string_indexofLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17037 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 31746 "ad_aarch64.cpp"
  }
}

void string_indexofULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp6
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17058 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */,
                      opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp6 */,
                      -1, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 31776 "ad_aarch64.cpp"
  }
}

void string_indexof_conUUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UU);
  
#line 31804 "ad_aarch64.cpp"
  }
}

void string_indexof_conLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17100 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::LL);
  
#line 31832 "ad_aarch64.cpp"
  }
}

void string_indexof_conULNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// int_cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17121 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, zr,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, zr, zr,
                      icnt2, opnd_array(0)->as_Register(ra_,this)/* result */, StrIntrinsicNode::UL);
  
#line 31860 "ad_aarch64.cpp"
  }
}

void string_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17143 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ string_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                           opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 31883 "ad_aarch64.cpp"
  }
}

void stringL_indexof_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17162 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ stringL_indexof_char(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */,
                            opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */,
                            opnd_array(6)->as_Register(ra_,this,idx6)/* tmp3 */);
  
#line 31906 "ad_aarch64.cpp"
  }
}

void string_equalsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17178 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 1);
  
#line 31926 "ad_aarch64.cpp"
  }
}

void string_equalsUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17194 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */,
                     opnd_array(0)->as_Register(ra_,this)/* result */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, 2);
  
#line 31946 "ad_aarch64.cpp"
  }
}

void array_equalsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17211 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 1);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31972 "ad_aarch64.cpp"
  }
}

void array_equalsCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ary2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17232 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* ary2 */,
                                   opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */,
                                   opnd_array(0)->as_Register(ra_,this)/* result */, as_Register(R10_enc), 2);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 31998 "ad_aarch64.cpp"
  }
}

void count_positivesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// ary1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17249 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ count_positives(opnd_array(1)->as_Register(ra_,this,idx1)/* ary1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* len */, opnd_array(0)->as_Register(ra_,this)/* result */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 32019 "ad_aarch64.cpp"
  }
}

void string_compressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17270 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ char_array_compress(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                           opnd_array(0)->as_Register(ra_,this)/* result */,
                           opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                           opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* tmp4 */);
  
#line 32044 "ad_aarch64.cpp"
  }
}

void string_inflateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp4
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17287 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    address tpc = __ byte_array_inflate(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                                        opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* tmp1 */, opnd_array(5)->as_FloatRegister(ra_,this,idx5)/* tmp2 */,
                                        opnd_array(6)->as_FloatRegister(ra_,this,idx6)/* tmp3 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp4 */);
    if (tpc == NULL) {
      ciEnv::current()->record_failure("CodeCache is full");
      return;
    }
  
#line 32072 "ad_aarch64.cpp"
  }
}

void encode_iso_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17311 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(0)->as_Register(ra_,this)/* result */, false,
                        as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                        as_FloatRegister(V2_enc), as_FloatRegister(V3_enc));
  
#line 32093 "ad_aarch64.cpp"
  }
}

void encode_ascii_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 17331 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    __ encode_iso_array(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* len */,
                        opnd_array(0)->as_Register(ra_,this)/* result */, true,
                        as_FloatRegister(V0_enc), as_FloatRegister(V1_enc),
                        as_FloatRegister(V2_enc), as_FloatRegister(V3_enc));
  
#line 32114 "ad_aarch64.cpp"
  }
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void loadV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3163 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32144 "ad_aarch64.cpp"
  }
}

void loadV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3169 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32161 "ad_aarch64.cpp"
  }
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3175 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32178 "ad_aarch64.cpp"
  }
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3181 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32195 "ad_aarch64.cpp"
  }
}

void storeV2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3187 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32213 "ad_aarch64.cpp"
  }
}

void storeV4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3193 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32231 "ad_aarch64.cpp"
  }
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3199 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32249 "ad_aarch64.cpp"
  }
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3205 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 32267 "ad_aarch64.cpp"
  }
}

void reinterpretDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 128 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 32283 "ad_aarch64.cpp"
  }
}

void reinterpretXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 141 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 32299 "ad_aarch64.cpp"
  }
}

void reinterpretD2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 154 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher 64-bits of the "dst" register must be cleared to zero.
    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32318 "ad_aarch64.cpp"
  }
}

void reinterpretX2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 170 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher 64-bits of the "dst" register must be cleared to zero.
    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32337 "ad_aarch64.cpp"
  }
}

void reinterpretS2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 186 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32354 "ad_aarch64.cpp"
  }
}

void reinterpretX2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 200 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32371 "ad_aarch64.cpp"
  }
}

void reinterpretS2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 214 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32388 "ad_aarch64.cpp"
  }
}

void reinterpretD2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 228 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // The higher bits of the "dst" register must be cleared to zero.
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32405 "ad_aarch64.cpp"
  }
}

void vcvt8Bto8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 242 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 32421 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 32437 "ad_aarch64.cpp"
  }
}

void vcvt8Sto8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 32453 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 275 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
  
#line 32469 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 286 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
  
#line 32485 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 297 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
  
#line 32501 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 308 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 32517 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 319 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 32533 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 332 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
  
#line 32550 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 346 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 32567 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 364 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 0);
    __ scvtfs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), rscratch1);
    __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 1);
    __ scvtfs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), rscratch1);
    __ ins(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), 1, 0);
  
#line 32589 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 379 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32605 "ad_aarch64.cpp"
  }
}

void vcvt4Ito4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 390 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32621 "ad_aarch64.cpp"
  }
}

void vcvt2Lto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 401 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32637 "ad_aarch64.cpp"
  }
}

void vcvt4Sto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 414 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 32654 "ad_aarch64.cpp"
  }
}

void vcvt2Ito2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 428 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
    __ scvtfv(__ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 32671 "ad_aarch64.cpp"
  }
}

void vcvt4Bto4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 443 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ sxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ scvtfv(__ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 32689 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 458 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 32706 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 470 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32722 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 481 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32738 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 492 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 32754 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 505 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
  
#line 32771 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 523 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, 1);
    // We can't use fcvtzs(vector, integer) instruction here because we need
    // saturation arithmetic. See JDK-8276151.
    __ fcvtzdw(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ fcvtzdw(rscratch2, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
    __ fmovs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), rscratch1);
    __ mov(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, 1, rscratch2);
  
#line 32794 "ad_aarch64.cpp"
  }
}

void vcvt4Fto4BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 543 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
  
#line 32812 "ad_aarch64.cpp"
  }
}

void vcvt2Fto2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 556 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2S);
  
#line 32828 "ad_aarch64.cpp"
  }
}

void vcvt2Dto2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 567 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fcvtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
  
#line 32844 "ad_aarch64.cpp"
  }
}

void vroundvecD2Fto2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 581 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ vector_round_neon(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                         as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp3 */), __ T2S);
  
#line 32866 "ad_aarch64.cpp"
  }
}

void vroundvecX4Fto4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 596 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ vector_round_neon(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                         as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp3 */), __ T4S);
  
#line 32888 "ad_aarch64.cpp"
  }
}

void vroundvecX2Dto2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 611 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ vector_round_neon(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                         as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp3 */), __ T2D);
  
#line 32910 "ad_aarch64.cpp"
  }
}

void reduce_add8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 632 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32932 "ad_aarch64.cpp"
  }
}

void reduce_add16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 652 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32954 "ad_aarch64.cpp"
  }
}

void reduce_add4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 672 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32976 "ad_aarch64.cpp"
  }
}

void reduce_add8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 692 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ addw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 32998 "ad_aarch64.cpp"
  }
}

void reduce_add2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, 0);
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33019 "ad_aarch64.cpp"
  }
}

void reduce_mul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 735 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33053 "ad_aarch64.cpp"
  }
}

void reduce_mul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 773 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T8B,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ B, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33091 "ad_aarch64.cpp"
  }
}

void reduce_mul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 811 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33120 "ad_aarch64.cpp"
  }
}

void reduce_mul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 843 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), __ T4H,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ S,
           as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ T4H,
            as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */));
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 0);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ umov(opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), __ H, 1);
    __ mulw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(6)->as_Register(ra_,this,idx6)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33154 "ad_aarch64.cpp"
  }
}

void reduce_mul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 872 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 33176 "ad_aarch64.cpp"
  }
}

void reduce_max8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 892 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33198 "ad_aarch64.cpp"
  }
}

void reduce_max16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 912 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33220 "ad_aarch64.cpp"
  }
}

void reduce_max4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 932 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33242 "ad_aarch64.cpp"
  }
}

void reduce_max8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 952 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33264 "ad_aarch64.cpp"
  }
}

void reduce_max4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 972 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33286 "ad_aarch64.cpp"
  }
}

void reduce_min8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 992 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33308 "ad_aarch64.cpp"
  }
}

void reduce_min16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1012 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T16B, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ B, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33330 "ad_aarch64.cpp"
  }
}

void reduce_min4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1032 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33352 "ad_aarch64.cpp"
  }
}

void reduce_min8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1052 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T8H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ smov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ H, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33374 "ad_aarch64.cpp"
  }
}

void reduce_min4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1072 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33396 "ad_aarch64.cpp"
  }
}

void reduce_max2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1092 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smaxp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::GT);
  
#line 33418 "ad_aarch64.cpp"
  }
}

void reduce_min2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1112 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sminp(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T2S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S, 0);
    __ cmpw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */));
    __ cselw(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), Assembler::LT);
  
#line 33440 "ad_aarch64.cpp"
  }
}

void reduce_max2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1134 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::GT);
  
#line 33464 "ad_aarch64.cpp"
  }
}

void reduce_min2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1158 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ cmp(as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(1)->reg(ra_,this,idx1)/* isrc */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
    __ umov(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ cmp(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ csel(as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), Assembler::LT);
  
#line 33488 "ad_aarch64.cpp"
  }
}

void reduce_max2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1176 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 33507 "ad_aarch64.cpp"
  }
}

void reduce_max4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1190 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 33526 "ad_aarch64.cpp"
  }
}

void reduce_max2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1204 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmaxp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 33545 "ad_aarch64.cpp"
  }
}

void reduce_min2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1218 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S);
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 33564 "ad_aarch64.cpp"
  }
}

void reduce_min4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1232 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */));
  
#line 33583 "ad_aarch64.cpp"
  }
}

void reduce_min2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1246 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fminp(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D);
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */));
  
#line 33602 "ad_aarch64.cpp"
  }
}

void reduce_and8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1267 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33627 "ad_aarch64.cpp"
  }
}

void reduce_orr8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1293 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33652 "ad_aarch64.cpp"
  }
}

void reduce_eor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1319 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33677 "ad_aarch64.cpp"
  }
}

void reduce_and16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1346 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33703 "ad_aarch64.cpp"
  }
}

void reduce_orr16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1374 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33729 "ad_aarch64.cpp"
  }
}

void reduce_eor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1402 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 8);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxtb(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33755 "ad_aarch64.cpp"
  }
}

void reduce_and4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1428 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33779 "ad_aarch64.cpp"
  }
}

void reduce_orr4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1452 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33803 "ad_aarch64.cpp"
  }
}

void reduce_eor4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1476 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33827 "ad_aarch64.cpp"
  }
}

void reduce_and8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1501 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33852 "ad_aarch64.cpp"
  }
}

void reduce_orr8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1527 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33877 "ad_aarch64.cpp"
  }
}

void reduce_eor8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1553 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 16);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
    __ sxth(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33902 "ad_aarch64.cpp"
  }
}

void reduce_and2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1576 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33924 "ad_aarch64.cpp"
  }
}

void reduce_orr2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1596 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33946 "ad_aarch64.cpp"
  }
}

void reduce_eor2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1616 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33968 "ad_aarch64.cpp"
  }
}

void reduce_and4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1637 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ andw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 33991 "ad_aarch64.cpp"
  }
}

void reduce_orr4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1659 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ orrw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 34014 "ad_aarch64.cpp"
  }
}

void reduce_eor4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1681 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Assembler::LSR, 32);
    __ eorw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 34037 "ad_aarch64.cpp"
  }
}

void reduce_and2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1702 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 34059 "ad_aarch64.cpp"
  }
}

void reduce_orr2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1722 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ orr (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 34081 "ad_aarch64.cpp"
  }
}

void reduce_eor2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1742 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 0);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ D, 1);
    __ eor (opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 34103 "ad_aarch64.cpp"
  }
}

void insertIDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1762 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(Matcher::vector_element_basic_type(this)),
           opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 34126 "ad_aarch64.cpp"
  }
}

void insertIXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1782 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(Matcher::vector_element_basic_type(this)),
           opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 34149 "ad_aarch64.cpp"
  }
}

void insert2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1800 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
           opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 34172 "ad_aarch64.cpp"
  }
}

void insert2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1819 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 34194 "ad_aarch64.cpp"
  }
}

void insert4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1836 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 34216 "ad_aarch64.cpp"
  }
}

void insert2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1853 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 34238 "ad_aarch64.cpp"
  }
}

void extract8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1870 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 34255 "ad_aarch64.cpp"
  }
}

void extract16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1882 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 34272 "ad_aarch64.cpp"
  }
}

void extract4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1894 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 34289 "ad_aarch64.cpp"
  }
}

void extract8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1906 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 34306 "ad_aarch64.cpp"
  }
}

void extract2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1918 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 34323 "ad_aarch64.cpp"
  }
}

void extract4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1930 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 34340 "ad_aarch64.cpp"
  }
}

void extract2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1942 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, opnd_array(2)->constant());
  
#line 34357 "ad_aarch64.cpp"
  }
}

void extract2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1954 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if ((0 == opnd_array(2)->constant()) &&
        (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) == as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */))) {
      /* empty */
    } else if (opnd_array(2)->constant()== 0) {
      __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
    }
  
#line 34382 "ad_aarch64.cpp"
  }
}

void extract4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1974 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if ((0 == opnd_array(2)->constant()) &&
        (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) == as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */))) {
      /* empty */
    } else if (opnd_array(2)->constant()== 0) {
      __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
    }
  
#line 34407 "ad_aarch64.cpp"
  }
}

void extract2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1994 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    if ((0 == opnd_array(2)->constant()) &&
        (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) == as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */))) {
      /* empty */
    } else if (opnd_array(2)->constant()== 0) {
      __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, opnd_array(2)->constant());
    }
  
#line 34432 "ad_aarch64.cpp"
  }
}

void vcmpDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2016 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    assert(type2aelembytes(bt) != 8, "not supported");
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ false);
  
#line 34453 "ad_aarch64.cpp"
  }
}

void vcmpXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2031 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_compare(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                    as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant(), /*isQ*/ true);
  
#line 34473 "ad_aarch64.cpp"
  }
}

void vmul2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2056 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 0);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 0);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 0, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    __ umov(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), __ D, 1);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), __ D, 1);
    __ mul(as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */), as_Register(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */));
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 1, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
  
#line 34499 "ad_aarch64.cpp"
  }
}

void vnot2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34517 "ad_aarch64.cpp"
  }
}

void vnot2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34535 "ad_aarch64.cpp"
  }
}

void vnot2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34553 "ad_aarch64.cpp"
  }
}

void vnot2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34571 "ad_aarch64.cpp"
  }
}

void vnot2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34589 "ad_aarch64.cpp"
  }
}

void vnot2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2079 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34607 "ad_aarch64.cpp"
  }
}

void vnot4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34625 "ad_aarch64.cpp"
  }
}

void vnot4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34643 "ad_aarch64.cpp"
  }
}

void vnot4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34661 "ad_aarch64.cpp"
  }
}

void vnot4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34679 "ad_aarch64.cpp"
  }
}

void vnot4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34697 "ad_aarch64.cpp"
  }
}

void vnot4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34715 "ad_aarch64.cpp"
  }
}

void vnot2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2107 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 34733 "ad_aarch64.cpp"
  }
}

void vnot2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2107 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ notr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 34751 "ad_aarch64.cpp"
  }
}

void vand_not2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34770 "ad_aarch64.cpp"
  }
}

void vand_not2I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34789 "ad_aarch64.cpp"
  }
}

void vand_not2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34808 "ad_aarch64.cpp"
  }
}

void vand_not2I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34827 "ad_aarch64.cpp"
  }
}

void vand_not2I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34846 "ad_aarch64.cpp"
  }
}

void vand_not2I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34865 "ad_aarch64.cpp"
  }
}

void vand_not2I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34884 "ad_aarch64.cpp"
  }
}

void vand_not2I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34903 "ad_aarch64.cpp"
  }
}

void vand_not2I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34922 "ad_aarch64.cpp"
  }
}

void vand_not2I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 34941 "ad_aarch64.cpp"
  }
}

void vand_not2I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 34960 "ad_aarch64.cpp"
  }
}

void vand_not2I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2124 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34979 "ad_aarch64.cpp"
  }
}

void vand_not4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 34998 "ad_aarch64.cpp"
  }
}

void vand_not4I_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 35017 "ad_aarch64.cpp"
  }
}

void vand_not4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35036 "ad_aarch64.cpp"
  }
}

void vand_not4I_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35055 "ad_aarch64.cpp"
  }
}

void vand_not4I_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35074 "ad_aarch64.cpp"
  }
}

void vand_not4I_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 35093 "ad_aarch64.cpp"
  }
}

void vand_not4I_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35112 "ad_aarch64.cpp"
  }
}

void vand_not4I_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35131 "ad_aarch64.cpp"
  }
}

void vand_not4I_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35150 "ad_aarch64.cpp"
  }
}

void vand_not4I_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 35169 "ad_aarch64.cpp"
  }
}

void vand_not4I_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35188 "ad_aarch64.cpp"
  }
}

void vand_not4I_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2139 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35207 "ad_aarch64.cpp"
  }
}

void vand_not2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2152 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35226 "ad_aarch64.cpp"
  }
}

void vand_not2L_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2152 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 35245 "ad_aarch64.cpp"
  }
}

void vand_not2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2152 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 35264 "ad_aarch64.cpp"
  }
}

void vand_not2L_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2152 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35283 "ad_aarch64.cpp"
  }
}

void vmax8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2168 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35302 "ad_aarch64.cpp"
  }
}

void vmax16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2182 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35321 "ad_aarch64.cpp"
  }
}

void vmax4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2196 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35340 "ad_aarch64.cpp"
  }
}

void vmax8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2210 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35359 "ad_aarch64.cpp"
  }
}

void vmax2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2224 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35378 "ad_aarch64.cpp"
  }
}

void vmax4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2238 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ maxv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35397 "ad_aarch64.cpp"
  }
}

void vmin8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2253 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35416 "ad_aarch64.cpp"
  }
}

void vmin16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2267 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35435 "ad_aarch64.cpp"
  }
}

void vmin4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2281 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35454 "ad_aarch64.cpp"
  }
}

void vmin8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2295 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35473 "ad_aarch64.cpp"
  }
}

void vmin2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2309 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35492 "ad_aarch64.cpp"
  }
}

void vmin4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2323 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ minv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35511 "ad_aarch64.cpp"
  }
}

void vmax2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2340 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 35532 "ad_aarch64.cpp"
  }
}

void vmin2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2357 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cmgt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 35553 "ad_aarch64.cpp"
  }
}

void vbsl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2374 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 35572 "ad_aarch64.cpp"
  }
}

void vbsl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2387 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ bsl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 35591 "ad_aarch64.cpp"
  }
}

void loadmask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2402 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35607 "ad_aarch64.cpp"
  }
}

void loadmask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2414 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35623 "ad_aarch64.cpp"
  }
}

void storemask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2426 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35640 "ad_aarch64.cpp"
  }
}

void storemask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2438 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35657 "ad_aarch64.cpp"
  }
}

void loadmask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2451 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35674 "ad_aarch64.cpp"
  }
}

void loadmask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2465 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35691 "ad_aarch64.cpp"
  }
}

void storemask4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2479 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35709 "ad_aarch64.cpp"
  }
}

void storemask8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2493 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35727 "ad_aarch64.cpp"
  }
}

void loadmask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2510 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35745 "ad_aarch64.cpp"
  }
}

void loadmask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2528 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35763 "ad_aarch64.cpp"
  }
}

void storemask2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2544 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35782 "ad_aarch64.cpp"
  }
}

void storemask4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2560 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35801 "ad_aarch64.cpp"
  }
}

void loadmask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2579 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35820 "ad_aarch64.cpp"
  }
}

void storemask2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2597 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T2D);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S);
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 35840 "ad_aarch64.cpp"
  }
}

void vmaskcastDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2616 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 35856 "ad_aarch64.cpp"
  }
}

void vmaskcastXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2630 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // empty
  
#line 35872 "ad_aarch64.cpp"
  }
}

void loadcon8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2647 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 35889 "ad_aarch64.cpp"
  }
}

void loadcon16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2660 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ lea(rscratch1, ExternalAddress(StubRoutines::aarch64::vector_iota_indices()));
    __ ldrq(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), rscratch1);
  
#line 35906 "ad_aarch64.cpp"
  }
}

void loadshuffle8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2676 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35923 "ad_aarch64.cpp"
  }
}

void loadshuffle16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2690 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 35940 "ad_aarch64.cpp"
  }
}

void loadshuffle4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2704 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 35956 "ad_aarch64.cpp"
  }
}

void loadshuffle8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2717 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
  
#line 35972 "ad_aarch64.cpp"
  }
}

void loadshuffle4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2732 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ T8B);
    __ uxtl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H);
  
#line 35989 "ad_aarch64.cpp"
  }
}

void rearrange8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2768 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 36008 "ad_aarch64.cpp"
  }
}

void rearrange16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2783 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 36027 "ad_aarch64.cpp"
  }
}

void rearrange4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2802 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T8B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 36054 "ad_aarch64.cpp"
  }
}

void rearrange8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2827 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x02);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T8H, 0x0100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 36081 "ad_aarch64.cpp"
  }
}

void rearrange4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp0
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2853 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */), __ T16B, 0x04);
    __ mov(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ T4S, 0x03020100);
    __ mulv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp0 */));
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */));
    __ tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 36108 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2878 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 36130 "ad_aarch64.cpp"
  }
}

void anytrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2898 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, zr);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::NE);
  
#line 36152 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2918 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 36174 "ad_aarch64.cpp"
  }
}

void alltrue_in_mask16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2938 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // No need to use src2.
    __ uminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ B, 0);
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, 0xff);
    __ csetw(opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::EQ);
  
#line 36196 "ad_aarch64.cpp"
  }
}

void vabs8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2956 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36212 "ad_aarch64.cpp"
  }
}

void vabs16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2968 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36228 "ad_aarch64.cpp"
  }
}

void vabs4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2980 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36244 "ad_aarch64.cpp"
  }
}

void vabs8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2992 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36260 "ad_aarch64.cpp"
  }
}

void vabs2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3004 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36276 "ad_aarch64.cpp"
  }
}

void vabs4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3016 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36292 "ad_aarch64.cpp"
  }
}

void vabs2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3028 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ absr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36308 "ad_aarch64.cpp"
  }
}

void vabs2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3040 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36324 "ad_aarch64.cpp"
  }
}

void vabs4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3052 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36340 "ad_aarch64.cpp"
  }
}

void vabs2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3064 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36356 "ad_aarch64.cpp"
  }
}

void vabd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3078 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36374 "ad_aarch64.cpp"
  }
}

void vabd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3091 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36392 "ad_aarch64.cpp"
  }
}

void vabd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3104 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fabd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36410 "ad_aarch64.cpp"
  }
}

void replicate8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3118 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36426 "ad_aarch64.cpp"
  }
}

void replicate16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3130 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36442 "ad_aarch64.cpp"
  }
}

void replicate8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3143 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, opnd_array(1)->constant()& 0xff);
  
#line 36458 "ad_aarch64.cpp"
  }
}

void replicate16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3155 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, opnd_array(1)->constant()& 0xff);
  
#line 36474 "ad_aarch64.cpp"
  }
}

void replicate4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3168 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36490 "ad_aarch64.cpp"
  }
}

void replicate8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3180 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36506 "ad_aarch64.cpp"
  }
}

void replicate4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3193 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H, opnd_array(1)->constant()& 0xffff);
  
#line 36522 "ad_aarch64.cpp"
  }
}

void replicate8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3205 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H, opnd_array(1)->constant()& 0xffff);
  
#line 36538 "ad_aarch64.cpp"
  }
}

void replicate2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3217 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36554 "ad_aarch64.cpp"
  }
}

void replicate4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3229 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36570 "ad_aarch64.cpp"
  }
}

void replicate2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3241 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, opnd_array(1)->constant());
  
#line 36586 "ad_aarch64.cpp"
  }
}

void replicate4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3253 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, opnd_array(1)->constant());
  
#line 36602 "ad_aarch64.cpp"
  }
}

void replicate2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3265 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36618 "ad_aarch64.cpp"
  }
}

void replicate2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3277 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, opnd_array(1)->constantL());
  
#line 36634 "ad_aarch64.cpp"
  }
}

void replicate2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3289 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36650 "ad_aarch64.cpp"
  }
}

void replicate4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3301 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36666 "ad_aarch64.cpp"
  }
}

void replicate2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3313 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 36682 "ad_aarch64.cpp"
  }
}

void reduce_add2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3331 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T2S,
             as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 36704 "ad_aarch64.cpp"
  }
}

void reduce_add4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3350 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ S, 0);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
  
#line 36726 "ad_aarch64.cpp"
  }
}

void reduce_mul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3370 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 36748 "ad_aarch64.cpp"
  }
}

void reduce_mul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// isrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// itmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3392 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ mulv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ T2S,
            as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 0);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* isrc */);
    __ umov(opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ S, 1);
    __ mul(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(5)->as_Register(ra_,this,idx5)/* itmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */);
  
#line 36775 "ad_aarch64.cpp"
  }
}

void reduce_add2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3414 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36799 "ad_aarch64.cpp"
  }
}

void reduce_add4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3438 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fadds(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36831 "ad_aarch64.cpp"
  }
}

void reduce_mul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3466 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36855 "ad_aarch64.cpp"
  }
}

void reduce_mul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// fsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3490 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* fsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 2);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 3);
    __ fmuls(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36887 "ad_aarch64.cpp"
  }
}

void reduce_add2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3518 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ faddd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36911 "ad_aarch64.cpp"
  }
}

void reduce_mul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dsrc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vsrc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3538 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dsrc */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vsrc */), 0, 1);
    __ fmuld(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 36935 "ad_aarch64.cpp"
  }
}

void vadd8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3560 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36954 "ad_aarch64.cpp"
  }
}

void vadd16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3574 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36973 "ad_aarch64.cpp"
  }
}

void vadd4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3589 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 36992 "ad_aarch64.cpp"
  }
}

void vadd8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3603 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37011 "ad_aarch64.cpp"
  }
}

void vadd2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3617 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37030 "ad_aarch64.cpp"
  }
}

void vadd4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3631 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37049 "ad_aarch64.cpp"
  }
}

void vadd2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3645 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ addv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37068 "ad_aarch64.cpp"
  }
}

void vadd2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3659 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37087 "ad_aarch64.cpp"
  }
}

void vadd4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3673 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37106 "ad_aarch64.cpp"
  }
}

void vadd2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3686 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37125 "ad_aarch64.cpp"
  }
}

void vsub8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37144 "ad_aarch64.cpp"
  }
}

void vsub16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3717 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37163 "ad_aarch64.cpp"
  }
}

void vsub4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3732 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37182 "ad_aarch64.cpp"
  }
}

void vsub8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3746 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37201 "ad_aarch64.cpp"
  }
}

void vsub2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3760 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37220 "ad_aarch64.cpp"
  }
}

void vsub4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3774 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37239 "ad_aarch64.cpp"
  }
}

void vsub2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3788 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ subv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37258 "ad_aarch64.cpp"
  }
}

void vsub2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3802 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37277 "ad_aarch64.cpp"
  }
}

void vsub4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3816 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37296 "ad_aarch64.cpp"
  }
}

void vsub2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3830 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37315 "ad_aarch64.cpp"
  }
}

void vmul8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3847 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37334 "ad_aarch64.cpp"
  }
}

void vmul16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3861 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37353 "ad_aarch64.cpp"
  }
}

void vmul4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3876 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37372 "ad_aarch64.cpp"
  }
}

void vmul8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3890 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37391 "ad_aarch64.cpp"
  }
}

void vmul2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3904 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37410 "ad_aarch64.cpp"
  }
}

void vmul4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3918 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mulv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37429 "ad_aarch64.cpp"
  }
}

void vmul2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3932 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37448 "ad_aarch64.cpp"
  }
}

void vmul4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3946 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37467 "ad_aarch64.cpp"
  }
}

void vmul2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3960 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37486 "ad_aarch64.cpp"
  }
}

void vmla4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3977 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37506 "ad_aarch64.cpp"
  }
}

void vmla4S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3977 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37526 "ad_aarch64.cpp"
  }
}

void vmla8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3991 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37546 "ad_aarch64.cpp"
  }
}

void vmla8S_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3991 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37566 "ad_aarch64.cpp"
  }
}

void vmla2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4005 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37586 "ad_aarch64.cpp"
  }
}

void vmla2I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4005 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37606 "ad_aarch64.cpp"
  }
}

void vmla4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4019 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37626 "ad_aarch64.cpp"
  }
}

void vmla4I_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4019 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlav(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37646 "ad_aarch64.cpp"
  }
}

void vmla2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37666 "ad_aarch64.cpp"
  }
}

void vmla4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4049 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37686 "ad_aarch64.cpp"
  }
}

void vmla2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4064 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37706 "ad_aarch64.cpp"
  }
}

void vmls4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4080 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37726 "ad_aarch64.cpp"
  }
}

void vmls8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4093 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37746 "ad_aarch64.cpp"
  }
}

void vmls2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4106 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37766 "ad_aarch64.cpp"
  }
}

void vmls4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4119 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ mlsv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37786 "ad_aarch64.cpp"
  }
}

void vmls2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4134 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37806 "ad_aarch64.cpp"
  }
}

void vmls2F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4134 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37826 "ad_aarch64.cpp"
  }
}

void vmls4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4149 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37846 "ad_aarch64.cpp"
  }
}

void vmls4F_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4149 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37866 "ad_aarch64.cpp"
  }
}

void vmls2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4164 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37886 "ad_aarch64.cpp"
  }
}

void vmls2D_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4164 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src1 */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 37906 "ad_aarch64.cpp"
  }
}

void vmuladdS2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4182 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ smullv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ T4H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ smullv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ addpv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
             as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */),
             as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 37933 "ad_aarch64.cpp"
  }
}

void vdiv2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4204 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37952 "ad_aarch64.cpp"
  }
}

void vdiv4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4218 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37971 "ad_aarch64.cpp"
  }
}

void vdiv2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4232 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fdiv(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 37990 "ad_aarch64.cpp"
  }
}

void vsqrt2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4247 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38006 "ad_aarch64.cpp"
  }
}

void vsqrt4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4258 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38022 "ad_aarch64.cpp"
  }
}

void vsqrt2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4269 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38038 "ad_aarch64.cpp"
  }
}

void vnegIDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4283 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), false);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38056 "ad_aarch64.cpp"
  }
}

void vnegIXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4297 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), true);
    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38074 "ad_aarch64.cpp"
  }
}

void vneg2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4311 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38091 "ad_aarch64.cpp"
  }
}

void vneg2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4324 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38108 "ad_aarch64.cpp"
  }
}

void vneg4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4337 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38125 "ad_aarch64.cpp"
  }
}

void vneg2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4350 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 38142 "ad_aarch64.cpp"
  }
}

void vand8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4366 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38161 "ad_aarch64.cpp"
  }
}

void vand16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4380 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ andr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38180 "ad_aarch64.cpp"
  }
}

void vor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4397 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38199 "ad_aarch64.cpp"
  }
}

void vor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4411 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38218 "ad_aarch64.cpp"
  }
}

void vxor8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4428 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38237 "ad_aarch64.cpp"
  }
}

void vxor16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4442 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 38256 "ad_aarch64.cpp"
  }
}

void vslcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4464 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 38272 "ad_aarch64.cpp"
  }
}

void vslcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4475 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 38288 "ad_aarch64.cpp"
  }
}

void vsrcnt8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B, rscratch1);
  
#line 38305 "ad_aarch64.cpp"
  }
}

void vsrcnt16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4501 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negw(rscratch1, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
    __ dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B, rscratch1);
  
#line 38322 "ad_aarch64.cpp"
  }
}

void vsll8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4513 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38341 "ad_aarch64.cpp"
  }
}

void vsll16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4526 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38360 "ad_aarch64.cpp"
  }
}

void vsra8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4567 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38379 "ad_aarch64.cpp"
  }
}

void vsra8B_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4583 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38401 "ad_aarch64.cpp"
  }
}

void vsra16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4598 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38420 "ad_aarch64.cpp"
  }
}

void vsra16B_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4613 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38442 "ad_aarch64.cpp"
  }
}

void vsrl8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38461 "ad_aarch64.cpp"
  }
}

void vsrl8B_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4645 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38483 "ad_aarch64.cpp"
  }
}

void vsrl16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4660 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38502 "ad_aarch64.cpp"
  }
}

void vsrl16B_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4675 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38524 "ad_aarch64.cpp"
  }
}

void vsll8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4691 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38549 "ad_aarch64.cpp"
  }
}

void vsll16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4710 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38574 "ad_aarch64.cpp"
  }
}

void vsra8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4730 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38594 "ad_aarch64.cpp"
  }
}

void vsra16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4744 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38614 "ad_aarch64.cpp"
  }
}

void vsrl8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4759 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38639 "ad_aarch64.cpp"
  }
}

void vsrl16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4778 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38664 "ad_aarch64.cpp"
  }
}

void vsll4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4797 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38683 "ad_aarch64.cpp"
  }
}

void vsll8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4810 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38702 "ad_aarch64.cpp"
  }
}

void vsra4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4824 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38721 "ad_aarch64.cpp"
  }
}

void vsra4S_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4840 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38743 "ad_aarch64.cpp"
  }
}

void vsra8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4855 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38762 "ad_aarch64.cpp"
  }
}

void vsra8S_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4870 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38784 "ad_aarch64.cpp"
  }
}

void vsrl4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4886 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38803 "ad_aarch64.cpp"
  }
}

void vsrl4S_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4902 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38825 "ad_aarch64.cpp"
  }
}

void vsrl8SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4917 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 38844 "ad_aarch64.cpp"
  }
}

void vsrl8S_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4932 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 38866 "ad_aarch64.cpp"
  }
}

void vsll4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4948 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38891 "ad_aarch64.cpp"
  }
}

void vsll8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4967 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38916 "ad_aarch64.cpp"
  }
}

void vsra4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4987 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38936 "ad_aarch64.cpp"
  }
}

void vsra8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5001 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 38956 "ad_aarch64.cpp"
  }
}

void vsrl4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5016 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 38981 "ad_aarch64.cpp"
  }
}

void vsrl8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5035 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) {
      __ eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 39006 "ad_aarch64.cpp"
  }
}

void vsll2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5054 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39025 "ad_aarch64.cpp"
  }
}

void vsll4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5067 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39044 "ad_aarch64.cpp"
  }
}

void vsra2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5080 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39063 "ad_aarch64.cpp"
  }
}

void vsra2I_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5095 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39085 "ad_aarch64.cpp"
  }
}

void vsra4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5110 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39104 "ad_aarch64.cpp"
  }
}

void vsra4I_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5125 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39126 "ad_aarch64.cpp"
  }
}

void vsrl2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5140 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39145 "ad_aarch64.cpp"
  }
}

void vsrl2I_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5155 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39167 "ad_aarch64.cpp"
  }
}

void vsrl4INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5170 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39186 "ad_aarch64.cpp"
  }
}

void vsrl4I_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5185 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39208 "ad_aarch64.cpp"
  }
}

void vsll2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5200 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 39227 "ad_aarch64.cpp"
  }
}

void vsll4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5213 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 39246 "ad_aarch64.cpp"
  }
}

void vsra2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5226 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39265 "ad_aarch64.cpp"
  }
}

void vsra4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5239 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39284 "ad_aarch64.cpp"
  }
}

void vsrl2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5252 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39303 "ad_aarch64.cpp"
  }
}

void vsrl4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5265 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39322 "ad_aarch64.cpp"
  }
}

void vsll2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5278 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39341 "ad_aarch64.cpp"
  }
}

void vsra2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5291 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39360 "ad_aarch64.cpp"
  }
}

void vsra2L_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5306 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ sshl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39382 "ad_aarch64.cpp"
  }
}

void vsrl2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5321 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 39401 "ad_aarch64.cpp"
  }
}

void vsrl2L_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5336 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ negr(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
    __ ushl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 39423 "ad_aarch64.cpp"
  }
}

void vsll2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5351 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ shl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           (int)opnd_array(2)->constant());
  
#line 39442 "ad_aarch64.cpp"
  }
}

void vsra2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5364 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ sshr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39461 "ad_aarch64.cpp"
  }
}

void vsrl2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5377 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ushr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39480 "ad_aarch64.cpp"
  }
}

void vsraa8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5390 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 39501 "ad_aarch64.cpp"
  }
}

void vsraa8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5390 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 39522 "ad_aarch64.cpp"
  }
}

void vsraa16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5404 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 39543 "ad_aarch64.cpp"
  }
}

void vsraa16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5404 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 8) sh = 7;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 39564 "ad_aarch64.cpp"
  }
}

void vsraa4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 39585 "ad_aarch64.cpp"
  }
}

void vsraa4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 39606 "ad_aarch64.cpp"
  }
}

void vsraa8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
  
#line 39627 "ad_aarch64.cpp"
  }
}

void vsraa8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh >= 16) sh = 15;
    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
  
#line 39648 "ad_aarch64.cpp"
  }
}

void vsraa2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5446 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 39668 "ad_aarch64.cpp"
  }
}

void vsraa2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5446 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39688 "ad_aarch64.cpp"
  }
}

void vsraa4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5459 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 39708 "ad_aarch64.cpp"
  }
}

void vsraa4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5459 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39728 "ad_aarch64.cpp"
  }
}

void vsraa2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5472 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 39748 "ad_aarch64.cpp"
  }
}

void vsraa2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5472 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ ssra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39768 "ad_aarch64.cpp"
  }
}

void vsrla8B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5485 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8B,
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 39790 "ad_aarch64.cpp"
  }
}

void vsrla8B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5485 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8B,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 39812 "ad_aarch64.cpp"
  }
}

void vsrla16B_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5500 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 39834 "ad_aarch64.cpp"
  }
}

void vsrla16B_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5500 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 8) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 39856 "ad_aarch64.cpp"
  }
}

void vsrla4S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5515 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4H,
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 39878 "ad_aarch64.cpp"
  }
}

void vsrla4S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5515 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 39900 "ad_aarch64.cpp"
  }
}

void vsrla8S_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5530 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(3)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), sh);
    }
  
#line 39922 "ad_aarch64.cpp"
  }
}

void vsrla8S_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5530 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    int sh = (int)opnd_array(2)->constant();
    if (sh < 16) {
      __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), sh);
    }
  
#line 39944 "ad_aarch64.cpp"
  }
}

void vsrla2I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5545 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 39964 "ad_aarch64.cpp"
  }
}

void vsrla2I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5545 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 39984 "ad_aarch64.cpp"
  }
}

void vsrla4I_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5558 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 40004 "ad_aarch64.cpp"
  }
}

void vsrla4I_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5558 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 40024 "ad_aarch64.cpp"
  }
}

void vsrla2L_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5571 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
            (int)opnd_array(3)->constant());
  
#line 40044 "ad_aarch64.cpp"
  }
}

void vsrla2L_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5571 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ usra(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
            (int)opnd_array(2)->constant());
  
#line 40064 "ad_aarch64.cpp"
  }
}

void vmax2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5585 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40083 "ad_aarch64.cpp"
  }
}

void vmax4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5599 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40102 "ad_aarch64.cpp"
  }
}

void vmax2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5613 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmax(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40121 "ad_aarch64.cpp"
  }
}

void vmin2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5627 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40140 "ad_aarch64.cpp"
  }
}

void vmin4FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5641 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40159 "ad_aarch64.cpp"
  }
}

void vmin2DNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5655 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ fmin(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 40178 "ad_aarch64.cpp"
  }
}

void vround2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5667 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D,
                  as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 40208 "ad_aarch64.cpp"
  }
}

void vpopcountIDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5691 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (bt == T_SHORT || bt == T_INT) {
      __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8B,
                as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
      if (bt == T_INT) {
        __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4H,
                  as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
      }
    }
  
#line 40234 "ad_aarch64.cpp"
  }
}

void vpopcountIXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5712 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (bt == T_SHORT || bt == T_INT) {
      __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
                as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
      if (bt == T_INT) {
        __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
                  as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
      }
    }
  
#line 40260 "ad_aarch64.cpp"
  }
}

void vpopcountLDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5738 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ xtn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2S,
           as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T2D);
  
#line 40285 "ad_aarch64.cpp"
  }
}

void vpopcountLXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5759 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    __ cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T8H,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    __ uaddlp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T4S,
              as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 40308 "ad_aarch64.cpp"
  }
}

void vmask_truecount8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5781 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as bytes with
    // 0x00/0x01 as element values.
    __ addv(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ T8B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ B, 0);
  
#line 40328 "ad_aarch64.cpp"
  }
}

void vmask_truecount16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5797 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as bytes with
    // 0x00/0x01 as element values.
    __ addv(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ T16B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ umov(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), __ B, 0);
  
#line 40348 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue_LT8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5813 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
    __ movw(rscratch1, Matcher::vector_length(this, opnd_array(1)));
    __ cmpw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1);
    __ cselw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::GE);
  
#line 40378 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5839 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or VLENGTH if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by reversing the bits and counting the leading
    // zero bytes.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ lsrw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 3);
  
#line 40405 "ad_aarch64.cpp"
  }
}

void vmask_firsttrue16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5861 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the first active lane of the
    // vector mask, or 16 (VLENGTH) if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    Label FIRST_TRUE_INDEX;

    // Try to compute the result from lower 64 bits.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, zr);
    __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, FIRST_TRUE_INDEX);

    // Compute the result from the higher 64 bits.
    __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 8);

    // Reverse the bits and count the leading zero bytes.
    __ bind(FIRST_TRUE_INDEX);
    __ rbit(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ addw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 40442 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5893 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the last active lane of the
    // vector mask, or -1 if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.
    //
    // Computed by counting the leading zero bytes and
    // subtracting it by 7 (VLENGTH - 1).
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ movw(rscratch1, 7);
    __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 40469 "ad_aarch64.cpp"
  }
}

void vmask_lasttrue16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5915 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Returns the index of the last active lane of the
    // vector mask, or -1 if no lane is active.
    //
    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    Label LAST_TRUE_INDEX;

    // Try to compute the result from higher 64 bits.
    __ fmovhid(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 16 - 1);
    __ cbnz(opnd_array(0)->as_Register(ra_,this)/* dst */, LAST_TRUE_INDEX);

    // Compute the result from the lower 64 bits.
    __ fmovd(opnd_array(0)->as_Register(ra_,this)/* dst */, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ movw(rscratch1, 8 - 1);

    // Count the leading zero bytes and subtract it by 15 (VLENGTH - 1).
    __ bind(LAST_TRUE_INDEX);
    __ clz(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ subw(opnd_array(0)->as_Register(ra_,this)/* dst */, rscratch1, opnd_array(0)->as_Register(ra_,this)/* dst */, Assembler::LSR, 3);
  
#line 40505 "ad_aarch64.cpp"
  }
}

void vmask_tolong8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5945 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    __ fmovd(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ bytemask_compress(as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 40525 "ad_aarch64.cpp"
  }
}

void vmask_tolong16BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5959 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    // Input "src" is a vector of boolean represented as
    // bytes with 0x00/0x01 as element values.

    __ umov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 0);
    __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 1);
    __ bytemask_compress(as_Register(opnd_array(0)->reg(ra_,this)/* dst */));
    __ bytemask_compress(rscratch1);
    __ orr(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_Register(opnd_array(0)->reg(ra_,this)/* dst */),
           rscratch1, Assembler::LSL, 8);
  
#line 40549 "ad_aarch64.cpp"
  }
}

void countLeadingZerosVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5980 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), false);
    __ clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 40567 "ad_aarch64.cpp"
  }
}

void countLeadingZerosVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5993 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), true);
    if (bt != T_LONG) {
      __ clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else {
      __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 0);
      __ clz(rscratch1, rscratch1);
      __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 0, rscratch1);
      __ umov(rscratch1, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, 1);
      __ clz(rscratch1, rscratch1);
      __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 1, rscratch1);
    }
  
#line 40594 "ad_aarch64.cpp"
  }
}

void countTrailingZerosVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6017 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), false);
    __ neon_reverse_bits(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, false);
    __ clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 40613 "ad_aarch64.cpp"
  }
}

void countTrailingZerosVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6031 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_Arrangement size = __ esize2arrangement((unsigned)type2aelembytes(bt), true);
    __ neon_reverse_bits(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, true);
    if (bt != T_LONG) {
      __ clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    } else {
      __ umov(rscratch1, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 0);
      __ clz(rscratch1, rscratch1);
      __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 0, rscratch1);
      __ umov(rscratch1, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 1);
      __ clz(rscratch1, rscratch1);
      __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, 1, rscratch1);
    }
  
#line 40641 "ad_aarch64.cpp"
  }
}

void vreverseDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6056 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_reverse_bits(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, false);
  
#line 40658 "ad_aarch64.cpp"
  }
}

void vreverseXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6068 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_reverse_bits(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, true);
  
#line 40675 "ad_aarch64.cpp"
  }
}

void vreverseBytesDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6082 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_reverse_bytes(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, false);
  
#line 40692 "ad_aarch64.cpp"
  }
}

void vreverseBytesXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6094 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_neon.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ neon_reverse_bytes(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), bt, true);
  
#line 40709 "ad_aarch64.cpp"
  }
}

void loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 187 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, dst_reg, ptrue,
                          bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40729 "ad_aarch64.cpp"
  }
}

void storeVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, src_reg, ptrue,
                          bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40750 "ad_aarch64.cpp"
  }
}

void loadV2_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3163 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40767 "ad_aarch64.cpp"
  }
}

void storeV2_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3187 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::H,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40785 "ad_aarch64.cpp"
  }
}

void loadV4_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3169 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40802 "ad_aarch64.cpp"
  }
}

void storeV4_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3193 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::S,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40820 "ad_aarch64.cpp"
  }
}

void loadV8_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3175 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40837 "ad_aarch64.cpp"
  }
}

void storeV8_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3199 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::D,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40855 "ad_aarch64.cpp"
  }
}

void loadV16_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 3181 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::ldr, dst_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40872 "ad_aarch64.cpp"
  }
}

void storeV16_vregNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3205 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStore(C2_MacroAssembler(&cbuf), &MacroAssembler::str, src_reg, MacroAssembler::Q,
       opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40890 "ad_aarch64.cpp"
  }
}

void loadV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 313 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pgtmp */), __ elemType_to_regVariant(bt),
                         Matcher::vector_length(this));
    FloatRegister dst_reg = as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, dst_reg,
                          as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40913 "ad_aarch64.cpp"
  }
}

void storeV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 333 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), __ elemType_to_regVariant(bt),
                         Matcher::vector_length(this, opnd_array(2)));
    FloatRegister src_reg = as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, src_reg,
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40937 "ad_aarch64.cpp"
  }
}

void loadV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 352 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
                          as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40957 "ad_aarch64.cpp"
  }
}

void storeV_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 366 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */),
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), bt, bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 40978 "ad_aarch64.cpp"
  }
}

void vmask_andNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 382 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 40996 "ad_aarch64.cpp"
  }
}

void vmask_orNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 394 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 41014 "ad_aarch64.cpp"
  }
}

void vmask_xorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  {
    C2_MacroAssembler _masm(&cbuf);

#line 406 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 41032 "ad_aarch64.cpp"
  }
}

void vmask_and_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 420 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 41051 "ad_aarch64.cpp"
  }
}

void vmask_and_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pn
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pm
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 432 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_PRegister(opnd_array(0)->reg(ra_,this)/* pd */), ptrue,
               as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pn */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pm */));
  
#line 41070 "ad_aarch64.cpp"
  }
}

void reinterpretNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 447 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 41086 "ad_aarch64.cpp"
  }
}

void reinterpretResizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 460 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    uint length_in_bytes_src = Matcher::vector_length_in_bytes(this, opnd_array(1));
    uint length_in_bytes_dst = Matcher::vector_length_in_bytes(this);
    uint length_in_bytes_resize = length_in_bytes_src < length_in_bytes_dst ?
                                  length_in_bytes_src : length_in_bytes_dst;
    assert(length_in_bytes_src <= MaxVectorSize && length_in_bytes_dst <= MaxVectorSize,
           "invalid vector length");
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */), __ B, length_in_bytes_resize);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B, 0);
    __ sve_sel(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pgtmp */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */));
  
#line 41113 "ad_aarch64.cpp"
  }
}

void vmask_reinterpret_same_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 484 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 41129 "ad_aarch64.cpp"
  }
}

void vmask_reinterpret_diff_esizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 498 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType from_bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant from_size = __ elemType_to_regVariant(from_bt);
    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_cpy(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), from_size, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), -1, false);
    __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), -1);
  
#line 41151 "ad_aarch64.cpp"
  }
}

void vabsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 517 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41168 "ad_aarch64.cpp"
  }
}

void vabsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 530 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41185 "ad_aarch64.cpp"
  }
}

void vabsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 543 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41202 "ad_aarch64.cpp"
  }
}

void vabsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 556 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41219 "ad_aarch64.cpp"
  }
}

void vabsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 569 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41236 "ad_aarch64.cpp"
  }
}

void vabsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 582 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 41253 "ad_aarch64.cpp"
  }
}

void vabsB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 596 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41272 "ad_aarch64.cpp"
  }
}

void vabsS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 609 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41291 "ad_aarch64.cpp"
  }
}

void vabsI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 622 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41310 "ad_aarch64.cpp"
  }
}

void vabsL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 635 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_abs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41329 "ad_aarch64.cpp"
  }
}

void vabsF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 648 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41348 "ad_aarch64.cpp"
  }
}

void vabsD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 661 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fabs(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 41367 "ad_aarch64.cpp"
  }
}

void vaddBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 676 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41386 "ad_aarch64.cpp"
  }
}

void vaddSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 689 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41405 "ad_aarch64.cpp"
  }
}

void vaddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 702 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41424 "ad_aarch64.cpp"
  }
}

void vaddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 715 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41443 "ad_aarch64.cpp"
  }
}

void vaddFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 728 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41462 "ad_aarch64.cpp"
  }
}

void vaddDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 741 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41481 "ad_aarch64.cpp"
  }
}

void vaddB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 756 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41501 "ad_aarch64.cpp"
  }
}

void vaddS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 769 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41521 "ad_aarch64.cpp"
  }
}

void vaddI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 782 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41541 "ad_aarch64.cpp"
  }
}

void vaddL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 795 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41561 "ad_aarch64.cpp"
  }
}

void vaddF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 808 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41581 "ad_aarch64.cpp"
  }
}

void vaddD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 821 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadd(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 41601 "ad_aarch64.cpp"
  }
}

void vaddImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 836 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, -val);
    }
  
#line 41623 "ad_aarch64.cpp"
  }
}

void vaddImmB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 836 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B, -val);
    }
  
#line 41645 "ad_aarch64.cpp"
  }
}

void vaddImmSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 852 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, -val);
    }
  
#line 41667 "ad_aarch64.cpp"
  }
}

void vaddImmS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 852 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H, -val);
    }
  
#line 41689 "ad_aarch64.cpp"
  }
}

void vaddImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 868 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, -val);
    }
  
#line 41711 "ad_aarch64.cpp"
  }
}

void vaddImmI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 868 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constant();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S, -val);
    }
  
#line 41733 "ad_aarch64.cpp"
  }
}

void vaddImmLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 884 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(2)->constantL();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, -val);
    }
  
#line 41755 "ad_aarch64.cpp"
  }
}

void vaddImmL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 884 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int32_t val = opnd_array(1)->constantL();
    if (val > 0){
      __ sve_add(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D, val);
    } else if (val < 0){
      __ sve_sub(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D, -val);
    }
  
#line 41777 "ad_aarch64.cpp"
  }
}

void vandBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 902 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 41795 "ad_aarch64.cpp"
  }
}

void vandB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 902 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41813 "ad_aarch64.cpp"
  }
}

void vandHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 914 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 41831 "ad_aarch64.cpp"
  }
}

void vandH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 914 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41849 "ad_aarch64.cpp"
  }
}

void vandSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 926 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 41867 "ad_aarch64.cpp"
  }
}

void vandS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 926 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41885 "ad_aarch64.cpp"
  }
}

void vandDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 938 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 41903 "ad_aarch64.cpp"
  }
}

void vandD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 938 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 41921 "ad_aarch64.cpp"
  }
}

void vorBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 950 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 41939 "ad_aarch64.cpp"
  }
}

void vorB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 950 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41957 "ad_aarch64.cpp"
  }
}

void vorHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 962 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 41975 "ad_aarch64.cpp"
  }
}

void vorH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 962 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 41993 "ad_aarch64.cpp"
  }
}

void vorSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 974 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 42011 "ad_aarch64.cpp"
  }
}

void vorS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 974 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 42029 "ad_aarch64.cpp"
  }
}

void vorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 986 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 42047 "ad_aarch64.cpp"
  }
}

void vorD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 986 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 42065 "ad_aarch64.cpp"
  }
}

void vxorBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 998 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 42083 "ad_aarch64.cpp"
  }
}

void vxorB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 998 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ B,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 42101 "ad_aarch64.cpp"
  }
}

void vxorHNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1010 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 42119 "ad_aarch64.cpp"
  }
}

void vxorH_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1010 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ H,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 42137 "ad_aarch64.cpp"
  }
}

void vxorSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1022 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
         (uint64_t)(opnd_array(2)->constant()));
  
#line 42155 "ad_aarch64.cpp"
  }
}

void vxorS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1022 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ S,
         (uint64_t)(opnd_array(1)->constant()));
  
#line 42173 "ad_aarch64.cpp"
  }
}

void vxorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         (uint64_t)(opnd_array(2)->constantL()));
  
#line 42191 "ad_aarch64.cpp"
  }
}

void vxorD_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst_src */), __ D,
         (uint64_t)(opnd_array(1)->constantL()));
  
#line 42209 "ad_aarch64.cpp"
  }
}

void vandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1047 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_and(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42228 "ad_aarch64.cpp"
  }
}

void vorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1062 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42247 "ad_aarch64.cpp"
  }
}

void vxorNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1077 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42266 "ad_aarch64.cpp"
  }
}

void vand_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1092 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_and(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42288 "ad_aarch64.cpp"
  }
}

void vor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1109 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_orr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42310 "ad_aarch64.cpp"
  }
}

void vxor_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1126 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_eor(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
          as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42332 "ad_aarch64.cpp"
  }
}

void vnotINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42350 "ad_aarch64.cpp"
  }
}

void vnotI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 42368 "ad_aarch64.cpp"
  }
}

void vnotI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42386 "ad_aarch64.cpp"
  }
}

void vnotI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 42404 "ad_aarch64.cpp"
  }
}

void vnotI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42422 "ad_aarch64.cpp"
  }
}

void vnotI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1145 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 42440 "ad_aarch64.cpp"
  }
}

void vnotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1157 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 42458 "ad_aarch64.cpp"
  }
}

void vnotL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1157 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_not(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */));
  
#line 42476 "ad_aarch64.cpp"
  }
}

void vnotI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1173 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42496 "ad_aarch64.cpp"
  }
}

void vnotI_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1173 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42516 "ad_aarch64.cpp"
  }
}

void vnotI_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1173 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42536 "ad_aarch64.cpp"
  }
}

void vnotL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1186 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_not(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 42556 "ad_aarch64.cpp"
  }
}

void vand_notINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42576 "ad_aarch64.cpp"
  }
}

void vand_notI_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 42596 "ad_aarch64.cpp"
  }
}

void vand_notI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42616 "ad_aarch64.cpp"
  }
}

void vand_notI_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42636 "ad_aarch64.cpp"
  }
}

void vand_notI_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42656 "ad_aarch64.cpp"
  }
}

void vand_notI_5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 42676 "ad_aarch64.cpp"
  }
}

void vand_notI_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42696 "ad_aarch64.cpp"
  }
}

void vand_notI_6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42716 "ad_aarch64.cpp"
  }
}

void vand_notI_7Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42736 "ad_aarch64.cpp"
  }
}

void vand_notI_9Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 42756 "ad_aarch64.cpp"
  }
}

void vand_notI_8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42776 "ad_aarch64.cpp"
  }
}

void vand_notI_10Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1203 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42796 "ad_aarch64.cpp"
  }
}

void vand_notLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1216 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42816 "ad_aarch64.cpp"
  }
}

void vand_notL_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1216 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */));
  
#line 42836 "ad_aarch64.cpp"
  }
}

void vand_notL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1216 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42856 "ad_aarch64.cpp"
  }
}

void vand_notL_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// m1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1216 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_bic(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src1 */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42876 "ad_aarch64.cpp"
  }
}

void vand_notI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42897 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42918 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42939 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 42960 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 42981 "ad_aarch64.cpp"
  }
}

void vand_notI_masked_4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 43002 "ad_aarch64.cpp"
  }
}

void vand_notL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// m1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1246 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43023 "ad_aarch64.cpp"
  }
}

void vand_notL_masked_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// m1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1246 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_bic(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ elemType_to_regVariant(bt),
               as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src2 */));
  
#line 43044 "ad_aarch64.cpp"
  }
}

void vdivFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1261 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43062 "ad_aarch64.cpp"
  }
}

void vdivDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1273 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43080 "ad_aarch64.cpp"
  }
}

void vfdivF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1287 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43100 "ad_aarch64.cpp"
  }
}

void vfdivD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1300 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fdiv(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 43120 "ad_aarch64.cpp"
  }
}

void vminNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1315 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 43146 "ad_aarch64.cpp"
  }
}

void vmaxNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1335 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 43172 "ad_aarch64.cpp"
  }
}

void vmin_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1357 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smin(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 43199 "ad_aarch64.cpp"
  }
}

void vmax_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1377 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (is_floating_point_type(bt)) {
      __ sve_fmax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    } else {
      assert(is_integral_type(bt), "unsupported type");
      __ sve_smax(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), size,
                  as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    }
  
#line 43226 "ad_aarch64.cpp"
  }
}

void vfmlaFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1400 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43245 "ad_aarch64.cpp"
  }
}

void vfmlaDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1413 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43264 "ad_aarch64.cpp"
  }
}

void vfmadF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1428 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43284 "ad_aarch64.cpp"
  }
}

void vfmadD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1441 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43304 "ad_aarch64.cpp"
  }
}

void vfmlsF1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1458 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43323 "ad_aarch64.cpp"
  }
}

void vfmlsF2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1473 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43342 "ad_aarch64.cpp"
  }
}

void vfmlsD1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1488 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43361 "ad_aarch64.cpp"
  }
}

void vfmlsD2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1503 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43380 "ad_aarch64.cpp"
  }
}

void vfmsbF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1520 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmsb(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43400 "ad_aarch64.cpp"
  }
}

void vfmsbD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1535 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmsb(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43420 "ad_aarch64.cpp"
  }
}

void vfnmlaF1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1553 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43439 "ad_aarch64.cpp"
  }
}

void vfnmlaF2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1569 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43458 "ad_aarch64.cpp"
  }
}

void vfnmlaD1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1585 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43477 "ad_aarch64.cpp"
  }
}

void vfnmlaD2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1601 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43496 "ad_aarch64.cpp"
  }
}

void vfnmadF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1619 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43516 "ad_aarch64.cpp"
  }
}

void vfnmadD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1635 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmad(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43536 "ad_aarch64.cpp"
  }
}

void vfnmlsFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1652 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43555 "ad_aarch64.cpp"
  }
}

void vfnmlsDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1667 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43574 "ad_aarch64.cpp"
  }
}

void vfnmsbF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmsb(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43594 "ad_aarch64.cpp"
  }
}

void vfnmsbD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1699 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fnmsb(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43614 "ad_aarch64.cpp"
  }
}

void vmlaBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1715 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43633 "ad_aarch64.cpp"
  }
}

void vmlaB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1715 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 43652 "ad_aarch64.cpp"
  }
}

void vmlaSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1729 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43671 "ad_aarch64.cpp"
  }
}

void vmlaS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1729 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 43690 "ad_aarch64.cpp"
  }
}

void vmlaINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1743 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43709 "ad_aarch64.cpp"
  }
}

void vmlaI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1743 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 43728 "ad_aarch64.cpp"
  }
}

void vmlaLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1757 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43747 "ad_aarch64.cpp"
  }
}

void vmlaL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst_src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1757 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src2 */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src3 */));
  
#line 43766 "ad_aarch64.cpp"
  }
}

void vmlaB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1773 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43786 "ad_aarch64.cpp"
  }
}

void vmlaS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1787 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43806 "ad_aarch64.cpp"
  }
}

void vmlaI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1801 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43826 "ad_aarch64.cpp"
  }
}

void vmlaL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1815 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mla(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43846 "ad_aarch64.cpp"
  }
}

void vmlsBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1831 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43865 "ad_aarch64.cpp"
  }
}

void vmlsSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1845 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43884 "ad_aarch64.cpp"
  }
}

void vmlsINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1859 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43903 "ad_aarch64.cpp"
  }
}

void vmlsLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1873 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
      ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43922 "ad_aarch64.cpp"
  }
}

void vmlsB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1889 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43942 "ad_aarch64.cpp"
  }
}

void vmlsS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1903 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43962 "ad_aarch64.cpp"
  }
}

void vmlsI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1917 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 43982 "ad_aarch64.cpp"
  }
}

void vmlsL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1931 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mls(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* src3 */));
  
#line 44002 "ad_aarch64.cpp"
  }
}

void vmulBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1945 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44020 "ad_aarch64.cpp"
  }
}

void vmulSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44038 "ad_aarch64.cpp"
  }
}

void vmulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1969 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44056 "ad_aarch64.cpp"
  }
}

void vmulLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1981 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44074 "ad_aarch64.cpp"
  }
}

void vmulFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 1993 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44093 "ad_aarch64.cpp"
  }
}

void vmulDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2006 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44112 "ad_aarch64.cpp"
  }
}

void vmulB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2021 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44132 "ad_aarch64.cpp"
  }
}

void vmulS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44152 "ad_aarch64.cpp"
  }
}

void vmulI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2047 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44172 "ad_aarch64.cpp"
  }
}

void vmulL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2060 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_mul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44192 "ad_aarch64.cpp"
  }
}

void vmulF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2073 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44212 "ad_aarch64.cpp"
  }
}

void vmulD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2086 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmul(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44232 "ad_aarch64.cpp"
  }
}

void vnegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2102 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_neg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44250 "ad_aarch64.cpp"
  }
}

void vnegLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2116 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_neg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44267 "ad_aarch64.cpp"
  }
}

void vnegFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2129 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44284 "ad_aarch64.cpp"
  }
}

void vnegDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2142 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44301 "ad_aarch64.cpp"
  }
}

void vnegI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2156 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_neg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44321 "ad_aarch64.cpp"
  }
}

void vnegL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2170 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_neg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44340 "ad_aarch64.cpp"
  }
}

void vnegF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2183 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44359 "ad_aarch64.cpp"
  }
}

void vnegD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2196 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fneg(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44378 "ad_aarch64.cpp"
  }
}

void vpopcountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2212 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44396 "ad_aarch64.cpp"
  }
}

void vpopcountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2227 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cnt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 44413 "ad_aarch64.cpp"
  }
}

void vpopcountLINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2248 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cnt(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S,
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 44434 "ad_aarch64.cpp"
  }
}

void vpopcountI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2264 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_cnt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ elemType_to_regVariant(bt),
         as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44453 "ad_aarch64.cpp"
  }
}

void vpopcountL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2278 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cnt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
         as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 44471 "ad_aarch64.cpp"
  }
}

void vblendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2292 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    Assembler::SIMD_RegVariant size =
               __ elemType_to_regVariant(Matcher::vector_element_basic_type(this));
    __ sve_sel(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
               as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 44492 "ad_aarch64.cpp"
  }
}

void vstoremaskBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2308 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, false);
  
#line 44509 "ad_aarch64.cpp"
  }
}

void vstoremask_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// size
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2320 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant((int)opnd_array(2)->constant());
    __ sve_cpy(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 1, false);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ B,
                         as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44531 "ad_aarch64.cpp"
  }
}

void vloadmask_loadVNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2340 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Load mask values which are boolean type, and extend them to the
    // expected vector element type. Convert the vector to predicate.
    BasicType to_vect_bt = Matcher::vector_element_basic_type(this);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */),
                          ptrue, T_BOOLEAN, to_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(to_vect_bt),
               ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
  
#line 44555 "ad_aarch64.cpp"
  }
}

void vloadmask_loadV_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vtmp
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2362 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Load valid mask values which are boolean type, and extend them to the
    // expected vector element type. Convert the vector to predicate.
    BasicType to_vect_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(to_vect_bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), size, Matcher::vector_length(this));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), false, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp */),
                          as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), T_BOOLEAN, to_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp */), 0);
  
#line 44581 "ad_aarch64.cpp"
  }
}

void storeV_vstoremaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2386 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType from_vect_bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    assert(type2aelembytes(from_vect_bt) == (int)opnd_array(3)->constant(), "unsupported type.");
    Assembler::SIMD_RegVariant size = __ elemBytes_to_regVariant(opnd_array(3)->constant());
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), 1, false);
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */),
                          ptrue, T_BOOLEAN, from_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 44606 "ad_aarch64.cpp"
  }
}

void storeV_vstoremask_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// esize
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2408 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Convert the valid src predicate to vector, and store the vector
    // elements as boolean values.
    BasicType from_vect_bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(from_vect_bt);
    __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), 1, false);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), size, Matcher::vector_length(this, opnd_array(2)));
    loadStoreA_predicated(C2_MacroAssembler(&cbuf), true, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */),
                          as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), T_BOOLEAN, from_vect_bt, opnd_array(1)->opcode(),
                          as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
  
#line 44634 "ad_aarch64.cpp"
  }
}

void reduce_addINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2431 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44656 "ad_aarch64.cpp"
  }
}

void reduce_addLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2447 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44677 "ad_aarch64.cpp"
  }
}

void reduce_addFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2461 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44695 "ad_aarch64.cpp"
  }
}

void reduce_addDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2474 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44713 "ad_aarch64.cpp"
  }
}

void reduce_addI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2489 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44738 "ad_aarch64.cpp"
  }
}

void reduce_addL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2508 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44761 "ad_aarch64.cpp"
  }
}

void reduce_addF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2524 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ S, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44781 "ad_aarch64.cpp"
  }
}

void reduce_addD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2539 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44801 "ad_aarch64.cpp"
  }
}

void reduce_addI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2555 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44824 "ad_aarch64.cpp"
  }
}

void reduce_addL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2570 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44846 "ad_aarch64.cpp"
  }
}

void reduce_addF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2583 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ S,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44865 "ad_aarch64.cpp"
  }
}

void reduce_addD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1_dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2595 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fadda(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1_dst */), __ D,
                 as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 44884 "ad_aarch64.cpp"
  }
}

void reduce_andINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2612 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44906 "ad_aarch64.cpp"
  }
}

void reduce_andLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 44927 "ad_aarch64.cpp"
  }
}

void reduce_andI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2646 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44952 "ad_aarch64.cpp"
  }
}

void reduce_andL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2666 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 44975 "ad_aarch64.cpp"
  }
}

void reduce_andI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 44998 "ad_aarch64.cpp"
  }
}

void reduce_andL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2700 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45020 "ad_aarch64.cpp"
  }
}

void reduce_orINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2718 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45042 "ad_aarch64.cpp"
  }
}

void reduce_orLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2735 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45063 "ad_aarch64.cpp"
  }
}

void reduce_orI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2752 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45088 "ad_aarch64.cpp"
  }
}

void reduce_orL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2772 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45111 "ad_aarch64.cpp"
  }
}

void reduce_orI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2790 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45134 "ad_aarch64.cpp"
  }
}

void reduce_orL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2806 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45156 "ad_aarch64.cpp"
  }
}

void reduce_eorINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2824 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45178 "ad_aarch64.cpp"
  }
}

void reduce_eorLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2841 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45199 "ad_aarch64.cpp"
  }
}

void reduce_eorI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2858 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45224 "ad_aarch64.cpp"
  }
}

void reduce_eorL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2878 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45247 "ad_aarch64.cpp"
  }
}

void reduce_eorI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2896 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45270 "ad_aarch64.cpp"
  }
}

void reduce_eorL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2912 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45292 "ad_aarch64.cpp"
  }
}

void reduce_maxINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2931 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45314 "ad_aarch64.cpp"
  }
}

void reduce_maxLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2948 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45335 "ad_aarch64.cpp"
  }
}

void reduce_maxI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2966 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45360 "ad_aarch64.cpp"
  }
}

void reduce_maxL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 2986 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45383 "ad_aarch64.cpp"
  }
}

void reduce_maxFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3003 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45402 "ad_aarch64.cpp"
  }
}

void reduce_maxF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3019 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45423 "ad_aarch64.cpp"
  }
}

void reduce_maxDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3035 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45442 "ad_aarch64.cpp"
  }
}

void reduce_maxD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3051 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fmaxv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45463 "ad_aarch64.cpp"
  }
}

void reduce_maxI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3070 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45486 "ad_aarch64.cpp"
  }
}

void reduce_maxL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3087 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45508 "ad_aarch64.cpp"
  }
}

void reduce_maxF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3102 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxs(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45528 "ad_aarch64.cpp"
  }
}

void reduce_maxD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3116 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fmaxv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmaxd(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45548 "ad_aarch64.cpp"
  }
}

void reduce_minINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3134 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45570 "ad_aarch64.cpp"
  }
}

void reduce_minLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3151 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           ptrue, as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 45591 "ad_aarch64.cpp"
  }
}

void reduce_minI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3169 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    Assembler::SIMD_RegVariant variant = __ elemType_to_regVariant(bt);
    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), variant, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45616 "ad_aarch64.cpp"
  }
}

void reduce_minL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3189 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 45639 "ad_aarch64.cpp"
  }
}

void reduce_minFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3206 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45658 "ad_aarch64.cpp"
  }
}

void reduce_minF_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3222 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ S, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45679 "ad_aarch64.cpp"
  }
}

void reduce_minDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3238 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45698 "ad_aarch64.cpp"
  }
}

void reduce_minD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3254 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_fminv(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), __ D, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45719 "ad_aarch64.cpp"
  }
}

void reduce_minI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3273 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(2));
    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, bt,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45742 "ad_aarch64.cpp"
  }
}

void reduce_minL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3290 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_reduce_integral(this->ideal_Opcode(), opnd_array(4)->as_Register(ra_,this,idx4)/* dst */, T_LONG,
                           opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */),
                           as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 45764 "ad_aarch64.cpp"
  }
}

void reduce_minF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3305 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45784 "ad_aarch64.cpp"
  }
}

void reduce_minD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3319 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fminv(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ fmind(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
  
#line 45804 "ad_aarch64.cpp"
  }
}

void vroundDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rmode
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3333 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    switch (opnd_array(2)->constant()) {
      case RoundDoubleModeNode::rmode_rint:
        __ sve_frintn(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_floor:
        __ sve_frintm(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
      case RoundDoubleModeNode::rmode_ceil:
        __ sve_frintp(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
             ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
        break;
    }
  
#line 45834 "ad_aarch64.cpp"
  }
}

void vroundFtoINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3358 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int vlen = Matcher::vector_length_in_bytes(this);
    if (vlen > 16) {
      __ vector_round_sve(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                          as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                          as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ S);
    } else {
      __ vector_round_neon(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                           as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp3 */),
                           __ esize2arrangement(type2aelembytes(bt),
                              /*isQ*/ vlen == 16));
    }
  
#line 45867 "ad_aarch64.cpp"
  }
}

void vroundDtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3382 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    int vlen = Matcher::vector_length_in_bytes(this);
    if (vlen > 16) {
      __ vector_round_sve(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                          as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                          as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* ptmp */), __ D);
    } else {
      __ vector_round_neon(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                           as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp2 */),
                           as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp3 */),
                           __ esize2arrangement(type2aelembytes(bt),
                              /*isQ*/ vlen == 16));
    }
  
#line 45900 "ad_aarch64.cpp"
  }
}

void replicateBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3407 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45916 "ad_aarch64.cpp"
  }
}

void replicateSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3418 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45932 "ad_aarch64.cpp"
  }
}

void replicateINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3429 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45948 "ad_aarch64.cpp"
  }
}

void replicateLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3440 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 45964 "ad_aarch64.cpp"
  }
}

void replicateB_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3451 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, opnd_array(1)->constant());
  
#line 45980 "ad_aarch64.cpp"
  }
}

void replicateS_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3462 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, opnd_array(1)->constant());
  
#line 45996 "ad_aarch64.cpp"
  }
}

void replicateI_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3473 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, opnd_array(1)->constant());
  
#line 46012 "ad_aarch64.cpp"
  }
}

void replicateL_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3484 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, opnd_array(1)->constantL());
  
#line 46028 "ad_aarch64.cpp"
  }
}

void replicateFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3495 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 46045 "ad_aarch64.cpp"
  }
}

void replicateDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3507 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 46062 "ad_aarch64.cpp"
  }
}

void vasrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3521 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46080 "ad_aarch64.cpp"
  }
}

void vasrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3533 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46098 "ad_aarch64.cpp"
  }
}

void vasrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3545 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46116 "ad_aarch64.cpp"
  }
}

void vasrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3557 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46134 "ad_aarch64.cpp"
  }
}

void vlslBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3569 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46152 "ad_aarch64.cpp"
  }
}

void vlslSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3581 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46170 "ad_aarch64.cpp"
  }
}

void vlslINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3593 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46188 "ad_aarch64.cpp"
  }
}

void vlslLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3605 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46206 "ad_aarch64.cpp"
  }
}

void vlsrBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3617 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ B,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46224 "ad_aarch64.cpp"
  }
}

void vlsrSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3629 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ H,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46242 "ad_aarch64.cpp"
  }
}

void vlsrINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3641 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46260 "ad_aarch64.cpp"
  }
}

void vlsrLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3653 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shift */));
  
#line 46278 "ad_aarch64.cpp"
  }
}

void vasrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3665 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) con = 7;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46303 "ad_aarch64.cpp"
  }
}

void vasrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3684 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) con = 15;
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46328 "ad_aarch64.cpp"
  }
}

void vasrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3703 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46352 "ad_aarch64.cpp"
  }
}

void vasrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3721 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_asr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46376 "ad_aarch64.cpp"
  }
}

void vlsrB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3739 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46405 "ad_aarch64.cpp"
  }
}

void vlsrS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3762 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46434 "ad_aarch64.cpp"
  }
}

void vlsrI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3785 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46458 "ad_aarch64.cpp"
  }
}

void vlsrL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3803 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con == 0) {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46482 "ad_aarch64.cpp"
  }
}

void vlslB_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3821 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 8) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46506 "ad_aarch64.cpp"
  }
}

void vlslS_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3839 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    if (con >= 16) {
      __ sve_eor(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      return;
    }
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46530 "ad_aarch64.cpp"
  }
}

void vlslI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3857 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46549 "ad_aarch64.cpp"
  }
}

void vlslL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3870 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    __ sve_lsl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), con);
  
#line 46568 "ad_aarch64.cpp"
  }
}

void vshiftcntBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3884 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46584 "ad_aarch64.cpp"
  }
}

void vshiftcntB_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3884 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46600 "ad_aarch64.cpp"
  }
}

void vshiftcntSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3897 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46616 "ad_aarch64.cpp"
  }
}

void vshiftcntS_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3897 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46632 "ad_aarch64.cpp"
  }
}

void vshiftcntINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3909 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46648 "ad_aarch64.cpp"
  }
}

void vshiftcntI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3909 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46664 "ad_aarch64.cpp"
  }
}

void vshiftcntLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3921 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46680 "ad_aarch64.cpp"
  }
}

void vshiftcntL_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3921 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_dup(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* cnt */));
  
#line 46696 "ad_aarch64.cpp"
  }
}

void vasrB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3934 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46716 "ad_aarch64.cpp"
  }
}

void vasrS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3947 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46736 "ad_aarch64.cpp"
  }
}

void vasrI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3960 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46756 "ad_aarch64.cpp"
  }
}

void vasrL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3973 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46776 "ad_aarch64.cpp"
  }
}

void vlslB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3986 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46796 "ad_aarch64.cpp"
  }
}

void vlslS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3999 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46816 "ad_aarch64.cpp"
  }
}

void vlslI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4012 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46836 "ad_aarch64.cpp"
  }
}

void vlslL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4025 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46856 "ad_aarch64.cpp"
  }
}

void vlsrB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4038 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46876 "ad_aarch64.cpp"
  }
}

void vlsrS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4051 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46896 "ad_aarch64.cpp"
  }
}

void vlsrI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4064 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46916 "ad_aarch64.cpp"
  }
}

void vlsrL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4077 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 46936 "ad_aarch64.cpp"
  }
}

void vasrB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4090 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 8, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 46956 "ad_aarch64.cpp"
  }
}

void vasrS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4103 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 16, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 46976 "ad_aarch64.cpp"
  }
}

void vasrI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4116 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 32, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 46996 "ad_aarch64.cpp"
  }
}

void vasrL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4129 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 64, "invalid shift immediate");
    __ sve_asr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47016 "ad_aarch64.cpp"
  }
}

void vlsrB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4142 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 8, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47036 "ad_aarch64.cpp"
  }
}

void vlsrS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4155 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 16, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47056 "ad_aarch64.cpp"
  }
}

void vlsrI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4168 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 32, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47076 "ad_aarch64.cpp"
  }
}

void vlsrL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4181 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con > 0 && con < 64, "invalid shift immediate");
    __ sve_lsr(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47096 "ad_aarch64.cpp"
  }
}

void vlslB_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4194 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 8, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ B, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47116 "ad_aarch64.cpp"
  }
}

void vlslS_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4207 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 16, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ H, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47136 "ad_aarch64.cpp"
  }
}

void vlslI_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4220 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 32, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47156 "ad_aarch64.cpp"
  }
}

void vlslL_imm_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4233 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(2)->constant();
    assert(con >= 0 && con < 64, "invalid shift immediate");
    __ sve_lsl(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D, as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */), con);
  
#line 47176 "ad_aarch64.cpp"
  }
}

void vsqrtFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4249 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 47193 "ad_aarch64.cpp"
  }
}

void vsqrtDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4262 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 47210 "ad_aarch64.cpp"
  }
}

void vsqrtF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4276 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ S,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 47229 "ad_aarch64.cpp"
  }
}

void vsqrtD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4289 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsqrt(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), __ D,
            as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
            as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 47248 "ad_aarch64.cpp"
  }
}

void vsubBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4304 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47267 "ad_aarch64.cpp"
  }
}

void vsubSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4317 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47286 "ad_aarch64.cpp"
  }
}

void vsubINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4330 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47305 "ad_aarch64.cpp"
  }
}

void vsubLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4343 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47324 "ad_aarch64.cpp"
  }
}

void vsubFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4356 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47343 "ad_aarch64.cpp"
  }
}

void vsubDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4369 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47362 "ad_aarch64.cpp"
  }
}

void vsubB_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4384 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ B,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47382 "ad_aarch64.cpp"
  }
}

void vsubS_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4397 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ H,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47402 "ad_aarch64.cpp"
  }
}

void vsubI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4410 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47422 "ad_aarch64.cpp"
  }
}

void vsubL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4423 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47442 "ad_aarch64.cpp"
  }
}

void vsubF_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4436 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ S,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47462 "ad_aarch64.cpp"
  }
}

void vsubD_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4449 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fsub(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src1 */), __ D,
            as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
            as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
  
#line 47482 "ad_aarch64.cpp"
  }
}

void vmaskcastNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4466 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // empty
  
#line 47498 "ad_aarch64.cpp"
  }
}

void vmaskcast_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4481 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmaskcast_extend(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            Matcher::vector_length_in_bytes(this), Matcher::vector_length_in_bytes(this, opnd_array(1)));
  
#line 47515 "ad_aarch64.cpp"
  }
}

void vmaskcast_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4497 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmaskcast_narrow(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            Matcher::vector_length_in_bytes(this), Matcher::vector_length_in_bytes(this, opnd_array(1)));
  
#line 47532 "ad_aarch64.cpp"
  }
}

void vcvtBtoX_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4512 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    if (to_bt == T_FLOAT || to_bt == T_DOUBLE) {
      __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size);
    }
  
#line 47553 "ad_aarch64.cpp"
  }
}

void vcvtStoBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4531 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */));
  
#line 47571 "ad_aarch64.cpp"
  }
}

void vcvtStoX_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4545 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H);
    if (to_bt == T_FLOAT || to_bt == T_DOUBLE) {
      __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), to_size);
    }
  
#line 47592 "ad_aarch64.cpp"
  }
}

void vcvtItoBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4564 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ B,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 47611 "ad_aarch64.cpp"
  }
}

void vcvtItoSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4579 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_narrow(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ H,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */));
  
#line 47629 "ad_aarch64.cpp"
  }
}

void vcvtItoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4593 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 47645 "ad_aarch64.cpp"
  }
}

void vcvtItoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4606 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 47661 "ad_aarch64.cpp"
  }
}

void vcvtItoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4619 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sunpklo(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D);
  
#line 47678 "ad_aarch64.cpp"
  }
}

void vcvtLtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4633 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 47699 "ad_aarch64.cpp"
  }
}

void vcvtLtoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4650 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));

  
#line 47720 "ad_aarch64.cpp"
  }
}

void vcvtLtoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4666 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_scvtf(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
  
#line 47736 "ad_aarch64.cpp"
  }
}

void vcvtFtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4681 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_fcvtzs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 47758 "ad_aarch64.cpp"
  }
}

void vcvtFtoINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4698 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
  
#line 47774 "ad_aarch64.cpp"
  }
}

void vcvtFtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4711 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_sunpklo(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S);
  
#line 47791 "ad_aarch64.cpp"
  }
}

void vcvtFtoDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4725 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S);
    __ sve_fcvt(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S);
  
#line 47808 "ad_aarch64.cpp"
  }
}

void vcvtDtoX_narrowNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4742 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType to_bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant to_size = __ elemType_to_regVariant(to_bt);
    __ sve_fcvtzs(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), to_size,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 47830 "ad_aarch64.cpp"
  }
}

void vcvtDtoLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4759 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvtzs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
  
#line 47846 "ad_aarch64.cpp"
  }
}

void vcvtDtoFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4773 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_fcvt(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D);
    __ sve_vector_narrow(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ S,
                         as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* dst */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 47866 "ad_aarch64.cpp"
  }
}

void extractBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4790 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract_integral(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ B, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            (int)(opnd_array(2)->constant()), /* is_signed */ true, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 47885 "ad_aarch64.cpp"
  }
}

void extractSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4804 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract_integral(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ H, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            (int)(opnd_array(2)->constant()), /* is_signed */ true, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 47904 "ad_aarch64.cpp"
  }
}

void extractINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4818 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract_integral(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            (int)(opnd_array(2)->constant()), /* is_signed */ true, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 47923 "ad_aarch64.cpp"
  }
}

void extractLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4832 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_extract_integral(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                            (int)(opnd_array(2)->constant()), /* is_signed */ false, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 47942 "ad_aarch64.cpp"
  }
}

void extractB_LT16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4845 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ smov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B, opnd_array(2)->constant());
  
#line 47959 "ad_aarch64.cpp"
  }
}

void extractS_LT8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4857 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ smov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ H, opnd_array(2)->constant());
  
#line 47976 "ad_aarch64.cpp"
  }
}

void extractI_LT4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4869 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ smov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ S, opnd_array(2)->constant());
  
#line 47993 "ad_aarch64.cpp"
  }
}

void extractL_LT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4881 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ umov(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ D, opnd_array(2)->constant());
  
#line 48010 "ad_aarch64.cpp"
  }
}

void extractFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4893 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    if ((as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) == as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) && (opnd_array(2)->constant()== 0)) {
      /* empty */
    } else if (opnd_array(2)->constant()== 0) {
      __ fmovs(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else if (opnd_array(2)->constant()< 4) {
      __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ S, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, (int)(opnd_array(2)->constant()));
    } else {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      __ sve_ext(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(2)->constant()<< 2);
    }
  
#line 48036 "ad_aarch64.cpp"
  }
}

void extractDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4914 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    if ((as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) == as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) && (opnd_array(2)->constant()== 0)) {
      /* empty */
    } else if (opnd_array(2)->constant()== 0) {
      __ fmovd(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    } else if (opnd_array(2)->constant()== 1) {
      __ ins(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0, 1);
    } else {
      __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      __ sve_ext(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(2)->constant()<< 3);
    }
  
#line 48062 "ad_aarch64.cpp"
  }
}

void vtest_alltrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4940 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_eors(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), ptrue,
                as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::EQ);
  
#line 48082 "ad_aarch64.cpp"
  }
}

void vtest_anytrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4957 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // "src2" is not used for sve.
    __ sve_ptest(ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */));
    __ csetw(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), Assembler::NE);
  
#line 48101 "ad_aarch64.cpp"
  }
}

void insertI_le128bitsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4976 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), Matcher::vector_length_in_bytes(this) == 8 ? __ T8B : __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(Matcher::vector_element_basic_type(this)),
           opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 48125 "ad_aarch64.cpp"
  }
}

void insertI_small_indexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5001 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ block_comment("insert into vector (B/H/S) {");
      __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), size, -16, 1);
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), size, ptrue,
                 as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), (int)(opnd_array(3)->constant()) - 16);
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
      __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
    __ block_comment("} insert into vector (B/H/S)");
  
#line 48155 "ad_aarch64.cpp"
  }
}

void insertINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5031 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ block_comment("insert into vector (B/H/S) {");
      __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), size, 0, 1);
      __ sve_dup(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), size, (int)(opnd_array(3)->constant()));
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), size, ptrue,
                 as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */));
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
      __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
    __ block_comment("} insert into vector (B/H/S)");
  
#line 48187 "ad_aarch64.cpp"
  }
}

void insertL_128bitsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5055 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
      __ orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ T16B,
             as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
    __ mov(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D, opnd_array(3)->constant(), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
  
#line 48210 "ad_aarch64.cpp"
  }
}

void insertLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5077 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ block_comment("insert into vector (L) {");
      __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ D, -16, 1);
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ D, ptrue,
                 as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), (int)(opnd_array(3)->constant()) - 16);
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
      __ sve_cpy(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ D,
                 as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), opnd_array(2)->as_Register(ra_,this,idx2)/* val */);
    __ block_comment("} insert into vector (L)");
  
#line 48239 "ad_aarch64.cpp"
  }
}

void insertF_le128bitsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5100 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), Matcher::vector_length_in_bytes(this) == 8 ? __ T8B : __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 48261 "ad_aarch64.cpp"
  }
}

void insertF_small_indexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5120 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ block_comment("insert into vector (F) {");
      __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, -16, 1);
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ S, ptrue,
                 as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
      __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
    __ block_comment("} insert into vector (F)");
  
#line 48287 "ad_aarch64.cpp"
  }
}

void insertFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5144 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ block_comment("insert into vector (F) {");
      __ sve_index(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), __ S, 0, 1);
      __ sve_dup(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S, (int)(opnd_array(3)->constant()));
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), __ S, ptrue,
                 as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp1 */), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */));
      __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                 as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ S,
                 as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
    __ block_comment("} insert into vector (F)");
  
#line 48317 "ad_aarch64.cpp"
  }
}

void insertD_128bitsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5167 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ T16B,
           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ ins(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
           as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */), opnd_array(3)->constant(), 0);
  
#line 48339 "ad_aarch64.cpp"
  }
}

void insertDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// val
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// dst
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5187 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ block_comment("insert into vector (D) {");
      __ sve_index(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D, -16, 1);
      __ sve_cmp(Assembler::EQ, as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), __ D, ptrue,
                 as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), (int)(opnd_array(3)->constant()) - 16);
      __ sve_orr(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                 as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      __ sve_cpy(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* dst */), __ D,
                 as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* pgtmp */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* val */));
    __ block_comment("} insert into vector (D)");
  
#line 48367 "ad_aarch64.cpp"
  }
}

void loadshuffleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5208 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    if (bt == T_BYTE) {
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                   as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
    } else {
      __ sve_vector_extend(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */),  __ elemType_to_regVariant(bt),
                           as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    }
  
#line 48392 "ad_aarch64.cpp"
  }
}

void rearrangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shuffle
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5231 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_tbl(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
               as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* shuffle */));
  
#line 48412 "ad_aarch64.cpp"
  }
}

void gatherINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5250 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), ptrue,
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 48430 "ad_aarch64.cpp"
  }
}

void gatherLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5266 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), ptrue, as_Register(opnd_array(1)->base(ra_,this,idx1)),
                       as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* tmp */));
  
#line 48450 "ad_aarch64.cpp"
  }
}

void gatherI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5285 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */), __ S, Matcher::vector_length(this));
    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 48470 "ad_aarch64.cpp"
  }
}

void gatherL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5302 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ D, Matcher::vector_length(this));
    __ sve_uunpklo(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp */));
  
#line 48492 "ad_aarch64.cpp"
  }
}

void gatherI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5320 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ld1w_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
  
#line 48511 "ad_aarch64.cpp"
  }
}

void gatherL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// idx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// pg
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5335 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* idx */));
    __ sve_ld1d_gather(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(3)->reg(ra_,this,idx3)/* pg */),
                       as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 48532 "ad_aarch64.cpp"
  }
}

void scatterINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5353 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 48551 "ad_aarch64.cpp"
  }
}

void scatterLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5369 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), ptrue,
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* tmp */));
  
#line 48572 "ad_aarch64.cpp"
  }
}

void scatterI_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5388 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */), __ S, Matcher::vector_length(this, opnd_array(2)));
    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 48593 "ad_aarch64.cpp"
  }
}

void scatterL_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5405 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_ptrue_lanecnt(as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */), __ D, Matcher::vector_length(this, opnd_array(2)));
    __ sve_uunpklo(as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(5)->reg(ra_,this,idx5)/* ptmp */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp */));
  
#line 48616 "ad_aarch64.cpp"
  }
}

void scatterI_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5423 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_st1w_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
  
#line 48636 "ad_aarch64.cpp"
  }
}

void scatterL_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// idx
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5438 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_uunpklo(as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */), __ D, as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* idx */));
    __ sve_st1d_scatter(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src */), as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */),
                        as_Register(opnd_array(1)->base(ra_,this,idx1)), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* tmp */));
  
#line 48658 "ad_aarch64.cpp"
  }
}

void loadconBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5454 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_index(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B, 0, 1);
  
#line 48674 "ad_aarch64.cpp"
  }
}

void populateindexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5467 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_index(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                 as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src1 */), opnd_array(2)->constant());
  
#line 48693 "ad_aarch64.cpp"
  }
}

void stringL_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5490 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */, opnd_array(0)->as_Register(ra_,this)/* result */,
                               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* ztmp1 */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* ztmp2 */),
                               as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_PRegister(opnd_array(7)->reg(ra_,this,idx7)/* ptmp */), true /* isL */);
  
#line 48717 "ad_aarch64.cpp"
  }
}

void stringU_indexof_char_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// ch
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// ztmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// ztmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5508 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ string_indexof_char_sve(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* ch */, opnd_array(0)->as_Register(ra_,this)/* result */,
                               as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* ztmp1 */), as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* ztmp2 */),
                               as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */), as_PRegister(opnd_array(7)->reg(ra_,this,idx7)/* ptmp */), false /* isL */);
  
#line 48741 "ad_aarch64.cpp"
  }
}

void string_compareLL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5534 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::LL);
  
#line 48772 "ad_aarch64.cpp"
  }
}

void string_compareLU_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5557 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::LU);
  
#line 48803 "ad_aarch64.cpp"
  }
}

void string_compareUL_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5580 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::UL);
  
#line 48834 "ad_aarch64.cpp"
  }
}

void string_compareUU_sveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// vtmp2
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp1
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// pgtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5603 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Count is in 8-bit bytes; non-Compact chars are 16 bits.
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */,
                      opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */, opnd_array(0)->as_Register(ra_,this)/* result */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */,
                      opnd_array(7)->as_FloatRegister(ra_,this,idx7)/* vtmp1 */, opnd_array(8)->as_FloatRegister(ra_,this,idx8)/* vtmp2 */, fnoreg,
                      as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp1 */), as_PRegister(opnd_array(10)->reg(ra_,this,idx10)/* pgtmp2 */),
                      StrIntrinsicNode::UU);
  
#line 48865 "ad_aarch64.cpp"
  }
}

void vmask_truecountNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5621 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 48883 "ad_aarch64.cpp"
  }
}

void vmask_firsttrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5637 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this, opnd_array(1));
    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    // When the input predicate is all-false, the result should be the vector length
    // instead of max vector register size.
    if (length_in_bytes == MaxVectorSize) {
      __ sve_brkb(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), false);
    } else {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), size, Matcher::vector_length(this, opnd_array(1)));
      __ sve_brkb(as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), false);
    }
    __ sve_cntp(opnd_array(0)->as_Register(ra_,this)/* dst */, size, ptrue, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */));
  
#line 48911 "ad_aarch64.cpp"
  }
}

void vmask_lasttrueNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// ptmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5660 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this, opnd_array(1));
    __ sve_vmask_lasttrue(opnd_array(0)->as_Register(ra_,this)/* dst */, bt, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* ptmp */));
  
#line 48929 "ad_aarch64.cpp"
  }
}

void vmask_tolongNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// vtmp1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// vtmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5673 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_vmask_tolong(as_Register(opnd_array(0)->reg(ra_,this)/* dst */), as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
                        Matcher::vector_element_basic_type(this, opnd_array(1)),
                        Matcher::vector_length(this, opnd_array(1)),
                        as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* vtmp1 */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* vtmp2 */));
  
#line 48950 "ad_aarch64.cpp"
  }
}

void vmaskAll_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5695 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    int con = (int)opnd_array(1)->constant();
    if (con == 0) {
      __ sve_pfalse(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                           Matcher::vector_length(this));
    }
  
#line 48974 "ad_aarch64.cpp"
  }
}

void vmaskAllINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5717 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (length_in_bytes < MaxVectorSize) {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, Matcher::vector_length(this));
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
                 as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    } else {
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    }
  
#line 49001 "ad_aarch64.cpp"
  }
}

void vmaskAll_immLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5738 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    long con = (long)opnd_array(1)->constantL();
    if (con == 0) {
      __ sve_pfalse(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */));
    } else {
      assert(con == -1, "invalid constant value for mask");
      BasicType bt = Matcher::vector_element_basic_type(this);
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                           Matcher::vector_length(this));
    }
  
#line 49025 "ad_aarch64.cpp"
  }
}

void vmaskAllLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5760 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    __ sve_dup(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    if (length_in_bytes < MaxVectorSize) {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, Matcher::vector_length(this));
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size,
                 as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    } else {
      __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
    }
  
#line 49052 "ad_aarch64.cpp"
  }
}

void vmaskcmpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5784 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    uint length_in_bytes = Matcher::vector_length_in_bytes(this);
    BasicType bt = Matcher::vector_element_basic_type(this);
    if (length_in_bytes == MaxVectorSize) {
      __ sve_compare(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                     as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant());
    } else {
      __ sve_ptrue_lanecnt(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ elemType_to_regVariant(bt),
                           Matcher::vector_length(this));
      __ sve_compare(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                     as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant());
    }
  
#line 49080 "ad_aarch64.cpp"
  }
}

void vmaskcmp_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cond
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5806 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    __ sve_compare(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), bt, as_PRegister(opnd_array(4)->reg(ra_,this,idx4)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src1 */),
                   as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* src2 */), (int)opnd_array(3)->constant());
  
#line 49101 "ad_aarch64.cpp"
  }
}

void vloadmaskBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5823 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), __ B,
               ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), 0);
  
#line 49118 "ad_aarch64.cpp"
  }
}

void vloadmask_extendNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5836 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_vector_extend(as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), __ B);
    __ sve_cmp(Assembler::NE, as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(2)->reg(ra_,this,idx2)/* tmp */), 0);
  
#line 49138 "ad_aarch64.cpp"
  }
}

void mcompressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5854 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_cntp(rscratch1, size, ptrue, as_PRegister(opnd_array(1)->reg(ra_,this,idx1)/* pg */));
    __ sve_whilelo(as_PRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, zr, rscratch1);
  
#line 49157 "ad_aarch64.cpp"
  }
}

void vcompressNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5872 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_compact(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */));
  
#line 49176 "ad_aarch64.cpp"
  }
}

void vcompressBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// vtmp3
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// vtmp4
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// ptmp
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5887 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_compress_byte(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
                         as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */),as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */),
                         as_FloatRegister(opnd_array(6)->reg(ra_,this,idx6)/* vtmp3 */),as_FloatRegister(opnd_array(7)->reg(ra_,this,idx7)/* vtmp4 */),
                         as_PRegister(opnd_array(8)->reg(ra_,this,idx8)/* ptmp */), as_PRegister(opnd_array(9)->reg(ra_,this,idx9)/* pgtmp */));
  
#line 49203 "ad_aarch64.cpp"
  }
}

void vcompressSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// vtmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// vtmp2
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// pgtmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5902 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    __ sve_compress_short(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
                          as_FloatRegister(opnd_array(4)->reg(ra_,this,idx4)/* vtmp1 */),as_FloatRegister(opnd_array(5)->reg(ra_,this,idx5)/* vtmp2 */), as_PRegister(opnd_array(6)->reg(ra_,this,idx6)/* pgtmp */));
  
#line 49225 "ad_aarch64.cpp"
  }
}

void vexpandNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5917 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    // Example input:   src   = 1 2 3 4 5 6 7 8
    //                  pg    = 1 0 0 1 1 0 1 1
    // Expected result: dst   = 4 0 0 5 6 0 7 8

    // The basic idea is to use TBL which can shuffle the elements in the given
    // vector flexibly. HISTCNT + SUB is used to generate the second source input
    // for TBL whose value is used to select the indexed element from src vector.

    BasicType bt = Matcher::vector_element_basic_type(this);
    assert(UseSVE == 2 && !is_subword_type(bt), "unsupported");
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    // dst = 0 0 0 0 0 0 0 0
    __ sve_dup(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, 0);
    // dst = 5 0 0 4 3 0 2 1
    __ sve_histcnt(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */),
                   as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
    // dst = 4 -1 -1 3 2 -1 1 0
    __ sve_sub(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, 1);
    // dst = 4 0 0 5 6 0 7 8
    __ sve_tbl(as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */), size, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */),
               as_FloatRegister(opnd_array(3)->reg(ra_,this,idx3)/* dst */));
  
#line 49263 "ad_aarch64.cpp"
  }
}

void vmask_genNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// len
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5949 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_whilelo(as_PRegister(opnd_array(0)->reg(ra_,this)/* pg */), size, zr, as_Register(opnd_array(1)->reg(ra_,this,idx1)/* len */));
  
#line 49281 "ad_aarch64.cpp"
  }
}

void vcountLeadingZerosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5965 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 49299 "ad_aarch64.cpp"
  }
}

void vcountLeadingZeros_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5980 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_clz(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), size,
        as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 49319 "ad_aarch64.cpp"
  }
}

void vcountTrailingZerosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5998 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_rbit(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    __ sve_clz(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */));
  
#line 49338 "ad_aarch64.cpp"
  }
}

void vcountTrailingZeros_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6015 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_rbit(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), size,
        as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
    __ sve_clz(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), size,
        as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 49360 "ad_aarch64.cpp"
  }
}

void vreverseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6034 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_rbit(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
  
#line 49378 "ad_aarch64.cpp"
  }
}

void vreverse_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6049 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    __ sve_rbit(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), size,
        as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
  
#line 49398 "ad_aarch64.cpp"
  }
}

void vreverseBytesNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6066 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (bt == T_BYTE) {
      if (as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */) != as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */)) {
        __ sve_orr(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
      }
    } else {
      __ sve_revb(as_FloatRegister(opnd_array(0)->reg(ra_,this)/* dst */), size, ptrue, as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* src */));
    }
  
#line 49422 "ad_aarch64.cpp"
  }
}

void vreverseBytes_maskedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst_src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pg
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6087 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64_sve.ad"

    BasicType bt = Matcher::vector_element_basic_type(this);
    Assembler::SIMD_RegVariant size = __ elemType_to_regVariant(bt);
    if (bt == T_BYTE) {
      // do nothing
    } else {
      __ sve_revb(as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */), size,
          as_PRegister(opnd_array(2)->reg(ra_,this,idx2)/* pg */), as_FloatRegister(opnd_array(1)->reg(ra_,this,idx1)/* dst_src */));
    }
  
#line 49446 "ad_aarch64.cpp"
  }
}

void compareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 31 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49469 "ad_aarch64.cpp"
  }
}

void compareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 77 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49490 "ad_aarch64.cpp"
  }
}

void compareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {

#line 40 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    MacroAssembler _masm(&cbuf);
    guarantee(opnd_array(1)->index(ra_,this,idx1) == -1 && opnd_array(1)->disp(ra_,this,idx1) == 0, "impossible encoding");
    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49513 "ad_aarch64.cpp"
  }
}

void compareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 115 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49534 "ad_aarch64.cpp"
  }
}

void compareAndExchangeN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 131 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 49557 "ad_aarch64.cpp"
  }
}

void compareAndExchangeP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 147 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 49580 "ad_aarch64.cpp"
  }
}

void compareAndExchangeNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 164 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 49603 "ad_aarch64.cpp"
  }
}

void compareAndExchangePAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 181 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(5)->as_Register(ra_,this,idx5)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ true, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
  
#line 49626 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapN_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 198 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49649 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapP_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 215 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ false, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49672 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapNAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 234 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49695 "ad_aarch64.cpp"
  }
}

void weakCompareAndSwapPAcq_shenandoahNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 253 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/shenandoah/shenandoah_aarch64.ad"

    Register tmp = opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */;
    __ mov(tmp, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */); // Must not clobber oldval.
    // Weak is not currently supported by ShenandoahBarrierSet::cmpxchg_oop
    ShenandoahBarrierSet::assembler()->cmpxchg_oop(&_masm, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, tmp, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */,
                                                   /*acquire*/ true, /*release*/ true, /*is_cae*/ false, opnd_array(0)->as_Register(ra_,this)/* res */);
  
#line 49718 "ad_aarch64.cpp"
  }
}

void zLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 64 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    const Address ref_addr = mem2address(opnd_array(1)->opcode(), as_Register(opnd_array(1)->base(ra_,this,idx1)), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1));
    __ ldr(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, ref_addr);
    z_load_barrier(_masm, this, ref_addr, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 49737 "ad_aarch64.cpp"
  }
}

void zLoadPVolatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 84 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ ldar(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, rscratch2 /* tmp */, barrier_data());
  
#line 49755 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 49788 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapP_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 103 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 49821 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 49854 "ad_aarch64.cpp"
  }
}

void zCompareAndSwapPAcq_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 135 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, rscratch2);
    __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, rscratch2);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), rscratch2 /* ref */, rscratch1 /* tmp */ );
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, rscratch2);
      __ cset(opnd_array(4)->as_Register(ra_,this,idx4)/* res */, Assembler::EQ);
      __ bind(good);
    }
  
#line 49887 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 165 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 false /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 49918 "ad_aarch64.cpp"
  }
}

void zCompareAndExchangePAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// res
  {
    C2_MacroAssembler _masm(&cbuf);

#line 193 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    guarantee(opnd_array(1)->index(ra_,this,idx1)== -1 && opnd_array(1)->disp(ra_,this,idx1)== 0, "impossible encoding");
    __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
               true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
    if (barrier_data() != ZLoadBarrierElided) {
      Label good;
      __ ldr(rscratch1, Address(rthread, ZThreadLocalData::address_bad_mask_offset()));
      __ andr(rscratch1, rscratch1, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ cbz(rscratch1, good);
      z_load_barrier_slow_path(_masm, this, Address(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */), opnd_array(4)->as_Register(ra_,this,idx4)/* res */, rscratch1 /* tmp */);
      __ cmpxchg(opnd_array(1)->as_Register(ra_,this,idx1)/* mem */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Assembler::xword,
                 true /* acquire */, true /* release */, false /* weak */, opnd_array(4)->as_Register(ra_,this,idx4)/* res */);
      __ bind(good);
    }
  
#line 49949 "ad_aarch64.cpp"
  }
}

void zGetAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 221 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchg(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 49968 "ad_aarch64.cpp"
  }
}

void zGetAndSetPAcqNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newv
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// prev
  {
    C2_MacroAssembler _masm(&cbuf);

#line 238 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/gc/z/z_aarch64.ad"

    __ atomic_xchgal(opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, opnd_array(2)->as_Register(ra_,this,idx2)/* newv */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem */);
    z_load_barrier(_masm, this, Address(noreg, 0), opnd_array(3)->as_Register(ra_,this,idx3)/* prev */, rscratch2 /* tmp */, barrier_data());
  
#line 49987 "ad_aarch64.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmCM0_orderedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmN0Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchallocNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2L_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeB_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmB0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeC_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmC0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmI0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmL0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeP_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmP0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeN_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeimmN0_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeD_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* cacheWBNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeINode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapINode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapBAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapSAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setNAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_setPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addINode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addL_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addLi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addI_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIiAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* get_and_addIi_no_resAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeVNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV2_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV2_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV4_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV4_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16_vregNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadVNode::memory_operand() const { return _opnds[1]; }
const MachOper* vloadmask_loadV_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremaskNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeV_vstoremask_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherINode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherLNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherI_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherL_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherI_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* gatherL_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterINode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterLNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterI_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterL_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterI_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* scatterL_maskedNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangeNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndExchangePAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapN_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapP_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapNAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* weakCompareAndSwapPAcq_shenandoahNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zLoadPVolatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapP_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndSwapPAcq_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePNode::memory_operand() const { return _opnds[1]; }
const MachOper* zCompareAndExchangePAcqNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPNode::memory_operand() const { return _opnds[1]; }
const MachOper* zGetAndSetPAcqNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVectMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    true ,  // AryEq
    false,  // AtanD
    true ,  // Binary
    false,  // Blackhole
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    true ,  // ReverseBytesV
    false,  // CProj
    true ,  // CacheWB
    true ,  // CacheWBPreSync
    true ,  // CacheWBPostSync
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    false,  // CallLeafVector
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastDD
    true ,  // CastFF
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastVV
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // CompressBits
    false,  // ExpandBits
    false,  // ConstraintCast
    true ,  // CMoveD
    false,  // CMoveVD
    true ,  // CMoveF
    false,  // CMoveVF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapB
    true ,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // WeakCompareAndSwapB
    true ,  // WeakCompareAndSwapS
    true ,  // WeakCompareAndSwapI
    true ,  // WeakCompareAndSwapL
    true ,  // WeakCompareAndSwapP
    true ,  // WeakCompareAndSwapN
    true ,  // CompareAndExchangeB
    true ,  // CompareAndExchangeS
    true ,  // CompareAndExchangeI
    true ,  // CompareAndExchangeL
    true ,  // CompareAndExchangeP
    true ,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    false,  // LongCountedLoop
    false,  // LongCountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountLeadingZerosV
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CountTrailingZerosV
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // UDivI
    false,  // UDivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    false,  // UDivModI
    false,  // UDivModL
    true ,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // FmaD
    true ,  // FmaF
    true ,  // Goto
    true ,  // Halt
    true ,  // CountPositives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    true ,  // MulAddS2I
    true ,  // MaxI
    false,  // MaxL
    true ,  // MaxD
    true ,  // MaxF
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // StoreStoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // MinL
    true ,  // MinF
    true ,  // MinD
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    false,  // UModI
    false,  // UModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    false,  // IsInfiniteF
    false,  // IsInfiniteD
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // UMulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    false,  // NegI
    false,  // NegL
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    true ,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // Opaque2
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    true ,  // OverflowAddI
    true ,  // OverflowSubI
    true ,  // OverflowMulI
    true ,  // OverflowAddL
    true ,  // OverflowSubL
    true ,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // SubTypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PopCountVI
    true ,  // PopCountVL
    true ,  // PopulateIndex
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // ReverseI
    false,  // ReverseL
    true ,  // ReverseV
    false,  // Root
    false,  // RoundDouble
    true ,  // RoundDoubleMode
    true ,  // RoundDoubleModeV
    false,  // RoundFloat
    true ,  // RotateLeft
    false,  // RotateLeftV
    true ,  // RotateRight
    false,  // RotateRightV
    true ,  // SafePoint
    false,  // SafePointScalarObject
    true ,  // ShenandoahCompareAndExchangeP
    true ,  // ShenandoahCompareAndExchangeN
    true ,  // ShenandoahCompareAndSwapN
    true ,  // ShenandoahCompareAndSwapP
    true ,  // ShenandoahWeakCompareAndSwapN
    true ,  // ShenandoahWeakCompareAndSwapP
    false,  // ShenandoahIUBarrier
    false,  // ShenandoahLoadReferenceBarrier
    false,  // SCMemProj
    true ,  // CopySignD
    true ,  // CopySignF
    true ,  // SignumD
    true ,  // SignumF
    false,  // SignumVF
    false,  // SignumVD
    true ,  // SqrtD
    true ,  // SqrtF
    true ,  // RoundF
    true ,  // RoundD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrCompressedCopy
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // StrIndexOfChar
    true ,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // MacroLogicV
    true ,  // ThreadLocal
    false,  // Unlock
    false,  // URShiftB
    false,  // URShiftS
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    true ,  // AddReductionVI
    true ,  // AddVL
    true ,  // AddReductionVL
    true ,  // AddVF
    true ,  // AddReductionVF
    true ,  // AddVD
    true ,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    true ,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    true ,  // MulReductionVI
    true ,  // MulVL
    true ,  // MulReductionVL
    true ,  // MulVF
    true ,  // MulReductionVF
    true ,  // MulVD
    true ,  // MulReductionVD
    true ,  // MulAddVS2VI
    true ,  // FmaVD
    true ,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    true ,  // AbsVB
    true ,  // AbsVS
    true ,  // AbsVI
    true ,  // AbsVL
    true ,  // AbsVF
    true ,  // AbsVD
    true ,  // NegVI
    true ,  // NegVL
    true ,  // NegVF
    true ,  // NegVD
    true ,  // SqrtVD
    true ,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    true ,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    true ,  // AndReductionV
    true ,  // OrV
    true ,  // OrReductionV
    true ,  // XorV
    true ,  // XorReductionV
    true ,  // MinV
    true ,  // MaxV
    true ,  // MinReductionV
    true ,  // MaxReductionV
    true ,  // CompressV
    true ,  // CompressM
    true ,  // ExpandV
    true ,  // LoadVector
    true ,  // LoadVectorGather
    true ,  // LoadVectorGatherMasked
    true ,  // StoreVector
    true ,  // StoreVectorScatter
    true ,  // StoreVectorScatterMasked
    true ,  // LoadVectorMasked
    true ,  // StoreVectorMasked
    false,  // VectorCmpMasked
    true ,  // VectorMaskGen
    false,  // VectorMaskOp
    true ,  // VectorMaskTrueCount
    true ,  // VectorMaskFirstTrue
    true ,  // VectorMaskLastTrue
    true ,  // VectorMaskToLong
    false,  // VectorLongToMask
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    true ,  // RoundVF
    true ,  // RoundVD
    false,  // Extract
    true ,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    true ,  // ExtractS
    true ,  // ExtractI
    true ,  // ExtractL
    true ,  // ExtractF
    true ,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false,  // Whitespace
    false,  // VectorBox
    false,  // VectorBoxAllocate
    false,  // VectorUnbox
    false,  // VectorMaskWrapper
    true ,  // VectorMaskCmp
    true ,  // VectorMaskCast
    true ,  // VectorTest
    true ,  // VectorBlend
    true ,  // VectorRearrange
    true ,  // VectorLoadMask
    true ,  // VectorLoadShuffle
    true ,  // VectorLoadConst
    true ,  // VectorStoreMask
    true ,  // VectorReinterpret
    false,  // VectorCast
    true ,  // VectorCastB2X
    true ,  // VectorCastS2X
    true ,  // VectorCastI2X
    true ,  // VectorCastL2X
    true ,  // VectorCastF2X
    true ,  // VectorCastD2X
    false,  // VectorUCastB2X
    false,  // VectorUCastS2X
    false,  // VectorUCastI2X
    true ,  // VectorInsert
    true ,  // MaskAll
    true ,  // AndVMask
    true ,  // OrVMask
    true    // XorVMask
};


int Compile::sync_stack_slots() const { return 2; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 2 +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::varargs_C_out_slots_killed() const { return frame::arg_reg_save_area_bytes/BytesPerInt; }

OptoRegPair Matcher::return_value(uint ideal_reg) {

#line 4182 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 50735 "ad_aarch64.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg) {

#line 4182 "/builddir/build/BUILD/java-19-openjdk-19.0.2.0.7-1.rolling.el9.aarch64/openjdk/src/hotspot/cpu/aarch64/aarch64.ad"

    // TODO do we allow ideal_reg == Op_RegN???
    assert(ideal_reg >= Op_RegI && ideal_reg <= Op_RegL,
           "only return normal values");

    static const int lo[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      R0_num,                            // Op_RegN
      R0_num,                            // Op_RegI
      R0_num,                            // Op_RegP
      V0_num,                            // Op_RegF
      V0_num,                            // Op_RegD
      R0_num                             // Op_RegL
    };

    static const int hi[Op_RegL + 1] = { // enum name
      0,                                 // Op_Node
      0,                                 // Op_Set
      OptoReg::Bad,                      // Op_RegN
      OptoReg::Bad,                      // Op_RegI
      R0_H_num,                          // Op_RegP
      OptoReg::Bad,                      // Op_RegF
      V0_H_num,                          // Op_RegD
      R0_H_num                           // Op_RegL
    };

    return OptoRegPair(hi[ideal_reg], lo[ideal_reg]);
  
#line 50771 "ad_aarch64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R12_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R29_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R31_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_deep_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
